% --- Source file: Surv.Rd ---
\name{Surv}
\alias{Surv}
\alias{is.Surv}
\alias{print.Surv}
\alias{Math.Surv}
\alias{Summary.Surv}
\alias{[.Surv}
\alias{format.Surv}
\alias{as.data.frame.Surv}
\alias{as.character.Surv}
\alias{as.matrix.Surv}
\alias{is.na.Surv}
\alias{Ops.Surv}
\title{
  Create a Survival Object 
}
\description{
Create a survival object, usually used as a response variable in a model 
formula. Argument matching is special for this function, see Details below.
}
\usage{
Surv(time, time2, event,
    type=c('right', 'left', 'interval', 'counting', 'interval2'),
    origin=0)
is.Surv(x)
}
\arguments{
  \item{time}{
    for right censored data, this is the follow up time.  For interval
    data, the first argument is the starting time for the interval. 
  }
  \item{event}{
    The status indicator, normally 0=alive, 1=dead.  Other choices are
    \code{TRUE}/\code{FALSE} (\code{TRUE} = death) or 1/2 (2=death). For
    interval censored data, the status indicator is 0=right censored,
    1=event at \code{time}, 2=left censored, 3=interval censored.
    Although unusual, the event indicator can be omitted, in which case
    all subjects are assumed to have an event.
  }
  \item{time2}{
    ending time of the interval for interval censored  or counting
    process data only.  Intervals are assumed to be open on the left and
    closed on the right, \code{(start, end]}.  For counting process
    data, \code{event} indicates whether an event occurred at the end of
    the interval.
  }
  \item{type}{
    character string specifying the type of censoring. Possible values
    are \code{"right"}, \code{"left"}, \code{"counting"},
    \code{"interval"}, or \code{"interval2"}.  The default is
    \code{"right"} or \code{"counting"} depending on whether the
    \code{time2} argument is absent or present, respectively.
  }
  \item{origin}{
    for counting process data, the hazard function origin.  This option
    was intended to be used in conjunction with a model containing
    time dependent
    strata in order to align the subjects properly when they cross over
    from one strata to another, but it has rarely proven useful.}
  \item{x}{
    any R object.
  }
}

\value{
  An object of class \code{Surv}.  There are methods for \code{print},
  \code{is.na}, and subscripting survival objects.   \code{Surv} objects
  are implemented as a matrix of 2 or 3 columns.

  In the case of \code{is.Surv}, a logical value \code{TRUE} if \code{x}
  inherits from class \code{"Surv"}, otherwise an \code{FALSE}.
}
\details{
  Typical usages are
\preformatted{
Surv(time, event)
Surv(time, time2, event, type= )
}
The \code{time},\code{time2} and \code{event} arguments are matched by
position, not by name, so use, eg, \code{Surv(time, dead)} rather than
\code{Surv(time, event=dead)}

In theory it is possible to represent interval censored data without a 
third column containing the explicit status.  Exact, right censored, 
left censored and interval censored observation would be represented as 
intervals of [a,a], (a, infinity), (-infinity,b), and [a,b]  
respectively; each interval is a pair of time points 
within which the event is  
known to have occurred. 

If \code{type="interval2"} then the representation given above is 
assumed, with \code{NA} taking the place of infinity.  
If \code{type="interval"} then \code{event} must be given.  
If \code{event} is \code{0}, \code{1}, or \code{2}, 
the relevant 
information is assumed to be contained in \code{time},
the value in \code{time2} is ignored,
and the second column of the internal representation contains a 
placeholder value.

Presently, the only methods allowing interval censored data are the 
parametric models computed by \code{survreg} and survival curves
computed by \code{survfit}; for both of these, 
the distinction between open and closed intervals
is unimportant.  
The distinction is important for counting process data and 
the Cox model. 

The function tries to distinguish between the use of 0/1 and 1/2 coding for 
left and right censored data using 
\code{if (max(status)==2)}. 
If 1/2 coding is used and all the subjects are censored, it will 
guess wrong.
In any questionable case it is safer to use logical coding,
e.g., \code{Surv(time, status==3)} would indicate that a \code{3} is
the code for an event.

Surv objects can be subscripted either as an object, e.g.
\code{x[1:3]} using a single subscript;
in which case the \code{drop} argument is ignored;
or as a matrix, using two arguments.
If the second subscript is missing and \code{drop=F}
(the default),
the result of the subscripting will be a Surv object, e.g., 
\code{x[1:3,,drop=F]},
otherwise the result will be a matrix (or vector), in accordance with
the default behavior for subscripting matrices. 
}

\seealso{
\code{\link{coxph}},  
\code{\link{survfit}},  
\code{\link{survreg}}.   
}
\examples{
with(lung, Surv(time, status))
Surv(heart$start, heart$stop, heart$event) 
}
\keyword{survival}

\eof
% --- Source file: aareg.Rd ---
\name{aareg}
\alias{aareg}
\title{
  Aalen's additive regression model for censored data
}
\description{
Returns an object of class \code{"aareg"} that
represents an Aalen model.
}
\usage{
aareg(formula, data, weights, subset, na.action,
   qrtol=1e-07, nmin, dfbeta=FALSE, taper=1,
   test = c('aalen', 'variance', 'nrisk'),
    model=FALSE, x=FALSE, y=FALSE) 
}
\arguments{
\item{formula}{
a formula object, with the response on the left of a `~' operator and 
the terms,
 separated by \code{+} operators, on the right. 
The response must be a \code{Surv} object.
Due to a particular computational approach that is used, the model
MUST include an intercept term.  If "-1" is used in the model
formula the program will ignore it.
}
\item{data}{
data frame in which to interpret the variables named in the
\code{formula},
\code{subset}, and \code{weights} arguments.
This may also be a single number to handle
some speci al cases -- see below for details. If
\code{data} is missi ng, the variables in the
model formula should be in the search path.
}
\item{weights}{
vector of observation weights. If supplied, the fitting algorithm
minimizes the sum of the weights multiplied by the squared residuals
(see below for additional technical details). The length of
\code{weights} must be the same as the number of
observations. The weights must be nonnegative and it i s recommended
that they be strictly positive, since zero weights are ambiguous.  To
exclude particular observations from the model, use the
\code{subset} argument instead of zero weights.
}
\item{subset}{
expression specifying which subset of observations should be used in
the fit. Th is can be a logical vector (which is replicated to have
length equal to the numb er of observations), a numeric vector
indicating the observation numbers to be i ncluded, or a character
vector of the observation names that should be included.  All
observations are included by default.
}
\item{na.action}{
a function to filter missing data. This is applied to the
\code{model.fr ame} after any
\code{subset} argument has be en applied. The
default is \code{na.fail}, which returns a n
error if any missing values are found. An alternative is
\code{na.excl ude}, which deletes observations
that contain one or more missing values.
}
\item{qrtol}{
tolerance for detection of singularity in the QR decomposition
}
\item{nmin}{
minimum number of observations for an estimate; defaults to 3 times the
number of covariates.
This essentially truncates the computations near the tail of the data
set, when n is small and the calcualtions can become numerically
unstable.
}
\item{dfbeta}{
should the array of dfbeta residuals be computed.  This implies computation
of the sandwich variance estimate.
The residuals will always be computed if there is a
\code{cluster} term in the model formula.
}
\item{taper}{
allows for a smoothed variance estimate.
Var(x), where x is the set of covariates, is an important component of the
calculations for the Aalen regression model.  
At any given time point t, it is computed over all subjects who are still
at risk at time t.
The tape argument allows smoothing these estimates,
for example \code{taper=(1:4)/4} would cause
the variance estimate used at any event time to be a weighted average
of the estimated variance matrices at the last 4 death times,
with a weight of 1 for the current death time and decreasing to 1/4 for
prior event times.
The default value gives the standard Aalen model.
}
\item{test}{
selects the weighting to be used, for computing an overall ``average''
coefficient vector over time and the subsequent test for equality to zero.
}
\item{model, x, y }{
should copies of the model frame, the x matrix of predictors, or the
response vector y be included in the saved result.
}
}
\value{
an object of class \code{"aareg"} 
representing the fit.
}
\details{
The Aalen model assumes that the cumulative hazard H(t) for a subject
can be expressed as a(t) + X B(t), where a(t) is a time-dependent intercept
term, X is the vector of covariates for the subject (possibly time-dependent),
and B(t) is a time-dependent matrix of coefficients.
The estimates are inheritly non-parametric; a fit of the model will normally
be followed by one or more plots of the estimates.

The estimates may become unstable near the tail of a data set, since the
increment to B at time t is based on the subjects still at risk at time
t.  The tolerance and/or nmin parameters may act to truncate the estimate
before the last death.
The \code{taper} argument can also be used to smooth
out the tail of the curve.
In practice, the addition of a taper such as 1:10 appears to have little
effect on death times when n is still reasonably large, but can considerably
dampen wild occilations in the tail of the plot.  
}
\section{References}{
Aalen, O.O. (1989). A linear regression model for the analysis of life times.
Statistics in Medicine, 8:907-925.

Aalen, O.O (1993). Further results on the non-parametric linear model in
survival analysis.  Statistics in Medicine. 12:1569-1588.
}
\seealso{
print.aareg, summary.aareg, plot.aareg
}
\examples{
# Fit a model to the lung cancer data set
lfit <- aareg(Surv(time, status) ~ age + sex + ph.ecog, data=lung,
                     nmin=1)
\dontrun{
lfit
Call:
aareg(formula = Surv(time, status) ~ age + sex + ph.ecog, data = lung, nmin = 1
        )

  n=227 (1 observations deleted due to missing values)
    138 out of 138 unique event times used

              slope      coef se(coef)     z        p 
Intercept  5.26e-03  5.99e-03 4.74e-03  1.26 0.207000
      age  4.26e-05  7.02e-05 7.23e-05  0.97 0.332000
      sex -3.29e-03 -4.02e-03 1.22e-03 -3.30 0.000976
  ph.ecog  3.14e-03  3.80e-03 1.03e-03  3.70 0.000214

Chisq=26.73 on 3 df, p=6.7e-06; test weights=aalen

plot(lfit[4], ylim=c(-4,4))  # Draw a plot of the function for ph.ecog
}
lfit2 <- aareg(Surv(time, status) ~ age + sex + ph.ecog, data=lung,
                  nmin=1, taper=1:10)
\dontrun{lines(lfit2[4], col=2)  # Nearly the same, until the last point}

# A fit to the mulitple-infection data set of children with
# Chronic Granuomatous Disease.  See section 8.5 of Therneau and Grambsch.
fita2 <- aareg(Surv(tstart, tstop, status) ~ treat + age + inherit +
                         steroids + cluster(id), data=cgd)
\dontrun{
  n= 203 
    69 out of 70 unique event times used

                     slope      coef se(coef) robust se     z        p
Intercept         0.004670  0.017800 0.002780  0.003910  4.55 5.30e-06
treatrIFN-g      -0.002520 -0.010100 0.002290  0.003020 -3.36 7.87e-04
age              -0.000101 -0.000317 0.000115  0.000117 -2.70 6.84e-03
inheritautosomal  0.001330  0.003830 0.002800  0.002420  1.58 1.14e-01
steroids          0.004620  0.013200 0.010600  0.009700  1.36 1.73e-01

Chisq=16.74 on 4 df, p=0.0022; test weights=aalen
}
}
\keyword{survival}
% docclass is function
\eof
% --- Source file: aml.Rd ---
\name{aml}
\docType{data}
\alias{aml}
\alias{leukemia}
\title{Acute Myelogenous Leukemia survival data}
\description{Survival in patients with Acute Myelogenous Leukemia.
  The question at the time was whether the standard course of
chemotherapy should be extended ('maintainance') for additional
cycles.}
\usage{
aml
leukemia
}
\format{
  \tabular{ll}{
    time:\tab survival or censoring time\cr
    status:\tab censoring status\cr
    x: \tab maintenance chemotherapy given? (factor)\cr
  }
}
\source{
  Rupert G. Miller (1997),
  \emph{Survival Analysis}.
  John Wiley & Sons.
  ISBN: 0-471-25218-2.
}
\keyword{datasets}
\eof
% --- Source file: anova.coxph.Rd ---
\name{anova.coxph}
\alias{anova.coxph}
\alias{anova.coxphlist}
\title{Analysis of Deviance for a Cox model.}
\usage{
\method{anova}{coxph}(object, \dots,  test = NULL)
}
\description{
  Compute an analysis of deviance table for one or more Cox model fits.
}
\arguments{
  \item{object}{An object of class \code{coxph}}
  \item{\dots}{Further \code{coxph} objects}
  \item{test}{a character string, (partially) matching one of \code{"Chisq"},
    \code{"F"} or \code{"Cp"}. See \code{\link{stat.anova}}.}
}
\details{
  Specifying a single object gives a sequential analysis of deviance
  table for that fit.  That is, the reductions in the residual deviance
  as each term of the formula is added in turn are given in as
  the rows of a table, plus the residual deviances themselves.


  If more than one object is specified, the table has a row for the
  residual degrees of freedom and deviance for each model. For all
  but the first model, the change in degrees of freedom and deviance
  is also given. (This only make statistical sense if the models are
  nested.)  It is conventional to list the models from smallest to
  largest, but this is up to the user.
  
  The table will optionally contain test statistics (and P values)
  comparing the reduction in deviance for the row to the residuals.
    Mallows' \eqn{C_p}{Cp} statistic is the residual
    deviance plus twice the  residual degrees of freedom, which is closely
  related to AIC. Don't use \code{test=F}, it doesn't make sense for a
  Cox model.
}
\value{
  An object of class \code{"anova"} inheriting from class \code{"data.frame"}.
}
\section{Warning}{
  The comparison between two or more models by \code{anova} or
   will only be valid if they
  are fitted to the same dataset. This may be a problem if there are
  missing values.}
\seealso{
  \code{\link{coxph}}, \code{\link{anova}}.
}
\examples{
fit <- coxph(Surv(futime, fustat) ~ resid.ds *rx + ecog.ps, data = ovarian) 
anova(fit)
anova(fit,test="Chisq")
fit2 <- coxph(Surv(futime, fustat) ~ resid.ds +rx + ecog.ps, data
=ovarian)
anova(fit2,fit)
 }
\keyword{models}
\keyword{regression}
\keyword{survival}

\eof
% --- Source file: attrassign.Rd ---
\name{attrassign}
\alias{attrassign.default}
\alias{attrassign}
\alias{attrassign.lm}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Create new-style "assign" attribute}
\description{
The \code{"assign"} attribute on model matrices describes which columns
come from which terms in the model formula. It has two versions. R uses
the original version, but the alternate version found in
S-plus is sometimes useful.
}
\usage{
\method{attrassign}{default}(object, tt,...)
\method{attrassign}{lm}(object,...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{object}{model matrix or linear model object}
  \item{tt}{terms object}
  \item{...}{ignored}
}

\value{
 A list with names corresponding to the term names and elements
 that are vectors indicating which columns come from which terms
}

\details{
  For instance consider the following
  \preformatted{
    survreg(Surv(time, status) ~ age + sex + factor(ph.ecog), lung)
  }
  R gives the compact for for assign, a vector (0, 1, 2, 3, 3, 3);
  which can be
  read as ``the first column of the X matrix (intercept) goes with none
  of the terms, the second column of X goes with term 1 of the model
  equation, the third column of X with term 2, and columns 4-6 with
  term 3''.
 
  The alternate (S-Plus default) form is a list
  \preformatted{
       $(Intercept)     1
       $age             2
       $sex             3
       $factor(ph.ecog) 4 5 6
     }
   }
   
\seealso{\code{\link{terms}},\code{\link{model.matrix}}}

\examples{
formula <- Surv(time,status)~factor(edema)
tt <- terms(formula)
mf <- model.frame(tt,data=pbc)
mm <- model.matrix(tt,mf)
## a few rows of data
mm[1:3,]
## old-style assign attribute
attr(mm,"assign")
## alternate style assign attribute
attrassign(mm,tt)
}
\keyword{models}%-- one or more ...
\eof
% --- Source file: basehaz.Rd ---
\name{basehaz}
\alias{basehaz}
\title{Compute the baseline survival curve for a Cox model}
\description{
  Compute the baseline survival curve for a Cox model.
}
\usage{
basehaz(fit, centered = TRUE)
}
\arguments{
  \item{fit}{The result of a \code{coxph} fit.}
  \item{centered}{If TRUE, the resultant curve is for a hypothetical
    subject whose covariate values are the corresponding means from the
    original data, otherwise for a hypothetical subject with a mean
    vector of zero.}
}
\details{
  This function exists primarily because users will look for the phrase
  'baseline hazard' (often SAS converts looking for familiar
  keywords.) The primary function for creating a survival curve is
  \code{survfit}, which this calls.  See that manual page for more
  options, including confidence limits and the ability to use other
  covariate vectors.  The result of \code{survfit} also has print, plot
  and summary methods that make it far more useful. 
}
\value{
  a data frame with components
  \item{time}{The sorted vector of unique time points (those at which an
    event occurred}
  \item{hazard}{The baseline hazard function}
  \item{strata}{If \code{fit} was a stratified Cox model, the strata.
    There will be one survival curve per strata.}
}

\seealso{\code{\link{survfit}}}
\keyword{survival }

\eof
% --- Source file: bladder.Rd ---
\name{bladder}
\docType{data}
\alias{bladder}
\alias{bladder1}
\alias{bladder2}
\title{Bladder Cancer Recurrences}
\usage{
bladder1
bladder
bladder2
}
\description{Data on recurrences of bladder cancer, used by many people
  to demonstrate methodology for recurrent event modelling.

 Bladder1 is the full data set from the study. It contains all three treatment
arms and all recurrences for 118 subjects; the maximum observed number
of recurrences is 9.

Bladder is the data set that appears most commonly in the literature. 
It uses only the 85 subjects with nonzero follow-up who were
assigned to either thiotepa or placebo.  The status variable is 1 for
recurrence and 0 for everything else (including death for any reason).
The data set is laid out in the competing risks format of the paper by
Wei, Lin, and Weissfeld.

Bladder2 uses the same subset of subjects as bladder, but formated in the
(start, stop] or Anderson-Gill style.  
Note that in transforming from the WLW to the AG style data set there
is a quite common programming mistake that leads to extra follow-up time
for 12 subjects (all those with more than 4 recurrences); this includes
some earlier releases of the data in R.
}
\format{
  bladder1
  \tabular{ll}{
    id:\tab Patient id\cr
    treatment:\tab Placebo, pyridoxine (vitamin B6), or thiotepa\cr
    number:\tab Initial number of tumours (8=8 or more)\cr
    size:\tab Size (cm) of largest initial tumour\cr
    recur:\tab Number of recurrences \cr
    start,stop:\tab The start and end time of each time interval\cr
    status:\tab End of interval code, 0=censored, 1=recurrence, \cr
           \tab 2=death from bladder disease, 3=death other/unknown cause\cr
    rtumor:\tab Number of tumors found at the time of a recurrence\cr
    rsize:\tab Size of largest tumor at a recurrence\cr
    enum:\tab Event number (observation number within patient)\cr
  }
  bladder
  \tabular{ll}{
    id:\tab Patient id\cr
    rx:\tab Treatment 1=placebo  2=thiotepa\cr
    number:\tab Initial number of tumours (8=8 or more)\cr
    size:\tab size (cm) of largest initial tumour\cr
    stop:\tab recurrence or censoring time\cr
    enum:\tab which recurrence (up to 4)\cr
  }
  bladder2 
  \tabular{ll}{
    id:\tab Patient id\cr
    rx:\tab Treatment 1=placebo  2=thiotepa\cr
    number:\tab Initial number of tumours (8=8 or more)\cr
    size:\tab size (cm) of largest initial tumour\cr
    start:\tab start of interval (0 or previous recurrence time)\cr
    stop:\tab recurrence or censoring time\cr
    enum:\tab which recurrence (up to 4)\cr
  }
  
}
\source{
  Andrews DF, Hertzberg AM (1985), 
DATA: A Collection of Problems from Many Fields for the Student 
and Research Worker, New York: Springer-Verlag.

  LJ Wei, DY Lin, L Weissfeld (1989),
  Regression analysis of multivariate incomplete failure time data by
  modeling marginal distributions.
  \emph{Journal of the American Statistical Association},
  \bold{84}.
}
\keyword{datasets}
\keyword{survival}
\eof
% --- Source file: cch.Rd ---
\alias{cch}
\name{cch}
\title{Fits proportional hazards regression model to case-cohort data}

\description{ Returns estimates and standard errors from relative risk
regression fit to data from case-cohort studies. A choice is available
among the Prentice, Self-Prentice and Lin-Ying methods for unstratified
data. For stratified data the choice is between Borgan I, a
generalization of the Self-Prentice estimator for unstratified
case-cohort data, and Borgan II, a generalization of the Lin-Ying
estimator.
}
\usage{
cch(formula, data = sys.parent(), subcoh, id, stratum=NULL, cohort.size,
    method =c("Prentice","SelfPrentice","LinYing","I.Borgan","II.Borgan"),
    robust=FALSE)
}
\arguments{
\item{formula}{
A formula object that must have a \code{\link{Surv}} object as the response. 
The Surv object must be of type \code{"right"}, or of type \code{"counting"}.
}
\item{subcoh}{
  Vector of indicatorsfor subjects sampled as part of the
  sub-cohort. Code \code{1} or \code{TRUE} for members of the
  sub-cohort, \code{0} or \code{FALSE} for others. If \code{data} is a
  data frame then \code{subcoh} may be a one-sided formula.
}
\item{id}{
Vector of unique identifiers, or formula specifying such a vector.
}
\item{stratum}{A vector of stratum indicators or a formula specifying
  such a vector}
\item{cohort.size}{
Vector with size of each stratum original cohort from which subcohort was sampled
}
\item{data}{
An optional data frame in which to interpret the variables 
occurring in the formula. 
}
\item{method}{
Three procedures are available. The default method is "Prentice", with 
options for "SelfPrentice" or "LinYing". }
\item{robust}{For \code{"LinYing"} only, if \code{robust=TRUE}, use design-based standard errors even for
  phase I}
}
\value{
An object of class "cch"  incorporating a list of estimated regression coefficients and two estimates of their 
asymptotic variance-covariance matrix.
\item{coef}{
regression coefficients.

}
\item{naive.var}{
Self-Prentice model based variance-covariance matrix.

}
\item{var}{
Lin-Ying empirical variance-covariance matrix. 

}}
\details{
Implements methods for case-cohort data analysis described by Therneau and
Li (1999). The three methods differ in the choice of "risk sets" used to
compare the covariate values of the failure with those of others at risk at
the time of failure. "Prentice" uses the sub-cohort members "at risk" plus
the failure if that occurs outside the sub-cohort and is score unbiased.
"SelfPren" (Self-Prentice) uses just the sub-cohort members "at risk". These
two have the same asymptotic variance-covariance matrix. "LinYing" (Lin-Ying)
uses the all members of the sub-cohort and all failures outside the sub-cohort
who are "at risk". The methods also differ in the weights given to different
score contributions.

The \code{data} argument must not have missing values for any variables
in the model.  There must not be any censored observations outside the subcohort.
}

\author{Norman Breslow, modified by Thomas Lumley}
\references{
Prentice, RL (1986). A case-cohort design for epidemiologic cohort studies and
disease prevention trials. Biometrika 73: 1--11.


Self, S and Prentice, RL (1988). Asymptotic distribution theory and efficiency
results for case-cohort studies. Annals of Statistics 16: 64--81.


Lin, DY and Ying, Z (1993). Cox regression with incomplete covariate measurements.
Journal of the American Statistical Association 88: 1341--1349.


Barlow, WE (1994). Robust variance estimation for the case-cohort design. Biometrics
50: 1064--1072


Therneau, TM and Li, H (1999). Computing the Cox model for case-cohort designs.
Lifetime Data Analysis 5: 99--112.


Borgan, \eqn{O}{O}, Langholz, B, Samuelsen, SO, Goldstein, L and Pogoda, J (2000)
 Exposure stratified case-cohort designs. Lifetime Data Analysis 6, 39-58.

}
\seealso{
\code{twophase} and \code{svycoxph} in the "survey" package for
more general two-phase designs. \url{http://faculty.washington.edu/tlumley/survey/}
}
\examples{
## The complete Wilms Tumor Data 
## (Breslow and Chatterjee, Applied Statistics, 1999)
## subcohort selected by simple random sampling.
##

subcoh <- nwtco$in.subcohort
selccoh <- with(nwtco, rel==1|subcoh==1)
ccoh.data <- nwtco[selccoh,]
ccoh.data$subcohort <- subcoh[selccoh]
## central-lab histology 
ccoh.data$histol <- factor(ccoh.data$histol,labels=c("FH","UH"))
## tumour stage
ccoh.data$stage <- factor(ccoh.data$stage,labels=c("I","II","III","IV"))
ccoh.data$age <- ccoh.data$age/12 # Age in years

##
## Standard case-cohort analysis: simple random subcohort 
##

fit.ccP <- cch(Surv(edrel, rel) ~ stage + histol + age, data =ccoh.data,
   subcoh = ~subcohort, id=~seqno, cohort.size=4028)


fit.ccP

fit.ccSP <- cch(Surv(edrel, rel) ~ stage + histol + age, data =ccoh.data,
   subcoh = ~subcohort, id=~seqno, cohort.size=4028, method="SelfPren")

summary(fit.ccSP)

##
## (post-)stratified on instit
##
stratsizes<-table(nwtco$instit)
fit.BI<- cch(Surv(edrel, rel) ~ stage + histol + age, data =ccoh.data,
   subcoh = ~subcohort, id=~seqno, stratum=~instit, cohort.size=stratsizes,
   method="I.Borgan")

summary(fit.BI)
}

\keyword{survival}
\eof
% --- Source file: cgd.Rd ---
\name{cgd}
\docType{data}
\alias{cgd}
\title{Chronic Granulotomous Disease data}

\description{Data are from a placebo controlled trial of gamma
interferon in chronic granulotomous disease (CGD). Uses the complete
data on time to first serious infection observed through end of study
for each patient, which includes the initial serious infections observed
through the 7/15/89 interim analysis data cutoff, plus the residual data
on occurence of initial serious infections between the interim analysis
cutoff and the final blinded study visit for each patient. Only one
patient was taken off on the day of his last infection.
}
\usage{cgd}
\format{
  \tabular{ll}{
   id:\tab subject identifiction number\cr
   center:\tab enrolling center \cr
   random:\tab date of randomization \cr
   treatment:\tab placebo or gamma interferon \cr
   sex:\tab  \cr
   age:\tab age in years, at study entry \cr
   height:\tab height in cm at study entry\cr
   weight: \tab weight in kg at study entry\cr
   inherit:\tab pattern of inheritance \cr
   steroids:\tab use of steroids at study entry,1=yes\cr
   propylac: \tab use of prophylactic antibiotics at study entry\cr
   hos.cat:\tab a categorization of the centers into 4 groups\cr
   tstart, tstop:\tab start and end of each time interval \cr
   status:\tab 1=the interval ends with an infection \cr
   enum: \tab observation number within subject\cr
   }
 }
\source{
  Fleming and Harrington, Counting Processes and Survival Analysis,
  appendix D.2. 
}
\keyword{datasets}
\keyword{survival}
\eof
% --- Source file: clogit.Rd ---
\name{clogit}
\alias{clogit}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Conditional logistic regression }
\description{
  Estimates a logistic regression model by maximising the conditional
  likelihood. Uses a model formula of the form
  \code{case.status~exposure+strata(matched.set)}.
  The default is to use the exact conditional likelihood, a commonly
  used approximate conditional likelihood is provided for compatibility
  with older software.
}
\usage{
clogit(formula, data, method=c("exact", "approximate"), na.action=getOption("na.action"), subset=NULL,control=coxph.control())
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{formula}{Model formula}
  \item{data}{data frame }
  \item{method}{correct or approximate conditonal likelihood?}
  \item{na.action}{missing value handling}
  \item{subset}{subset of records to use }
  \item{control}{control values}
}

\value{
  An object of class \code{"clogit"}, which is a wrapper for a
  \code{"coxph"} object.
}
\author{Thomas Lumley}


\seealso{\code{\link{strata}},\code{\link{coxph}},\code{\link{glm}} }

\examples{
\dontrun{clogit(case~spontaneous+induced+strata(stratum),data=infert)}
}
\keyword{survival}%-- one or more ...
\keyword{models}
\eof
% --- Source file: cluster.Rd ---
\name{cluster}
\alias{cluster}
\title{
  Identify clusters. 
}
\description{
This is a special function used in the context of survival models.  It 
identifies correlated groups of observations, and is used on the right hand 
side of a formula.
Using \code{cluster()} in a formula implies that
robust sandwich variance estimators are desired.}
\usage{
cluster(x)
}
\arguments{
  \item{x}{
    A character, factor, or numeric variable. 
  }
}
\value{
  \code{x} 
}
\details{
The function's only action is semantic, to mark a variable as the 
cluster indicator.
The resulting variance is what is known as the ``working independence''
variance  in a GEE model.
}
\seealso{
\code{\link{coxph}},  \code{\link{survreg}}   
}
\examples{
marginal.model <- coxph(Surv(time, status) ~ rx + cluster(litter), rats)
frailty.model  <- coxph(Surv(time, status) ~ rx + frailty(litter), rats)
}
\keyword{survival}


\eof
% --- Source file: colon.Rd ---
\name{colon}
\alias{colon}
\title{Chemotherapy for Stage B/C colon cancer}
\usage{colon}
\description{These are data from one of the first successful trials of
    adjuvant chemotherapy for colon cancer. Levamisole is a low-toxicity
    compound previously used to treat worm infestations in animals; 5-FU
    is a moderately toxic (as these things go) chemotherapy agent. There
  are two records per person, one for recurrence and one for death}
\format{
\tabular{ll}{
id:\tab id\cr
study:\tab 1 for all patients\cr
rx:\tab Treatment - Obs(ervation), Lev(amisole), Lev(amisole)+5-FU\cr
sex:\tab  1=male\cr
age:\tab in years\cr
obstruct:\tab obstruction of colon by tumour\cr
perfor:\tab perforation of colon\cr
adhere:\tab adherence to nearby organs\cr
nodes:\tab number of lymph nodes with detectable cancer\cr
time:\tab days until event or censoring\cr
status:\tab censoring status\cr
differ:\tab differentiation of tumour (1=well, 2=moderate, 3=poor)\cr
extent:\tab Extent of local spread (1=submucosa, 2=muscle, 3=serosa,
4=contiguous structures)\cr
surg:\tab time from surgery to registration (0=short, 1=long)\cr
node4:\tab more than 4 positive lymph nodes\cr
etype:\tab event type: 1=recurrence,2=death\cr
}}

\source{Danyu Lin}
\keyword{survival}
\eof
% --- Source file: cox.zph.Rd ---
\name{cox.zph}
\alias{cox.zph}
\alias{[.cox.zph}
\alias{print.cox.zph}
\title{
  Test the Proportional Hazards Assumption of a Cox Regression
}
\description{
Test the proportional hazards assumption for a Cox regression model fit 
(\code{coxph}). 
}
\usage{
cox.zph(fit, transform="km", global=TRUE)
}
\arguments{
  \item{fit}{
    the result of fitting a Cox regression model, using the \code{coxph} function. 
  }
  \item{transform}{
    a character string specifying how the survival times should be transformed 
    before the test is performed. 
    Possible values are \code{"km"}, \code{"rank"}, \code{"identity"} or  a 
    function of one argument. 
  }
  \item{global}{
    should a global chi-square test be done, in addition to the 
    per-variable tests. 
  }
}
\value{
an object of class \code{"cox.zph"}, with components: 

\item{table}{
a matrix with one row for each variable, and optionally a last row for 
the global test. 
Columns of the matrix contain the correlation coefficient between transformed 
survival time and the scaled Schoenfeld residuals, a chi-square, 
and the two-sided p-value. 
For the global test there is no appropriate correlation, so an NA is 
entered into the matrix as a placeholder. 
}
\item{x}{
the transformed time axis. 
}
\item{y}{
the matrix of scaled Schoenfeld residuals.  There will be one column per 
variable and one row per event.  The row labels contain the original event 
times (for the identity transform, these will be the same as \code{x}).
}
\item{call}{
the calling sequence for the routine. 

The computations require the original \code{x} matrix of the Cox model fit. 
Thus it saves time if the \code{x=TRUE} option is used in \code{coxph}. 
This function would usually be followed by both a plot and a print of 
the 
result. 
The plot gives an estimate of the time-dependent coefficient \code{beta(t)}. 
If the proportional hazards assumption is true, \code{beta(t)} will be a 
horizontal 
line.  The printout gives a test for \code{slope=0}. 
}
}
\references{
P. Grambsch and T. Therneau (1994), 
Proportional hazards tests and diagnostics based on weighted residuals. 
\emph{Biometrika,}
\bold{81}, 515-26. 
}
\seealso{
\code{\link{coxph}},  \code{\link{Surv}}.   
}
\examples{
fit <- coxph(Surv(futime, fustat) ~ age + ecog.ps,  
             data=ovarian) 
temp <- cox.zph(fit) 
print(temp)                  # display the results 
plot(temp)                   # plot curves 
}
\keyword{survival}
\eof
% --- Source file: coxph.Rd ---
\name{coxph}
\alias{coxph}
\alias{vcov.coxph}
\alias{print.coxph.null}
\alias{print.coxph.penal}
\alias{model.frame.coxph}
\alias{coxph.penalty}
\alias{[.coxph.penalty}
\alias{coxph.getdata}
\alias{summary.coxph.penal}
\title{
  Fit Proportional Hazards Regression Model 
}
\description{
Fits a Cox proportional hazards regression model. 
Time dependent variables, time dependent strata, multiple events per subject, 
and other extensions are incorporated using the counting process formulation 
of Andersen and Gill. 
}
\usage{
coxph(formula, data=, weights, subset, 
      na.action, init, control, 
      method=c("efron","breslow","exact"), 
      singular.ok=TRUE, robust=FALSE, 
      model=FALSE, x=FALSE, y=TRUE, ...)
}
\arguments{
  \item{formula}{
    a formula object, with the response on the left of a \code{~} operator, and 
    the terms on the right.  The response must be a survival object as 
    returned by the \code{Surv} function. 
  }
  \item{data}{
    a data.frame in which to interpret the variables named in 
    the \code{formula}, or in the \code{subset} and the \code{weights}
    argument. 
  }
  \item{weights}{
    vector of case weights.  If \code{weights} is a vector of integers,
    then the 
    estimated coefficients are equivalent to estimating the model from data 
    with the individual cases replicated as many times as indicated by 
    \code{weights}. 
  }
  \item{subset}{
    expression indicating which subset of the rows of data should be used in 
    the fit.    All observations are included by default. 
  }
  \item{na.action}{
    a missing-data filter function.  This is applied to the model.frame
    after any 
    subset argument has been used.  Default is \code{options()\$na.action}. 
  }
  \item{init}{
    vector of initial values of the iteration.  Default initial 
    value is zero for all variables. 
  }
  \item{control}{
    Object of class \code{\link{coxph.control}} specifying iteration limit
    and other control options. Default is \code{coxph.control(...)}.
  }
  \item{method}{
    a character string specifying the method for tie handling.  If there  
    are no tied death times all the methods are equivalent. 
    Nearly all Cox regression programs use the Breslow method by default, 
    but not this one. 
    The Efron approximation is used as the default here, as it is much more 
    accurate when dealing with tied death times, and is as efficient 
    computationally. 
    The exact method computes the exact partial likelihood, which is 
    equivalent 
    to a conditional logistic model.  If there are a large number of ties 
    the computational time will be excessive. 
  }
  \item{singular.ok}{
    logical value indicating how to handle collinearity in the model matrix. 
    If \code{TRUE}, the program will automatically skip over columns of the X 
    matrix that are linear combinations of earlier columns.  In this case the 
    coefficients for such columns will be NA, and the variance matrix will 
    contain zeros. For ancillary calculations, such as the linear
    predictor, 
    the missing coefficients are treated as zeros. 
  }
  \item{robust}{
    if \code{TRUE} a robust variance estimate is returned.
    Default is \code{TRUE} if the model includes a \code{cluster}
    operative, 
    \code{FALSE} otherwise. 
  }
  \item{model}{
    logical value: if \code{TRUE}, the model frame is returned in component
    \code{model}. 
  }
  \item{x}{
    logical value: if \code{TRUE}, the model frame is returned in
    component \code{x}. 
  }
  \item{y}{
    logical value: if \code{TRUE}, the model frame is returned in
    component \code{y}. 
  }
  \item{...}{Other arguments will be passed to \code{\link{coxph.control}}
  }
}
\value{
an object of class \code{"coxph"} representing the fit. 
See \code{coxph.object} for details.  
}
\section{Side Effects}{
Depending on the call, the \code{predict}, \code{residuals}, and \code{survfit} routines may 
need to reconstruct the x matrix created by \code{coxph}.  Differences in the 
environment, such as which data frames are attached or the value of 
\code{options()\$contrasts}, may cause this computation to fail or worse, to be 
incorrect.  See the survival overview document for details. 
}
\details{
The proportional hazards model is usually expressed in terms of a 
single survival time value for each person, with possible censoring. 
Andersen and Gill reformulated the same problem as a counting process; 
as time marches onward we observe the events for a subject, rather 
like watching a Geiger counter. 
The data for a subject is presented as multiple rows or "observations", 
each 
of which applies to an interval of observation (start, stop]. 
}
\section{Special terms}{
There are two special terms that may be used in the model equation. 
A \code{strata} term identifies a stratified Cox model; separate baseline 
hazard functions are fit for each strata. 
The \code{cluster} term is used to compute a robust variance for the model. 
The term \code{+ cluster(id)} where each value of \code{id} is unique is equivalent to 
specifying the \code{robust=T} argument, and produces an approximate 
jackknife estimate of the variance.  If the \code{id} variable were not 
unique, but instead 
identifies clusters of correlated observations, then the variance 
estimate is based on a grouped jackknife. 
}
\section{Convergence}{
In certain data cases the actual MLE estimate of a 
coefficient is infinity, e.g., a dichotomous variable where one of the 
groups has no events.  When this happens the associated coefficient 
grows at a steady pace and a race condition will exist in the fitting 
routine: either the log likelihood converges, the information matrix 
becomes effectively singular, an argument to exp becomes too large for 
the computer hardware, or the maximum number of interactions is
exceeded.
(Nearly always the first occurs.)
The routine attempts to detect when this has happened,
not always successfully.
The primary consequence for he user is that the Wald statistic,
coefficient/se(coefficient), is not valid in this case and should be
ignored; the likelihood ratio and Wald tests remain valid however.
}
\section{PENALISED REGRESSION}{
  \code{coxph} can now maximise a penalised partial likelihood with
arbitrary user-defined penalty.  Supplied penalty functions include
ridge regression (\link{ridge}), smoothing splines
(\link{pspline}), and frailty models (\link{frailty}).
} 
\references{
Andersen, P. and Gill, R. (1982). 
Cox's regression model for counting processes, a large sample study. 
\emph{Annals of Statistics}
\bold{10}, 1100-1120. 

Therneau, T., Grambsch, P., Modeling Survival Data: Extending the Cox Model. 
Springer-Verlag, 2000.
}
\seealso{
\code{\link{cluster}},  \code{\link{strata}},  \code{\link{Surv}},
\code{\link{survfit}, \code{\link{pspline}}, \code{\link{frailty}},
\code{\link{ridge}}}.   
}
\examples{
# Create the simplest test data set 
test1 <- list(time=c(4,3,1,1,2,2,3), 
              status=c(1,1,1,0,1,1,0), 
              x=c(0,2,1,1,1,0,0), 
              sex=c(0,0,0,0,1,1,1)) 
# Fit a stratified model 
coxph(Surv(time, status) ~ x + strata(sex), test1) 
# Create a simple data set for a time-dependent model 
test2 <- list(start=c(1,2,5,2,1,7,3,4,8,8), 
              stop=c(2,3,6,7,8,9,9,9,14,17), 
              event=c(1,1,1,1,1,1,1,0,0,0), 
              x=c(1,0,0,1,0,1,1,1,0,0)) 
summary(coxph(Surv(start, stop, event) ~ x, test2)) 

#
# Create a simple data set for a time-dependent model
#
test2 <- list(start=c(1, 2, 5, 2, 1, 7, 3, 4, 8, 8),
                stop =c(2, 3, 6, 7, 8, 9, 9, 9,14,17),
                event=c(1, 1, 1, 1, 1, 1, 1, 0, 0, 0),
                x    =c(1, 0, 0, 1, 0, 1, 1, 1, 0, 0) )


summary( coxph( Surv(start, stop, event) ~ x, test2))

# Fit a stratified model, clustered on patients 

bladder1 <- bladder[bladder$enum < 5, ] 
coxph(Surv(stop, event) ~ (rx + size + number) * strata(enum) + 
      cluster(id), bladder1) 
}
\keyword{survival}

\eof
% --- Source file: coxph.control.Rd ---
\name{coxph.control}
\alias{coxph.control}
\title{Ancillary arguments for controling coxph fits}
\description{
This is used to set various numeric parameters controling a Cox model fit.
Typically it would only be used in a call to \code{coxph}.
}
\usage{
coxph.control(eps = 1e-08, toler.chol = .Machine$double.eps^0.75, iter.max = 15, toler.inf = sqrt(eps), outer.max = 10)
}
\arguments{
  \item{eps}{Iteration continues until the relative change in the log partial
likelihood is less than eps.  Must be positive.}
  \item{toler.chol}{Tolerance for detection of singularity during a Cholesky
decomposion of the variance matrix, i.e., for detecting a redundant predictor
variable.}
  \item{iter.max}{Maximum number of iterations to attempt for convergence.}
  \item{toler.inf}{Tolerance criteria for the warning message about a possible
infinite coefficient value.}
  \item{outer.max}{For a penalized coxph model, e.g. with pspline terms, there
is an outer loop of iteration to determine the penalty parameters; maximum
number of iterations for this outer loop.}
}

\value{
  a list containing the values of each of the above constants
}
\author{Terry Therneau }
\seealso{\code{\link{coxph}}
  }
\keyword{survival}
\eof
% --- Source file: coxph.detail.Rd ---
\name{coxph.detail}
\alias{coxph.detail}
\title{
Details of a Cox Model Fit
}
\description{
Returns the individual contributions to the first and second derivative
matrix, at each unique event time.
}
\usage{
coxph.detail(object, riskmat=FALSE)
}
\arguments{
 \item{object}{
   a Cox model object, i.e., the result of \code{coxph}.
 }
 \item{riskmat}{
   include the at-risk indicator matrix in the output?
 }
}
\value{
   a list with components
   \item{time}{
   the vector of unique event times
   }
    \item{nevent}{
    the number of events at each of these time points.
    }
    \item{means}{
    a matrix with one row for each event time and one column for each variable
    in the Cox model, containing the weighted mean of the variable at that time,
    over all subjects still at risk at that time.  The weights are the risk
    weights \code{exp(x \%*\% fit$coef)}.
    }
    \item{nrisk}{
    number of subjects at risk.
    }
    \item{hazard}{
    the hazard increment.
    }
    \item{score}{
    the contribution to the score vector (first derivative of the log
    partial likelihood) at each time point.
    }
    \item{imat}{
    the contribution to the information matrix (second derivative of the
    log partial likelihood) at each time point.
    }
    \item{varhaz}{
    the variance of the hazard increment.
    }
    \item{x,y}{
    copies of the input data.
    }
    \item{strata}{
    only present for a stratified Cox model, this is
    a table giving the number of time points of component \code{time} that
    were contributed by each of the strata.
    }
    \item{riskmat}{
      a matrix with one row for each time and one column for each observation
    containing a 0/1 value to indicate whether that observation was (1) or
    was not (0) at risk at the given time point.
  }
}
\details{
This function may be useful for those who wish to investigate new methods or
extensions to the Cox model.  The example below shows one way to calculate
the Schoenfeld residuals.
}
\seealso{
  \code{\link{coxph}}, \code{\link{residuals.coxph}}
  }
\examples{
fit   <- coxph(Surv(futime,fustat) ~ age + rx + ecog.ps, ovarian, x=TRUE)
fitd  <- coxph.detail(fit)
events <- fit$y[,2]==1
etime  <- fit$y[events,1]   #the event times --- may have duplicates
indx   <- match(etime, fitd$time)
sresid <- fit$x[events,] - fitd$means[indx,]
}
\keyword{survival}

\eof
% --- Source file: coxph.object.Rd ---
\name{coxph.object}
\alias{coxph.object}
\alias{extractAIC.coxph.penal}
\alias{print.coxph}
\title{
  Proportional Hazards Regression Object 
}
\description{
This class of objects is returned by the \code{coxph} class of functions 
to represent a fitted proportional hazards model. 
Objects of this class have methods for the functions \code{print}, 
\code{summary}, \code{residuals}, \code{predict} and \code{survfit}. 
}
\section{Components}{
The following components must be included in a legitimate \code{coxph} 
object. 
}
\arguments{
\item{coefficients}{
the coefficients of the linear predictor, which multiply the columns of 
the 
model matrix.  If the model is over-determined there will be missing 
values in the vector corresponding to the redundant columns in the model 
matrix. 
}
\item{var}{
the variance matrix of the coefficients.  Rows and columns corresponding to 
any missing coefficients are set to zero. 
}
\item{naive.var}{
this component will be present only if the \code{robust} option was true.  If so, 
the \code{var} component will contain the robust estimate of variance, and this 
component will contain the ordinary estimate. 
}
\item{loglik}{
a vector of length 2 containing the log-likelihood with the initial values and 
with the final values of the coefficients. 
}
\item{score}{
value of the efficient score test, at the initial value of the coefficients. 
}
\item{rscore}{
the robust log-rank statistic, if a robust variance was requested. 
}
\item{wald.test}{
the Wald test of whether the final coefficients differ from the initial values. 
}
\item{iter}{
number of iterations used. 
}
\item{linear.predictors}{
the vector of linear predictors, one per subject. 
}
\item{residuals}{
the martingale residuals. 
}
\item{means}{
vector of column means of the X matrix.  Subsequent survival curves are 
adjusted to this value. 
}
\item{n}{
the number of observations used in the fit. 
}
\item{weights}{
the vector of case weights, if one was used. 
}
\item{method}{
the computation method used. 
}
\item{na.action}{
the na.action attribute, if any, that was returned by the \code{na.action} 
routine. 

The object will also contain the following, for documentation see the \code{lm} 
object: \code{terms}, \code{assign}, \code{formula}, \code{call}, and, optionally, \code{x}, \code{y}, 
and/or \code{frame}. 
}
}
\seealso{
\code{\link{coxph}},  \code{\link{coxph.detail}},  \code{\link{cox.zph}},  \code{\link{residuals.coxph}},  \code{\link{survfit}},  \code{\link{survreg}}.   
}
\keyword{survival}
\eof
% --- Source file: dsurvreg.Rd ---
\name{dsurvreg}
\alias{dsurvreg}
\alias{psurvreg}
\alias{qsurvreg}
\title{
  Distributions available in survreg.
}
\description{
Density, cumulative probability, and quantiles for the set of distributions
supported by the \code{survreg} function.
}
\usage{
dsurvreg(x, mean, scale=1, distribution='weibull', parms)
psurvreg(q, mean, scale=1, distribution='weibull', parms)
qsurvreg(p, mean, scale=1, distribution='weibull', parms)
}
\arguments{
\item{x}{
vector of quantiles. 
Missing values (\code{NA}s) are allowed. 
}
\item{q}{
vector of quantiles. 
Missing values (\code{NA}s) are allowed. 
}
\item{p}{
vector of probabilities. 
Missing values (\code{NA}s) are allowed. 
}
\item{mean}{
vector of means. 
This is replicated to be the same length as \code{p} 
or \code{q}.
}
\item{scale}{
vector of (positive) scale factors.
This is replicated to be the same length as \code{p} 
or \code{q}.
}
\item{distribution}{
character string giving the name of the distribution.  This must be one
of the elements of \code{survreg.distributions}
}
\item{parms}{
optional parameters, if any, of the distribution.  For the t-distribution
this is the degrees of freedom.
}
}
\value{
density (\code{dsurvreg}), 
probability (\code{psurvreg}), 
quantile (\code{qsurvreg}), or 
for the requested distribution with mean and scale
parameters \code{mean} and 
\code{sd}. 
}
\details{
Elements of \code{q} or 
\code{p} that are missing will cause the corresponding 
elements of the result to be missing. 

The \code{mean} and \code{scale}
values are as they would be for \code{survreg}.
In particular, if
the distribution is one that involves a transformation, then they are the
mean and scale of the transformed distribution.  
For example, the Weibull distribution is fit using the
Extreme value distribution along with a log transformation.
Letting \eqn{F(t) = 1 - \exp[-(at)^p]}{F(t) = 1 - exp(-(at)^p)}
be the cumulative distribution of the
Weibull, the mean corresponds to \eqn{-\log(a)}{-log(a)} and the scale
to \eqn{1/p} 
(Kalbfleish and Prentice, section 2.2.2).
}
\section{References}{
Kalbfleish, J. D. and Prentice, R. L. (1970). 
\emph{The Statistical Analysis of Failure Time Data}
Wiley, New York. 
}
\seealso{
\code{\link{survreg}}, 
\code{\link{Normal}}
}
\examples{
# List of distributions available
names(survreg.distributions)
\dontrun{
 [1] "extreme"     "logistic"    "gaussian"    "weibull"     "exponential"
 [6] "rayleigh"    "loggaussian" "lognormal"   "loglogistic" "t"          
}
# Compare results
all.equal(dsurvreg(1:10, 2, 5, dist='lognormal'), dlnorm(1:10, 2, 5))

# Hazard function for a Weibull distribution
x   <- seq(.1, 3, length=30)
haz <- dsurvreg(x, 2, 3)/ (1-psurvreg(x, 2, 3))
\dontrun{
plot(x, haz, log='xy', ylab="Hazard") #line with slope (1/scale -1)
}
}
\keyword{distribution}
% docclass is function
% Converted by Sd2Rd version 37351.
\eof
% --- Source file: frailty.Rd ---
\name{frailty}
\alias{frailty}
\alias{frailty.gamma}
\alias{frailty.gaussian}
\alias{frailty.t}
\title{
  Random effects terms
}
\description{
The frailty function allows one to add a simple random effects term to
a Cox or survreg model.
}
\usage{
frailty(x, distribution="gamma", ...)
frailty.gamma(x, sparse = (nclass > 5), theta, df, eps = 1e-05, method = c("em","aic", "df", "fixed"), ...) 
frailty.gaussian(x, sparse = (nclass > 5), theta, df, method =c("reml","aic", "df", "fixed"), ...)
frailty.t(x, sparse = (nclass > 5), theta, df, eps = 1e-05, tdf = 5,method = c("aic", "df", "fixed"), ...)
}

\arguments{
  \item{x}{
    the variable to be entered as a random effect.  
    It is always treated as a factor.
  }
  \item{distribution}{
    either the \code{gamma}, 
    \code{gaussian} or \code{t}
    distribution may be specified.
    The routines \code{frailty.gamma},
    \code{frailty.gaussian} and 
    \code{frailty.t} do the actual work.
  }
  \item{\dots}{Arguments for specific distribution, including (but not
    limited to) }
  \item{sparse}{
    cutoff for using a sparse coding of the data matrix.  
    If the total number of levels of \code{x} is larger
    than this value, then a sparse matrix approximation is used.
    The correct cutoff is still a matter of exploration: if the number of
    levels is very large (thousands) then the non-sparse calculation may not be
    feasable in terms of both memory and compute time.  
    Likewise, the accuracy of the sparse approximation appears to be related to
    the maximum proportion of subjects in any one class, being best when no
    one class has a large membership.
  }
  \item{theta}{
    if specified, this fixes the variance of the random effect.
    If not, the variance is a parameter, and a best solution is sought.
    Specifying this implies \code{method='fixed'}.
  }
  \item{df}{
    if specified, this fixes the degrees of freedom for the random effect.
    Specifying this implies \code{method='df'}.
    Only one of \code{theta} or 
    \code{df} should be specified.
  }
  \item{method}{
    the method used to select a solution for theta, the variance of the
    random effect.  
    The \code{fixed} corresponds to a user-specified
    value, and no iteration is done.
    The \code{df} selects the variance such that the
    degrees of freedom for the random effect matches a user specified value.
    The \code{aic} method seeks to 
    maximize Akiake's information criteria 
    2*(partial likelihood - df).
    The \code{ml} and \code{reml}
    methods are specific to Cox models with gamma and gaussian random effects,
    respectively.
    Please see further discussion below.
  }
  \item{tdf}{
    the degrees of freedom for the t-distribution.
  }
  \item{eps}{
    convergence critera for the iteration on theta.
  }
}
\value{
this function is used in the model statment of either
\code{coxph} or \code{survreg}.
It's results are used internally.
}
\details{
The \code{frailty} plugs into the general penalized
modeling framework provided by the \code{coxph} 
and \code{survreg} routines.  
This framework deals with likelihood, penalties, and degrees of freedom;
these aspects work well with either parent routine.

Therneau, Grambsch, and Pankratz show how maximum likelihood estimation for
the Cox model with a gamma frailty can be accomplished using a general
penalized routine, and Ripatti and Palmgren work through a similar argument
for the Cox model with a gaussian frailty.  Both of these are specific to
the Cox model.  
Use of gamma/ml or gaussian/reml with 
\code{survreg} does not lead to valid results. 

The extensible structure of the penalized methods is such that the penalty
function, such as \code{frailty} or
\code{pspine}, is completely separate from the modeling
routine.  The strength of this is that a user can plug in any penalization
routine they choose.  A weakness is that it is very difficult for the
modeling routine to know whether a sensible penalty routine has been
supplied.  
}
\section{References}{
S Ripatti and J Palmgren, Estimation of multivariate frailty 
models using penalized partial likelihood,
Biometrics, 56:1016-1022, 2000.

T Therneau, P Grambsch and VS Pankratz,
Penalized survival models and frailty,
J Computational and Graphical Statistics, 12:156-175, 2003.
}
\seealso{
\link{coxph}, \link{survreg}, \link[pkg=bdsmatrix]{coxme}
}
\examples{
# Random institutional effect
coxph(Surv(time, status) ~ age + frailty(inst, df=4), lung)

# Litter effects for the rats data
rfit2a <- survreg(Surv(time, status) ~ rx +
                  frailty.gaussian(litter, df=13, sparse=FALSE), rats )
rfit2b <- survreg(Surv(time, status) ~ rx +
                  frailty.gaussian(litter, df=13, sparse=TRUE), rats )
}
\keyword{survival}

\eof
% --- Source file: heart.Rd ---
\name{heart}
\docType{data}
\alias{jasa1}
\alias{jasa}
\alias{heart}
\title{Stanford Heart Transplant data}
\description{Survival of patients on the waiting list for the Stanford
  heart transplant program.}
\usage{
heart
jasa
jasa1
}
\format{
  jasa: original data
  \tabular{ll}{
   birth.dt:\tab birth date \cr
   accept.dt:\tab acceptance into program \cr
   tx.date:\tab transplant date \cr
   fu.date:\tab end of followup \cr
   fustat:\tab dead or alive \cr
   surgery:\tab prior bypass surgery\cr
   age: \tab age (in days)\cr
   futime:\tab followup time\cr
   wait.time:\tab time before transplant\cr
   transplant:\tab transplant indicator\cr
   mismatch:\tab mismatch score\cr
   hla.a2:\tab particular type of mismatch\cr
   mscore:\tab another mismatch score\cr
   reject:\tab rejection occurred\cr
 }

 jasa1, heart: processed data
  \tabular{ll}{
    start, stop, event: \tab Entry and exit time and status for this interval of time\cr
    age:\tab age-48 years\cr
    year:\tab year of acceptance (in years after 1 Nov 1967)\cr
    surgery:\tab prior bypass surgery 1=yes\cr
    transplant: \tab received transplant 1=yes\cr
    id:\tab patient id\cr
  }
}
\seealso{\code{\link{stanford2}}}
\source{
  J Crowley and M Hu (1977),
  Covariance analysis of heart transplant survival data.
  \emph{Journal of the American Statistical Association},
  \bold{72}, 27--36.
}
\keyword{datasets}
\keyword{survival}
\eof
% --- Source file: is.ratetable.Rd ---
\name{is.ratetable}
\alias{is.ratetable}
\alias{Math.ratetable}
\alias{Ops.ratetable}
\title{
  Verify that an object is of class ratetable. 
}
\description{
The function verifies not only the \code{class} attribute, but the 
structure of the object. 
}
\usage{
is.ratetable(x, verbose=FALSE)
}
\arguments{
\item{x}{
the object to be verified. 
}
\item{verbose}{
if \code{TRUE} and the object is not a ratetable, 
then return a character string describing the way(s) in which \code{x} 
fails to be a proper ratetable object. 
}
}
\value{
returns \code{TRUE} if \code{x} is a ratetable, and \code{FALSE} or a description if it is not. 
}
\details{
Rate tables are used by the \code{pyears} and \code{survexp} functions, and normally 
contain death rates for some population, categorized by age, sex, or other 
variables.  They have a fairly rigid structure, and the \code{verbose} option 
can help in creating a new rate table. 
}
\seealso{
\code{\link{pyears}},  \code{\link{survexp}}.   
}
\examples{
is.ratetable(survexp.us)  # True
is.ratetable(cancer)      # False
}

\keyword{survival}
\eof
% --- Source file: kidney.Rd ---
\name{kidney}
\alias{kidney}
\title{Kidney catheter data}
\format{
\tabular{ll}{
patient:\tab id\cr
time:\tab time\cr
status:\tab event status\cr
age:\tab in years\cr
sex:\tab 1=male, 2=female\cr
disease:\tab  disease type (0=GN, 1=AN, 2=PKD, 3=Other)\cr
frail:\tab frailty estimate from original paper\cr
}}
\description{
Data on the recurrence times to infection, at the point of insertion of
  the catheter, for kidney patients using portable dialysis equipment.
  Catheters may be removed for reasons other than infection, in which case
  the observation is censored.  Each patient has exactly 2 observations.

This data has often been used to illustrate the use of random effects
(frailty) in a survival model.  However, one of the males (id 21) is a
large outlier, with much longer survival than his peers.  If this
observation is removed no evidence remains for a random subject effect.
  
}
\section{Note}{
  The original paper ignored the issue of tied times and so is not
  exactly reproduced by the survival package.
}
\examples{
kfit <- coxph(Surv(time, status)~ age + sex + disease + frailty(id), kidney)
kfit0 <- coxph(Surv(time, status)~ age + sex + disease, kidney)
kfitm1 <- coxph(Surv(time,status) ~ age + sex + disease + 
		frailty(id, dist='gauss'), kidney)

}
\source{
  CA McGilchrist, CW Aisbett (1991),
  Regression with frailty in survival analysis. 
  \emph{Biometrics} \bold{47}, 461--66.
}
\keyword{survival}
\eof
% --- Source file: lines.survfit.Rd ---
\name{lines.survfit}
\alias{lines.survfit}
\alias{points.survfit}
\title{
  Add Lines or Points to a Survival Plot 
}
\description{
Often used to add the expected survival curve(s) to a Kaplan-Meier plot 
generated with \code{plot.survfit}. 
}
\usage{
\method{lines}{survfit}(x, type="s", mark=3, col=1, lty=1,
lwd=1, mark.time=TRUE, 
	xscale=1,  firstx=0, firsty=1, xmax, fun, conf.int=FALSE,  ...)
\method{points}{survfit}(x, ...)
}

\arguments{
\item{x}{
a survival object, generated from the \code{survfit} or \code{survexp} functions. 
}
\item{type}{
the line type, as described in \code{lines}.  The default is a step function 
for \code{survfit} objects, and a connected line for \code{survexp} objects. 
}
\item{mark, col, lty, lwd}{
vectors giving the mark symbol, color, line type and line width for the 
added curves. 
}
\item{...}{other graphical parameters}
\item{mark.time}{
controls the labeling of the curves.   
If \code{FALSE}, no labeling is done.   
If \code{TRUE}, then curves are marked at each censoring time.   
If \code{mark.time} is a numeric vector, then curves are marked at  
the specified time points. 
}
\item{xscale}{
a number used to divide the x values.  If time was originally in days, a 
value of 365.25 would give a plotted scale in years. 
}
\item{firstx, firsty}{
the starting point for the survival curves.  If either of these is set to 
\code{NA} or < blank > the plot will start at the first time point of the curve. 
}
\item{xmax}{
the maximum horizontal plot coordinate.     
This shortens the curve before plotting it, so unlike using the 
\code{xlim} graphical parameter, warning messages about out of bounds points are 
not generated. 
}
\item{fun}{
an arbitrary function defining a transformation of the survival curve. 
For example \code{fun=log} is an alternative way to draw a log-survival curve 
(but with the axis labeled with log(S) values). 
Four often used transformations can be specified with a character 
argument instead: "log" is the same as using the \code{log=T} option, 
"event" plots cumulative events (f(y) = 1-y), 
"cumhaz" plots the cumulative hazard function (f(y) = -log(y)) 
and "cloglog" creates a complimentary log-log survival plot  
(f(y) = log(-log(y) along with log scale for the x-axis). 
}
\item{conf.int}{
if \code{TRUE}, confidence bands for the curves are also plotted. 
If set to \code{"only"}, then only the CI bands are plotted, and the curve 
itself is left off.   
This can be useful for fine control over the colors or line types of a plot. 
}
}
\value{
a list with components \code{x} and \code{y}, containing the coordinates of the 
last point on each of the curves (but not of the confidence limits). 
This may be useful for labeling. 
}
\section{Side Effects}{
one or more curves are added to the current plot. 
}
\seealso{
\code{\link{lines}},  \code{\link{par}},  \code{\link{plot.survfit}},  \code{\link{survfit}},  \code{\link{survexp}}.   
}
\examples{
fit <- survfit(Surv(time, status) ~ sex, pbc,subset=1:312)
plot(fit, mark.time=FALSE, xscale=365.25,
        xlab='Years', ylab='Survival')
lines(fit[1], lwd=2, xscale=365.24)    #darken the first curve and add marks


# Add expected survival curves for the two groups,
#   based on the US census data
# The data set does not have entry date, use the midpoint of the study
efit <- survexp(~ ratetable(sex=sex,age=age*365.35,year=as.Date('1979/1/1')) +
            sex, data=pbc,  times=(0:24)*182)
temp <- lines(efit, lty=2, xscale=365.24, lwd=2:1)
text(temp, c("Male", "Female"), adj= -.1) #labels just past the ends
title(main="Primary Biliary Cirrhosis, Observed and Expected")

}
\keyword{survival}
\eof
% --- Source file: lung.Rd ---
\name{lung}
\docType{data}
\alias{cancer}
\alias{lung}
\title{NCCTG Lung Cancer Data}
\description{
  Survival in patients with advanced lung cancer from the North
  Central Cancer Treatment Group.  Performance
  scores rate how well the patient can perform usual daily activities.
}
\usage{
lung
cancer
}
\format{
  \tabular{ll}{
    inst:\tab Institution code\cr
    time:\tab Survival time in days\cr
    status:\tab censoring status 1=censored, 2=dead\cr
    age:\tab Age in years\cr
    sex:\tab  Male=1 Female=2\cr
    ph.ecog:\tab ECOG performance score (0=good 5=dead)\cr
    ph.karno:\tab Karnofsky performance score (bad=0-good=100) rated by physician\cr
    pat.karno:\tab Karnofsky performance score as rated by patient\cr
    meal.cal:\tab Calories consumed at meals\cr
    wt.loss:\tab Weight loss in last six months\cr
  }
}
\source{Terry Therneau}
\references{
  Loprinzi CL. Laurie JA. Wieand HS. Krook JE. Novotny PJ.
  Kugler JW. Bartel J. Law M. Bateman M. Klatt NE. et al.
  Prospective evaluation of prognostic variables from patient-completed
  questionnaires. North Central Cancer Treatment Group.
  Journal of Clinical Oncology. 12(3):601-7, 1994. }
\keyword{datasets}
\eof
% --- Source file: mgus.Rd ---
\name{mgus}
\alias{mgus}
\alias{mgus1}
\alias{mgus2}
\docType{data}
\title{Monoclonal gammapothy data}
\description{
Natural history of 241 subjects with monoclonal gammapothy of
undetermined significance (MGUS).
}
\usage{
mgus
mgus1
mgus2
}
\format{
  mgus: A data frame with 241 observations on the following 12 variables.
  \tabular{ll}{
    id:\tab subject id \cr
    age:\tab age in years \cr
    sex:\tab \code{male} or \code{female} \cr
    dxyr:\tab year of diagnosis \cr
    pcdx:\tab for subjects who progress to a plasma cell malignancy \cr
       \tab the subtype of malignancy: multiple myeloma (MM) is the \cr
       \tab most common, followed by amyloidosis (AM), macroglobulinemia (MA),\cr
      \tab and other lymphprolifative (LP) \cr
    pctime:\tab days from MGUS until diagnosis of a plasma cell malignancy \cr
    futime:\tab days from diagnosis to last follow-up \cr
    death:\tab 1= follow-up is until death \cr
    alb:\tab albumin level at MGUS diagnosis \cr
    creat:\tab creatinine at MGUS diagnosis \cr
    hgb:\tab hemoglobin at MGUS diagnosis \cr
    mspike:\tab size of the monoclonal protien spike at diagnosis \cr
    }

   mgus1: The same data set in start,stop format. Contains the id, age, sex, and
  laboratory variable described above along with
  \tabular{ll}{ 
    start, stop:\tab sequential intervals of time for each
      subject \cr
    status:\tab =1 if the interval ends in an event \cr
    event:\tab the event type \cr
  }

  mgus2: The mgus data, but formatted in the competing risks style.  Each
  subject has three observations, one for time to death, one for time to
  MM, and one for time to a PC malignancy other than MM.
  Contains the id, age, sex, and
  laboratory variable described above along with 
    \tabular{ll}{
    time:\tab time to event or censoring \cr
    status:\tab 1 if the event occured, 0 otherwise \cr
    event:\tab death, myeloma, or other \cr
  }
}

  
\details{
 Plasma cells are responsible for manufacturing immunoglobulins, an
important part of the immune defense. At any given time there are
estimated to be about \eqn{10^6} different immunoglobulins in the circulation
at any one time.  When a patient has a plasma cell malignancy the
distribuion will become dominated by a single isotype, the product of
the malignant clone, visible as a spike on a serum protein
electrophoresis. Monoclonal gammapothy of undertermined significance
(MGUS) is the presence of such a spike, but in a patient with no
evidence of overt malignancy.  This data set of 241 sequential subjects
at Mayo Clinic was the groundbreaking study defining the natural history
of such subjects. 
}
\source{
Mayo Clinic data courtesy of Dr. Robert Kyle.
}
\references{
 R Kyle, Benign monoclonal gammopathy -- after 20 to 35 years of
 follow-up,
 Mayo Clinic Proc 1993; 68:26-36. 
}
\keyword{datasets}
\keyword{survival}
\eof
% --- Source file: nwtco.Rd ---
\name{nwtco}
\alias{nwtco}
\docType{data}
\title{Data from the National Wilm's Tumor Study}
\description{
  Missing data/masurement error example. Tumor histology predicts
  survival, but prediction is stronger with central lab histology than
  with the local institution determination.
}
\usage{nwtco}
\format{
  A data frame with 4028 observations on the following 9 variables.
  \describe{
    \item{\code{seqno}}{id number}
    \item{\code{instit}}{Histology from local institution}
    \item{\code{histol}}{Histology from central lab}
    \item{\code{stage}}{Disease stage}
    \item{\code{study}}{study}
    \item{\code{rel}}{indicator for relapse}
    \item{\code{edrel}}{time to relapse}
    \item{\code{age}}{age in months}
    \item{\code{in.subcohort}}{Included in the subcohort for the example in the
    paper}
  }
}
\source{
  \url{http://faculty.washington.edu/norm/software.html}
}
\references{
  NE Breslow and N Chatterjee (1999),
  Design and analysis of two-phase studies with binary outcome applied
  to Wilms tumour prognosis.
  \emph{Applied Statistics} \bold{48}, 457--68.
}
\examples{
with(nwtco, table(instit,histol))
anova(coxph(Surv(edrel,rel)~histol+instit,data=nwtco))
anova(coxph(Surv(edrel,rel)~instit+histol,data=nwtco))
}
\keyword{datasets}
\eof
% --- Source file: ovarian.Rd ---
\name{ovarian}
\alias{ovarian}
\docType{data}
\title{Ovarian Cancer Survival Data}
\usage{ovarian}
\description{Survival in a randomised trial comparing two treatments for
    ovarian cancer (? from an Eastern Cooperative Oncology Group study)}
\format{
  \tabular{ll}{
    futime:\tab survival or censoring time\cr
    fustat:\tab censoring status\cr
    age: \tab in years\cr
    resid.ds:\tab residual disease present (1=no,2=yes)\cr
    rx:\tab treatment group\cr
    ecog.ps:\tab ECOG performance status (1 is better, see reference)\cr
  }
}
\source{Terry Therneau}
\references{for ECOG performance status: \url{http://ecog.dfci.harvard.edu/~ecogdba/general/perf_stat.html}}
\keyword{datasets}
\keyword{survival}
\eof
% --- Source file: pbc.Rd ---
\name{pbc}
\alias{pbc}
\docType{data}
\title{Mayo Clinic Primary Biliary Cirrhosis Data}
\description{D
This data is from the Mayo Clinic
trial in primary biliary cirrhosis (PBC) of the liver conducted between 1974
and 1984.  
A total of 424 PBC patients, referred to Mayo Clinic during that ten-year
interval, met eligibility criteria for the randomized placebo controlled
trial of the drug D-penicillamine.  The first 312 cases in the data set
participated in the randomized trial and contain largely complete data.  The
additional 112 cases did not participate in the clinical trial, but consented
to have basic measurements recorded and to be followed for survival.  Six of
those cases were lost to follow-up shortly after diagnosis, so the data here
are on an additional 106 cases as well as the 312 randomized participants.
    
A nearly identical data set found in appendix D of Fleming and Harrington;
this version has fewer missing values.
}
\usage{pbc}
\format{
  \tabular{ll}{
    age:\tab in years\cr
    albumin:\tab serum albumin (mg/dl)\cr
    alk.phos:\tab alkaline phosphotase (U/liter)\cr
    ascites:\tab presence of ascites \cr
    ast:\tab aspartate aminotransferase, once called SGOT (U/ml)\cr
    bili:\tab serum bilirunbin (mg/dl)\cr
    chol:\tab serum cholesterol (mg/dl)\cr
    copper:\tab urine copper (ug/day)\cr
    edema:\tab 0 no edema, 0.5 untreated or successfully treated\cr
    \tab 1 edema despite diuretic therapy\cr
    hepato:\tab presence of hepatomegaly or enlarged liver\cr
    id:\tab case number\cr
    platelet:\tab platelet count\cr
    protime:\tab standardised blood clotting time\cr
    sex:\tab m/f\cr
    spiders:\tab blood vessel malformations in the skin\cr
    stage:\tab histologic stage of disease (needs biopsy)\cr
    status:\tab status at endpoint, 0/1/2 for censored, transplant, dead\cr
    time: \tab number of days between registration and the earlier of death,\cr
       \tab transplantion, or study analysis in July, 1986\cr
    trt:\tab 1/2/NA for D-penicillmain, placebo, not randomised\cr
    trig:\tab triglycerides (mg/dl)\cr
  }
}
\source{
  T Therneau and P Grambsch (2000),
  \emph{Modeling Survival Data: Extending the Cox Model},
  Springer-Verlag, New York.
  ISBN: 0-387-98784-3.
}
\keyword{datasets}
\eof
% --- Source file: pbcseq.Rd ---
\name{pbcseq}
\alias{pbcseq}
\docType{data}
\title{Mayo Clinic Primary Biliary Cirrhosis, sequential data}
\description{
This data is a continuation of the PBC data set,
and contains the follow-up laboratory data for each study patient.
An analysis based on the data can be found in Murtagh, et. al.
  
The primary PBC data set contains only baseline measurements 
of the laboratory 
paramters.  This data set contains multiple laboratory results, but
only on the 312 randomized patients.  Some baseline data values in this file
differ from the original PBC file, for instance, the data errors in
prothrombin time and age which were discovered after the orignal analysis
(see Fleming and Harrington, figure 4.6.7).
   
One "feature" of the data deserves special comment.  The last
observation before death or liver transplant often has many more
missing covariates than other data rows.  The original clinical
protocol for these patients specified visits at 6 months, 1 year, and
annually thereafter.  At these protocol visits lab values were
obtained for a large pre-specified battery of tests.  "Extra" visits,
often undertaken because of worsening medical condition, did not
necessarily have all this lab work. 
The missing values are thus potentially informative.
}
\usage{pbc}
\format{
  \tabular{ll}{
    id:\tab case number\cr
    age:\tab in years\cr
    sex:\tab m/f\cr
    trt:\tab 1/2/NA for D-penicillmain, placebo, not randomised\cr
    time:\tab number of days between registration and the earlier of death,\cr
       \tab transplantion, or study analysis in July, 1986\cr
    status:\tab status at endpoint, 0/1/2 for censored, transplant, dead\cr
    day:\tab number of days between enrollment and this visit date\cr
       \tab all measurements below refer to this date\cr
    albumin:\tab serum albumin (mg/dl)\cr
    alk.phos:\tab alkaline phosphotase (U/liter)\cr
    ascites:\tab presence of ascites \cr
    ast:\tab aspartate aminotransferase, once called SGOT (U/ml)\cr
    bili:\tab serum bilirunbin (mg/dl)\cr
    chol:\tab serum cholesterol (mg/dl)\cr
    copper:\tab urine copper (ug/day)\cr
    edema:\tab 0 no edema, 0.5 untreated or successfully treated\cr
    \tab 1 edema despite diuretic therapy\cr
    hepato:\tab presence of hepatomegaly or enlarged liver\cr
    platelet:\tab platelet count\cr
    protime:\tab standardised blood clotting time\cr
    spiders:\tab blood vessel malformations in the skin\cr
    stage:\tab histologic stage of disease (needs biopsy)\cr
    trig:\tab triglycerides (mg/dl)\cr
  }
}
\source{
  T Therneau and P Grambsch,
  "Modeling Survival Data: Extending the Cox Model",
  Springer-Verlag, New York, 2000.
  ISBN: 0-387-98784-3.
}
\references{
  Murtaugh PA. Dickson ER. Van Dam GM. Malinchoc M. Grambsch PM.
  Langworthy AL. Gips CH.  "Primary biliary cirrhosis: prediction of short-term
  survival based on repeated patient visits." Hepatology. 20(1.1):126-34, 1994.

  Fleming T and Harrington D., "Counting Processes and Survival Analysis",
  Wiley, New York, 1991.
  }
\keyword{datasets}
\eof
% --- Source file: plot.aareg.Rd ---
\name{plot.aareg}
\alias{plot.aareg}
\title{
  Plot an aareg object.
}
\description{
Plot the estimated coefficient function(s) from a fit
of Aalen's additive regression model.
}
\usage{
\method{plot}{aareg}(x, se=TRUE, maxtime, type='s', ...)
}
\arguments{
  \item{x}{
    the result of a call to the \code{aareg} function
  }
  \item{se}{
    if TRUE, standard error bands are included on the plot
  }
  \item{maxtime}{
    upper limit for the x-axis.
  }
  \item{type}{
    graphical parameter for the type of line, default is "steps".
  }
  \item{\dots }{
    other graphical parameters such as line type, color, or axis labels.
  }
}
\section{Side Effects}{
A plot is produced on the current graphical device.
}
\section{References}{
Aalen, O.O. (1989). A linear regression model for the analysis of life times.
Statistics in Medicine, 8:907-925.
}
\seealso{
aareg
}

\eof
% --- Source file: plot.cox.zph.Rd ---
\name{plot.cox.zph}
\alias{plot.cox.zph}
\title{
  Graphical Test of Proportional Hazards 
}
\description{
Displays a graph of the scaled Schoenfeld residuals, along with a smooth curve. 
}
\usage{
\method{plot}{cox.zph}(x, resid=TRUE, se=TRUE, df=4, nsmo=40, var, \dots)
}
\arguments{
\item{x}{
result of the \code{cox.zph} function. 
}
\item{resid}{
a logical value, if \code{TRUE} the residuals are included on the plot, as well as the smooth fit. 
}
\item{se}{
a logical value, if \code{TRUE}, confidence bands at two standard errors 
will be added. 
}
\item{df}{
the degrees of freedom for the fitted natural spline, \code{df=2} leads 
to a linear fit. 
}
\item{nsmo}{
number of points used to plot the fitted spline. 
}
\item{var}{
the set of variables for which plots are desired.  By default, plots are 
produced in turn for each variable of a model.  Selection of a single variable 
allows other features to be added to the plot, e.g., a horizontal line at 
zero or a main title. 

This has been superseded by a subscripting method; see the example below. 
}
\item{\dots}{
additional graphical arguments passed to the \code{plot} function. 
}
}
\section{Side Effects}{
a plot is produced on the current graphics device. 
}
\seealso{
\code{\link{coxph}},  \code{\link{cox.zph}}.   
}
\examples{
vfit <- coxph(Surv(time,status) ~ trt + factor(celltype) + 
              karno + age, data=veteran, x=TRUE) 
temp <- cox.zph(vfit) 
plot(temp, var=5)      # Look at Karnofsy score, old way of doing plot 
plot(temp[5])     # New way with subscripting 
abline(0, 0, lty=3) 
# Add the linear fit as well  
abline(lm(temp$y[,5] ~ temp$x)$coefficients, lty=4, col=3)  
title(main="VA Lung Study") 
}
\keyword{survival}

\eof
% --- Source file: plot.survfit.Rd ---
\name{plot.survfit}
\alias{plot.survfit}
\title{
  Plot Method for 'survfit' 
}
\usage{
\method{plot}{survfit}(x, conf.int=, mark.time=TRUE, 
 mark=3, col=1, lty=1, lwd=1, cex=1, log=FALSE, xscale=1, yscale=1,  
 firstx=0, firsty=1, xmax, ymin=0, fun, 
 xlab="", ylab="", xaxs="S", ...)
}
\arguments{
  \item{x}{
    an object of class \code{survfit}, usually returned by the
    \code{survfit} function. 
  }
  \item{conf.int}{
    determines whether confidence intervals will be plotted.  The default is to 
    do so if there is only 1 curve, i.e., no strata. 
  }
  \item{mark.time}{
    controls the labeling of the curves.  If set to \code{FALSE}, no
    labeling is done. 
    If \code{TRUE}, then curves are marked at each censoring time which
    is not also a death time.  If \code{mark.time} is a 
    numeric vector, then curves are marked at the specified time points. 
  }
  \item{mark}{
    vector of mark parameters, which will be used to label the curves. 
    The \code{lines} help file contains examples of the possible marks. 
    The vector is reused cyclically if it is shorter than the number of curves. 
  }
  \item{col}{
    a vector of integers specifying colors for each curve. 
    The default value is 1. 
  }
  \item{lty}{
    a vector of integers specifying line types for each curve. 
    The default value is 1. 
  }
  \item{lwd}{
    a vector of numeric values for line widths. The default value is 1. 
  }
  \item{cex}{
    a numeric value specifying the size of the marks. 
    This is not treated as a vector; all marks have the same size.
  }
  \item{log}{
    a logical value, if TRUE the y axis wll be on a log scale. 
    Alternately, one of the standard character strings "x", "y", or "xy"
    can be given to specific logarithmic horizontal and/or vertical axes.
  }
  \item{yscale}{
    a numeric value used to multiply the labels on the y axis. 
    A value of 100, for instance, would be used to give a percent scale. 
    Only the labels are 
    changed, not the actual plot coordinates, so that adding a curve with 
    "\code{lines(surv.exp(...))}", say,  
    will perform as it did without the \code{yscale} argument. 
  }
  \item{xscale}{
    a numeric value used like \code{yscale} for labels on the x axis.  
    A value of 365.25 will give labels in years instead of the original days.  
  }
  \item{firstx, firsty}{
    the starting point for the survival curves.  If either of these is set to 
    \code{NA} the plot will start at the first time point of the curve. 
    By default, the plot program obeys tradition by having the plot start at
    (0,0).

    If \code{start.time} argument is used in \code{survfit}, \code{firstx}
    is set to that value.
  }
  \item{xmax}{
    the maximum horizontal plot coordinate.  This can be used to shrink
    the range of a plot.  It shortens the curve before plotting it, so
    that unlike using the \code{xlim} graphical parameter, warning
    messages about out of bounds points are not generated.
  }
  \item{ymin}{
    lower boundary for y values.  Survival curves are most often drawn in the 
    range of 0-1, even if none of the curves approach zero. 
    The parameter is ignored if the \code{fun} argument is present,
    or if it has been set to \code{NA}. 
  }
  \item{fun}{
    an arbitrary function defining a transformation of the survival curve. 
    For example \code{fun=log} is an alternative way to draw a log-survival curve 
    (but with the axis labeled with log(S) values), 
    and \code{fun=sqrt} would generate a curve on square root scale. 
    Four often used transformations can be specified with a character 
    argument instead: \code{"log"} is the same as using the \code{log=T} option, 
    \code{"event"} plots cumulative events (f(y) = 1-y),  
    \code{"cumhaz"} plots the cumulative hazard function (f(y) = -log(y)), and 
    \code{"cloglog"} creates a complimentary log-log survival plot (f(y) = 
    log(-log(y)) along with log scale for the x-axis).  
  }
  \item{xlab}{
    label given to the x-axis. 
  }
  \item{ylab}{
    label given to the y-axis. 
  }
  \item{xaxs}{
    either \code{"S"} for a survival curve or a standard x axis style as
    listed in \code{par}.
    Survival curves are usually displayed with the curve touching the y-axis,
    but not touching the bounding box of the plot on the other 3 sides.
    Type \code{"S"} accomplishes this by manipulating the plot range and
    then using the \code{"i"} style internally.
  }
  \item{\dots}{for future methods}
}
\value{
a list with components \code{x} and \code{y}, containing the coordinates of the last point 
on each of the curves (but not the confidence limits).   
This may be useful for labeling. 
}
\description{
A plot of survival curves is produced, one curve for each strata. 
The \code{log=T} option does extra work to avoid log(0), and to try to create a 
pleasing result.  If there are zeros, they are plotted by default at 
0.8 times the smallest non-zero value on the curve(s). 
}
\section{Bugs}{
Survival curve objects created from a \code{coxph} model does not include
the censoring times. Therefore, specifying \code{mark.time=T} does not work.
If you want to mark censoring times on the curve(s) resulting   
from a \code{coxph} fit, provide a vector of times as the
\code{mark.time} argument  
in the call to \code{plot.survfit} or \code{lines.survfit}.  
}
\seealso{
\code{\link{par}},  
\code{\link{survfit}},  
\code{\link{lines.survfit}}.   
}
\examples{
leukemia.surv <- survfit(Surv(time, status) ~ x, data = aml) 
plot(leukemia.surv, lty = 2:3) 
legend(100, .9, c("Maintenance", "No Maintenance"), lty = 2:3) 
title("Kaplan-Meier Curves\nfor AML Maintenance Study") 
lsurv2 <- survfit(Surv(time, status) ~ x, aml, type='fleming') 
plot(lsurv2, lty=2:3, fun="cumhaz", 
	xlab="Months", ylab="Cumulative Hazard") 
}
\keyword{survival}
\keyword{hplot}
\eof
% --- Source file: predict.coxph.Rd ---
\name{predict.coxph}
\alias{predict.coxph}
\alias{predict.coxph.penal}
\title{
  Predictions for a Cox model 
}
\description{
  Compute fitted values and regression terms for a model fitted by
  \code{\link{coxph}}
}
\usage{
\method{predict}{coxph}(object, newdata,
type=c("lp", "risk", "expected", "terms"),
se.fit=FALSE, terms=names(object$assign), collapse,
safe=FALSE, ...)
}
\arguments{
\item{object}{
the results of a coxph fit. 
}
\item{newdata}{
  Optional new data at which to do predictions.
  If absent predictions are for the 
data frame used in the original fit. 
}
\item{type}{
the type of predicted value. 
Choices are the linear predictor (\code{"lp"}), the risk score exp(lp)
(\code{"risk"}), 
the expected number of events given the covariates and follow-up time 
(\code{"expected"}), and the terms of the linear predictor (\code{"terms"}). 
}
\item{se.fit}{
if TRUE, pointwise standard errors are produced for the predictions. 
}
\item{terms}{
if type="terms", this argument can be used to specify which terms should be 
included; the default is all. 
}
\item{collapse}{
optional vector of subject identifiers.  
If specified, the output will contain one entry per subject rather than one 
entry per observation. 
}
\item{safe}{not used in R}
\item{\dots}{For future methods}
}
\value{
a vector or matrix of predictions, or a list containing the predictions 
(element "fit") and their standard errors (element "se.fit") if the se.fit 
option is TRUE. 
}

\seealso{
\code{\link{predict}},\code{\link{coxph}},\code{\link{termplot}} }

\examples{
fit <- coxph(Surv(time, status) ~ age + ph.ecog + strata(inst), lung) 
mresid <- lung$status - predict(fit, type='expected') #Martingale resid 
predict(fit,type="lp")
predict(fit,type="risk")
predict(fit,type="expected")
predict(fit,type="terms")
predict(fit,type="lp",se.fit=TRUE)
predict(fit,type="risk",se.fit=TRUE)
predict(fit,type="expected",se.fit=TRUE)
predict(fit,type="terms",se.fit=TRUE)
}
\keyword{survival}
\eof
% --- Source file: predict.survreg.Rd ---
\name{predict.survreg}
\alias{predict.survreg}
\alias{predict.survreg.penal}
\title{
  Predicted Values for a `survreg' Object
}
\description{
Predicted values for a \code{survreg} object 
}
\usage{
\method{predict}{survreg}(object, newdata,  
type=c("response", "link", "lp", "linear", "terms", "quantile",  
	"uquantile"),  
 se.fit=FALSE, terms=NULL, p=c(0.1, 0.9),...)
}
\arguments{
\item{object}{
result of a model fit using the \code{survreg} function. 
}
\item{newdata}{
data for prediction.  If absent predictions are for the 
subjects used in the original fit. 
}
\item{type}{
the type of predicted value.  
This can be on the original scale of the data (response), 
the linear predictor (\code{"linear"}, with \code{"lp"} as an allowed abbreviation), 
a predicted quantile on the original scale of the data (\code{"quantile"}), 
a quantile on the linear predictor scale (\code{"uquantile"}),
or the matrix of terms for the linear predictor (\code{"terms"}).
At this time \code{"link"} and linear predictor (\code{"lp"}) are identical. 
}
\item{se.fit}{
if \code{TRUE}, include the standard errors of the prediction in the result. 
}
\item{terms}{
subset of terms.  The default for residual type \code{"terms"} is a matrix with 
one column for every term (excluding the intercept) in the model. 
}
\item{p}{
vector of percentiles.  This is used only for quantile predictions. 
}
\item{\dots}{for future methods}
}
\value{
a vector or matrix of predicted values. 
}
\references{
Escobar and Meeker (1992). Assessing influence in regression analysis with 
censored data. \emph{Biometrics,} 48, 507-528. 
}
\seealso{
\code{\link{survreg}},  \code{\link{residuals.survreg}}   
}
\examples{
# Draw figure 1 from Escobar and Meeker
fit <- survreg(Surv(time,status) ~ age + age^2, data=stanford2, 
	dist='lognormal') 
plot(stanford2$age, stanford2$time, xlab='Age', ylab='Days', 
	xlim=c(0,65), ylim=c(.01, 10^6), log='y') 
pred <- predict(fit, newdata=list(age=1:65), type='quantile', 
	         p=c(.1, .5, .9)) 
matlines(1:65, pred, lty=c(2,1,2), col=1) 

# Predicted Weibull survival curve for a lung cancer subject with
#  ECOG score of 2
lfit <- survreg(Surv(time, status) ~ ph.ecog, data=lung)
pct <- 1:98/100   # The 100th percentile of predicted survival is at +infinity
ptime <- predict(lfit, newdata=data.frame(ph.ecog=2), type='quantile',
                 p=pct, se=TRUE)
matplot(cbind(ptime$fit, ptime$fit + 2*ptime$se.fit,
                         ptime$fit - 2*ptime$se.fit)/30.5, 1-pct,
        xlab="Months", ylab="Survival", type='l', lty=c(1,2,2), col=1)
}
\keyword{survival}
\eof
% --- Source file: print.aareg.Rd ---
\name{print.aareg}
\alias{print.aareg}
\title{
  Print an aareg object
}
\description{
Print out a fit of Aalen's additive regression model
}
\usage{
\method{print}{aareg}(x, maxtime, test=c("aalen", "nrisk"),scale=1,...)
}
\arguments{
\item{x}{
the result of a call to the \code{aareg} function
}
\item{maxtime}{
the upper time point to be used in the test for non-zero slope
}
\item{test}{
the weighting to be used in the test for non-zero slope.
The default weights are based on the variance of each coefficient, as
a function of time.  The alternative weight is proportional to the number
of subjects still at risk at each time point.
}
\item{scale}{scales the coefficients.  
For some data sets, the coefficients of the Aalen model will be very
small (10-4); this simply multiplies the printed values by a constant,
say 1e6, to make the printout easier to read.}
\item{\dots}{for future methods}
}
\value{
the calling argument is returned.
}
\section{Side Effects}{
the results of the fit are displayed.
}
\details{
The estimated increments in the coefficient estimates can become quite
unstable near the end of follow-up, due to the small number of observations
still at risk in a data set.
Thus, the test for slope will sometimes be more powerful if this last
`tail' is excluded.
}
\section{References}{
Aalen, O.O. (1989). A linear regression model for the analysis of life times.
Statistics in Medicine, 8:907-925.
}
\seealso{
aareg
}
\keyword{survival}
% docclass is function
% Converted by Sd2Rd version 37351.
\eof
% --- Source file: print.summary.coxph.Rd ---
\name{print.summary.coxph}
\alias{print.summary.coxph}
\title{
  Print method for summary.coxph objects
}
\description{
  Produces a printed summary of a fitted coxph model 
}
\usage{
\method{print}{summary.coxph}(x, digits=max(getOption("digits") - 3, 3),
signif.stars = getOption("show.signif.stars"), ...)
}
\arguments{
  \item{x}{
    the result of a call to \code{summary.coxph} 
  }
  \item{digits}{significant digits to print}
  \item{signif.stars}{
    Show stars to highlight small p-values
  }
  \item{\dots}{For future methods}
}
\eof
% --- Source file: print.summary.survfit.Rd ---
\name{print.summary.survfit}
\alias{print.summary.survfit}
\title{
  Print Survfit Summary 
}
\description{
Prints the result of \code{summary.survfit}. 
}
\usage{
\method{print}{summary.survfit}(x, digits = max(options() $digits-4, 3), ...)
}
\arguments{
\item{x}{
an object of class \code{"summary.survfit"}, which is the result of the 
\code{summary.survfit} function. 
}
\item{digits}{
the number of digits to use in printing the numbers. 
}
  \item{\dots}{for future methods}
}
\value{
\code{x}, with the invisible flag set to prevent printing. 
}
\section{Side Effects}{
prints the summary created by \code{summary.survfit}. 
}
\seealso{
\code{\link{options}},  \code{\link{print}},  \code{\link{summary.survfit}}.   
}
\keyword{print}
% docclass is function
% Converted by Sd2Rd version 37351.
\eof
% --- Source file: print.survfit.Rd ---
\name{print.survfit}
\alias{print.survfit}
\title{
  Print a Short Summary of a Survival Curve 
}
\description{
  Print number of observations, number of events, the restricted
  mean survival and its  
standard error, and the median survival with confidence limits for the  
median. 
}
\usage{
\method{print}{survfit}(x, scale=1, digits = max(options()$digits - 4,3),
    print.rmean=getOption("survfit.print.rmean"),
    rmean = getOption('survfit.rmean'),...)
}
\arguments{
\item{x}{
the result of a call to the \code{survfit} function. 
}
\item{scale}{
a numeric value to rescale the survival time, e.g., 
if the input data to survfit were in days, 
\code{scale=365} would scale the printout to years. 
}
\item{digits}{Number of digits to print}
\item{print.rmean,rmean}{Options for computation and display of the
  restricted mean.}
\item{\dots}{for future results}
}
\value{
x, with the invisible flag set to prevent printing. 
}
\section{Side Effects}{
he number of observations, the number of events,  the median survival
with its confidence interval, and optionally the
restricted mean survival (\code{rmean}) and its standard error, are printed.
If there are multiple curves, there is one line of output for each. 
}
\details{
The mean and its variance are based on a truncated estimator.  That is, if the 
last observation(s) is not a death, then the survival curve estimate does not 
go to zero and the mean is undefined.
There are four possible approaches, which are selected by the
\code{rmean} option.
The first is to set the upper limit to a constant, e.g.,\code{rmean=365}.
In this case the reported mean would be the expected number of days, out
of the first 365, that would be experienced by each group.  This is
useful if interest focuses on a fixed period.
Other options are \code{"none"} (no estimate), \code{"common"} and
\code{"individual"}.
For the last of these, the mean is computed as the area under the curve,
over the
range from 0 to the maximum observed time for that curve.
Since the end point is random, values for different curves are not
comparable and the printed standard errors are an underestimate as
they do not take into account this random variation.  This option is
provided mainly for backwards compatability, as this estimate was the
default (only) one in earlier releases of the code.
The \code{"common"} option uses the maximum time for all curves in the
object as a common upper limit for the auc calculation.


The median and its confidence interval are defined by drawing a horizontal 
line at 0.5 on the plot of the survival curve and its confidence bands. 
The intersection of the line with the lower CI band defines the lower limit 
for the median's interval, and similarly for the upper band.  If any of the 
intersections is not a point, then we use the smallest point of intersection, 
e.g., if the survival curve were exactly equal to 0.5 over an interval. 
}
\section{References}{
Miller, Rupert G., Jr. (1981).  
\emph{Survival Analysis.}
New York:Wiley, p 71. 
}
\seealso{
\code{\link{summary.survfit}}. 
}
\keyword{survival}
% docclass is function
% Converted by Sd2Rd version 37351.
\eof
% --- Source file: pspline.Rd ---
\name{pspline}
\alias{pspline}
\title{Smoothing splines using a pspline basis}
\usage{
pspline(x, df=4, theta, nterm=2.5 * df, degree=3, eps=0.1, method, ...)
}
\arguments{
  \item{x}{predictor.  The function does not apply to factor variables.}
  \item{df}{the desired degrees of freedom.
    One of the arguments \code{df} or \code{theta}' must be given, but not both.
    If \code{df=0}, then the AIC = (loglik -df) is used to choose an
    "optimal" degrees of freedom.  If AIC is chosen, then an optional
    argument `caic=T' can be used to specify the corrected AIC of
    Hurvich et. al.
  }
  \item{theta}{roughness penalty for the fit.
    It is a monotone function of the degrees of freedom, with theta=1
    corresponding to a linear fit and theta=0 to an unconstrained fit
    of nterm degrees of freedom.
  }
  \item{nterm}{ number of splines in the basis }
  \item{degree}{ degree of splines }
  \item{eps}{accuracy for \code{df} }
  \item{method}{the method for choosing the tuning parameter \code{theta}.
    If theta is given, then 'fixed' is assumed.
    If the degrees of freedom is given, then 'df' is assumed.
    If method='aic' then the degrees of freedom is chosen automatically using
    Akaike's information criterion.}
  \item{\dots}{optional arguments to the control function}
  }
\description{
    Specifies a penalised spline basis for the predictor.
    This is done by fitting a comparatively small set of splines and
    penalising the integrated second derivative.
    Traditional smoothing splines use one basis per observation, but several
    authors have pointed out that the final results of the fit are 
    indistinguishable for any number of basis functions greater than about 
    2-3 times the degrees of freedom. 
    Eilers and Marx point out that if the basis functions are evenly spaced,
    this leads to significant computational simplifications.
}

\value{
  Object of class \code{coxph.penalty} containing the spline basis,
 with the appropriate attributes to be
recognized as a penalized term by the coxph or survreg functions.
}

\seealso{\code{\link{coxph}},\code{\link{survreg}},\code{\link{ridge}},
  \code{\link{frailty}}
}
\references{
Eilers, Paul H. and Marx, Brian D. (1996).
Flexible smoothing with B-splines and penalties.
    Statistical Science, 11, 89-121.

Hurvich, C.M. and Simonoff, J.S. and Tsai, Chih-Ling (1998).
Smoothing parameter selection in nonparametric regression using
        an improved Akaike information criterion,
JRSSB, volume 60, 271--293.
}    
\examples{
lfit6 <- survreg(Surv(time, status)~pspline(age, df=2), cancer)
plot(cancer$age, predict(lfit6), xlab='Age', ylab="Spline prediction")
title("Cancer Data")
fit0 <- coxph(Surv(time, status) ~ ph.ecog + age, cancer)
fit1 <- coxph(Surv(time, status) ~ ph.ecog + pspline(age,3), cancer)
fit3 <- coxph(Surv(time, status) ~ ph.ecog + pspline(age,8), cancer)
fit0
fit1
fit3
}
\keyword{ survival}

\eof
% --- Source file: pyears.Rd ---
\name{pyears}
\alias{pyears}
\title{
  Person Years 
}
\description{
This function computes the person-years of follow-up time contributed by a 
cohort of subjects, stratified into subgroups. 
It also computes the number of subjects who contribute to each cell of the 
output table, and optionally the number of events and/or expected number of 
events in each cell. 
}
\usage{
pyears(formula, data, weights, subset, na.action,  
       ratetable=survexp.us, scale=365.25, expect=c('event', 'pyears'),
       model=FALSE, x=FALSE, y=FALSE, data.frame=FALSE)
}
\arguments{
  \item{formula}{
    a formula object. 
    The response variable will be a vector of follow-up times 
    for each subject, or a \code{Surv} object containing the survival
    time and an event indicator. 
    The predictors consist of optional grouping variables 
    separated by + operators (exactly as in \code{survfit}),
    time-dependent grouping 
    variables such as age (specified with \code{tcut}), and optionally a 
    \code{ratetable} term. 
    This latter matches each subject to his/her expected cohort. 
  }
  \item{data}{
    a data frame in which to interpret the variables named in 
    the \code{formula}, or in the \code{subset} and the \code{weights}
    argument. 
  }
  \item{weights}{
    case weights. 
  }
  \item{subset}{
    expression saying that only a subset of the rows of the data 
    should be used in the fit. 
  }
  \item{na.action}{
    a missing-data filter function, applied to the model.frame, after any 
    \code{subset} argument has been used.  Default is \code{options()$na.action}. 
  }
  \item{ratetable}{
    a table of event rates, such as \code{survexp.uswhite}. 
  }
  \item{scale}{
    a scaling for the results.  As most rate tables are in units/day, the 
    default value of 365.25 causes the output to be reported in years. 
  }
  \item{expect}{
    should the output table include the expected number of events, or the
    expected number of person-years of observation.  This is only valid with
    a rate table.
  }
  \item{data.frame}{
    return a data frame rather than a set of arrays.}
  \item{model, x, y}{
    If any of these is true, then the
    model frame, the model matrix, and/or the vector of response times will be
    returned as components of the final result.
  }
}
\value{
a list with components: 

\item{pyears}{
an array containing the person-years of exposure. (Or other units, depending 
on the rate table and the scale).
The dimension and dimmanes of the array correspond to the variables on
the right hand side of the model equation.
}
\item{n}{
an array containing the number of subjects who contribute time to each cell 
of the \code{pyears} array. 
}
\item{event}{
an array containing the observed number of events.  This will be present only 
if the response variable is a \code{Surv} object. 
}
\item{expected}{
an array containing the expected number of events (or person years if 
\code{expect ="pyears"}).  This will be present only if there was a 
\code{ratetable} term. 
}
\item{data}{
if the \code{data.frame} option was set, a data frame containing the
variables \code{n}, \code{event}, \code{pyears} and \code{event} that
supplants the four arrays listed above,
along with variables corresponding to each dimension.
There will be one row for each cell in the arrays.}
\item{offtable}{
the number of person-years of exposure in the cohort that was not part of 
any cell in the \code{pyears} array.  This is often useful as an error check;
if 
there is a mismatch of units between two variables, nearly all the person 
years may be off table. 
}
\item{summary}{
a summary of the rate-table matching. This is also useful as an error 
check. 
}
\item{call}{
an image of the call to the function. 
}
\item{na.action}{
the \code{na.action} attribute contributed by an \code{na.action}
routine, if any. 
}
}
\details{
Because \code{pyears} may have several time variables, it is necessary that all 
of them be in the same units.  For instance, in the call 
\preformatted{
 py <- pyears(futime ~ rx + ratetable(age=age, sex=sex, year=entry.dt)) 
}
with a ratetable whose natural unit is days, it is important that
\code{futime}, 
\code{age} and \code{entry.dt} all be in days. 
Given the wide range of possible inputs, 
it is difficult for the routine to do sanity checks of this aspect. 

A special function \code{tcut} is needed to specify time-dependent cutpoints. 
For instance, assume that age is in years, and that the desired final 
arrays have as one of their margins the age groups 0-2, 2-10, 10-25, and 25+. 
A subject who enters the study at age 4 and remains under observation for 
10 years will contribute follow-up time to both the 2-10 and 10-25 
subsets.  If \code{cut(age, c(0,2,10,25,100))} were used in the formula, the 
subject would be classified according to his starting age only. 
The \code{tcut} function has the same arguments as \code{cut}, 
but produces a different output object which allows the \code{pyears} function 
to correctly track the subject. 

The results of \code{pyears} are normally used as input to further calculations. 
The \code{print} routine, therefore, is designed to give only a summary of the 
table. 

The example below is from a study of hip fracture rates from 1930 - 1990 
in Rochester, Minnesota.  Survival post hip fracture has increased over 
that time, but so has the survival of elderly subjects in the population 
at large.  A model of relative survival helps to clarify what has happened: 
Poisson regression is used, but replacing exposure time with expected 
exposure (for an age and sex matched control). 
Death rates change with age, of course, so the result is carved into 
1 year increments of time.  Males and females were done separately. 
}
\seealso{
\code{\link{ratetable}},  \code{\link{survexp}},  \code{\link{Surv}}.   
}
\examples{
# Look at progression rates jointly by calendar date and age
# 
temp.yr  <- tcut(mgus$dxyr, 55:92, labels=as.character(55:91)) 
temp.age <- tcut(mgus$age, 34:101, labels=as.character(34:100))
ptime <- ifelse(is.na(mgus$pctime), mgus$futime, mgus$pctime)
pstat <- ifelse(is.na(mgus$pctime), 0, 1)
pfit <- pyears(Surv(ptime/365.25, pstat) ~ temp.yr + temp.age + sex,  mgus,
     data.frame=TRUE) 
# Turn the factor back into numerics for regression
tdata <- pfit$data
tdata$age <- as.numeric(as.character(tdata$temp.age))
tdata$year<- as.numeric(as.character(tdata$temp.yr))
fit1 <- glm(event ~ year + age+ sex +offset(log(pyears)),
             data=tdata, family=poisson)
\dontrun{
# fit a gam model 
gfit.m <- gam(y ~ s(age) + s(year) + offset(log(time)),  
                        family = poisson, data = tdata) 
}

# Example #2  Create the hearta data frame: 
hearta <- by(heart, heart$id,  
             function(x)x[x$stop == max(x$stop),]) 
hearta <- do.call("rbind", hearta) 
# Produce pyears table of death rates on the surgical arm
#  The first is by age at randomization, the second by current age
fit1 <- pyears(Surv(stop/365.25, event) ~ cut(age + 48, c(0,50,60,70,100)) + 
       surgery, data = hearta, scale = 1)
fit2 <- pyears(Surv(stop/365.25, event) ~ tcut(age + 48, c(0,50,60,70,100)) + 
       surgery, data = hearta, scale = 1)
fit1$event/fit1$pyears  #death rates on the surgery and non-surg arm

fit2$event/fit2$pyears  #death rates on the surgery and non-surg arm
}
\keyword{survival}
\eof
% --- Source file: ratetable.Rd ---
\name{ratetable}
\alias{ratetable}
\alias{[.ratetable}
\alias{[.ratetable2}
\alias{print.ratetable}
\alias{is.na.ratetable}
\alias{summary.ratetable}
\title{Ratetable reference in formula}
\description{
This function matches variable names in data to those in a ratetable for
\code{\link{survexp}}
}
\usage{
ratetable(...)
}

\arguments{
  \item{\dots}{tags matching dimensions of the ratetable and variables
    in the data frame (see example)}
}

\value{
  A data frame
}

\seealso{\code{\link{survexp}},\code{\link{survexp.us}},\code{\link{is.ratetable}}}

\examples{

fit <- survfit(Surv(time, status) ~ sex, pbc,subset=1:312)

# The data set does not have entry date, use the midpoint of the study
efit <- survexp(~ ratetable(sex=sex,age=age*365.35,year=as.Date('1979/1/1')) +
            sex, data=pbc,  times=(0:24)*182)
\dontrun{
plot(fit, mark.time=F, xscale=365.25, xlab="Years post diagnosis",
        ylab="Survival")
lines(efit, col=2, xscale=365.25) # Add the expected survival line
}
}
\keyword{survival}%-- one or more ...
\eof
% --- Source file: rats.Rd ---
\name{rats}
\alias{rats}
\docType{data}
\title{Rat data from Gail et al.}
\description{48 rats were injected with a carcinogen, and then
  randomized to either drug or placebo.  The number of tumors ranges
  from 0 to 13; all rats were  censored at 6 months after randomization.
}
\usage{rats}
\format{
  \tabular{ll}{
    rat:\tab id\cr
    rx:\tab treatment,(1=drug, 0=control) \cr
    observation:\tab within rat\cr
    start:\tab entry time\cr
    stop:\tab exit time\cr
    status:\tab event status\cr
  }
}
\source{
  MH Gail, TJ Santner, and CC Brown (1980),
  An analysis of comparative carcinogenesis experiments based on
  multiple times to tumor.
  \emph{Biometrics} \bold{36}, 255--266.
}
\keyword{survival}
\keyword{datasets}
\eof
% --- Source file: residuals.coxph.Rd ---
\name{residuals.coxph}
\alias{residuals.coxph.penal}
\alias{residuals.coxph.null}
\alias{residuals.coxph}
\title{
Calculate Residuals for a `coxph' Fit
}
\description{
Calculates martingale, deviance, score or Schoenfeld residuals for a
Cox proportional hazards model.
}
\usage{
\method{residuals}{coxph}(object,
       type=c("martingale", "deviance", "score", "schoenfeld",
	      "dfbeta", "dfbetas", "scaledsch","partial"),
       collapse=FALSE, weighted=FALSE, ...)
\method{residuals}{coxph.null}(object,
       type=c("martingale", "deviance","score","schoenfeld"),
       collapse=FALSE, weighted=FALSE, ...)
}
\arguments{
\item{object}{
an object inheriting from class \code{coxph}, representing a fitted Cox
regression model.
Typically this is the output from the \code{coxph} function.
}
\item{type}{
character string indicating the type of residual desired.
Possible values are \code{"martingale"}, \code{"deviance"}, \code{"score"}, \code{"schoenfeld"},
"dfbeta"', \code{"dfbetas"}, and \code{"scaledsch"}.
Only enough of the string to determine a unique match is required.
}
\item{collapse}{
vector indicating which rows to collapse (sum) over.
In time-dependent models more than one row data can pertain
to a single individual.
If there were 4 individuals represented by 3, 1, 2 and 4 rows of data
respectively, then \code{collapse=c(1,1,1, 2, 3,3, 4,4,4,4)} could be used to
obtain per subject rather than per observation residuals.
}
\item{weighted}{
if \code{TRUE} and the model was fit with case weights, then the weighted
residuals are returned.
}\item{...}{other unused arguments}}
\value{
For martingale and deviance residuals, the returned object is a vector
with one element for each subject (without \code{collapse}).
For score residuals it is a matrix
with one row per subject and one column per variable.
The row order will match the input data for the original fit.
For Schoenfeld residuals, the returned object is a matrix with one row
for each event and one column per variable.  The rows are ordered by time
within strata, and an attribute \code{strata} is attached that contains the
number of observations in each strata.
The scaled Schoenfeld residuals are used in the \code{cox.zph} function.


The score residuals are each individual's contribution to the score vector.
Two transformations of
this are often more useful: \code{dfbeta} is the approximate change in the
coefficient vector if that observation were dropped,
and \code{dfbetas} is the approximate change in the coefficients, scaled by
the standard error for the coefficients.
}
\section{NOTE}{
For deviance residuals, the status variable may need to be reconstructed.
For score and Schoenfeld residuals, the X matrix will need to be reconstructed.
}
\references{
T. Therneau, P. Grambsch, and T. Fleming. "Martingale based residuals
for survival models", \emph{Biometrika}, March 1990.
}
\seealso{
\code{\link{coxph}}}
\examples{

 fit <- coxph(Surv(start, stop, event) ~ (age + surgery)* transplant,
               data=heart)
 mresid <- resid(fit, collapse=heart$id)
}
\keyword{survival}
% Converted by Sd2Rd version 0.3-2.
\eof
% --- Source file: residuals.survreg.Rd ---
\name{residuals.survreg}
\alias{residuals.survreg}
\alias{residuals.survreg.penal}
\title{Compute Residuals for `survreg' Objects}
\description{
This is a method for the function \code{\link{residuals}} for objects
inheriting from class \code{survreg}.  
}
\usage{
\method{residuals}{survreg}(object, type=c("response", "deviance","dfbeta","dfbetas",
"working","ldcase","ldresp","ldshape", "matrix"), rsigma=TRUE,
collapse=FALSE, weighted=FALSE, ...)
}
\arguments{
\item{object}{
an object inheriting from class \code{survreg}.
}
\item{type}{
type of residuals, with choices of \code{"response"}, \code{"deviance"},
\code{"dfbeta"}, \code{"dfbetas"}, \code{"working"}, \code{"ldcase"}, \code{"lsresp"},
\code{"ldshape"}, and \code{"matrix"}.  See the LaTeX documentation
(\code{survival/doc/survival.ps.gz}) for more
detail.
}
\item{rsigma}{
include the scale parameters in the variance matrix, when doing computations.
(I can think of no good reason not to).
}
\item{collapse}{
optional vector of subject groups.  If given, this must be of the same
length as the residuals, and causes the result to be per group residuals.
}
\item{weighted}{
give weighted residuals?  Normally residuals are unweighted.
}\item{...}{other unused arguments}}
\value{
A vector or matrix of residuals is returned.
Response residuals are on the scale of the original data,
working residuals are on the scale of the linear predictor,
and deviance residuals are on log-likelihood scale.
The dfbeta residuals are a matrix, where the ith row gives the
approximate change in the coefficients due to the addition of subject i.
The dfbetas matrix contains the dfbeta residuals, with each column
scaled by the standard deviation of that coefficient.


The matrix type produces a matrix based on derivatives of the log-likelihood
function.  Let \eqn{L} be the log-likelihood, \eqn{p} be the linear predictor \eqn{X\beta}{X \%*\% coef},
and \eqn{s} be \eqn{\log(\sigma)}.  Then the 6 columns of the matrix are
\eqn{L}, \eqn{dL/dp},\eqn{\partial^2L/\partial p^2}{ddL/(dp dp)},
\eqn{dL/ds}, \eqn{\partial^2L/\partial s^2}{ddL/(ds ds)}  and
\eqn{\partial^2L/\partial p\partial s}{ddL/(dp ds)}.  Diagnostics based on these quantities
are discussed in an article by Escobar and Meeker.
The main ones are the likelihood displacement residuals for perturbation
of a case weight (\code{ldcase}), the response value (\code{ldresp}), and the \code{shape}.
}
\references{
Escobar, L. A. and Meeker, W. Q. (1992).
Assessing influence in regression analysis with censored data.
\emph{Biometrics}
\bold{48}, 507-528.
}
\seealso{\code{\link{predict.survreg}}}
\examples{
fit <- survreg(Surv(time,status) ~x, aml)
rr  <- residuals(fit, type='matrix')
}
\keyword{survival}
% Converted by Sd2Rd version 0.3-2.
\eof
% --- Source file: ridge.Rd ---
\name{ridge}
\alias{ridge}
\title{ Ridge regression}
\usage{
ridge(..., theta, df=nvar/2, eps=0.1, scale=TRUE)
}
\arguments{
 \item{\dots}{predictors to be ridged }
 \item{theta}{penalty is \code{theta}/2 time sum of squared coefficients }
 \item{df}{Approximate degrees of freedom }
 \item{eps}{ Accuracy required for \code{df} }
 \item{scale}{ Scale variables before applying penalty? }
}
\description{
 When used in a \link{coxph} or \link{survreg} model formula,
specifies a ridge regression term.  The likelihood is penalised by
\code{theta}/2 time the sum of squared coefficients. If \code{scale=T}
the penalty is calculated for coefficients based on rescaling the
predictors to have unit variance. If \code{df} is specified then \code{theta} is chosen based on an approximate degrees of freedom.
 } 

\value{
 An object of class \code{coxph.penalty} containing the data and
control functions.  } 

\references{
Gray (1992) "Flexible methods of analysing survival data using splines, with applications to breast cancer prognosis" JASA 87:942--951
 }

\seealso{ \code{\link{coxph}},\code{\link{survreg}},\code{\link{pspline}},\code{\link{frailty}} }

\examples{

fit1 <- coxph(Surv(futime, fustat) ~ rx + ridge(age, ecog.ps, theta=1),
	      ovarian)
fit1

lfit0 <- survreg(Surv(time, status) ~1, cancer)
lfit1 <- survreg(Surv(time, status) ~ age + ridge(ph.ecog, theta=5), cancer)
lfit2 <- survreg(Surv(time, status) ~ sex + ridge(age, ph.ecog, theta=1), cancer)
lfit3 <- survreg(Surv(time, status) ~ sex + age + ph.ecog, cancer)

lfit0
lfit1
lfit2
lfit3
}
\keyword{survival }%-- one or more ...
\eof
% --- Source file: stanford2.Rd ---
\name{stanford2}
\alias{stanford2}
\docType{data}
\title{More Stanford Heart Transplant data}
\description{
  This contains the Stanford Heart Transplant data in a different
  format.  The main data set is in \code{\link{heart}}.
}
\usage{stanford2}
\format{
  \tabular{ll}{
    id:  \tab ID number\cr
    time:\tab survival or censoring time\cr
    status:\tab censoring status\cr
    age: \tab in years\cr
    t5: \tab T5 mismatch score\cr
  }
}
\seealso{
  \code{\link{predict.survreg}},
  \code{\link{heart}}
}
\source{
  LA Escobar and WQ Meeker Jr (1992),
  Assessing influence in regression analysis with censored data.
  \emph{Biometrics} \bold{48}, 507--528.
  Page 519.
}
\keyword{datasets}
\keyword{survival}
\eof
% --- Source file: strata.Rd ---
\name{strata}
\alias{strata}
\title{
  Identify Stratification Variables 
}
\description{
This is a special function used in the context of the Cox survival model. 
It identifies stratification variables when they appear on the right hand 
side of a formula. 
}
\usage{
strata(..., na.group=FALSE, shortlabel=FALSE, sep=', ')
}
\arguments{
\item{\dots}{
any number of variables.  All must be the same length. 
}
\item{na.group}{
a logical variable, if \code{TRUE}, then missing values are treated as a 
distinct level of each variable. 
}
\item{shortlabel}{if \code{TRUE} omit variable names from resulting
  factor labels}
\item{sep}{
the character used to separate groups, in the created label
}
}
\value{
a new factor, whose levels are all possible combinations of the factors 
supplied as arguments. 
}
\details{
The result is identical to the \code{interaction} function, 
but for the labeling of the factors (\code{strata} is more verbose). 
}
\seealso{
\code{\link{coxph}}, \code{\link{interaction}}
}
\examples{
a<-factor(rep(1:3,4))
b<-factor(rep(1:4,3))
levels(strata(a))
levels(strata(a,b,shortlabel=TRUE))

coxph(Surv(futime, fustat) ~ age + strata(rx), data=ovarian) 
}
\keyword{survival}
\eof
% --- Source file: summary.aareg.Rd ---
\name{summary.aareg}
\alias{summary.aareg}
\title{
  Summarize an aareg fit
}
\description{
Creates the overall test statistics for an Aalen additive regression model
}
\usage{
\method{summary}{aareg}(object, maxtime, test=c("aalen", "nrisk"), scale=1,...)
}
\arguments{
\item{object}{
the result of a call to the \code{aareg} function
}
\item{maxtime}{
truncate the input to the model at time "maxtime"
}
\item{test}{
the relative time weights that will be used to compute the test
}
\item{scale}{
scales the coefficients.  
For some data sets, the coefficients of the Aalen model will be very
small (10-4); this simply multiplies the printed values by a constant,
say 1e6, to make the printout easier to read.
}
\item{\dots}{for future methods}
}
\value{
a list is returned with the following components

\item{ table }{
a matrix with rows for the intercept and each covariate, and columns
giving a slope estimate, the test statistic, it's standard error,
the z-score and a p-value
}
\item{ test }{
the time weighting used for computing the test statistics
}
\item{ test.statistic }{
the vector of test statistics
}
\item{ test.var }{
the model based variance matrix for the test statistic
}
\item{ test.var2 }{
optionally, a robust variance matrix for the test statistic
}
\item{ chisq }{
the overall test (ignoring the intercept term) for significance of
any variable
}
\item{ n }{
a vector containing the number of observations, the number of unique death
times used in the computation, and the total number of unique death times
}
}
\details{
It is not uncommon for the very right-hand tail of the plot to have
large outlying values, particularly for the standard error.  
The \code{maxtime} parameter can then be used to
truncate the range so as to avoid these.
This gives an updated value for the test statistics, without refitting the
model.
}
\seealso{
aareg, plot.aareg
}
\examples{
afit <- aareg(Surv(time, status) ~ age + sex + ph.ecog, data=lung,
     dfbeta=TRUE)
summary(afit)
\dontrun{
              slope   test se(test) robust se     z        p 
Intercept  5.05e-03    1.9     1.54      1.55  1.23 0.219000
      age  4.01e-05  108.0   109.00    106.00  1.02 0.307000
      sex -3.16e-03  -19.5     5.90      5.95 -3.28 0.001030
  ph.ecog  3.01e-03   33.2     9.18      9.17  3.62 0.000299

Chisq=22.84 on 3 df, p=4.4e-05; test weights=aalen
}

summary(afit, maxtime=600)
\dontrun{
              slope   test se(test) robust se      z        p 
Intercept  4.16e-03   2.13     1.48      1.47  1.450 0.146000
      age  2.82e-05  85.80   106.00    100.00  0.857 0.392000
      sex -2.54e-03 -20.60     5.61      5.63 -3.660 0.000256
  ph.ecog  2.47e-03  31.60     8.91      8.67  3.640 0.000271

Chisq=27.08 on 3 df, p=5.7e-06; test weights=aalen
}}
\keyword{survival}

\eof
% --- Source file: summary.coxph.Rd ---
\name{summary.coxph}
\alias{summary.coxph}
\title{
  Summary method for Cox models 
}
\description{
Produces a summary of a fitted coxph model 
}
\usage{
\method{summary}{coxph}(object, conf.int=0.95, scale=1,...)
}
\arguments{
  \item{object}{
    the result of a coxph fit 
  }
  \item{conf.int}{
    level for computation of the confidence intervals. 
    If set to FALSE no confidence intervals are printed 
  }
  \item{scale}{
    vector of scale factors for the coefficients, defaults to 1. 
    The confidence limits are for the risk change associated with one scale unit. 
  }
  \item{\dots}{for future methods}
}
\value{
An object of class \code{summary.coxph}. 
}
\seealso{
  coxph, print.coxph  
}
\examples{
fit <- coxph(Surv(time, status) ~ age + sex, lung) 
summary(fit) 
\dontrun{
Call: 
coxph(formula = Surv(time, status) ~ age + sex, data = lung) 
  
  n= 228  
  
      coef exp(coef) se(coef)     z      p  
age  0.017     1.017  0.00922  1.85 0.0650 
sex -0.513     0.599  0.16745 -3.06 0.0022 
  
    exp(coef) exp(-coef) lower .95 upper .95  
age     1.017      0.983     0.999     1.036 
sex     0.599      1.670     0.431     0.831 
  
Rsquare= 0.06   (max possible= 0.999 ) 
Likelihood ratio test= 14.1  on 2 df,   p=0.000857 
Wald test            = 13.5  on 2 df,   p=0.00119 
Score (logrank) test = 13.7  on 2 df,   p=0.00105 
}}
\keyword{survival}
% docclass is function
% Converted by Sd2Rd version 37351.
\eof
% --- Source file: summary.survfit.Rd ---
\name{summary.survfit}
\alias{summary.survfit}
\title{
  Summary of a Survival Curve 
}
\description{
  Returns a list containing the survival curve, confidence limits for the 
  curve, and other information. 
}

\usage{
  \method{summary}{survfit}(object, times=, censored=FALSE, scale=1,
  extend=FALSE, rmean=getOption('survfit.rmean'), ...)
  }
\arguments{
    \item{object}{
      the result of a call to the \code{survfit} function. 
    }
    \item{times}{
    vector of times; 
    the returned matrix will contain 1 row for each time. 
    This must be in increasing order and missing values are not allowed. 
    If \code{censored=T}, the default \code{times} vector contains all
    the unique times in \code{fit}, otherwise
    the default \code{times} vector uses only the event (death) times. 
    }
    \item{censored}{
    logical value:  should the censoring times be included in the output?
    This is ignored if the \code{times} argument is present. 
    }
    \item{scale}{
    numeric value to rescale the survival time, e.g., if the input data to 
    \code{survfit} were in 
    days, \code{scale = 365.25} would scale the output to years. 
    }
    \item{extend}{
    logical value: if TRUE, prints information for all specified \code{times}, 
    even if there are no subjects left at the end of the specified
    \code{times}. 
    This is only valid if the \code{times} argument is present. 
  }
  \item{rmean}{Show restricted mean: see
  \code{\link{print.summary.survfit}} for details}
  \item{\dots}{for future methods}
  }

\value{
a list with the following components: 

\item{surv}{
the estimate of survival at time t+0. 
}
\item{time}{
the timepoints on the curve. 
}
\item{n.risk}{
the number of subjects at risk at time t-0 
(but see the comments on weights in the \code{survfit} help file). 
}
\item{n.event}{
if the \code{times} argument is missing, then this column is the number of 
events that occurred at time t. 
Otherwise, it is the cumulative number of events that have occurred 
since the last time listed until time t+0. 
}
\item{n.entered}{
This is present only for counting process survival data.
If the \code{times} argument is 
missing, this column is the number of subjects that entered at time t. 
Otherwise, it is the cumulative number of subjects that have entered 
since the last time listed until time t.  
}
\item{n.exit.censored}{

if the \code{times} argument is 
missing, this column is the number of subjects that left without an 
event at time t. 
Otherwise, it is the cumulative number of subjects that have left 
without an event 
since the last time listed until time t+0.  
This is only present for counting process survival data.
}
\item{std.err}{
the standard error of the survival value. 
}
\item{conf.int}{
level of confidence for the confidence intervals of survival. 
}
\item{lower}{
lower confidence limits for the curve. 
}
\item{upper}{
upper confidence limits for the curve. 
}
\item{strata}{
indicates stratification of curve estimation.  
If \code{strata} is not \code{NULL}, 
there are multiple curves in the result and the \code{surv}, \code{time}, \code{n.risk}, etc.  
vectors will contain multiple curves, pasted end to end.  
The levels of \code{strata} (a factor) are the labels for the curves. 
}
\item{call}{
the statement used to create the \code{fit} object. 
}
\item{na.action}{
same as for \code{fit}, if present. 
}
\item{table}{
table of information that is returned from \code{print.survfit} function. 
}
\item{type}{
type of data censoring.  Passed through from the fit object. 
}
}
\seealso{
\code{\link{survfit}},  \code{\link{print.summary.survfit}}   
}
\examples{
summary( survfit( Surv(futime, fustat)~1, data=ovarian))
summary( survfit( Surv(futime, fustat)~rx, data=ovarian))
}
\keyword{survival}
\eof
% --- Source file: survConcordance.Rd ---
\name{survConcordance}
\alias{survConcordance}
\title{
  Compute a concordance measure.
}
\description{
This function computes the concordance between a right-censored
survival time and a single continuous covariate
}
\usage{
survConcordance(formula, data, weights, subset, na.action)
}
\arguments{
\item{formula}{
a formula with a survival time on the left and a single covariate on the
right.
}
\item{data}{
a data frame
}
\item{weights,subset,na.action}{as for \code{coxph}}
}
\value{
an object containing the concordance, followed by the
number of pairs that agree, disagree, are tied, and are
not comparable.  
}
\details{
Concordance is defined as Pr(agreement) for any two randomly chosen
observations, where in this case agreement means that the observation
with the shorter survival time of the two 
also has the larger risk score.
The predictor (or risk score) will often be the result of
a Cox model or other regression.

For continuous covariates concordance is equivalent to Kendall's tau,
and for logistic regression is is equivalent to the area under the ROC
curve.  A value of 1 signifies perfect agreement, .6-.7 
a common result for survival data, .5 an agreement that is no
better than chance, and .3-.4 the performace of some stock market analysts.

The computation involves all n(n-1)/2 pairs of data points in the sample.
For survival data, however, some of the pairs are incomparable.  
For instance a pair of times (5+, 8), the first being a censored value.
We do not know whether the first survival time is greater than or less than
the second.
Among observations that are comparable, pairs may also be tied on
survival time (but only if both are uncensored) or on the predictor.
The final concondance is (agree + tied/2)/(agree + disagree + tied).

There is, unfortunately, one aspect of the formula above that is unclear.
Should the count of ties include observations that are tied on survival time y,
tied on the predictor x, or both?
In 2 by 2 tables, Kendall's tau-b is equal to (agree - disagree)/ n,
where n is the geometric mean of (agree + disagree + tied.x) and
(agree + disagree + tied.y).  The Goodman-Kruskal Gamma statistic is
(agree-disagree)/(agree + disagree), ignoring ties.  It ranges from -1 to 
+1 similar to a correlation coefficient. 

In this program we count those observations which were tied on x, but not
tied on y (survival time), as `ties'.  All of the components are returned
in the result, however, so people can compute other combinations if interested.
(If two observations have the same survival and the same x, they are counted
in the tied.time category).  
}
\seealso{
summary.coxph
}
\examples{
survConcordance(Surv(time, status) ~age, data=lung)
\dontrun{
  n= 228 
Concordance= 0.5501899 , Gamma= 0.1034234 
 agree disagree tied.x tied.time incomparable 
 10717     8708    589        28         5836
}

options(na.action=na.exclude)
fit <- coxph(Surv(time, status) ~ ph.ecog + age + sex, lung)
survConcordance(Surv(time, status) ~predict(fit), lung)
\dontrun{
  n=227 (1 observations deleted due to missing values)
Concordance= 0.6371102 , Gamma= 0.2759638 
 agree disagree tied.x tied.time incomparable 
 12544     7118    125        28         5836
}}
\keyword{survival}
% docclass is function
% Converted by Sd2Rd version 37351.
\eof
% --- Source file: survSplit.Rd ---
\name{survSplit}
\alias{survSplit}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Split a survival data set at specified times }
\description{
  Given a survival data set and a set of specified cut times, split
  each record into multiple subrecords at each cut time.  The new data
  set will be in `counting process' format, with a start time, stop
  time, and event status for each record. 
}
\usage{
survSplit(data, cut, end, event, start, id = NULL, zero = 0,
  episode=NULL)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{data}{data frame}
  \item{cut}{vector of timepoints to cut at}
  \item{end}{character string with name of event time variable }
  \item{event}{character string with name of censoring indicator }
  \item{start}{character string with name of start time variable (will
    be created if it does not exist) }
  \item{id}{character string with name of new id variable to create (optional)}
  \item{zero}{If \code{start} doesn't already exist, this is the time
    that the original records start. May be a vector or single value.}
  \item{episode}{character string with name of new episode variable (optional)}
}

\value{
 New, longer, data frame.
}

\details{
  The function also works when the original data are in
  counting-process format, but the \code{id} and \code{episode} options
  are of little use in this context.
 
  }

\seealso{\code{\link{Surv}}, \code{\link{cut}}, \code{\link{reshape}} }

\examples{
aml3<-survSplit(aml,cut=c(5,10,50),end="time",start="start",
      event="status",episode="i")

summary(aml)
summary(aml3)

coxph(Surv(time,status)~x,data=aml)
## the same
coxph(Surv(start,time,status)~x,data=aml3)

aml4<-survSplit(aml3,cut=20,end="time",start="start", event="status")
coxph(Surv(start,time,status)~x,data=aml4)

}
\keyword{survival }% at least one, from doc/KEYWORDS
\keyword{utilities}% __ONLY ONE__ keyword per line
\eof
% --- Source file: survdiff.Rd ---
\name{survdiff}
\alias{survdiff}
\alias{print.survdiff}
\title{
Test Survival Curve Differences
}
\description{
Tests if there is a difference between two or more survival curves using
the \eqn{G^\rho}{G-rho} family of tests, or for a single curve against a known alternative.
}
\usage{
survdiff(formula, data, subset, na.action, rho=0)
}
\arguments{
\item{formula}{
a formula expression as for other survival models, of the form
\code{Surv(time, status) ~ predictors}.  For a one-sample test, the predictors
must consist of a single \code{offset(sp)} term, where \code{sp} is a vector giving the
survival probability of each subject.  For a k-sample test, each unique
combination of predictors defines a subgroup.
A \code{strata} term may be used to produce a stratified test.
To cause missing values in the predictors to be treated as a separate
group, rather than being omitted, use the \code{strata} function with its
\code{na.group=T} argument.
}
\item{data}{
an optional data frame in which to interpret the variables occurring in the
formula.
}
\item{subset}{
expression indicating which subset of the rows of data should be used in
the fit.  This can be a logical vector (which is replicated to have
length equal to the number of observations), a numeric vector indicating
which observation numbers are to be included (or excluded if negative),
or a character vector of row names to be included.  All observations are
included by default.
}
\item{na.action}{
a missing-data filter function.  This is applied to the \code{model.frame} after any
subset argument has been used.  Default is \code{options()$na.action}.
}
\item{rho}{
a scalar parameter that controls the type of test.
}}
\value{
a list with components:

\item{n}{
the number of subjects in each group.
}
\item{obs}{
the weighted observed number of events in each group.
If there are strata, this will be a matrix with one column per stratum.
}
\item{exp}{
the weighted expected number of events in each group.
If there are strata, this will be a matrix with one column per stratum.
}
\item{chisq}{
the chisquare statistic for a test of equality.
}
\item{var}{
the variance matrix of the test.
}
\item{strata}{
optionally, the number of subjects contained in each stratum.
}}
\section{METHOD}{
This function implements the G-rho family of
Harrington and Fleming (1982), with weights on each death of \eqn{S(t)^\rho}{S(t)^rho},
where \eqn{S(t)}{S} is the Kaplan-Meier estimate of survival.
With \code{rho = 0} this is the log-rank or Mantel-Haenszel test,
and with \code{rho = 1} it is equivalent to the Peto & Peto modification
of the Gehan-Wilcoxon test.


If the right hand side of the formula consists only of an offset term,
then a one sample test is done.
To cause missing values in the predictors to be treated as a separate
group, rather than being omitted, use the \code{factor} function with its
\code{exclude} argument.
}
\references{
Harrington, D. P. and Fleming, T. R. (1982).
A class of rank test procedures for censored survival data.
\emph{Biometrika}
\bold{69}, 553-566.}
\examples{
## Two-sample test
survdiff(Surv(futime, fustat) ~ rx,data=ovarian)

## Stratified 7-sample test

survdiff(Surv(time, status) ~ pat.karno + strata(inst), data=lung)

## Expected survival for heart transplant patients based on
## US mortality tables
expect <- survexp(futime ~ ratetable(age=(accept.dt - birth.dt),
     sex=1,year=accept.dt,race="white"), jasa, cohort=FALSE,
     ratetable=survexp.usr)
## actual survival is much worse (no surprise)
survdiff(Surv(jasa$futime, jasa$fustat) ~ offset(expect))
}
\keyword{survival}
% Converted by Sd2Rd version 0.3-2. and hand edited.
\eof
% --- Source file: survexp.Rd ---
\name{survexp}
\alias{survexp}
\alias{print.survexp}
\title{
  Compute Expected Survival 
}
\description{
Returns either the expected survival of a cohort of subjects, or the 
individual expected survival for each subject. 
}
\usage{
survexp(formula, data, weights, subset, na.action, times, cohort=TRUE, 
        conditional=FALSE, ratetable=survexp.us, scale=1, npoints, 
        se.fit, model=FALSE, x=FALSE, y=FALSE)
}
\arguments{
\item{formula}{
formula object.  The response variable is a vector of follow-up times 
and is optional.  The predictors consist of optional grouping variables 
separated by the \code{+} operator (as in \code{survfit}), along with a \code{ratetable}  
term.  The \code{ratetable} term matches each subject to his/her expected cohort. 
}
\item{data}{
data frame in which to interpret the variables named in 
the \code{formula}, \code{subset} and \code{weights} arguments. 
}
\item{weights}{
case weights. 
}
\item{subset}{
expression indicating a subset of the rows of \code{data} to be used in the fit. 
}
\item{na.action}{
function to filter missing data. This is applied to the model frame after  
\code{subset} has been applied.  Default is \code{options()$na.action}. A possible 
value for \code{na.action} is \code{na.omit}, which deletes observations that contain 
one or more missing values. 
}
\item{times}{
vector of follow-up times at which the resulting survival curve is  
evaluated.  If absent, the result will be reported for each unique  
value of the vector of follow-up times supplied in \code{formula}. 
}
\item{cohort}{
logical value: if \code{FALSE}, each subject is treated as a subgroup of size 1. 
The default is \code{TRUE}. 
}
\item{conditional}{
logical value: if \code{TRUE}, the follow-up times supplied in \code{formula} 
are death times and conditional expected survival is computed. 
If \code{FALSE}, the follow-up times are potential censoring times.  
If follow-up times are missing in \code{formula}, this argument is ignored.   
}
\item{ratetable}{
a table of event rates, such as \code{survexp.uswhite}, or a fitted Cox model. 
}
\item{scale}{
numeric value to scale the results.  If \code{ratetable} is in units/day, 
\code{scale = 365.25} causes the output to be reported in years. 
}
\item{npoints}{
number of points at which to calculate intermediate results, evenly spaced  
over the range of the follow-up times.  The usual (exact) calculation is done  
at each unique follow-up time. For very large data sets specifying \code{npoints}  
can reduce the amount of memory and computation required. 
For a prediction from a Cox model \code{npoints} is ignored. 
}
\item{se.fit}{
compute the standard error of the predicted survival.  
The default is to compute standard errors whenever  
possible, which at this time is only for the Ederer method and a Cox  
model as the rate table. 
}
\item{model,x,y}{
flags to control what is returned.  If any of these is true, then the
model frame, the model matrix, and/or the vector of response times will be
returned as components of the final result, with the same names as the
flag arguments.
}}

\value{
if \code{cohort=TRUE} an object of class \code{survexp}, 
otherwise a vector of per-subject expected survival values. 
The former contains the number of subjects at risk 
and the expected survival for the cohort at each requested time. 
}
\details{
Individual expected survival is usually used in models or testing, to 
`correct' for the age and sex composition of a group of subjects. 
For instance, assume that birth date, entry date into the study, 
sex and actual survival time are all known for a group of subjects. 
The \code{survexp.uswhite} population tables contain expected death rates 
based on calendar year, sex and age. 
Then 
\preformatted{
haz <- -log(survexp(death.time ~ ratetable(sex=sex, year=entry.dt, 
            age=(birth.dt-entry.dt)), cohort=FALSE)) 
}
gives for each subject the total hazard experienced up to their observed 
death time or censoring time. 
This probability can be used as a rescaled time value in models: 
\preformatted{
glm(status ~ 1 + offset(log(haz)), family=poisson) 
glm(status ~ x + offset(log(haz)), family=poisson) 
}
In the first model, a test for intercept=0 is the one sample log-rank 
test of whether the observed group of subjects has equivalent survival to 
the baseline population.  The second model tests for an effect of variable 
\code{x} after adjustment for age and sex. 

Cohort survival is used to produce an overall survival curve.  This is then 
added to the Kaplan-Meier plot of the study group for visual comparison 
between these subjects and the population at large.  There are three common 
methods of computing cohort survival. 
In the "exact method" of Ederer the cohort is not censored; this corresponds 
to having no response variable in the formula.  Hakulinen recommends censoring 
the cohort at the anticipated censoring time of each patient, and Verheul 
recommends censoring the cohort at the actual observation time of each 
patient. 
The last of these is the conditional method. 
These are obtained by using the respective time values as the 
follow-up time or response in the formula. 
}
\references{
Berry, G. (1983). The analysis of mortality by the subject-years method. 
\emph{Biometrics}, 39:173-84.

Ederer, F., Axtell, L. and Cutler, S. (1961). 
The relative survival rate: a statistical methodology. 
\emph{Natl Cancer Inst Monogr}, 6:101-21.

Hakulinen, T. (1982). 
Cancer survival corrected for heterogeneity in patient withdrawal. 
\emph{Biometrics}, 38:933-942.

Verheul, H., Dekker, E., Bossuyt, P., Moulijn, A. and Dunning, A. (1993). 
Background mortality in clinical survival studies. 
\emph{Lancet}, 341: 872-875.
}
\seealso{
\code{\link{survfit}}, \code{\link{pyears}},  \code{\link{survexp.us}},  \code{\link{survexp.fit}}.   
}
\examples{
# 
# Stanford heart transplant data
# Estimate of conditional survival  
survexp(futime ~ ratetable(sex="male", year=accept.dt,   
          age=(accept.dt-birth.dt)), conditional=TRUE, data=jasa) 
# Estimate of conditional survival stratified by prior surgery 
survexp(futime ~ surgery + ratetable(sex="male", year=accept.dt,  
	age=(accept.dt-birth.dt)), conditional=TRUE, data=jasa) 

## Compare the survival curves for the Mayo PBC data to Cox model fit
## 
pfit <-coxph(Surv(time,status>0) ~ trt + log(bili) + log(protime) + age +
                platelet, data=pbc)
plot(survfit(Surv(time, status>0) ~ trt, data=pbc))
lines(survexp( ~ trt, ratetable=pfit, data=pbc), col='purple')
}
\keyword{survival}

\eof
% --- Source file: survexp.fit.Rd ---
\name{survexp.fit}
\alias{survexp.fit}
\title{
  Compute Expected Survival 
}
\description{
Compute expected survival times. 
}
\usage{
survexp.fit(x, y, times, death, ratetable)
}
\arguments{
\item{x}{
a matrix. The first column contains the group, 
an integer value that divides the subjects into subsets. 
Remaining columns must match the dimensions of the \code{ratetable}, 
in the correct order. 
}
\item{y}{
the follow up time for each subject. 
}
\item{times}{
the vector of times at which a result will be computed. 
}
\item{death}{
a logical value, if \code{TRUE} the conditional survival is computed, 
if \code{FALSE} the cohort survival is computed. See
\code{\link{survexp}} for more details.
}
\item{ratetable}{
a rate table, such as \code{survexp.uswhite}. 
}
}
\value{
A list containing the number of subjects and the expected survival(s) 
at each time point. 
If there are multiple groups, these will be 
matrices with one column per group. 
}
\details{
For conditional survival \code{y} must be the time of last follow-up or death for 
each subject. 
For cohort survival it must be the potential censoring time for 
each subject, ignoring death. 

For an exact estimate \code{times} should be a superset of \code{y}, so that each 
subject at risk is at risk for the entire sub-interval of time. 
For a large data set, however, this can use an inordinate amount of 
storage and/or compute time.  If the \code{times} spacing is more coarse than 
this, an actuarial approximation is used which should, however, be extremely 
accurate as long as all of the returned values are > .99. 

For a subgroup of size 1 and \code{times} > \code{y}, 
the conditional method reduces to exp(-h) where 
h is the expected cumulative hazard for the subject over his/her 
observation time.  This is used to compute individual expected survival. 
}
\section{Warning}{
Most users will call the higher level routine \code{survexp}. 
Consequently, this function has very few error checks on its input arguments. 
}
\seealso{
\code{\link{survexp}},  \code{\link{survexp.us}}.   
}
\keyword{survival
}
% docclass is function
% Converted by Sd2Rd version 37351.
\eof
% --- Source file: survexp.us.Rd ---
\name{ratetables}
\alias{survexp.us}
\alias{survexp.usr}
\alias{survexp.az}
\alias{survexp.azr}
\alias{survexp.fl}
\alias{survexp.flr}
\alias{survexp.mn}
\alias{survexp.mnwhite}
\alias{survexp.wnc}
\title{
  Census Data Sets for the Expected Survival and Person Years Functions
}
\description{
  Census data sets for the expected survival and person years functions.
}
\details{
  \describe{
    \item{us}{
      total United States population, by age and sex, 1960 to 1980.
    }
    \item{uswhite}{
      United States white population, by age and sex, 1950 to 1980. This
      is no longer included, but can be extracted from
      \code{survexp.usr} as shown in the examples.
    }
    \item{usr}{
      United States population, by age, sex and race, 1960 to 1980.
      Race is white, nonwhite, or black.  For 1960 and 1970 the black
      population values were not reported separately, so the nonwhite
      values were used.
    }
    \item{mn}{
      total Minnesota population, by age and sex, 1970 and 1980.
    }
    \item{mnwhite}{
      Minnesota white population, by age and sex, 1960 to 1980.
    }
    \item{fl}{
      total Florida population, by age and sex, 1970 and 1980.
    }
    \item{flr}{
      Florida population, by age, sex and race, 1970-1980.  Race is
      white, nonwhite, or black.  For 1970 the black population values
      were not reported separately, so the nonwhite values were used.
    }
    \item{az}{
      total Arizona population, by age and sex, 1970 and 1980.
    }
    \item{azr}{
      Arizona population, by age, sex and race, 1970-1980.  Race is
      white versus nonwhite.  For 1970 the nonwhite population values
      were not reported separately.
      In order to make the rate table be a matrix, the 1980 values were
      repeated.  (White and non-white values are quite different).
    }
  }
  
  Each of these tables contains the daily hazard rate for a matched
  subject from the population, defined as \eqn{-\log(1-q)/365.24} where
  \eqn{q} is the 1 year probability of death as reported in the original
  tables.  For age 25 in 1970, for instance, \eqn{p = 1-q} is is the
  probability that a subject who becomes 25 years of age in 1970 will
  achieve his/her 26th birthday.  The tables are recast in terms of
  hazard per day entirely for computational convenience.  (The fraction
  .24 in the denominator is based on 24 leap years per century.)

  Each table is stored as an array, with additional attributes, and
  can be subset and manipulated as standard S arrays.  Interpolation
  between calendar years is done \dQuote{on the fly} by the
  \code{\link{survexp}} routine. 

  Some of the deficiencies, e.g., 1970 Arizona non-white, are a result
  of local (Mayo Clinic) conditions.  The data probably exists, but we
  don't have a copy it in the library.

  The tables have been augmented to contain extrapolated values for 1990
  and 2000.  The details can be found in Mayo Clinic Biostatistics
  technical report 63 at \url{http://www.mayo.edu/hsr/techrpt.html}.
}
\examples{
survexp.uswhite <- survexp.usr[,,"white",]
}
\keyword{survival}
\keyword{datasets}
\eof
% --- Source file: survfit.Rd ---
\name{survfit}
\alias{survfit}
\alias{survfit.formula}
\alias{[.survfit}
\title{
  Compute a Survival Curve for Censored Data 
}
\description{
Computes an estimate of a survival curve for censored data 
using either the Kaplan-Meier or the Fleming-Harrington method 
or computes the predicted survivor function.
For competing risks data it computes the
cumulative incidence curve. See \code{survfit.coxph} for survival curves
from a fitted Cox model.
}
\usage{
survfit(formula,...)
\method{survfit}{formula}(formula, data, weights, subset, na.action,  
        etype, id, ...)
}
\arguments{
  \item{formula}{
    a formula object, which must have a 
    \code{Surv} object as the  
    response on the left of the \code{~} operator and, if desired, terms  
    separated by + operators on the right. 
    One of the terms may be a \code{strata} object.
    For a single survival curve the right hand side should be \code{~ 1}.
  }
  \item{data}{
    a data frame in which to interpret the variables named in the formula, 
    \code{subset} and \code{weights} arguments. 
  }
  \item{weights}{
    The weights must be nonnegative and it is strongly recommended that  
    they be strictly positive, since zero weights are ambiguous, compared 
    to use of the \code{subset} argument.
  }
  \item{subset}{
    expression saying that only a subset of the rows of the data 
    should be used in the fit. 
  }
  \item{na.action}{
    a missing-data filter function, applied to the model frame, after any 
    \code{subset} argument has been used. 
    Default is \code{options()$na.action}. 
  }
  \item{etype}{
    a variable giving the type of event.
    Presence of this variable signals the program to compute the cumulative
    incidece estimate.  For each event \code{status==1}, the etype
    variable indicates the type of event.  For a censored observation the
    value of \code{etype} is ignored - but do not set it to NA, since that
    will cause na.action to delete the observation.
  }
  \item{id}{
    identifies individual subjects, when a given person can have multiple
    lines of data. when used with the \code{etype} variable, this allows
    the compuation of
    a cumulative prevalence estimate, i.e., the incidence over time.
  }
  \item{\dots}{
    The following additional arguments are passed to internal functions
    called by \code{survfit}.
    \describe{
      \item{type}{
	a character string specifying the type of survival curve. 
	Possible values are \code{"kaplan-meier"}, 
	\code{"fleming-harrington"} or \code{"fh2"} 
	if a formula is given 
	and \code{"aalen"} or \code{"kaplan-meier"} 
	if the first argument is a \code{coxph} object, 
	(only the first two characters are necessary). 
	The default is \code{"aalen"} when 
	a \code{coxph} object is given, 
	and it is \code{"kaplan-meier"} otherwise.  
	Earlier versions of \code{survfit} 
	used \code{type="tsiatis"} to get the \code{"aalen"} estimator.  For backward 
	compatibility, this is still allowed. 
      }
      \item{error}{
	a character string specifying the error.  Possible values are 
	\code{"greenwood"} for the Greenwood formula or 
	\code{"tsiatis"} for the Tsiatis formula, 
	(only the first character is 
	necessary).  
	The default is \code{"tsiatis"} when 
	a \code{coxph} object is given, and it is \code{"greenwood"} otherwise. 
      }
      \item{conf.type}{
	One of \code{"none"}, \code{"plain"}, \code{"log"} (the default),
	or \code{"log-log"}.  Only
	enough of the string to uniquely identify it is necessary.
	The first option causes confidence intervals not to be
	generated.  The second causes the standard intervals
	\code{curve +- k *se(curve)}, where k is determined from
	\code{conf.int}.  The log option calculates intervals based on the
	cumulative hazard or log(survival). The last option bases
	intervals on the log hazard or log(-log(survival)). 
      }
      \item{conf.lower}{
	a character string to specify modified lower limits to the curve, the 
	upper limit remains unchanged.  
	Possible values are \code{"usual"} (unmodified), 
	\code{"peto"}, 
	and \code{"modified"}.  T
	he modified lower limit 
	is based on an "effective n" argument.  The confidence 
	bands will agree with the usual calculation at each death time, but unlike 
	the usual bands the confidence interval becomes wider at each censored 
	observation.  The extra width is obtained by multiplying the usual 
	variance by a factor m/n, where n is the number currently at risk and 
	m is the number at risk at the last death time.  (The bands thus agree 
	with the un-modified bands at each death time.) 
	This is especially useful for survival curves with a long flat tail. 
	
	The Peto lower limit is based on the same "effective n" argument as the 
	modified limit, but also replaces the usual Greenwood variance term with 
	a simple approximation.  It is known to be conservative. 
      }
      \item{start.time}{
	numeric value specifying a time to start calculating survival
	information.
	The resulting curve is the survival conditional on surviving to
	\code{start.time}.
      }
      \item{conf.int}{
	the level for a two-sided confidence interval on the survival curve(s). 
	Default is 0.95. 
      }
      \item{se.fit}{
	a logical value indicating whether standard errors should be 
	computed.  Default is \code{TRUE}. 
      }
      
    }
  }
}
\value{
an object of class \code{"survfit"}.  
See \code{survfit.object} for 
details. Methods defined for survfit objects are  
\code{print}, \code{plot}, 
\code{lines}, and \code{points}. 
}
\details{
The estimates used are the Kalbfleisch-Prentice 
(Kalbfleisch and Prentice, 1980, p.86) and the Tsiatis/Link/Breslow, 
which reduce to the Kaplan-Meier and Fleming-Harrington estimates, 
respectively, when the weights are unity.  

The Greenwood formula for the variance is a sum of terms 
d/(n*(n-m)), where d is the number of deaths at a given time point, n 
is the sum of weights for all individuals still at risk at that time, and 
m is the sum of weights for the deaths at that time.  The 
justification is based on a binomial argument when weights are all 
equal to one; extension to the weighted case is ad hoc.  Tsiatis 
(1981) proposes a sum of terms d/(n*n), based on a counting process 
argument which includes the weighted case. 

The two variants of the F-H estimate have to do with how ties are handled.
If there were 3 deaths out of 10 at risk, then the first
increments the hazard by 3/10 and the second
by 1/10 + 1/9 + 1/8.
For the first method S(t) = exp(H), where H is 
the Nelson-Aalen cumulative hazard estimate,
whereas the \code{fh2} method will 
give results S(t) results closer to the Kaplan-Meier. 

When the data set includes left censored or interval censored data (or both),
then the EM approach of Turnbull is used to compute the overall curve.
When the baseline method is the Kaplan-Meier, this is known to converge to
the maximum likelihood estimate.

The cumulative incidence curve is an alternative to the Kaplan-Meier
for competing risks data.
For instance, in patients with MGUS, conversion to an overt plasma
cell malignancy occurs at about 1\% per year.  
A Kaplan-Meier estimate, treating death due to other causes as censored,
gives a 20 year cumulate rate of 33\% for the 241 early patients of Kyle.  
This estimates the incidence of conversion, if other causes of death were
removed.
  
The CI estimate, on the other hand, estimates the total number of
conversions that will actually occur.  Because the population is older,
this is much smaller than the KM, 22\% at 20 years for Kyle's data.
If there were no censoring, then CI(t) would simply be the total number
of patients with progression by time t, divided by the sample size n.

}
\section{References}{
Dorey, F. J. and Korn, E. L. (1987).  Effective sample sizes for confidence 
intervals for survival probabilities.  \emph{Statistics in Medicine} 
\bold{6}, 679-87. 

Fleming, T. H. and Harrington, D. P. (1984).  Nonparametric estimation of the 
survival distribution in censored data.  \emph{Comm. in Statistics}  
\bold{13}, 2469-86. 

Kablfleisch, J. D. and Prentice, R. L. (1980).  
\emph{The Statistical Analysis of Failure Time Data.}
New York:Wiley. 

Kyle, R. A. (1997).
Moncolonal gammopathy of undetermined significance and solitary
      plasmacytoma. Implications for progression to overt multiple myeloma\},
\emph{Hematology/Oncology Clinics N. Amer.}
\bold{11}, 71-87.

Link, C. L. (1984). Confidence intervals for the survival 
function using Cox's proportional hazards model with  
covariates.  \emph{Biometrics}  
\bold{40}, 601-610.

Turnbull, B. W. (1974).  Nonparametric estimation of a survivorship
function with doubly censored data. \emph{J Am Stat Assoc},
\bold{69}, 169-173. 

}
\seealso{
\code{\link{survfit.coxph}} for survival curves from Cox models.
  
\code{\link{print}},  
\code{\link{plot}},  
\code{\link{lines}},   
\code{\link{coxph}},  
\code{\link{Surv}},  
\code{\link{strata}}.   
}
\examples{
#fit a Kaplan-Meier and plot it 
fit <- survfit(Surv(time, status) ~ x, data = aml) 
plot(fit, lty = 2:3) 
legend(100, .8, c("Maintained", "Nonmaintained"), lty = 2:3) 

#fit a Cox proportional hazards model and plot the  
#predicted survival for a 60 year old 
fit <- coxph(Surv(futime, fustat) ~ age, data = ovarian) 
plot(survfit(fit, newdata=data.frame(age=60)),
     xscale=365.25, xlab = "Years", ylab="Survival") 

# Here is the data set from Turnbull
#  There are no interval censored subjects, only left-censored (status=3),
#  right-censored (status 0) and observed events (status 1)
#
#                             Time
#                         1    2   3   4
# Type of observation
#           death        12    6   2   3
#          losses         3    2   0   3
#      late entry         2    4   2   5
#
tdata <- data.frame(time  =c(1,1,1,2,2,2,3,3,3,4,4,4),
                    status=rep(c(1,0,2),4),
                    n     =c(12,3,2,6,2,4,2,0,2,3,3,5))
fit  <- survfit(Surv(time, time, status, type='interval') ~1, 
              data=tdata, weight=n)

#
# Time to progression/death for patients with monoclonal gammopathy
#  Competing risk curves (cumulative incidence)
fit1 <- survfit(Surv(stop, event=='progression') ~1, data=mgus1,
                    subset=(start==0))
fit2 <- survfit(Surv(stop, status) ~1, data=mgus1,
                    subset=(start==0), etype=event) #competing risks
# CI curves are always plotted from 0 upwards, rather than 1 down
plot(fit2, fun='event', xscale=365.25, xmax=7300, mark.time=FALSE,
            col=2:3, xlab="Years post diagnosis of MGUS")
lines(fit1, fun='event', xscale=365.25, xmax=7300, mark.time=FALSE,
            conf.int=FALSE)
text(10, .4, "Competing Risk: death", col=3)
text(16, .15,"Competing Risk: progression", col=2)
text(15, .30,"KM:prog")
}
\keyword{survival}
\eof
% --- Source file: survfit.coxph.Rd ---
\name{survfit.coxph}
\alias{survfit.coxph}
\title{
  Compute a Survival Curve from a Cox model
}
\description{
Computes the predicted survivor function for a Cox proportional 
hazards model. 
}
\usage{
\method{survfit}{coxph}(formula, newdata, 
        se.fit=TRUE, conf.int=.95,
        individual=FALSE, 
        type,vartype,
        conf.type=c("log","log-log","plain","none"),...)
}
\arguments{
  \item{formula}{
    A \code{coxph} object. 
  }
  \item{newdata}{
    a data frame with the same variable names as those that appear 
    in the \code{coxph} formula.  
    
    The curve(s) produced will be representative of a cohort whose 
    covariates correspond to the values in \code{newdata}. 
    Default is the mean of the covariates used in the 
    \code{coxph} fit. 
  }
  \item{individual}{
    a logical value indicating whether each row of \code{newdata} represents
    a distinct individual (FALSE, the default), 
    or if each row of the data frame represents different 
    time epochs for only one individual (TRUE).  
    In the former case the result will have one curve for each row in
    \code{newdata}, in the latter only a single curve will be produced.
  }
  \item{conf.int}{
    the level for a two-sided confidence interval on the survival curve(s). 
    Default is 0.95. 
  }
  \item{se.fit}{
    a logical value indicating whether standard errors should be 
    computed.  Default is \code{TRUE}. 
  }
  \item{type,vartype}{
    a character string specifying the type of survival curve. 
    Possible values are  \code{"aalen"} or \code{"kaplan-meier"} 
    (only the first two characters are necessary). 
    The default is \code{"aalen"}  
    Earlier versions of \code{survfit} 
    used \code{type="tsiatis"} to get the \code{"aalen"} estimator.  For backward 
    compatibility, this is still allowed. 
  }
 
  \item{conf.type}{
    One of \code{"none"}, \code{"plain"}, \code{"log"} (the default),
    or \code{"log-log"}.  Only
    enough of the string to uniquely identify it is necessary.
    The first option causes confidence intervals not to be
    generated.  The second causes the standard intervals
    \code{curve +- k *se(curve)}, where k is determined from
    \code{conf.int}.  The log option calculates intervals based on the
    cumulative hazard or log(survival). The last option bases
    intervals on the log hazard or log(-log(survival)). 
  }
  \item{\dots}{for future methods}
}
\value{
an object of class \code{"survfit"}.  
See \code{survfit.object} for 
details. Methods defined for survfit objects are  
\code{print}, \code{plot}, 
\code{lines}, and \code{points}. 
}
\details{
See \code{\link{survfit}} for more Details.
  
The estimates used are the Kalbfleisch-Prentice 
(Kalbfleisch and Prentice, 1980, p.86) and the Tsiatis/Link/Breslow, 
which reduce to the Kaplan-Meier and Fleming-Harrington estimates, 
respectively, when the weights are unity.  
When the parent data is a Cox model, there is an extra
term in the variance of the curve, due to the variance of the coefficients and 
hence variance in the computed weights.  Details of the Aalen 
estimator and its variance are found in Tsiatis (1981). 

The two variants of the F-H estimate have to do with how ties are handled.
If there were 3 deaths out of 10 at risk, then the first
increments the hazard by 3/10 and the second
by 1/10 + 1/9 + 1/8.
For the first method S(t) = exp(H), where H is 
the Nelson-Aalen cumulative hazard estimate,
whereas the \code{fh2} method will 
give results S(t) results closer to the Kaplan-Meier. 
For curves created 
after a Cox model these correspond to the Breslow and Efron estimates, 
respectively, and the proper choice is made automatically. 

}
\section{References}{
Dorey, F. J. and Korn, E. L. (1987).  Effective sample sizes for confidence 
intervals for survival probabilities.  \emph{Statistics in Medicine} 
\bold{6}, 679-87. 

Fleming, T. H. and Harrington, D. P. (1984).  Nonparametric estimation of the 
survival distribution in censored data.  \emph{Comm. in Statistics}  
\bold{13}, 2469-86. 

Kablfleisch, J. D. and Prentice, R. L. (1980).  
\emph{The Statistical Analysis of Failure Time Data.}
New York:Wiley. 

Link, C. L. (1984). Confidence intervals for the survival 
function using Cox's proportional hazards model with  
covariates.  \emph{Biometrics}  
\bold{40}, 601-610.

Tsiatis, A. (1981). A large sample study of the estimate 
for the integrated hazard function in Cox's regression 
model for survival data. \emph{Annals of Statistics}  
\bold{9}, 93-108. 
}
\seealso{
\code{\link{print}},  
\code{\link{plot}},  
\code{\link{lines}},   
\code{\link{coxph}},  
\code{\link{Surv}},  
\code{\link{strata}}.   
}
\examples{
#fit a Kaplan-Meier and plot it 
fit <- survfit(Surv(time, status) ~ x, data = aml) 
plot(fit, lty = 2:3) 
legend(100, .8, c("Maintained", "Nonmaintained"), lty = 2:3) 

#fit a Cox proportional hazards model and plot the  
#predicted survival for a 60 year old 
fit <- coxph(Surv(futime, fustat) ~ age, data = ovarian) 
plot(survfit(fit, newdata=data.frame(age=60)),
     xscale=365.25, xlab = "Years", ylab="Survival") 

# Here is the data set from Turnbull
#  There are no interval censored subjects, only left-censored (status=3),
#  right-censored (status 0) and observed events (status 1)
#
#                             Time
#                         1    2   3   4
# Type of observation
#           death        12    6   2   3
#          losses         3    2   0   3
#      late entry         2    4   2   5
#
tdata <- data.frame(time  =c(1,1,1,2,2,2,3,3,3,4,4,4),
                    status=rep(c(1,0,2),4),
                    n     =c(12,3,2,6,2,4,2,0,2,3,3,5))
fit  <- survfit(Surv(time, time, status, type='interval') ~1, 
              data=tdata, weight=n)

#
# Time to progression/death for patients with monoclonal gammopathy
#  Competing risk curves (cumulative incidence)
fit1 <- survfit(Surv(stop, event=='progression') ~1, data=mgus1,
                    subset=(start==0))
fit2 <- survfit(Surv(stop, status) ~1, data=mgus1,
                    subset=(start==0), etype=event) #competing risks
# CI curves are always plotted from 0 upwards, rather than 1 down
plot(fit2, fun='event', xscale=365.25, xmax=7300, mark.time=FALSE,
            col=2:3, xlab="Years post diagnosis of MGUS")
lines(fit1, fun='event', xscale=365.25, xmax=7300, mark.time=FALSE,
            conf.int=FALSE)
text(10, .4, "Competing Risk: death", col=3)
text(16, .15,"Competing Risk: progression", col=2)
text(15, .30,"KM:prog")
}
\keyword{survival}
\eof
% --- Source file: survfit.object.Rd ---
\name{survfit.object}
\alias{survfit.object}
\title{
  Survival Curve Object 
}
\description{
This class of objects is returned by the \code{survfit} class of functions
to represent a fitted survival curve. 

Objects of this class have methods for the functions \code{print},
\code{summary}, \code{plot}, \code{points} and \code{lines}. The
\code{\link{print.survfit}} method does more computation than is typical
for a print method and is documented on a separate page.
Class of objects that represent a fitted survival curve. 
}
\section{Structure}{
The following components must be included in a legitimate 
\code{survfit} 
object. 
}
\arguments{
\item{n}{
total number of subjects in each curve.
}
\item{time}{
the time points at which the curve has a step. 
}
\item{n.risk}{
the number of subjects at risk at t. 
}
\item{n.event}{
the number of events that occur at time t. 
}
\item{n.enter}{
for counting process data only,
the number of subjects that enter at time t. 
}
\item{n.censor}{
for counting process data only,
the number of subjects who exit the risk set,
without an event,  at time t. 
(For right censored data, this number can be computed from the successive
values of the number at risk).
}
\item{surv}{
the estimate of survival at time t+0. 
This may be a vector or a matrix. 
}
\item{std.err}{
the standard error of the cumulative hazard or -log(survival). 
}
\item{upper}{
upper confidence limit for the survival curve. 
}
\item{lower}{
lower confidence limit for the survival curve. 
}
\item{strata}{
if there are multiple curves, this component gives the number of elements of 
the \code{time} etc. vectors corresponding to the first curve,
the second curve, 
and so on.  The names of the elements are labels for the curves. 
}
\item{start.time}{
the value specified for the \code{start.time} argument,
if it was used in the call.  
}
\item{n.all}{
for counting process data, and any time that the 
\code{start.time} argument was used, this contains
the total number of observations that were available.
Not all may have been used in creating the curve, in which case this value
will be larger than \code{n} above.
of observations that were available
}
\item{conf.type}{
the approximation used to compute the confidence limits. 
}
\item{conf.int}{
the level of the confidence limits, e.g. 90 or 95\%. 
}
\item{na.action}{
the returned value from the na.action function, if any.  It will be used 
in the printout of the curve, e.g., the number of observations deleted due 
to missing values. 
}
\item{call}{
an image of the call that produced the object. 
}
\item{type}{
type of survival censoring. 
}
}
\section{Subscripts}{
Survfit objects that contain multiple survival curves can be subscripted. 
This is most often used to plot a subset of the curves. 
Usually a single subscript will be used.  In one particular case --
survival curves for multiple covariate values, from a Cox model that includes 
a \code{strata} statement -- there is a matrix of 
curves and 2 subscripts may be used. 
(In this case \code{summary.survfit} will 
also print the data as a matrix). 
}
\seealso{
\code{\link{plot.survfit}},  
\code{\link{summary.survfit}},
\code{\link{print.survfit}},
\code{\link{survfit}}.   
}
\keyword{survival}
\eof
% --- Source file: survival-internal.Rd ---
\name{survival-internal}
\alias{survival-internal}
\alias{survreg.fit}
\alias{survpenal.fit}
\alias{survdiff.fit}
\alias{is.category}
\alias{is.na.ratetable2}
\alias{is.na.coxph.penalty}
\alias{match.ratetable}
\alias{as.matrix.ratetable}
\alias{model.newframe}
\alias{coxpenal.df}
\alias{coxpenal.fit}
\alias{coxph.fit}
\alias{coxph.wtest}
\alias{agreg.fit}
\alias{agexact.fit}
\title{Internal survival functions}
\description{Internal survival functions}
\usage{
survreg.fit(x, y, weights, offset, init, controlvals, dist, scale = 0,
    nstrat = 1, strata, parms = NULL,assign)
survpenal.fit(x, y, weights, offset, init, controlvals, dist, scale = 0,
    nstrat = 1, strata, pcols, pattr, assign, parms = NULL)
survdiff.fit(y, x, strat, rho = 0)
is.category(x)
match.ratetable(R, ratetable)
\method{as.matrix}{ratetable}(x, ...)
is.na.ratetable2(x)
is.na.coxph.penalty(x)
model.newframe(object, newdata, safe = FALSE, response = FALSE, ...)
coxpenal.df(hmat, hinv, fdiag, assign.list, ptype, nvar, pen1,
    pen2, sparse)
coxpenal.fit(x, y, strata, offset, init, control, weights, method,
    rownames, pcols, pattr, assign)
coxph.fit(x, y, strata, offset, init, control, weights, method,
    rownames)
coxph.wtest(var, b, toler.chol = 1e-09)
agreg.fit(x, y, strata, offset, init, control, weights, method,
    rownames)
agexact.fit(x, y, strata, offset, init, control, weights, method,
    rownames) 
}
\details{The arguments to these routines are not guarranteed to stay the
same from release to release -- call them at your own risk!}
\keyword{survival}
\keyword{internal}
\eof
% --- Source file: survobrien.Rd ---
\name{survobrien}
\alias{survobrien}
\title{
 O'Brien's Test for Association of a Single Variable with Survival
}
\description{
Peter O'Brien's test for association of a single variable with survival 
This test is proposed in Biometrics, June 1978. 
}
\usage{
survobrien(formula, data)
}
\arguments{
\item{formula}{
a valid formula for a cox model, without time dependent covariates. 
}
\item{data}{
a data frame. 
}
}
\value{
a new data frame.  The original time and status variables are removed, 
and have been replaced with \code{start}, \code{stop}, and \code{event}.  If a 
predictor variable is a factor or is protected with \code{I()}, it is 
retained as is.  Other predictor variables have been replaced with 
time-dependent logit scores. 

Because of the time dependent variables, the new data frame will have many 
more rows that the original data, approximately \#rows * \#deaths /2. 
}
\section{Method}{
A time-dependent cox model can now be fit to the new data. 
The univariate statistic, as originally proposed, is equivalent to 
single variable score tests from the time-dependent model. 
This equivalence is the rationale for using the time dependent model as a 
multivariate extension of the original paper. 

In O'Brien's method, the x variables are re-ranked at each death time.  A 
simpler method, proposed by Prentice, ranks the data only once at the 
start. The results are usually similar. 
}
\references{
O'Brien, Peter, "A Nonparametric Test for Association with Censored Data", 
\emph{Biometrics} 34: 243-250, 1978. 
}
\seealso{
\code{\link{survdiff}} 
}
\keyword{survival}
\examples{
xx <- survobrien(Surv(futime, fustat) ~ age + factor(rx) + I(ecog.ps), 
			       data=ovarian) 
coxph(Surv(start, stop, event) ~ age, data=xx) 
coxph(Surv(start, stop, event) ~ age + rx + ecog.ps, data=xx) 
}
\eof
% --- Source file: survreg.Rd ---
\name{survreg}
\alias{survreg}
\alias{model.frame.survreg}
\alias{labels.survreg}
\alias{print.survreg.penal}
\alias{print.summary.survreg}
\alias{survReg}
\alias{anova.survreg}
\alias{vcov.survreg}
\alias{anova.survreglist}
\title{
  Regression for a Parametric Survival Model 
}
\description{
Fit a parametric survival regression model.
These are location-scale models for an arbitrary transform of the time
variable; the most common cases use a log transformation, leading to
accelerated failure time models.
}
\usage{
survreg(formula, data, weights, subset, 
        na.action, dist="weibull", init=NULL, scale=0, 
        control,parms=NULL,model=FALSE, x=FALSE,
        y=TRUE, robust=FALSE, score=FALSE, \dots)

}
\arguments{
\item{formula}{
a formula expression as for other regression models. 
The response is usually a survival object as returned by the \code{Surv} function. 
See the documentation for \code{Surv}, \code{lm} and \code{formula} for details. 
}
\item{data}{
a data frame in which to interpret the variables named in 
the \code{formula}, \code{weights} or the \code{subset} arguments. 
}
\item{weights}{optional vector of case weights}
\item{subset}{
  subset of the observations to be used in the fit
}
\item{na.action}{
a missing-data filter function, applied to the model.frame, after any 
\code{subset} argument has been used.  Default is \code{options()\$na.action}. 
}
\item{dist}{
assumed distribution for y variable. 
If the argument is a character string, then it is assumed to name an
element from \code{\link{survreg.distributions}}. These include
\code{"weibull"}, \code{"exponential"}, \code{"gaussian"},
\code{"logistic"},\code{"lognormal"} and \code{"loglogistic"}.
Otherwise, it is assumed to be a user defined list conforming to the
format described in \code{\link{survreg.distributions}}.
}
\item{parms}{
a list of fixed parameters.  For the t-distribution for instance this is
the degrees of freedom; most of the distributions have no parameters.
}
\item{init}{
optional vector of initial values for the parameters.
}
\item{scale}{
optional fixed value for the scale.  If set to <=0 then the scale is
estimated.
}
\item{control}{
a list of control values, in the format producted by
\code{\link{survreg.control}}. The default value is \code{survreg.control()}
}
\item{model,x,y}{
flags to control what is returned.  If any of these is true, then the
model frame, the model matrix, and/or the vector of response times will be
returned as components of the final result, with the same names as the
flag arguments.}
\item{score}{return the score vector. (This is expected to be zero upon
successful convergence.)
}
\item{robust}{Use robust 'sandwich' standard errors, based on
  independence of individuals if there is no \code{cluster()} term in
  the formula, based on independence of clusters if there is.}
\item{\dots}{
other arguments which will be passed to \code{survreg.control}.
}}
\value{
an object of class \code{survreg} is returned.
}
\seealso{
\code{\link{survreg.object}}, \code{\link{survreg.distributions}},
\code{\link{pspline}}, \code{\link{frailty}}, \code{\link{ridge}}
}
\examples{
# Fit an exponential model: these are all the same
survreg(Surv(futime, fustat) ~ ecog.ps + rx, ovarian, dist='weibull',scale=1)
survreg(Surv(futime, fustat) ~ ecog.ps + rx, ovarian,
        dist="exponential")


# There are multiple ways to parameterize a Weibull distribution. The survreg 
# function imbeds it in a general location-scale familiy, which is a 
# different parameterization than the rweibull function, and often leads
# to confusion.
#   survreg's scale  =    1/(rweibull shape)
#   survreg's intercept = log(rweibull scale)
#   For the log-likelihood all parameterizations lead to the same value.
y <- rweibull(1000, shape=2, scale=5)
survreg(Surv(y)~1, dist="weibull")

# Economists fit a model called `tobit regression', which is a standard
# linear regression with Gaussian errors, but with left censored data.
tobinfit <- survreg(Surv(durable, durable>0, type='left') ~ age + quant,
	            data=tobin, dist='gaussian')
}
\keyword{survival}
\eof
% --- Source file: survreg.control.Rd ---
\name{survreg.control}
\alias{survreg.control}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Package options for survreg and coxph}
\description{
This functions checks and packages the fitting options for 
\code{\link{survreg}}
}
\usage{
survreg.control(maxiter=30, rel.tolerance=1e-09, 
toler.chol=1e-10, iter.max, debug=0, outer.max=10)

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{maxiter}{maximum number of iterations }
  \item{rel.tolerance}{relative tolerance to declare convergence }
  \item{toler.chol}{Tolerance to declare Cholesky decomposition singular}
  \item{iter.max}{same as \code{maxiter}}
  \item{debug}{print debugging information}
  \item{outer.max}{maximum number of outer iterations for choosing
    penalty parameters}
}
\value{
 A list with the same elements as the input
}

\seealso{ \code{\link{survreg}}}

\examples{

}
\keyword{survival}

\eof
% --- Source file: survreg.distributions.Rd ---
\name{survreg.distributions}
\alias{survreg.distributions}
\title{Parametric Survival Distributions}
\usage{
survreg.distributions
}
\description{ List of distributions for accelerated failure models. These are
  location-scale families for some transformation of time. The entry
  describes  the cdf \eqn{F} and density \eqn{f} of a canonical member of
  the family.
}

\format{
 
  There are two basic formats, the first defines a distribution de novo,
the second defines a new distribution in terms of an old one.
  \tabular{ll}{
    name:\tab name of distribution\cr
    variance:\tab function(parms) returning the variance (currently unused)\cr
    init(x,weights,...):\tab Function returning an initial\cr
    \tab estimate of the mean and variance \cr
    \tab (used for initial values in the iteration)\cr
    density(x,parms):\tab Function returning a matrix with columns \eqn{F},\cr
    \tab \eqn{1-F},\eqn{f},\eqn{f'/f},\eqn{f''/f}\cr
    quantile(p,parms):\tab Quantile function\cr
    scale:\tab Optional fixed value for the scale parameter\cr
    parms:\tab Vector of default values and names for any additional parameters\cr
    deviance(y,scale,parms):\tab Function returning the deviance for a\cr
    \tab saturated model; used only for deviance residuals.
  }
  and to define one distribution in terms of another
  \tabular{ll}{
    name:\tab name of distribution\cr
    dist:\tab name of parent distribution\cr
    trans:\tab transformation (eg log)\cr
    dtrans:\tab derivative of transformation\cr
    itrans:\tab inverse of transformation\cr
    scale:\tab Optional fixed value for scale parameter\cr
  }
}

\details{
There are four basic distributions:\code{extreme}, \code{gaussian},
\code{logistic} and \code{t}. The last three
are parametrised in the same way as the distributions already present in
\R. The extreme value cdf is
\deqn{F=1-e^{-e^t}.}

When the logarithm of survival time has one of the first three distributions
we obtain respectively \code{weibull}, \code{lognormal}, and
\code{loglogistic}. The location-scale parameterizaion of a Weibull
distribution found in \code{survreg} is not the same as the parameterization
of \code{\link{rweibull}}.

The other predefined distributions are defined in terms of these. The
\code{exponential} and \code{rayleigh} distributions are Weibull
distributions with fixed \code{scale} of 1 and 0.5 respectively, and
\code{loggaussian} is a synonym for \code{lognormal}.

For speed parts of the three most commonly used distributions
are hardcoded in C; for this reason the elements of \code{survreg.distributions}
with names of "Extreme value", "Logisitic" and "Gaussian" should not be
modified.  (The order of these in the list is not important, recognition
is by name.)
As an alternative to modifying \code{survreg.distributions}
a new distribution can be specified as a separate list.
This is the preferred method of addition and is illustrated below.
}
\seealso{\code{\link{survreg}}, \code{\link{pweibull}},
  \code{\link{pnorm}},\code{\link{plogis}}, \code{\link{pt}},
  \code{\link{survregDtest}}
}
\examples{
# time transformation
survreg(Surv(time, status) ~ ph.ecog + sex, dist='weibull', data=lung)
# change the transformation to work in years
# intercept changes by log(365), everything else stays the same
my.weibull <- survreg.distributions$weibull
my.weibull$trans <- function(y) log(y/365)
my.weibull$itrans <- function(y) 365*exp(y)
survreg(Surv(time, status) ~ ph.ecog + sex, lung, dist=my.weibull)

# Weibull parametrisation
y<-rweibull(1000, shape=2, scale=5)
survreg(Surv(y)~1, dist="weibull")
# survreg parameters are scale=1/shape, intercept=log(scale)

# Cauchy fit
mycauchy <- list(name='Cauchy',
                 init= function(x, weights, ...) 
                      c(median(x), mad(x)),
                 density= function(x, parms) {
                      temp <- 1/(1 + x^2)
                      cbind(.5 + atan(temp)/pi, .5+ atan(-temp)/pi,
                            temp/pi, -2 *x*temp, 2*temp^2*(4*x^2*temp -1))
                      },
                 quantile= function(p, parms) tan((p-.5)*pi),
                 deviance= function(...) stop('deviance residuals not defined')
                 )
survreg(Surv(log(time), status) ~ ph.ecog + sex, lung, dist=mycauchy)
}
\keyword{survival}
\eof
% --- Source file: survreg.object.Rd ---
\name{survreg.object}
\alias{survreg.object}
\alias{print.survreg}
\alias{summary.survreg}

\title{
Parametric Survival Model Object
}
\description{
This class of objects is returned by the \code{survreg} function
to represent a fitted parametric survival model.
Objects of this class have methods for the functions \code{print},
\code{summary}, \code{predict}, and \code{residuals}.
}
\section{COMPONENTS}{
The following components must be included in a legitimate \code{survreg} object.
\describe{
\item{coefficients}{
the coefficients of the \code{linear.predictors}, which multiply  the
columns of the model
matrix.
It does not include the estimate of error (sigma).
The names of the coefficients are the names of the
single-degree-of-freedom effects (the columns of the
model matrix).
If the model is over-determined there will
be missing values in the coefficients corresponding to non-estimable
coefficients.
}
\item{icoef}{
coefficients of the baseline model, which will contain the intercept
and log(scale), or mulitple scale factors for a stratified model.
}
\item{var}{
the variance-covariance matrix for the parameters, including the log(scale)
parameter(s).
}
\item{loglik}{
a vector of length 2, containing the log-likelihood for the baseline and
full models. 
}
\item{iter}{
the number of iterations required
}
\item{linear.predictors}{
the linear predictor for each subject.
}
\item{df}{
the degrees of freedom for the final model.  For a penalized model
this will be a vector with one element per term.
}
\item{scale}{
the scale factor(s), with length equal to the number of strata.
}
\item{idf}{
degrees of freedom for the initial model.
}
\item{means}{
a vector of the column means of the coefficient matrix.
}
\item{dist}{
the distribution used in the fit.


The object will also have the following components found in 
other model results (some are optional):
\code{linear predictors}, \code{weights}, \code{x}, \code{y}, \code{model}, 
\code{call}, \code{terms} and \code{formula}.
See \code{lm}.
}}}
\seealso{
\code{\link{survreg}}, \code{\link{lm}}
}
\keyword{regression}
\keyword{survival}
% Converted by Sd2Rd version 0.3-2.
\eof
% --- Source file: survregDtest.Rd ---
\name{survregDtest}
\alias{survregDtest}
\title{Verify a survreg distribution}
\description{
  This routine is called by \code{survreg} to verify that a distribution
object is valid.  
}
\usage{
survregDtest(dlist, verbose = F)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dlist}{the list describing a survival distribution}
  \item{verbose}{return a simple TRUE/FALSE from the test for validity
(the default), or a verbose description of any flaws.}
}
\details{
  If the \code{survreg} function rejects your user-supplied distribution
as invalid, this routine will tell you why it did so.
}
\value{
  TRUE if the distribution object passes the tests, and either FALSE or a
vector of character strings if not.
}
\author{Terry Therneau}
\seealso{\code{\link{survreg.distributions}}, \code{\link{survreg}}}
\examples{
# An invalid distribution (it should have "init =" on line 2)
#  surveg would give an error message
mycauchy <- list(name='Cauchy',
                 init<- function(x, weights, ...) 
                      c(median(x), mad(x)),
                 density= function(x, parms) {
                      temp <- 1/(1 + x^2)
                      cbind(.5 + atan(temp)/pi, .5+ atan(-temp)/pi,
                            temp/pi, -2 *x*temp, 2*temp^2*(4*x^2*temp -1))
                      },
                 quantile= function(p, parms) tan((p-.5)*pi),
                 deviance= function(...) stop('deviance residuals not defined')
                 )

survregDtest(mycauchy, TRUE)
}
\keyword{survival}
\eof
% --- Source file: tcut.Rd ---
\name{tcut}
\alias{tcut}
\alias{[.tcut}
\title{Factors for person-year calculations}
\description{
Attaches categories for person-year calculations to a variable without
losing the underlying continuous representation
}
\usage{
tcut(x, breaks, labels, scale=1)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{numeric/date variable }
  \item{breaks}{breaks between categories, which are right-continuous }
  \item{labels}{labels for categories }
  \item{scale}{Multiply \code{x} and \code{breaks} by this.}
}

\value{
  An object of class \code{tcut}
}

\seealso{ \code{\link{cut}}, \code{\link{pyears}} }

\examples{
mdy.date <- function(m,d,y)
   as.Date(paste(ifelse(y<100, y+1900, y), m, d, sep='/'))
temp1 <- mdy.date(6,6,36)
temp2 <- mdy.date(6,6,55)# Now compare the results from person-years
#
temp.age <- tcut(temp2-temp1, floor(c(-1, (18:31 * 365.24))),
	labels=c('0-18', paste(18:30, 19:31, sep='-')))
temp.yr  <- tcut(temp2, mdy.date(1,1,1954:1965), labels=1954:1964)
temp.time <- 3700   #total days of fu
py1 <- pyears(temp.time ~ temp.age + temp.yr, scale=1) #output in days
py1
}
\keyword{survival}

\eof
% --- Source file: tobin.Rd ---
\name{tobin}
\alias{tobin}
\docType{data}
\title{Tobin's Tobit data}
\description{
  Economists fit a parametric censored data model called the
  \sQuote{tobit}.  These data are from Tobin's original paper. 
}
\usage{tobin}
\format{
  A data frame with 20 observations on the following 3 variables.
  \describe{
    \item{durable}{Durable goods purchase}
    \item{age}{Age in years}
    \item{quant}{Liquidity ratio (x 1000)}
  }
}
\source{
  J Tobin (1958),
  Estimation of relationships for limited dependent variables.
  \emph{Econometrica} \bold{26}, 24--36.
}
\examples{
tfit <- survreg(Surv(durable, durable>0, type='left') ~age + quant,
                data=tobin, dist='gaussian')

predict(tfit,type="response")

}
\keyword{datasets}
\eof
% --- Source file: untangle.specials.Rd ---
\name{untangle.specials}
\alias{untangle.specials}
\title{
Help Process the `specials' Argument of the `terms' Function.
}
\description{
Given a \code{terms} structure and a desired special name, this returns an
index appropriate for subscripting the \code{terms} structure and another
appropriate for the data frame.
}
\usage{
untangle.specials(tt, special, order=1)
}
\arguments{
\item{tt}{
a \code{terms} object.
}
\item{special}{
the name of a special function, presumably used in the terms object.
}
\item{order}{
the order of the desired terms.  If set to 2, interactions with the special
function will be included.
}}
\value{
a list with two components:
\item{vars}{
a vector of variable names, as would be found in the data frame, of the
specials.
}
\item{terms}{
a numeric vector, suitable for subscripting the terms structure, that indexes
the terms in the expanded model formula which involve the special.
}}
\examples{
formula<-Surv(tt,ss)~x+z*strata(id)
tms<-terms(formula,specials="strata")
## the specials attribute
attr(tms,"specials")
## main effects 
untangle.specials(tms,"strata")
## and interactions
untangle.specials(tms,"strata",order=1:2)
}
\keyword{survival}
% Converted by Sd2Rd version 0.3-2.
\eof
% --- Source file: veteran.Rd ---
\name{veteran}
\alias{veteran}
\docType{data}
\title{Veterans' Administration Lung Cancer study}
\description{Randomised trial of two treatment regimens for lung cancer.
  This is a standard survival analysis data set.} 
\usage{veteran}
\format{
  \tabular{ll}{
    trt:\tab 1=standard 2=test\cr
    celltype:\tab 1=squamous,  2=smallcell,  3=adeno,  4=large\cr
    time:\tab survival time\cr
    status:\tab censoring status\cr
    karno:\tab Karnofsky performance score (100=good)\cr
    diagtime:\tab months from diagnosis to randomisation\cr
    age:\tab in years\cr
    prior:\tab prior therapy 0=no, 1=yes\cr
  }
}
\source{
  D Kalbfleisch and RL Prentice (1980),
  \emph{The Statistical Analysis of Failure Time Data}.
  Wiley, New York.
}
\keyword{datasets}
\eof
