% --- Source file: Lattice.Rd ---
\name{Lattice}
\alias{Lattice}
\alias{lattice}
\alias{lattice-package}
\title{Lattice Graphics}
\description{
  Implementation of Trellis Graphics in R
}
\details{
  Trellis Graphics is a framework for data visualization developed at
  the Bell Labs by Rick Becker, Bill Cleveland et al, extending ideas
  presented in Bill Cleveland's 1993 book \emph{Visualizing Data}.

  Lattice is best thought of as an implementation of Trellis Graphics
  for R.  It is built upon the Grid graphics engine and requires the
  \code{grid} add-on package.  It is not (readily) compatible with
  traditional R graphics tools.  The public interface is based on the
  implementation in S-PLUS, but features several extensions, in addition
  to incompatibilities introduced through the use of \code{grid}.  To
  the extent possible, care has been taken to ensure that existing
  Trellis code written for S-PLUS works unchanged (or with minimal
  change) in Lattice. If you are having problems porting S-PLUS code,
  read the entry for \code{panel} in the documentation for
  \code{\link{xyplot}}. Most high level Trellis functions in S-PLUS are
  implemented, with the exception of \code{piechart}.

  Type \code{help(package = lattice)} to see a list of (public)
  Lattice graphics functions for which further documentation is
  available.  The \sQuote{See Also} section below has list of specific
  areas of possible interest and pointers to the help pages with
  respective details.  Apart from the documentation accompanying this
  package, several documents outlining the use of Trellis graphics are
  available from Bell Lab's website; these might provide a holistic
  introduction to the Trellis paradigm.  A book on lattice is also
  available as part of Springer's \sQuote{Use R} series.

  The example section below shows how to bring up a brief history of
  changes to the lattice package, which provides a summary of new
  features.
}

\note{
  High level Lattice functions (like \code{\link{xyplot}}) are different
  from conventional R graphics functions because they don't actually
  draw anything. Instead, they return an object of class
  \code{"trellis"} which has to be then
  \code{\link[lattice:print.trellis]{print}}ed or
  \code{\link[lattice:print.trellis]{plot}}ted to create the actual
  plot.  This is normally done automatically, but not when the high
  level functions are called inside another function (most often
  \code{source}) or other contexts where automatic printing is
  suppressed (e.g. \code{\link{for}} or \code{\link{while}} loops).  In
  such situations, an explicit call to \code{print} or \code{plot} is
  required.

  Lattice plots are highly customizable via user-modifiable settings.
  However, these are completely unrelated to base graphics settings; in
  particular, changing \code{par()} settings usually have no effect on
  lattice plots.
}

\references{

  Sarkar, Deepayan (2008) \dQuote{Lattice: Multivariate Data
    Visualization with R}, Springer.  ISBN: 978-0-387-75968-5
  \url{http://lmdvr.r-forge.r-project.org/}

  Bell Lab's Trellis Page:
  \url{http://cm.bell-labs.com/cm/ms/departments/sia/project/trellis/}

  Cleveland, W.S. (1993) \emph{Visualizing Data}.

  Becker, R.A., Cleveland, W.S. and Shyu, M.
  \dQuote{The Visual Design and Control of Trellis Display},
  \emph{Journal of Computational and Graphical Statistics}

}


\seealso{
  The Lattice user interface primarily consists of several \sQuote{high
    level} generic functions (listed below), each designed to create a
  particular type of statistical display by default.  While each
  function does different things, they share several common features,
  reflected in several common arguments that affect the resulting
  displays in similar ways.  These arguments are extensively (sometimes
  only) documented in the help page for \code{\link{xyplot}}.  This
  includes a discussion of \emph{conditioning} and control of the
  Trellis layout.

  Lattice employs an extensive system of user-controllable parameters to
  determine the look and feel of the displays it produces.  To learn how
  to use and customise the Graphical parameters used by the Lattice
  functions, see \code{\link{trellis.par.set}}.  For other settings, see
  \code{\link{lattice.options}}.  The default graphical settings are
  different for different graphical devices.  To learn how to initialise
  new devices with the desired settings or change the settings of the
  current device, see \code{\link{trellis.device}}.

  To learn about sophisticated (non-default) printing capabilities, see
  \code{\link{print.trellis}}.  See \code{\link{update.trellis}} to
  learn about manipulating a \code{"trellis"} object.  Tools to augment
  lattice plots after they are drawn (including
  \code{\link{locator}}-like functionality) is described in the
  \code{\link{trellis.focus}} help page.
  % \code{\link[lattice:interaction]{interaction}} help page.

  The following is a list of \sQuote{high level} functions in the
  Lattice package with a brief description of what they do.  In all
  cases, the actual display is produced by the so-called \code{panel}
  function, which has a suitable default, but can be substituted by an
  user defined function to create custom displays.  The user will most
  often be interested in the default panel functions, which have a
  separate help page, linked to from the help pages of the corresponding
  high level function.  Although documented separately, arguments to
  these panel functions can be supplied directly to the high level
  functions, which will forward the arguments as appropriate.

  \bold{Univariate:}  

  \code{\link{barchart}} bar plots

  \code{\link{bwplot}} box and whisker plots

  \code{\link{densityplot}} kernel density plots  

  \code{\link{dotplot}} dot plots

  \code{\link{histogram}} histograms

  \code{\link{qqmath}} quantile plots against mathematical distributions

  \code{\link{stripplot}} 1-dimensional scatterplot

  \bold{Bivariate:}

  \code{\link{qq}} q-q plot for comparing two distributions
  
  \code{\link{xyplot}} scatter plot (and possibly a lot more)

  \bold{Trivariate:}

  \code{\link{levelplot}} level plots (similar to image plots in R)

  \code{\link{contourplot}} contour plots

  \code{\link{cloud}} 3-D scatter plots

  \code{\link{wireframe}} 3-D surfaces (similar to persp plots in R)

  \bold{Hypervariate:}
  
  \code{\link{splom}} scatterplot matrix
  
  \code{\link{parallel}} parallel coordinate plots
  
  \bold{Miscellaneous:}

  \code{\link{rfs}} residual and fitted value plot (also see
  \code{\link{oneway}})

  \code{\link{tmd}} Tukey Mean-Difference plot

  Additionally, there are several panel functions that do little by
  themselves, but can be useful components of custom panel functions.
  These are documented in \code{\link{panel.functions}}.  Lattice also
  has a collection of convenience functions that correspond to the base
  graphics primitives \code{\link{lines}}, \code{\link{points}},
  etc.  They are implemented using Grid graphics, but try to be as close
  to the base versions as possible in terms of their argument
  list.  These functions have imaginative names like
  \code{\link{llines}} or \code{\link{panel.lines}} and are often useful
  when writing (or porting from S-PLUS code) nontrivial panel functions.
}

\examples{
\dontrun{
RShowDoc("NEWS", package = "lattice")
}
}

\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}
\eof
% --- Source file: Rows.Rd ---
\name{Rows}
\alias{Rows}
\title{Extract rows from a list}
\description{
  Convenience function to extract subset of a list. Usually used in
  creating keys.
}
\usage{
Rows(x, which)
}
\arguments{
  \item{x}{ list with each member a vector of the same length }
  \item{which}{ index for members of \code{x}}
}
\value{
  A list similar to \code{x}, with each \code{x[[i]]} replaced by
  \code{x[[i]][which]}
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{xyplot}}, \code{\link{Lattice}}}
\keyword{utilities}
















\eof
% --- Source file: axis.default.Rd ---
\name{axis.default}
\alias{axis.default}
\alias{xscale.components.default}
\alias{yscale.components.default}
\title{Default axis annotation utilities}

\description{
  Lattice funtions provide control over how the plot axes are annotated
  through a common interface.  There are two levels of control.  The
  \code{xscale.components} and \code{yscale.components} arguments can be
  functions that determine tick mark locations and labels given a
  packet.  For more direct control, the \code{axis} argument can be a
  function that actually draws the axes.  The functions documented here
  are the defaults for these arguments.  They can additonally be used as
  components of user written replacements.
}

\usage{
xscale.components.default(lim,
                          packet.number = 0,
                          packet.list = NULL,
                          top = TRUE,
                          \dots)
yscale.components.default(lim,
                          packet.number = 0,
                          packet.list = NULL,
                          right = TRUE,
                          \dots)
axis.default(side = c("top", "bottom", "left", "right"),
             scales, components, as.table,
             labels = c("default", "yes", "no"),
             ticks = c("default", "yes", "no"),
             \dots)

}

\arguments{

  \item{lim}{ the range of the data in that packet (data subset
    corresponding to a combination of levels of the conditioning
    variable).  The range is not necessarily numeric; e.g. for factors,
    they could be character vectors representing levels, and for the
    various date-time representations, they could be vectors of length 2
    with the corresponding class. }
  \item{packet.number}{ which packet (counted according to the packet
    order, described in \code{\link{print.trellis}}) is being
    processed.  In cases where all panels have the same limits, this
    function is called only once (rather than once for each packet), in
    which case this argument will have the value \code{0}.
  }
  \item{packet.list}{ list, as long as the number of packets, giving
    all the actual packets.  Specifically, each component is the
    list of arguments given to the panel function when and if that
    packet is drawn in a panel.  (This has not yet been implemented.) }
  \item{top, right}{ the value of the \code{top} and \code{right}
    components of the result, as appropriate.  See below for
    interpretation.}
  \item{side}{ on which side the axis is to be drawn.  The usual partial
    matching rules apply.  }
  \item{scales}{ the appropriate component of the \code{scales} argument
    supplied to the high level function, suitably standardized. }
  \item{components}{ list, similar to those produced by
    \code{xscale.components.default} and
    \code{yscale.components.default}.  }
  \item{as.table}{ the \code{as.table} argument in the high level
    function.  }
  \item{labels}{ whether labels are to be drawn.  By default, the rules
    determined by \code{scales} are used.  }
  \item{ticks}{ whether labels are to be drawn.  By default, the rules
    determined by \code{scales} are used.  }
  \item{\dots}{ many other arguments may be supplied, and are passed on
    to other internal functions. }
}

\value{

  \code{xscale.components.default} and \code{yscale.components.default}
  return a list of the form suitable as the \code{components} argument
  of \code{axis.default}.  Valid components in the return value of
  \code{xscale.components.default} are:

  \item{\code{num.limit}}{ A numeric limit for the box. }
  \item{\code{bottom}}{ A list with two elements, \code{ticks} and
    \code{labels}.  \code{ticks} must be a list with components
    \code{at} and \code{tck} which give the location and lengths of tick
    marks.  \code{tck} can be a vector, and will be recycled to be as
    long as \code{at}.  \code{labels} must be a list with components
    \code{at}, \code{labels}, and \code{check.overlap}.  \code{at} and
    \code{labels} give the location and labels of the tick labels; this
    is usually the same as the location of the ticks, but is not
    required to be so.  \code{check.overlap} is a logical flag
    indicating whether overlapping of labels should be avoided by
    omitting some of the labels while rendering.  }
  \item{\code{top}}{ This can be a logical flag; if \code{TRUE},
    \code{top} is treated as being the same as \code{bottom}; if
    \code{FALSE}, axis annotation for the top axis is omitted.
    Alternatively, \code{top} can be a list like \code{bottom}.
  }

  Valid components in the return value of
  \code{yscale.components.default} are \code{left} and \code{right}.
  Their interpretations are analogous to (respectively) the
  \code{bottom} and \code{top} components described above.
  
}

\details{

  These functions are part of a new API introduced in lattice 0.14 to
  provide the user more control over how axis annotation is done.
  While the API has been designed in anticipation of use that was
  previously unsupported, the implementation has initially focused on
  reproducing existing capabilities, rather then test new features.  At
  the time of writing, several features are unimplemented.  If you
  require them, please contact the maintainer.

}

\examples{

str(xscale.components.default(c(0, 1)))

set.seed(36872)
rln <- rlnorm(100)

densityplot(rln, 
            scales = list(x = list(log = 2), alternating = 3),
            xlab = "Simulated lognormal variates",
            xscale.components = function(...) {
                ans <- xscale.components.default(...)
                ans$top <- ans$bottom
                ans$bottom$labels$labels <- parse(text = ans$bottom$labels$labels)
                ans$top$labels$labels <-
                    if (require(MASS))
                        fractions(2^(ans$top$labels$at))
                    else
                        2^(ans$top$labels$at)
                ans
            })


## Direct use of axis to show two temperature scales (Celcius and
## Fahrenheit).  This does not work for multi-row plots, and doesn't
## do automatic allocation of space


F2C <- function(f) 5 * (f - 32) / 9 
C2F <- function(c) 32 + 9 * c / 5 

axis.CF <-
    function(side, ...) 
{
    ylim <- current.panel.limits()$ylim
    switch(side,
           left = {
               prettyF <- pretty(ylim)
               labF <- parse(text = sprintf("\%s ~ degree * F", prettyF))
               panel.axis(side = side, outside = TRUE,
                          at = prettyF, labels = labF)
           },
           right = {
               prettyC <- pretty(F2C(ylim))
               labC <- parse(text = sprintf("\%s ~ degree * C", prettyC))
               panel.axis(side = side, outside = TRUE,
                          at = C2F(prettyC), labels = labC)
           },
           axis.default(side = side, ...))
}

xyplot(nhtemp ~ time(nhtemp), aspect = "xy", type = "o",
       scales = list(y = list(alternating = 3)),
       axis = axis.CF, xlab = "Year", ylab = "Temperature", 
       main = "Yearly temperature in New Haven, CT")

## version using yscale.components

yscale.components.CF <-
    function(...)
{
    ans <- yscale.components.default(...)
    ans$right <- ans$left
    ans$left$labels$labels <-
        parse(text = sprintf("\%s ~ degree * F", ans$left$labels$at))
    prettyC <- pretty(F2C(ans$num.limit))
    ans$right$ticks$at <- C2F(prettyC)
    ans$right$labels$at <- C2F(prettyC)
    ans$right$labels$labels <-
        parse(text = sprintf("\%s ~ degree * C", prettyC))
    ans
}
      

xyplot(nhtemp ~ time(nhtemp), aspect = "xy", type = "o",
       scales = list(y = list(alternating = 3)),
       yscale.components = yscale.components.CF,
       xlab = "Year", ylab = "Temperature", 
       main = "Yearly temperature in New Haven, CT")


}


\seealso{
  \code{\link{Lattice}},
  \code{\link{xyplot}}, 
  \code{\link{print.trellis}}
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}

\eof
% --- Source file: banking.Rd ---
\name{banking}
\alias{banking}
\title{Banking}
\description{
  Calculates banking slope
}
\usage{
banking(dx, dy)
}
\arguments{
  \item{dx, dy}{ vector of consecutive x, y differences. }
}

\details{
  \code{banking} is the banking function used when
  \code{aspect = "xy"} in high level Trellis functions. It is usually not
  very meaningful except with \code{xyplot}.  It considers the
  absolute slopes (based on \code{dx} and \code{dy}) and returns a value
  which when adjusted by the panel scale limits will make the median of
  the above absolute slopes correspond to a 45 degree line.

  This function was inspired by the discussion of banking in the
  documentation for Trellis Graphics available at Bell Labs' website
  (see \code{\link{Lattice}}), but is most likely identical to an
  algorithm described by Cleveland et al (see below).  It is
  not clear (to the author) whether this is the algorithm used in
  S-PLUS.  Alternative banking rules, implemented as a similar function,
  can be used as a drop-in replacement by suitably modifying
  \code{lattice.options("banking")}.

}

\examples{

xyplot(sunspot.year ~ time(sunspot.year) | equal.count(time(sunspot.year)), 
       xlab = "", type = "l", aspect = "xy", strip = FALSE,
       scales = list(x = list(alternating = 2, relation = "sliced")),
       as.table = TRUE, main = "Yearly Sunspots")

}


\references{

  Cleveland, William S.,  McGill, Marylyn E. and McGill, Robert (1988),
    "The Shape Parameter of a Two-variable Graph",
    \emph{Journal of the American Statistical Association}, 83, 289-300
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{Lattice}}, \code{\link{xyplot}}}
\keyword{dplot}












\eof
% --- Source file: barchart.table.Rd ---
\name{barchart.table}
\title{table methods for barchart and dotplot}
\alias{barchart.table}
\alias{barchart.array}
\alias{barchart.matrix}
\alias{dotplot.table}
\alias{dotplot.array}
\alias{dotplot.matrix}

\usage{
\method{barchart}{table}(x, data, groups = TRUE,
         origin = 0, stack = TRUE, \dots, horizontal = TRUE)

\method{barchart}{array}(x, data, \dots)

\method{barchart}{matrix}(x, data, \dots)

\method{dotplot}{table}(x, data, groups = TRUE, \dots, horizontal = TRUE)

\method{dotplot}{array}(x, data, \dots)

\method{dotplot}{matrix}(x, data, \dots)
}

\description{
  Contingency tables are often displayed using barcharts and dotplots.
  These methods are provided for convenience and operate directly on
  tables.  Arrays and matrices are simply coerced to be a table.
}

\arguments{
  \item{x}{
    a \code{table}, \code{array} or \code{matrix} object.
  }
  \item{data}{
    should not be specified. If specified, will be ignored with a
    warning.
  }
  \item{groups}{
    logical, whether to use the last dimension as the grouping variable
    in the display.
  }
  \item{origin, stack}{
    arguments to \code{panel.barchart} controlling the display.  The
    defaults for the \code{table} method are different.
  }
  \item{horizontal}{ logical, indicating whether the plot should be
    horizontal (with the categorical variable on the y-axis) or vertical.
  }
  \item{\dots}{ other arguments, passed to the underlying \code{formula}
    method.
  }
}
  
\details{

  The first dimension is used as the variable on the vertical axis.  The
  last dimension is optionally used as a grouping variable (to produce
  stacked barcharts by default).  All other dimensions are used as
  conditioning variables.  The order of these variables cannot be
  altered (except by permuting the original argument using
  \code{\link{t}} or \code{\link{aperm}}).  For more flexibility, use
  the formula method after converting the table to a data frame using
  the relevant \code{\link[base:as.data.frame.table]{as.data.frame}}
  method.

}

\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}


\seealso{

  \code{\link{barchart}}, \code{\link{t}}, \code{\link{aperm}},
  \code{\link{table}}, \code{\link{panel.barchart}},
  \code{\link{Lattice}}

}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\examples{
barchart(Titanic, scales = list(x = "free"),
         auto.key = list(title = "Survived"))
}
\keyword{hplot}
\eof
% --- Source file: barley.Rd ---
\name{barley}
\alias{barley}
\docType{data}
\title{ Yield data from a Minnesota barley trial }

\description{
  Total yield in bushels per acre for 10 varieties at 6 sites in each of
  two years.
}

\usage{barley}

\format{
  A data frame with 120 observations on the following 4 variables.
  \describe{
    \item{yield}{Yield (averaged across three blocks) in bushels/acre.}
    \item{variety}{Factor with levels \code{"Svansota"}, \code{"No. 462"},
      \code{"Manchuria"}, \code{"No. 475"}, \code{"Velvet"},
      \code{"Peatland"}, \code{"Glabron"}, \code{"No. 457"},
      \code{"Wisconsin No. 38"}, \code{"Trebi"}.}
    \item{year}{Factor with levels \code{1932}, \code{1931}}
    \item{site}{Factor with 6 levels:  \code{"Grand Rapids"},
      \code{"Duluth"}, \code{"University Farm"}, \code{"Morris"},
      \code{"Crookston"}, \code{"Waseca"}}
  }
}

\details{
  These data are yields in bushels per acre, of 10 varieties of barley
  grown in 1/40 acre plots at University Farm, St. Paul, and at the five
  branch experiment stations located at Waseca, Morris, Crookston, Grand
  Rapids, and Duluth (all in Minnesota).  The varieties were grown in
  three randomized blocks at each of the six  stations during 1931 and
  1932, different land being used each year of the test.

  Immer et al. (1934) present the data for each Year*Site*Variety*Block.
  The data here is the average yield across the three blocks.

  Immer et al. (1934) refer (once) to the experiment as being conducted
  in 1930 and 1931, then later refer to it (repeatedly) as being
  conducted in 1931 and 1932.  Later authors have continued the
  confusion.

  Cleveland (1993) suggests that the data for the Morris site may have
  had the years switched.
  
}

\source{
  Immer, R. F., H. K. Hayes, and LeRoy Powers. (1934).  Statistical
  Determination of Barley Varietal Adaptation.  \emph{Journal of the
    American Society of Agronomy}, \bold{26}, 403--419.
}

\author{
  Documentation contributed by Kevin Wright.
}

\references{
  Cleveland, William S. (1993). \emph{Visualizing Data}.  Hobart Press,
  Summit, New Jersey.

  Fisher, R. A. (1971). \emph{The Design of Experiments}.  Hafner, New
  York, 9th edition.
}

\seealso{\code{\link[MASS]{immer}} in the MASS package for data from the
  same experiment 
  (expressed as total yield for 3 blocks) for a subset of varieties.}

\examples{
# Graphic suggesting the Morris data switched the years 1931 and 1932
# Figure 1.1 from Cleveland
dotplot(variety ~ yield | site, data = barley, groups = year,
        key = simpleKey(levels(barley$year), space = "right"),
        xlab = "Barley Yield (bushels/acre) ",
        aspect=0.5, layout = c(1,6), ylab=NULL)
}

\keyword{datasets}
\eof
% --- Source file: cloud.Rd ---
\name{cloud}
\title{3d Scatter Plot and Wireframe Surface Plot}
\alias{cloud}
\alias{wireframe}
\alias{cloud.formula}
\alias{cloud.matrix}
\alias{cloud.table}
\alias{wireframe.formula}
\alias{wireframe.matrix}
\usage{
cloud(x, data, \dots)
wireframe(x, data, \dots)

\method{cloud}{formula}(x,
      data,
      allow.multiple = is.null(groups) || outer,
      outer = FALSE,
      auto.key = FALSE,
      aspect = c(1,1),
      panel.aspect = 1,
      panel = lattice.getOption("panel.cloud"),
      prepanel = NULL,
      scales = list(),
      strip = TRUE,
      groups = NULL,
      xlab,
      ylab,
      zlab,
      xlim = if (is.factor(x)) levels(x) else range(x, finite = TRUE),
      ylim = if (is.factor(y)) levels(y) else range(y, finite = TRUE),
      zlim = if (is.factor(z)) levels(z) else range(z, finite = TRUE),
      at,
      drape = FALSE,
      pretty = FALSE,
      drop.unused.levels,
      \dots,
      lattice.options = NULL,
      default.scales =
      list(distance = c(1, 1, 1),
           arrows = TRUE,
           axs = axs.default),
      colorkey,
      col.regions,
      alpha.regions,
      cuts = 70,
      subset = TRUE,
      axs.default = "r")

\method{wireframe}{formula}(x,
          data,
          panel = lattice.getOption("panel.wireframe"),
          \dots)

% \method{wireframe}{formula}(x, data,
%           zoom,
%           scales,
%           at = pretty(z, cuts),
%           drape = FALSE,
%           shade = FALSE,
%           pretty = FALSE,
%           colorkey = any(drape),
%           cuts = 70,
%           col.regions,
%           alpha.regions,
%           \dots,
%           col.regions)
\method{cloud}{matrix}(x, data = NULL, type = "h", 
      zlab = deparse(substitute(x)), aspect, \dots,
      xlim, ylim, row.values, column.values)

\method{cloud}{table}(x, data = NULL, groups = FALSE,
      zlab = deparse(substitute(x)),
      type = "h", \dots)

\method{wireframe}{matrix}(x, data = NULL,
          zlab = deparse(substitute(x)), aspect, \dots,
          xlim, ylim, row.values, column.values)
}
\description{
  Generic functions to draw 3d scatter plots and surfaces.  The
  \code{"formula"} methods do most of the actual work.
}
\arguments{
  \item{x}{
    The object on which method dispatch is carried out.

    For the \code{"formula"} methods, a formula of the form \code{z ~ x
      * y | g1 * g2 * \dots}, where \code{z} is a numeric response, and
    \code{x}, \code{y} are numeric values. \code{g1, g2, \dots}, if
    present, are conditioning variables used for conditioning, and must
    be either factors or shingles. In the case of \code{wireframe},
    calculations are based on the assumption that the \code{x} and
    \code{y} values are evaluated on a rectangular grid defined by their
    unique values.  The grid points need not be equally spaced.

    For \code{wireframe}, \code{x}, \code{y} and \code{z} may also be
    matrices (of the same dimension), in which case they are taken to
    represent a 3-D surface parametrized on a 2-D grid (e.g., a sphere).
    Conditioning is not possible with this feature. See details below.

    Missing values are allowed, either as \code{NA} values in the
    \code{z} vector, or missing rows in the data frame (note however
    that in that case the X and Y grids will be determined only by the
    available values). For a grouped display (producing multiple
    surfaces), missing rows are not allowed, but \code{NA}-s in \code{z}
    are.

    Both \code{wireframe} and \code{cloud} have methods for
    \code{matrix} objects, in which case \code{x} provides the
    \code{z} vector described above, while its rows and columns are
    interpreted as the \code{x} and \code{y} vectors respectively.  This
    is similar to the form used in \code{persp}.
  }
  \item{data}{
    for the \code{"formula"} methods, an optional data frame in which
    variables in the formula (as well as \code{groups} and
    \code{subset}, if any) are to be evaluated.  \code{data} should not
    be specified except when using the \code{"formula"} method.
  }
  \item{row.values, column.values}{ Optional vectors of values that
    define the grid when \code{x} is a matrix.  \code{row.values} and
    \code{column.values} must have the same lengths as \code{nrow(x)}
    and \code{ncol(x)} respectively.  By default, row and column
    numbers. }
  \item{allow.multiple, outer, auto.key, prepanel, strip, groups, xlab,
    xlim, ylab, ylim, drop.unused.levels, lattice.options,
    default.scales, subset}{
    These arguments are documented in the help page for
    \code{\link{xyplot}}.  For the \code{cloud.table} method,
    \code{groups} must be a logical indicating whether the last
    dimension should be used as a grouping variable as opposed to a
    conditioning variable.  This is only relevant if the table has more
    than 2 dimensions.
  }
  \item{type}{
    type of display in \code{cloud} (see \code{\link{panel.3dscatter}}
    for details).  Defaults to \code{"h"} for the \code{matrix} method.
  }
  \item{aspect, panel.aspect}{
    unlike other high level functions, \code{aspect} is taken to be a
    numeric vector of length 2, giving the relative aspects of the
    y-size/x-size and z-size/x-size of the enclosing cube.  The usual
    role of the \code{aspect} argument in determining the aspect ratio
    of the panel (see \code{\link{xyplot}} for details) is played by
    \code{panel.aspect}, except that it can only be a numeric value.

    For the \code{matrix} methods, the default y/x aspect is
    \code{ncol(x) / nrow(x)} and the z/x aspect is the smaller of the
    y/x aspect and 1.
  }
  \item{panel}{
    panel function used to create the display.  See
    \code{\link{panel.cloud}} for (non-trivial) details.
  }
  \item{scales}{
    a list describing the scales.  As with other high level functions
    (see \code{\link{xyplot}} for details), this list can contain
    parameters in name=value form.  It can also contain components with
    the special names \code{x}, \code{y} and \code{z}, which can be
    similar lists with axis-specific values overriding the ones
    specified in \code{scales}. 

    The most common use for this argument is to set \code{arrows=FALSE},
    which causes tick marks and labels to be used instead of arrows
    being drawn (the default).  Both can be suppressed by
    \code{draw=FALSE}.  Another special component is \code{distance},
    which specifies the relative distance of the axis label from the
    bounding box.  If specified as a component of \code{scales} (as
    opposed to one of \code{scales$z} etc), this can be (and is recycled
    if not) a vector of length 3, specifying distances for the x, y and
    z labels respectively.

    Other components that work in the \code{scales} argument of
    \code{xyplot} etc. should also work here (as long as they make
    sense), including explicit specification of tick mark locations and
    labels.  (Not everything is implemented yet, but if you find
    something that should work but does not, feel free to bug the
    maintainer.)

    Note, however, that for these functions \code{scales} cannot contain
    information that is specific to particular panels.  If you really
    need that, consider using the \code{scales.3d} argument of
    \code{panel.cloud}.
  }
  \item{axs.default}{
    Unlike 2-D display functions, \code{cloud} does not expand the
    bounding box to slightly beyound the range of the data, even though
    it should.  This is primarily because this is the natural behaviour
    in \code{wireframe}, which uses the same code.  \code{axs.default}
    is intended to provide a different default for \code{cloud}.
    However, this feature has not yet been implemented.
  }
  \item{zlab}{
    Specifies a label describing the z variable in ways similar to
    \code{xlab} and \code{ylab} (i.e. \dQuote{grob}, character string,
    expression or list) in other high level functions.  Additionally, if
    \code{zlab} (and \code{xlab} and \code{ylab}) is a list, it can
    contain a component called \code{rot}, controlling the rotation for
    the label
  }
  \item{zlim}{
    limits for the z-axis. Similar to \code{xlim} and \code{ylim} in
    other high level functions
  }
  \item{drape}{
    logical, whether the wireframe is to be draped in color. If
    \code{TRUE}, the height of a facet is used to determine its color in
    a manner similar to the coloring scheme used in
    \code{\link{levelplot}}.  Otherwise, the background color is used to
    color the facets.  This argument is ignored if \code{shade = TRUE}
    (see \code{\link{panel.3dwire}}).
  }
  \item{at, col.regions, alpha.regions}{
    these arguments are analogous to those in
    \code{\link{levelplot}}. if \code{drape=TRUE}, \code{at} gives the
    vector of cutpoints where the colors change, and \code{col.regions}
    the vector of colors to be used in that case.  \code{alpha.regions}
    determines the alpha-transparency on supporting devices.  These are
    passed down to the panel function, and also used in the colorkey if
    appropriate.  The default for \code{col.regions} and
    \code{alpha.regions} is derived from the Trellis setting
    \code{"regions"}
  }
  \item{cuts}{
    if \code{at} is unspecified, the approximate number of cutpoints if
    \code{drape=TRUE}
  }
  \item{pretty}{
    whether automatic choice of cutpoints should be prettfied
  }
  \item{colorkey}{
    logical indicating whether a color key should be drawn
    alongside, or a list describing such a key.  See
    \code{\link{levelplot}} for details.
  }
  \item{\dots}{
    Any number of other arguments can be specified, and are passed to
    the panel function.  In particular, the arguments \code{distance},
    \code{perspective}, \code{screen} and \code{R.mat} are very
    important in determining the 3-D display.  The argument \code{shade}
    can be useful for \code{wireframe} calls, and controls shading of
    the rendered surface.  These arguments are described in detail in
    the help page for \code{\link{panel.cloud}}.

    Additionally, an argument called \code{zoom} may be specified, which
    should be a numeric scalar to be interpreted as a scale factor by
    which the projection is magnified.  This can be useful to get the
    variable names into the plot.  This argument is actually only used
    by the default prepanel function.
  }
}
\details{
  These functions produce three dimensional plots in each panel (as long
  as the default panel functions are used).  The orientation is obtained
  as follows: the data are scaled to fall within a bounding box that is
  contained in the [-0.5, 0.5] cube (even smaller for non-default values
  of \code{aspect}).  The viewing direction is given by a sequence of
  rotations specified by the \code{screen} argument, starting from the
  positive Z-axis. The viewing point (camera) is located at a distance
  of \code{1/distance} from the origin. If \code{perspective=FALSE},
  \code{distance} is set to 0 (i.e., the viewing point is at an infinite
  distance).

  \code{cloud} draws a 3-D Scatter Plot, while \code{wireframe} draws a
  3-D surface (usually evaluated on a grid). Multiple surfaces can be
  drawn by \code{wireframe} using the \code{groups} argument (although
  this is of limited use because the display is incorrect when the
  surfaces intersect). Specifying \code{groups} with \code{cloud}
  results in a \code{panel.superpose}-like effect (via
  \code{\link{panel.3dscatter}}).

  \code{wireframe} can optionally render the surface as being
  illuminated by a light source (no shadows though). Details can be
  found in the help page for \code{\link{panel.3dwire}}. Note that
  although arguments controlling these are actually arguments for the
  panel function, they can be supplied to \code{cloud} and
  \code{wireframe} directly.

  For single panel plots, \code{wireframe} can also plot parametrized
  3-D surfaces (i.e., functions of the form f(u,v) = (x(u,v), y(u,v),
  z(u,v)), where values of (u,v) lie on a rectangle. The simplest
  example of this sort of surface is a sphere parametrized by latitude
  and longitude. This can be achieved by calling \code{wireframe} with a
  formula \code{x} of the form \code{z~x*y}, where \code{x}, \code{y}
  and \code{z} are all matrices of the same dimension, representing the
  values of x(u,v), y(u,v) and z(u,v) evaluated on a discrete
  rectangular grid (the actual values of (u,v) are irrelevant).

  When this feature is used, the heights used to calculate \code{drape}
  colors or shading colors are no longer the \code{z} values, but the
  distances of \code{(x,y,z)} from the origin.

  Note that this feature does not work with \code{groups},
  \code{subscripts}, \code{subset}, etc. Conditioning variables are also
  not supported in this case.

  The algorithm for identifying which edges of the bounding box are
  \sQuote{behind} the points doesn't work in some extreme
  situations. Also, \code{\link{panel.cloud}} tries to figure out the
  optimal location of the arrows and axis labels automatically, but can
  fail on occasion (especially when the view is from \sQuote{below} the
  data). This can be manually controlled by the \code{scpos} argument in
  \code{\link{panel.cloud}}.

  These and all other high level Trellis functions have several other
  arguments in common. These are extensively documented only in the
  help page for \code{\link{xyplot}}, which should be consulted to learn
  more detailed usage.

}

\note{ There is a known problem with grouped \code{wireframe} displays
  when the (x, y) coordinates represented in the data do not represent
  the full evaluation grid.  The problem occurs whether the grouping is
  specified through the \code{groups} argument or through the formula
  interface, and currently causes memory access violations.  Depending
  on the circumstances, this is manifested either as a meaningless plot
  or a crash.  To work around the problem, it should be enough to have
  a row in the data frame for each grid point, with an \code{NA}
  response (\code{z}) in rows that were previously missing.  }

\references{
  Sarkar, Deepayan (2008) "Lattice: Multivariate Data Visualization with
  R", Springer. \url{http://lmdvr.r-forge.r-project.org/}
}

\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}
\seealso{
  \code{\link{Lattice}} for an overview of the package, as well as 
  \code{\link{xyplot}}, \code{\link{levelplot}},
  \code{\link{panel.cloud}}
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\examples{
## volcano  ## 87 x 61 matrix
wireframe(volcano, shade = TRUE,
          aspect = c(61/87, 0.4),
          light.source = c(10,0,10))

g <- expand.grid(x = 1:10, y = 5:15, gr = 1:2)
g$z <- log((g$x^g$g + g$y^2) * g$gr)
wireframe(z ~ x * y, data = g, groups = gr,
          scales = list(arrows = FALSE),
          drape = TRUE, colorkey = TRUE,
          screen = list(z = 30, x = -60))

cloud(Sepal.Length ~ Petal.Length * Petal.Width | Species, data = iris,
      screen = list(x = -90, y = 70), distance = .4, zoom = .6)

## cloud.table

cloud(prop.table(Titanic, margin = 1:3),
      type = c("p", "h"), strip = strip.custom(strip.names = TRUE),
      scales = list(arrows = FALSE, distance = 2), panel.aspect = 0.7,
      zlab = "Proportion")[, 1]

## transparent axes

par.set <-
    list(axis.line = list(col = "transparent"),
         clip = list(panel = "off"))
print(cloud(Sepal.Length ~ Petal.Length * Petal.Width, 
            data = iris, cex = .8, 
            groups = Species, 
            main = "Stereo",
            screen = list(z = 20, x = -70, y = 3),
            par.settings = par.set,
            scales = list(col = "black")),
      split = c(1,1,2,1), more = TRUE)
print(cloud(Sepal.Length ~ Petal.Length * Petal.Width,
            data = iris, cex = .8, 
            groups = Species,
            main = "Stereo",
            screen = list(z = 20, x = -70, y = 0),
            par.settings = par.set,
            scales = list(col = "black")),
      split = c(2,1,2,1))

}
\keyword{hplot}
\eof
% --- Source file: draw.colorkey.Rd ---
\name{draw.colorkey}
\alias{draw.colorkey}
\title{Produce a Colorkey for levelplot}
\description{
  Produces (and possibly draws) a Grid frame grob which is a colorkey
  that can be placed in other Grid plots. Used in levelplot
}
\usage{
draw.colorkey(key, draw=FALSE, vp=NULL)
}
\arguments{
  \item{key}{ A list determining the key. See documentation for
    \code{levelplot}, in particular the section describing the
    \code{colorkey} argument, for details.
  }
  \item{draw}{ logical, whether the grob is to be drawn. }
  \item{vp}{ viewport }
}
\value{
  A Grid frame object (that inherits from \code{"grob"})
}
\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{xyplot}}}
\keyword{dplot}

\eof
% --- Source file: draw.key.Rd ---
\name{draw.key}
\alias{draw.key}
\title{Produce a Legend or Key}
\description{
  Produces (and possibly draws) a Grid frame grob which is a legend (aka 
  key) that can be placed in other Grid plots.
}
\usage{
draw.key(key, draw=FALSE, vp=NULL, \dots)
}
\arguments{
  \item{key}{ A list determining the key. See documentation for
    \code{xyplot}, in particular the section describing the \code{key}
    argument, for details.
  }
  \item{draw}{ logical, whether the grob is to be drawn. }
  \item{vp}{ viewport }
  \item{\dots}{ignored}
}
\value{
  A Grid frame object (that inherits from \sQuote{grob}).
}
\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{xyplot}}}
\keyword{dplot}

\eof
% --- Source file: environmental.Rd ---
\name{environmental}
\alias{environmental}
\docType{data}
\title{ Atmospheric environmental conditions in New York City }

\description{
  Daily measurements of ozone concentration, wind speed, temperature and
  solar radiation in New York City from May to September of 1973.
}

\usage{environmental}

\format{
  A data frame with 111 observations on the following 4 variables.
  \describe{
    \item{ozone}{Average ozone concentration (of hourly measurements) of
      in parts per billion.}
    \item{radiation}{Solar radiation (from 08:00 to 12:00) in langleys.}
    \item{temperature}{Maximum daily emperature in degrees Fahrenheit.}
    \item{wind}{Average wind speed (at 07:00 and 10:00) in miles per hour.}
  }
}

\source{
  Bruntz, S. M., W. S. Cleveland, B. Kleiner, and J. L. Warner.  (1974).
  The Dependence of Ambient Ozone on Solar Radiation, Wind, Temperature,
  and Mixing Height.  In \emph{Symposium on Atmospheric Diffusion and
    Air Pollution}, pages 125--128.  American Meterological Society,
  Boston.
}

\author{
  Documentation contributed by Kevin Wright.
}

\references{
  Cleveland, William S. (1993). \emph{Visualizing Data}.  Hobart Press,
  Summit, New Jersey.
}

\examples{
# Scatter plot matrix with loess lines
splom(~environmental,
  panel=function(x,y){
    panel.xyplot(x,y)
    panel.loess(x,y)
  }
)


# Conditioned plot similar to figure 5.3 from Cleveland
attach(environmental)
Temperature <- equal.count(temperature, 4, 1/2)
Wind <- equal.count(wind, 4, 1/2)
xyplot((ozone^(1/3)) ~ radiation | Temperature * Wind,
  aspect=1,
	prepanel = function(x, y) 
		prepanel.loess(x, y, span = 1),
	panel = function(x, y){
		panel.grid(h = 2, v = 2)
		panel.xyplot(x, y, cex = .5)
		panel.loess(x, y, span = 1)
	},
	xlab = "Solar radiation (langleys)",
	ylab = "Ozone (cube root ppb)")
detach()

# Similar display using the coplot function
with(environmental,{
  coplot((ozone^.33) ~ radiation | temperature * wind,
  number=c(4,4),
  panel = function(x, y, ...) panel.smooth(x, y, span = .8, ...),
  xlab="Solar radiation (langleys)",
  ylab="Ozone (cube root ppb)")
})
}

\keyword{datasets}
\eof
% --- Source file: ethanol.Rd ---
\name{ethanol}
\alias{ethanol}
\docType{data}
\title{ Engine exhaust fumes from burning ethanol }

\description{
  Ethanol fuel was burned in a single-cylinder engine.  For various
  settings of the engine compression and equivalence ratio, the
  emissions of nitrogen oxides were recorded.
}

\usage{ethanol}

\format{
  A data frame with 88 observations on the following 3 variables.
  \describe{
    \item{NOx}{Concentration of nitrogen oxides (NO and NO2) in
      micrograms/J.}
    \item{C}{Compression ratio of the engine.}
    \item{E}{Equivalence ratio--a measure of the richness of the air and
      ethanol fuel mixture.}
  }
}

\source{
  Brinkman, N.D. (1981) Ethanol Fuel---A Single-Cylinder Engine Study of
  Efficiency and Exhaust Emissions. \emph{SAE transactions},
  \bold{90}, 1410--1424.
}

\author{
  Documentation contributed by Kevin Wright.
}

\references{
  Cleveland, William S. (1993). \emph{Visualizing Data}.  Hobart Press,
  Summit, New Jersey.
}

\examples{
## Constructing panel functions on the fly
EE <- equal.count(ethanol$E, number=9, overlap=1/4)
xyplot(NOx ~ C | EE, data = ethanol,
       prepanel = function(x, y) prepanel.loess(x, y, span = 1),
       xlab = "Compression ratio", ylab = "NOx (micrograms/J)",
       panel = function(x, y) {
           panel.grid(h=-1, v= 2)
           panel.xyplot(x, y)
           panel.loess(x,y, span=1)
       },
       aspect = "xy")

# Wireframe loess surface fit.  See Figure 4.61 from Cleveland.
require(stats)
with(ethanol, {
  eth.lo <- loess(NOx ~ C * E, span = 1/3, parametric = "C", 
                  drop.square = "C", family="symmetric")
  eth.marginal <- list(C = seq(min(C), max(C), length.out = 25), 
                       E = seq(min(E), max(E), length.out = 25))
  eth.grid <- expand.grid(eth.marginal)
  eth.fit <- predict(eth.lo, eth.grid)
  wireframe(eth.fit ~ eth.grid$C * eth.grid$E,
            shade=TRUE,
	    screen = list(z = 40, x = -60, y=0),
	    distance = .1,
	    xlab = "C", ylab = "E", zlab = "NOx")
})
}

\keyword{datasets}
\eof
% --- Source file: histogram.Rd ---
\name{histogram}
\alias{histogram}
\alias{histogram.factor}
\alias{histogram.numeric}
\alias{histogram.formula}
\alias{densityplot}
\alias{densityplot.numeric}
\alias{densityplot.formula}
\alias{do.breaks}
\title{Histograms and Kernel Density Plots}
\usage{
histogram(x, data, \dots)
densityplot(x, data, \dots)
\method{histogram}{formula}(x,
          data,
          allow.multiple, outer = TRUE,
          auto.key = FALSE,
          aspect = "fill",
          panel = lattice.getOption("panel.histogram"),
          prepanel, scales, strip, groups,
          xlab, xlim, ylab, ylim,
          type = c("percent", "count", "density"),
          nint = if (is.factor(x)) nlevels(x)
          else round(log2(length(x)) + 1),
          endpoints = extend.limits(range(as.numeric(x), finite = TRUE), prop = 0.04),
          breaks,
          equal.widths = TRUE,
          drop.unused.levels = lattice.getOption("drop.unused.levels"),
          \dots,
          lattice.options = NULL,
          default.scales = list(),
          subscripts,
          subset)

\method{histogram}{numeric}(x, data = NULL, xlab, \dots)
\method{histogram}{factor}(x, data = NULL, xlab, \dots)


\method{densityplot}{formula}(x,
            data,
            allow.multiple = is.null(groups) || outer,
            outer = !is.null(groups),
            auto.key = FALSE,
            aspect = "fill",
            panel = lattice.getOption("panel.densityplot"),
            prepanel, scales, strip, groups, weights,
            xlab, xlim, ylab, ylim,
            bw, adjust, kernel, window, width, give.Rkern,
            n = 50, from, to, cut, na.rm,
            drop.unused.levels = lattice.getOption("drop.unused.levels"),
            \dots,
            lattice.options = NULL,
            default.scales = list(),
            subscripts,
            subset)
\method{densityplot}{numeric}(x, data = NULL, xlab, \dots)

do.breaks(endpoints, nint)
}
\description{
  Draw Histograms and Kernel Density Plots, possibly conditioned on
  other variables.
}
\arguments{
  \item{x}{
    The object on which method dispatch is carried out.

    For the \code{formula} method, a formula of the form \code{~ x | g1
      * g2 * \dots} indicates that histograms or Kernel Density
    estimates of \code{x} should be produced conditioned on the levels
    of the (optional) variables \code{g1, g2, \dots}.  \code{x} can be
    numeric (or factor for \code{histogram}), and each of \code{g1, g2,
      \dots} must be either factors or shingles.

    As a special case, the right hand side of the formula can contain
    more than one variable separated by a \code{+} sign. What happens in
    this case is described in details in the documentation for
    \code{\link{xyplot}}.  Note that in either form, all the variables
    involved in the formula have to have same length.

    For the \code{numeric} and \code{factor} methods, \code{x}
    replaces the \code{x} vector described above.  Conditioning is not
    allowed in these cases.

  }
  \item{data}{
    For the \code{formula} method, an optional data frame in which
    variables are to be evaluated.  Ignored with a warning in other
    cases.
  }
  \item{type}{
    Character string indicating type of histogram to be drawn.
    \code{"percent"} and \code{"count"} give relative frequency
    and frequency histograms, and can be misleading when breakpoints are
    not equally spaced. \code{"density"} produces a density scale
    histogram.

    \code{type} defaults to \code{"percent"}, except when the
    breakpoints are unequally spaced or \code{breaks = NULL}, when it
    defaults to \code{"density"}.

  }
  \item{nint}{
    Number of bins.  Applies only when \code{breaks} is unspecified or
    \code{NULL} in the call.  Not applicable when the variable being
    plotted is a factor.
  }
  \item{endpoints}{
    vector of length 2 indicating the range of x-values that is to be
    covered by the histogram.  This applies only when \code{breaks} is
    unspecified and the variable being plotted is not a factor.  In
    \code{do.breaks}, this specifies the interval that is to be divided
    up.
  }
  \item{breaks}{ usually a numeric vector of length (number of bins +
    1) defining the breakpoints of the bins.  Note that when breakpoints
    are not equally spaced, the only value of \code{type} that makes
    sense is density.  When unspecified, the default is to use
    \preformatted{
      breaks = seq_len(1 + nlevels(x)) - 0.5
    }
    when \code{x} is a factor, and 
    \preformatted{
      breaks = do.breaks(endpoints, nint)
    }
    otherwise.  Breakpoints calculated in such a manner are used in all
    panels.

    Other values of \code{breaks} are possible, in which case they
    affect the display in each panel differently.  A special value of
    \code{breaks} is \code{NULL}, in which case the number of bins is
    determined by \code{nint} and then breakpoints are chosen according to
    the value of \code{equal.widths}.  Other valid values of
    \code{breaks} are those of the \code{breaks} argument in
    \code{\link{hist}}.  This allows specification of \code{breaks} as
    an integer giving the number of bins (similar to \code{nint}), as a
    character string denoting a method, and as a function.
  }
  \item{equal.widths}{ logical, relevant only when \code{breaks=NULL}.
    If \code{TRUE}, equally spaced bins will be selected, otherwise, 
    approximately equal area bins will be selected (this would mean that
    the breakpoints will \bold{not} be equally spaced).
  }
  \item{n}{ number of points at which density is to be evaluated }
  \item{panel}{ The function that uses the packet (subset of display
    variables) corresponding to a panel to create a display.  Default
    panel functions are documented separately, and often have arguments
    that can be used to customize its display in various ways.  Such
    arguments can usually be directly supplied to the high level
    function.  }
%   \item{panel.groups}{ function used as the \code{panel.groups} argument
%     when \code{panel.superpose} is used as the panel function, which
%     happens by default when \code{groups} is non-null.  }
  \item{allow.multiple, outer, auto.key, aspect, prepanel, scales,
    strip, groups, xlab, xlim, ylab, ylim, drop.unused.levels,
    lattice.options, default.scales, subscripts, subset}{ See
    \code{\link{xyplot}} }
  \item{weights}{ numeric vector of weights for the density
    calculations, evaluated in the non-standard manner used for
    \code{groups} and terms in the formula, if any.  If this is
    specified, it is subsetted using \code{subscripts} inside the panel
    function to match it to the corresponding \code{x} values.

    At the time of writing, \code{weights} do not work in conjunction
    with an extended formula specification (this is not too hard to fix,
    so just bug the maintainer if you need this feature).
  }
  \item{bw, adjust, kernel, window, width, give.Rkern, from, to, cut,
    na.rm}{ arguments to \code{\link{density}}, passed on as appropriate
  }
  \item{\dots}{ Further arguments.  See corresponding entry in
    \code{\link{xyplot}} for non-trivial details.  }
}
\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}
\details{
  \code{histogram} draws Conditional Histograms, while
  \code{densityplot} draws Conditional Kernel Density Plots.  The
  density estimate in \code{densityplot} is actually calculated using
  the function \code{density}, and all arguments accepted by it can be
  passed (as \code{\dots}) in the call to \code{densityplot} to control
  the output.  See documentation of \code{density} for details. (Note:
  The default value of the argument \code{n} of \code{density} is
  changed to 50.)
  
  These and all other high level Trellis functions have several
  arguments in common. These are extensively documented only in the
  help page for \code{xyplot}, which should be consulted to learn more
  detailed usage.

  \code{do.breaks} is an utility function that calculates breakpoints
  given an interval and the number of pieces to break it into.
  
}
\note{
  The form of the arguments accepted by the default panel function
  \code{panel.histogram} is different from that in S-PLUS. Whereas
  S-PLUS calculates the heights inside \code{histogram} and passes only
  the breakpoints and the heights to the panel function, here the
  original variable \code{x} is passed along with the breakpoints. This
  allows plots as in the second example below.
}

\references{
  Sarkar, Deepayan (2008) "Lattice: Multivariate Data Visualization with
  R", Springer. \url{http://lmdvr.r-forge.r-project.org/}
}

\seealso{
  \code{\link{xyplot}},
  \code{\link{panel.histogram}},
  \code{\link{density}},
  \code{\link{panel.densityplot}},
  \code{\link{panel.mathdensity}},
  \code{\link{Lattice}} 
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\examples{
require(stats)
histogram( ~ height | voice.part, data = singer, nint = 17,
          endpoints = c(59.5, 76.5), layout = c(2,4), aspect = 1,
          xlab = "Height (inches)")

histogram( ~ height | voice.part, data = singer,
          xlab = "Height (inches)", type = "density",
          panel = function(x, ...) {
              panel.histogram(x, ...)
              panel.mathdensity(dmath = dnorm, col = "black",
                                args = list(mean=mean(x),sd=sd(x)))
          } )

densityplot( ~ height | voice.part, data = singer, layout = c(2, 4),  
            xlab = "Height (inches)", bw = 5)
}
\keyword{hplot}
\eof
% --- Source file: interaction.Rd ---
\name{interaction}
\alias{panel.identify}
\alias{panel.identify.qqmath}
\alias{panel.identify.cloud}
\alias{panel.link.splom}
\alias{panel.brush.splom}
\alias{trellis.focus}
\alias{trellis.unfocus}
\alias{trellis.switchFocus}
\alias{trellis.panelArgs}
\alias{trellis.vpname}
\alias{trellis.grobname}
\concept{interaction}
\concept{augment}
\title{Functions to Interact with Lattice Plots}
\description{
  The classic Trellis paradigm is to plot the whole object at once,
  without the possibility of interacting with it afterwards.  However,
  by keeping track of the grid viewports where the panels and strips are
  drawn, it is possible to go back to them afterwards and enhance them
  one panel at a time.  These functions provide convenient interfaces to
  help in this.  Note that these are still experimental and the exact
  details may change in future.
}
\usage{
panel.identify(x, y = NULL,
               subscripts = seq_along(x),
               labels = subscripts, 
               n = length(x), offset = 0.5,
               threshold = 18, ## in points, roughly 0.25 inches
               panel.args = trellis.panelArgs(),
               \dots)
panel.identify.qqmath(x, distribution, groups, subscripts, labels,
                      panel.args = trellis.panelArgs(),
                      \dots)
panel.identify.cloud(x, y, z, subscripts,
                     perspective, distance, 
                     xlim, ylim, zlim,
                     screen, R.mat, aspect, scales.3d,
                     \dots,
                     panel.3d.identify,
                     n = length(subscripts),
                     offset = 0.5,
                     threshold = 18,
                     labels = subscripts,
                     panel.args = trellis.panelArgs())
panel.link.splom(threshold = 18, verbose = getOption("verbose"), \dots)
panel.brush.splom(threshold = 18, verbose = getOption("verbose"), \dots)


trellis.vpname(name = c("position", "split", "split.location", "toplevel",
               "figure", "panel", "strip", "strip.left", "legend",
               "main", "sub", "xlab", "ylab", "page"),
               column, row,
               side = c("left", "top", "right", "bottom", "inside"),
               clip.off = FALSE, prefix)
trellis.grobname(name, prefix)
trellis.focus(name, column, row, side, clip.off,
              highlight = interactive(), \dots,
              guess = TRUE, verbose = getOption("verbose"))
trellis.switchFocus(name, side, clip.off, highlight, \dots)
trellis.unfocus()
trellis.panelArgs(x, packet.number)
}

\arguments{
  \item{x, y, z}{ variables defining the contents of the panel.  In the
    case of \code{trellis.panelArgs}, a \code{"trellis"} object. }
  \item{n}{
    the number of points to identify by default (overridden by a right
    click)
  }
  \item{subscripts}{
    an optional vector of integer indices associated with each point.
    See details below.
  }
  \item{labels}{
    an optional vector of labels associated with each point.  Defaults
    to \code{subscripts}
  }
  \item{distribution, groups}{ typical panel arguments of
    \code{\link{panel.qqmath}}.  These will usually be obtained from
    \code{panel.args}
  }
  \item{offset}{
    the labels are printed either below, above, to the left or to the
    right of the identified point, depending on the relative location of
    the mouse click. The \code{offset} specifies (in "char" units) how
    far from the identified point the labels should be printed.
  }
  \item{threshold}{
    threshold in grid's \code{"points"} units. Points further than these
    from the mouse click position are not considered
  }
  \item{panel.args}{
    list that contains components names \code{x} (and usually \code{y}),
    to be used if \code{x} is missing.  Typically, when called after
    \code{trellis.focus}, this would appropriately be the arguments
    passed to that panel.
  }
  \item{perspective, distance, xlim, ylim, zlim, screen, R.mat, aspect,
    scales.3d}{
    arguments as passed to \code{\link{panel.cloud}}.  These are
    required to recompute the relevant three-dimensional projections in
    \code{panel.identify.cloud}.
  }
  \item{panel.3d.identify}{
    the function that is responsible for the actual interaction once the
    data rescaling and rotation computations have been done.  By
    default, an internal function similar to \code{panel.identify} is
    used.
  }
  \item{name}{
    character string indicating which viewport or grob we are looking
    for.  Although these do not necessarily provide access to all
    viewports and grobs created by a lattice plot, they cover most that
    users might find interesting.

    \code{trellis.vpname} and \code{trellis.focus} deal with viewport
    names only, and only accept the values explicitly listed above.
    \code{trellis.grobname} is meant to create names for grobs, and can
    currently accept any value.

    If \code{name}, as well as \code{column} and \code{row} is missing
    in a call to \code{trellis.focus}, the user can click inside a panel
    (or an associated strip) to focus on that panel.  Note however that
    this assumes equal width and height for each panel, and may not work
    when this is not true.

    When \code{name} is \code{"panel"}, \code{"strip"}, or
    \code{"strip.left"}, \code{column} and \code{row} must also be
    specified.  When \code{name} is \code{"legend"}, \code{side} must
    also be specified.

  }
  \item{column, row}{
    integers, indicating position of the panel or strip that should be
    assigned focus in the Trellis layout. Rows are usually calculated
    from the bottom up, unless the plot was created with
    \code{as.table=TRUE}
  }
  \item{guess}{
    logical.  If \code{TRUE}, and the display has only one panel, that
    panel will be automatically selected by a call to
    \code{trellis.focus}.
  }
  \item{side}{
    character string, relevant only for legends (i.e., when
    \code{name="legend"}), indicating their position.  Partial specification
    is allowed, as long as it is unambiguous.
  }
  \item{clip.off}{
    logical, whether clipping should be off, relevant when \code{name}
    is \code{"panel"} or \code{"strip"}.  This is necessary if axes are
    to be drawn outside the panel or strip.  Note that setting
    \code{clip.off=FALSE} does not necessarily mean that clipping is on;
    that is determined by conditions in effect during printing.

  }
  \item{prefix}{
    character string acting as a prefix, meant to distinguish otherwise
    equivalent viewports in different plots. This only becomes relevant
    when a particular page is occupied by more than one plot.  Defaults
    to the value appropriate for the last \code{"trellis"} object printed, as
    determined by the \code{prefix} argument in
    \code{\link{print.trellis}}.  Users should not usually need to
    supply a value for this argument (see note below), however, if
    supplied explicitly, this has to be a valid R symbol name (briefly,
    it must start with a letter or a period followed by a letter) and
    must not contain the grid path separator (currently \code{"::"})
  }
  \item{highlight}{
    logical, whether the viewport being assigned focus should be
    highlighted.  For \code{trellis.focus}, the default is \code{TRUE}
    in interactive mode, and \code{trellis.switchFocus} by default
    preserves the setting currently active.
  }
  \item{packet.number}{
    integer, which panel to get data from.  See
    \code{\link{packet.number}} for details on how this is calculated
  }
  \item{verbose}{ whether details  will be printed }
  \item{\dots}{
    For \code{panel.identify.qqmath}, extra parameters are passed on to
    \code{panel.identify}.  For \code{panel.identify}, extra arguments
    are treated as graphical parameters and are used for labelling.  For
    \code{trellis.focus} and \code{trellis.switchFocus}, these are used
    (in combination with \code{\link{lattice.options}}) for highlighting
    the chosen viewport if so requested.  Graphical parameters can be
    supplied for \code{panel.link.splom}.
  }
}

\details{
  \code{panel.identify} is similar to \code{\link{identify}}.  When
  called, it waits for the user to identify points (in the panel being
  drawn) via mouse clicks.  Clicks other than left-clicks terminate the
  procedure.  Although it is possible to call it as part of the panel
  function, it is more typical to use it to identify points after
  plotting the whole object, in which case a call to
  \code{trellis.focus} first is necessary.

  \code{panel.link.splom} is meant for use with \code{\link{splom}},
  and requires a panel to be chosen using \code{trellis.focus} before it
  is called.  Clicking on a point causes that and the corresponding
  proections in other pairwise scatter plots to be highlighted.
  \code{panel.brush.splom} is a (misnamed) alias for
  \code{panel.link.splom}, retained for back-compatibility.

  \code{panel.identify.qqmath} is a specialized wrapper meant for use
  with the display produced by \code{\link{qqmath}}.
  \code{panel.identify.qqmath} is a specialized wrapper meant for use
  with the display produced by \code{\link{cloud}}.  It would be unusual
  to call them except in a context where default panel function
  arguments are available through \code{trellis.panelArgs} (see below).
  
  One way in which \code{panel.identify} etc. are different from
  \code{\link{identify}} is in how it uses the \code{subscripts}
  argument.  In general, when one identifies points in a panel, one
  wants to identify the origin in the data frame used to produce the
  plot, and not within that particular panel.  This information is
  available to the panel function, but only in certain situations.  One
  way to ensure that \code{subscripts} is available is to specify
  \code{subscripts = TRUE} in the high level call such as \code{xyplot}.
  If \code{subscripts} is not explicitly specified in the call to
  \code{panel.identify}, but is available in \code{panel.args}, then
  those values will be used.  Otherwise, they default to
  \code{seq_along(x)}.  In either case, the final return value will be
  the subscripts that were marked.

  The process of printing (plotting) a Trellis object builds up a grid
  layout with named viewports which can then be accessed to modify the
  plot further.  While full flexibility can only be obtained by using
  grid functions directly, a few lattice functions are available for the
  more common tasks.

  \code{trellis.focus} can be used to move to a particular panel or
  strip, identified by its position in the array of panels.  It can also
  be used to focus on the viewport corresponding to one of the labels or
  a legend, though such usage would be less useful.  The exact
  viewport is determined by the \code{name} along with the other
  arguments, not all of which are relevant for all names.  Note that
  when more than one object is plotted on a page, \code{trellis.focus}
  will always go to the plot that was created last.  For more
  flexibility, use grid functions directly (see note below).

  After a successful call to \code{trellis.focus}, the desired viewport
  (typically panel or strip area) will be made the \sQuote{current}
  viewport (plotting area), which can then be enhanced by calls to
  standard lattice panel functions as well as grid functions.

  It is quite common to have the layout of panels chosen when a
  \code{"trellis"} object is drawn, and not before then.  Information on
  the layout (specifically, how many rows and columns, and which packet
  belongs in which position in this layout) is retained for the last
  \code{"trellis"} object plotted, and is available through
  \code{trellis.currentLayout}.

  \code{trellis.unfocus} unsets the focus, and makes the top level
  viewport the current viewport.

  \code{trellis.switchFocus} is a convenience function to switch from
  one viewport to another, while preserving the current \code{row} and
  \code{column}.  Although the rows and columns only make sense for
  panels and strips, they would be preserved even when the user switches
  to some other viewport (where row/column is irrelevant) and then
  switches back.
  
  Once a panel or strip is in focus, \code{trellis.panelArgs} can be
  used to retrieve the arguments that were available to the panel
  function at that position.  In this case, it can be called without
  arguments as

  \preformatted{
    trellis.panelArgs()
  }

  This usage is also allowed when a \code{"trellis"} object is being
  printed, e.g. inside the panel functions or the axis function (but not
  inside the prepanel function).  \code{trellis.panelArgs} can also
  retrieve the panel arguments from any \code{"trellis"} object.  Note
  that for this usage, one needs to specify the \code{packet.number} (as
  described under the \code{panel} entry in \code{\link{xyplot}}) and
  not the position in the layout, because a layout determines the panel
  only \bold{after} the object has been printed.

  It is usually not necessary to call \code{trellis.vpname} and
  \code{trellis.grobname} directly.  However, they can be useful in
  generating appropriate names in a portable way when using grid
  functions to interact with the plots directly, as described in the
  note below.

}


\value{
  \code{panel.identify} returns an integer vector containing the
  subscripts of the identified points (see details above).  The
  equivalent of \code{identify} with \code{pos=TRUE} is not yet
  implemented, but can be considered for addition if requested.

  \code{trellis.panelArgs} returns a named list of arguments that were
  available to the panel function for the chosen panel.

  \code{trellis.vpname} and \code{trellis.grobname} return character
  strings.

  \code{trellis.focus} has a meaningful return value only if it has been
  used to focus on a panel interactively, in which case the return value
  is a list with components \code{col} and \code{row} giving the column
  and row positions respectively of the chosen panel, unless the choice
  was cancelled (by a right click), in which case the return value is
  \code{NULL}.  If click was outside a panel, both \code{col} and
  \code{row} are set to 0.
}
  
\note{

  The viewports created by lattice is accessible to the user only up to a
  certain extent, as described above.  In particular,
  \code{trellis.focus} can only be used to manipulate the last plot
  drawn.  For full flexibility, use appropriate functions from the grid
  package directly.  For example,
  \code{\link[grid:current.viewport]{current.vpTree}} can be used to
  inspect the current viewport tree and
  \code{\link[grid:viewports]{seekViewport}} or
  \code{\link[grid:viewports]{downViewport}} can be used to navigate to
  these viewports.  For such usage, \code{trellis.vpname} and
  \code{trellis.grobname} (with a non-default \code{prefix} argument)
  provides a portable way to access the appropriate viewports and grobs
  by name.

}

\examples{

\dontrun{
xyplot(1:10 ~ 1:10)
trellis.focus("panel", 1, 1)
panel.identify()
}

xyplot(Petal.Length ~ Sepal.Length | Species, iris, layout = c(2, 2))
Sys.sleep(1)

trellis.focus("panel", 1, 1)
do.call("panel.lmline", trellis.panelArgs())
Sys.sleep(0.5)
trellis.unfocus()

trellis.focus("panel", 2, 1)
do.call("panel.lmline", trellis.panelArgs())
Sys.sleep(0.5)
trellis.unfocus()

trellis.focus("panel", 1, 2)
do.call("panel.lmline", trellis.panelArgs())
Sys.sleep(0.5)
trellis.unfocus()


## choosing loess smoothing parameter

p <- xyplot(dist ~ speed, cars)

panel.loessresid <-
    function(x = panel.args$x,
             y = panel.args$y,
             span,
             panel.args = trellis.panelArgs())
{
    fm <- loess(y ~ x, span = span)
    xgrid <- do.breaks(current.panel.limits()$xlim, 50)
    ygrid <- predict(fm, newdata = data.frame(x = xgrid))
    panel.lines(xgrid, ygrid)
    pred <- predict(fm)
    ## center residuals so that they fall inside panel
    resids <- y - pred + mean(y)
    fm.resid <- loess.smooth(x, resids, span = span)
    ##panel.points(x, resids, col = 1, pch = 4)
    panel.lines(fm.resid, col = 1)
}


spans <- c(0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8)
update(p, index.cond = list(rep(1, length(spans))))
panel.locs <- trellis.currentLayout()

i <- 1

for (row in 1:nrow(panel.locs))
    for (column in 1:ncol(panel.locs))
    if (panel.locs[row, column] > 0)
{
    trellis.focus("panel", row = row, column = column,
                  highlight = FALSE)
    panel.loessresid(span = spans[i])
    grid::grid.text(paste("span = ", spans[i]),
                    x = 0.25,
                    y = 0.75,
                    default.units = "npc")
    trellis.unfocus()
    i <- i + 1
}


}

\seealso{
  \code{\link{identify}}, \code{\link{Lattice}},
  \code{\link{print.trellis}}, \code{\link{trellis.currentLayout}},
  \code{\link[grid:current.viewport]{current.vpTree}},
  \code{\link[grid:viewports]{viewports}}
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}.  Felix
  Andrews provided initial implementations of
  \code{panel.identify.qqmath} and support for focusing on panels
  interctively.
}

\keyword{dplot}


\eof
% --- Source file: lattice.options.Rd ---
\name{lattice.options}
\alias{lattice.options}
\alias{lattice.getOption}
\title{ Low-level Options Controlling Behaviour of Lattice }
\description{
  Functions to handle settings used by lattice.  Their main purpose is
  to make code maintainance easier, and users normally should not need
  to use these functions.  However, fine control at this level maybe
  useful in certain cases.
}

\usage{
lattice.options(\dots)
lattice.getOption(name)
}
\arguments{
  \item{name}{ character giving the name of a setting }
  \item{\dots}{
    new options can be defined, or existing ones modified, using one or
    more arguments of the form \code{name = value} or by passing a list
    of such tagged values.  Existing values can be retrieved by
    supplying the names (as character strings) of the components as
    unnamed arguments.
  }
}
\details{
  These functions are modeled on \code{options} and \code{getOption},
  and behave similarly for the most part.  The components currently used
  are not documented here, but are fairly self-explanatory.
}

\value{
  \code{lattice.getOption} returns the value of a single component,
  whereas \code{lattice.options} always returns a list with one or more
  named components.  When changing the values of components, the old
  values of the modified components are returned by
  \code{lattice.options}.  If called without any arguments, the full
  list is returned. 
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}

\seealso{
  \code{\link{options}}, \code{\link{trellis.device}},
  \code{\link{trellis.par.get}}, \code{\link{Lattice}}
}

\examples{
str(lattice.options())
lattice.getOption("save.object")
}
\keyword{dplot}


\eof
% --- Source file: latticeParseFormula.Rd ---
\name{latticeParseFormula}
\alias{latticeParseFormula}
\title{Parse Trellis formula}
\usage{
latticeParseFormula(model, data, dimension = 2,
                    subset = TRUE, groups = NULL,
                    multiple, outer,
                    subscripts,
                    drop)
}
\description{
  this function is used by high level Lattice functions like
  \code{xyplot} to parse the formula argument and evaluate various
  components of the data.
}

\arguments{
  \item{model}{
    the model/formula to be parsed.  This can be in either of two
    possible forms, one for 2d and one for 3d formulas, determined by
    the \code{dimension} argument. The 2d formulas are of the form
    \code{y ~ x| g1 * \dots *gn}, and the 3d formulas are of the form
    \code{z ~ x * y | g1 * \dots* gn}. In the first form, \code{y} may
    be omitted. The conditioning variables \code{g1, \dots,gn} can be
    omitted in either case.
  }
  \item{data}{ the environment/dataset where the variables in the 
    formula are evaluated.
  }
  \item{dimension}{ dimension of the model, see above}
  \item{subset}{ index for choosing a subset of the data frame }
  \item{groups}{ the grouping variable, if present}
  \item{multiple, outer}{
    logicals, determining how a \sQuote{+} in the y and x components of
    the formula are processed. See \code{\link{xyplot}} for details
  }
  \item{subscripts}{ logical, whether subscripts are to be calculated }
  \item{drop}{
    logical or list, similar to the \code{drop.unused.levels} argument
    in \code{\link{xyplot}}, indicating whether unused levels of
    conditioning factors and data variables that are factors are to be
    dropped.
  }
}

\value{ returns a list with several components, including \code{left,
    right, left.name, right.name, condition} for 2-D, and \code{left,
    right.x, right.y, left.name, right.x.name, right.y.name, condition}
  for 3-D. Other possible components are groups, subscr

}

\seealso{
  \code{\link{xyplot}}, \code{\link{Lattice}}
}
\author{Saikat DebRoy, Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{utilities}
\eof
% --- Source file: level.colors.Rd ---
\name{level.colors}
\alias{level.colors}
\title{
  A function to compute false colors representing a numeric or
  categorical variable
}
\description{
  Calculates false colors from a numeric variable (including factors,
  using their numeric codes) given a color scheme and breakpoints.
}
\usage{
level.colors(x, at, col.regions, colors = TRUE, ...)
}
\arguments{
  \item{x}{ A numeric or \code{\link{factor}} variable. }
  \item{at}{ A numeric variable of breakpoints defining intervals along
    the range of \code{x}. }
  \item{col.regions}{ A specification of the colors to be assigned to
    each interval defined by \code{at}.  This could be either a vector
    of colors, or a function that produces a vector of colors when
    called with a single argument giving the number of colors.   See
    details below. }
  \item{colors}{ logical indicating whether colors should be computed
    and returned.  If \code{FALSE}, only the indices representing which
    interval (among those defined by \code{at}) each value in \code{x}
    falls into is returned.  }
  \item{\dots}{ Extra arguments, ignored. }
}
\value{
  A vector of the same length as \code{x}.  Depending on the
  \code{colors} argument, this could be either a vector of colors (in
  a form usable by \R), or a vector of integer indices representing
  which interval the values of \code{x} fall in.
}

\author{ Deepayan Sarkar \email{deepayan.sarkar@r-project.org} }

\seealso{ \code{\link{levelplot}}, \code{\link{colorRampPalette}}.  }

\details{

  If \code{at} has length n, then it defines n-1 intervals.  Values of
  \code{x} outside the range of \code{at} are not assigned to an
  interval, and the return value is \code{NA} for such values.

  Colors are chosen by assigning a color to each of the n-1 intervals.
  If \code{col.regions} is a palette function (such as
  \code{\link{topo.colors}}, or the result of calling
  \code{\link{colorRampPalette}}), it is called with n-1 as an argument
  to obtain the colors.  Otherwise, if there are exactly n-1 colors in
  \code{col.regions}, these get assigned to the intervals.  If there are
  fewer than n-1 colors, \code{col.regions} gets recycled.  If there are
  more, a more or less equally spaced (along the length of
  \code{col.regions}) subset is chosen.

}

\examples{

depth.col <-
    with(quakes, 
         level.colors(depth, at = do.breaks(range(depth), 30),
                      col.regions = terrain.colors))


xyplot(lat ~ long | equal.count(stations), quakes,
       strip = strip.custom(var.name = "Stations"),
       colours = depth.col,
       panel = function(x, y, colours, subscripts, ...) {
           panel.xyplot(x, y, pch = 21, col = "transparent",
                        fill = colours[subscripts], ...)
       })

}

\keyword{utilities}
\eof
% --- Source file: levelplot.Rd ---
\name{levelplot}
\title{Level plots and contour plots}
\alias{levelplot}
\alias{contourplot}
\alias{levelplot.formula}
\alias{contourplot.formula}
\alias{levelplot.table}
\alias{contourplot.table}
\alias{levelplot.array}
\alias{contourplot.array}
\alias{levelplot.matrix}
\alias{contourplot.matrix}
\usage{
levelplot(x, data, \dots)
contourplot(x, data, \dots)

\method{levelplot}{formula}(x,
          data,
          allow.multiple = is.null(groups) || outer,
          outer = TRUE,
          aspect = "fill",
          panel = lattice.getOption("panel.levelplot"),
          prepanel = NULL,
          scales = list(),
          strip = TRUE,
          groups = NULL,
          xlab,
          xlim,
          ylab,
          ylim,
          at,
          cuts = 15,
          pretty = FALSE,
          region = TRUE,
          drop.unused.levels = lattice.getOption("drop.unused.levels"),
          \dots,
          lattice.options = NULL,
          default.scales = list(),
          colorkey = region,
          col.regions,
          alpha.regions,
          subset = TRUE)

\method{contourplot}{formula}(x,
            data,
            panel = lattice.getOption("panel.contourplot"),
            cuts = 7,
            labels = TRUE,
            contour = TRUE,
            pretty = TRUE,
            region = FALSE,
            \dots)

\method{levelplot}{table}(x, data = NULL, aspect = "iso", \dots, xlim, ylim)

\method{contourplot}{table}(x, data = NULL, aspect = "iso", \dots, xlim, ylim)

\method{levelplot}{matrix}(x, data = NULL, aspect = "iso",
          \dots, xlim, ylim,
          row.values = seq_len(nrow(x)),
          column.values = seq_len(ncol(x)))

\method{contourplot}{matrix}(x, data = NULL, aspect = "iso",
            \dots, xlim, ylim,
            row.values = seq_len(nrow(x)),
            column.values = seq_len(ncol(x)))


\method{levelplot}{array}(x, data = NULL, \dots)

\method{contourplot}{array}(x, data = NULL, \dots)


}
\description{
  Draw Level Plots and Contour plots.
}
\arguments{
  \item{x}{
    for the \code{formula} method, a formula of the form \code{z ~ x * y
      | g1 * g2 * \dots}, where \code{z} is a numeric response, and
    \code{x}, \code{y} are numeric values evaluated on a rectangular
    grid.  \code{g1, g2, \dots} are optional conditional variables, and
    must be either factors or shingles if present.

    Calculations are based on the assumption that all x and y values are
    evaluated on a grid (defined by their unique values). The function
    will not return an error if this is not true, but the display might
    not be meaningful.  However, the x and y values need not be equally
    spaced.

    Both \code{levelplot} and \code{wireframe} have methods for
    \code{matrix}, \code{array}, and \code{table} objects, in which case
    \code{x} provides the \code{z} vector described above, while its
    rows and columns are interpreted as the \code{x} and \code{y}
    vectors respectively.  This is similar to the form used in
    \code{filled.contour} and \code{image}.  For higher-dimensional
    arrays and tables, further dimensions are used as conditioning
    variables.  Note that the dimnames may be duplicated; this is
    handled by calling \code{\link{make.unique}} to make the names
    unique (although the original labels are used for the x- and
    y-axes).
  }
  \item{data}{
    For the \code{formula} methods, an optional data frame in which
    variables in the formula (as well as \code{groups} and
    \code{subset}, if any) are to be evaluated.  Usually ignored with a
    warning in other cases.
  }
  \item{row.values, column.values}{ Optional vectors of values that
    define the grid when \code{x} is a matrix.  \code{row.values} and
    \code{column.values} must have the same lengths as \code{nrow(x)}
    and \code{ncol(x)} respectively.  By default, row and column
    numbers. }
  \item{panel}{
    panel function used to create the display, as described in
    \code{\link{xyplot}}
  }
  \item{aspect}{
    For the \code{matrix} methods, the default aspect ratio is chosen to
    make each cell square.  The usual default is \code{aspect="fill"},
    as described in \code{\link{xyplot}}.
  }
  \item{at}{
    numeric vector giving breakpoints along the range of
    \code{z}. Contours (if any) will be drawn at these heights, and the
    regions in between would be colored using \code{col.regions}.  In
    the latter case, values outside the range of \code{at} will not be
    drawn at all.  This serves as a way to limit the range of the data
    shown, similar to what a \code{zlim} argument might have been used
    for.  However, this also means that when supplying \code{at}
    explicitly, one has to be careful to include values outside the
    range of \code{z} to ensure that all the data are shown.
  }
  \item{col.regions}{ color vector to be used if regions is TRUE. The
    general idea is that this should be a color vector of moderately
    large length (longer than the number of regions. By default this is
    100). It is expected that this vector would be gradually varying in
    color (so that nearby colors would be similar). When the colors are
    actually chosen, they are chosen to be equally spaced along this
    vector.  When there are more regions than colors in
    \code{col.regions}, the colors are recycled.  The actual color
    assignment is performed by \code{\link{level.colors}}, which is
    documented separately.
  }
  \item{alpha.regions}{
    numeric, specifying alpha transparency (works only on some devices)
  }
  \item{colorkey}{logical specifying whether a color key is to be drawn
    alongside the plot, or a list describing the color key. The list may
    contain the following components:

    \describe{
    
      \item{\code{space}:}{
        location of the colorkey, can be one of \code{"left"},
	\code{"right"}, \code{"top"} and \code{"bottom"}.  Defaults to
	\code{"right"}.
      }
      
      \item{\code{x}, \code{y}:}{ location, currently unused }

      \item{\code{col}:}{ vector of colors }
      
      \item{\code{at}:}{
        numeric vector specifying where the colors change. must be of
        length 1 more than the col vector.
      }

      \item{\code{labels}:}{
        a character vector for labelling the \code{at} values, or more
        commonly, a list describing characteristics of the labels.  This
	list may include components \code{labels}, \code{at},
	\code{cex}, \code{col}, \code{rot}, \code{font}, \code{fontface}
	and \code{fontfamily}.
      }

      \item{\code{tick.number}:}{ approximate number of ticks. }

      \item{\code{corner}:}{ interacts with x, y; unimplemented }

      \item{\code{width}:}{ width of the key }

      \item{\code{height}:}{ length of key w.r.t side of plot. }
    }
  }
  \item{contour}{
    logical, whether to draw contour lines.
  }
  \item{cuts}{
    number of levels the range of \code{z} would be divided into
  }
  \item{labels}{
    typically a logical indicating whether contour lines should be
    labelled, but other possibilities for more sophisticated control
    exists.  Details are documented in the help page for
    \code{\link{panel.levelplot}}, to which this argument is passed on
    unchanged.  That help page also documents the \code{label.style}
    argument, which affects how the labels are rendered.
  }
  \item{pretty}{
    logical, whether to use pretty cut locations and labels
  }
  \item{region}{
    logical, whether regions between contour lines should be filled
  }
  \item{allow.multiple, outer, prepanel, scales, strip, groups, xlab,
    xlim, ylab, ylim, drop.unused.levels, lattice.options,
    default.scales, subset}{
    these arguments are described in the help page for
    \code{\link{xyplot}}.
  }
  \item{\dots}{ other arguments.  Some are processed by \code{levelplot}
    or \code{contourplot}, and those unrecognized are passed on to the
    panel function.  }
}
\details{
  These and all other high level Trellis functions have several
  arguments in common. These are extensively documented only in the
  help page for \code{xyplot}, which should be consulted to learn more
  detailed usage.

  Other useful arguments are mentioned in the help page for the default
  panel function \code{\link{panel.levelplot}} (these are formally
  arguments to the panel function, but can be specified in the high
  level calls directly).
}

\references{
  Sarkar, Deepayan (2008) "Lattice: Multivariate Data Visualization with
  R", Springer. \url{http://lmdvr.r-forge.r-project.org/}
}

\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}
\seealso{
  \code{\link{xyplot}}, \code{\link{Lattice}},
  \code{\link{panel.levelplot}}
}
\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\examples{
x <- seq(pi/4, 5 * pi, length.out = 100)
y <- seq(pi/4, 5 * pi, length.out = 100)
r <- as.vector(sqrt(outer(x^2, y^2, "+")))
grid <- expand.grid(x=x, y=y)
grid$z <- cos(r^2) * exp(-r/(pi^3))
levelplot(z~x*y, grid, cuts = 50, scales=list(log="e"), xlab="",
          ylab="", main="Weird Function", sub="with log scales",
          colorkey = FALSE, region = TRUE)


#S-PLUS example
require(stats)
attach(environmental)
ozo.m <- loess((ozone^(1/3)) ~ wind * temperature * radiation,
       parametric = c("radiation", "wind"), span = 1, degree = 2)
w.marginal <- seq(min(wind), max(wind), length.out = 50)
t.marginal <- seq(min(temperature), max(temperature), length.out = 50)
r.marginal <- seq(min(radiation), max(radiation), length.out = 4)
wtr.marginal <- list(wind = w.marginal, temperature = t.marginal,
        radiation = r.marginal)
grid <- expand.grid(wtr.marginal)
grid[, "fit"] <- c(predict(ozo.m, grid))
contourplot(fit ~ wind * temperature | radiation, data = grid,
            cuts = 10, region = TRUE,
            xlab = "Wind Speed (mph)",
            ylab = "Temperature (F)",
            main = "Cube Root Ozone (cube root ppb)")
detach()
}
\keyword{hplot}



\eof
% --- Source file: llines.Rd ---
\name{llines}
\alias{llines}
\alias{lpoints}
\alias{ltext}
\alias{llines.default}
\alias{lpoints.default}
\alias{ltext.default}
\alias{lplot.xy}
\alias{larrows}
\alias{lsegments}
\alias{lrect}
\alias{lpolygon}
\alias{panel.arrows}
\alias{panel.lines}
\alias{panel.points}
\alias{panel.segments}
\alias{panel.text}
\alias{panel.rect}
\alias{panel.polygon}
\title{Replacements of traditional graphics functions}

\description{

  These functions are intended to replace common low level traditional
  graphics functions, primarily for use in panel functions.  The
  originals can not be used (at least not easily) because lattice panel
  functions need to use grid graphics.  Low level drawing functions in
  grid can be used directly as well, and is often more flexible.  These
  functions are provided for convenience and portability.

}

\usage{
lplot.xy(xy, type, pch, lty, col, cex, lwd,
         font, fontfamily, fontface,
         col.line, col.symbol, alpha, fill,
         origin = 0, \dots)

llines(x, ...)
lpoints(x, ...)
ltext(x, ...)

\method{llines}{default}(x, y = NULL, type = "l",
       col, alpha, lty, lwd, \dots)
\method{lpoints}{default}(x, y = NULL, type = "p", col, pch, alpha, fill,
        font, fontfamily, fontface, cex, \dots)  
\method{ltext}{default}(x, y = NULL, labels = seq_along(x),
      col, alpha, cex, srt = 0,
      lineheight, font, fontfamily, fontface,
      adj = c(0.5, 0.5), pos = NULL, offset = 0.5, \dots)  

lsegments(x0, y0, x1, y1, x2, y2,
          col, alpha, lty, lwd, \dots)
lrect(xleft, ybottom, xright, ytop,
      x = (xleft + xright) / 2,
      y = (ybottom + ytop) / 2,
      width = xright - xleft,
      height = ytop - ybottom,
      col = "transparent",
      border = "black",
      lty = 1, lwd = 1, alpha = 1,
      just = "center",
      hjust = NULL, vjust = NULL,
      \dots)
larrows(x0 = NULL, y0 = NULL, x1, y1, x2 = NULL, y2 = NULL,
        angle = 30, code = 2, length = 0.25, unit = "inches",
        ends = switch(code, "first", "last", "both"),
        type = "open",
        col = add.line$col,
        alpha = add.line$alpha,
        lty = add.line$lty,
        lwd = add.line$lwd,
        fill = NULL, \dots)
lpolygon(x, y = NULL,
         border = "black", col = "transparent",
         font, fontface, \dots)

panel.lines(\dots)
panel.points(\dots)
panel.segments(\dots)
panel.text(\dots)
panel.rect(\dots)
panel.arrows(\dots)
panel.polygon(\dots)
}
\arguments{

  \item{ x, y, x0, y0, x1, y1, x2, y2, xy}{ locations. \code{x2} and
    \code{y2} are available for for S compatibility.  }
  \item{length, unit}{
    determines extent of arrow head.  \code{length} specifies the length
    in terms of \code{unit}, which can be any valid grid unit as long as
    it doesn't need a \code{data} argument.  \code{unit} defaults to
    inches, which is the only option in the base version of the
    function, \code{\link{arrows}}.  }
  \item{angle, code, type, labels, srt, adj, pos, offset}{ arguments
    controlling behaviour.  See respective base functions for details.
    For \code{larrows} and \code{panel.larrows}, \code{type} is either
    \code{"open"} or \code{"closed"}, indicating the type of
    arrowhead. }
  \item{ends}{ serves the same function as \code{code}, using
    descriptive names rather than integer codes.  If specified, this
    overrides \code{code}}
  \item{col, alpha, lty, lwd, fill, pch, cex, lineheight, font,
    fontfamily, fontface, col.line, col.symbol, border}{ graphical
    parameters.  \code{fill} applies to points when \code{pch} is in
    \code{21:25} and specifies the fill color, similar to the \code{bg}
    argument in the base graphics function \code{\link{points}}. For
    devices that support alpha-transparency, a numeric argument
    \code{alpha} between 0 and 1 can controls transparency.  Be careful
    with this, since for devices that do not support alpha-transparency,
    nothing will be drawn at all if this is set to anything other than
    0.  \code{font} and \code{fontface} are included in \code{lpolygon}
    only to ensure that they are not passed down (as
    \code{\link[grid:gpar]{gpar}} doesn't like them).
  }
  \item{origin}{ for \code{type="h"} or \code{type="H"}, the value to
    which lines drop down. }
  \item{xleft, ybottom, xright, ytop}{ see \code{\link{rect}}}
  \item{width, height, just, hjust, vjust}{ finer control over
    rectangles, see \code{\link[grid:grid.rect]{grid.rect}} }
  \item{\dots}{ extra arguments, passed on to lower level functions as
    appropriate.  }
}


\details{
  These functions are meant to be grid replacements of the corresponding
  base R graphics functions, to allow existing Trellis code to be used
  with minimal modification.  The functions \code{panel.*} are
  essentally identical to the \code{l*} versions, are recommended for
  use in new code (as opposed to ported code) as they have more readable
  names.

  See the documentation of the base functions for usage. Not all
  arguments are always supported. All these correspond to the default
  methods only.
%   For \code{ltext}, only values 0, .5 and 1 for \code{adj}
%   have any effect.
}
\note{
  There is a new \code{type="H"} option wherever appropriate, which is
  similar to \code{type="h"}, but with horizontal lines.
}

\seealso{\code{\link{points}}, \code{\link{lines}}, \code{\link{rect}},
  \code{\link{text}}, \code{\link{segments}}, \code{\link{arrows}},
  \code{\link{Lattice}}
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}
\eof
% --- Source file: lset.Rd ---
\name{lset}
\alias{lset}
\title{Interface to modify Trellis Settings - Deprecated}
\description{
  A (hopefully) simpler alternative to \code{trellis.par.get/set}.  This
  is deprecated, and the same functionality is now available with
  \code{trellis.par.set}
}

\usage{
lset(theme = col.whitebg())
}
\arguments{
  \item{theme}{ a list decribing how to change the settings of the
    current active device. Valid components are those in the list
    returned by \code{trellis.par.get()}. Each component must itself be
    a list, with one or more of the appropriate components (need not
    have all components). Changes are made to the settings for the
    currently active device only.
  }
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{utilities}
\eof
% --- Source file: make.groups.Rd ---
\name{make.groups}
\alias{make.groups}
\title{ Grouped data from multiple vectors }
\description{
  Combines two or more vectors, possibly of different lengths, producing
  a data frame with a second column indicating which of these vectors
  that row came from.  This is mostly useful for getting data into a
  form suitable for use in high level Lattice functions.
}
\usage{
make.groups(\dots)
}
\arguments{
  \item{\dots}{
    one or more vectors of the same type (coercion is attempted if not),
    or one or more data frames with similar columns, with possibly
    differing number of rows.
  }
}
\value{
  When all the input arguments are vectors, a data frame with two
  columns
  \item{\code{data}}{
    all the vectors supplied, concatenated
  }
  \item{\code{which}}{
    factor indicating which vector the corresponding \code{data} value
    came from
  }
  When all the input arguments are data frames, the result of
  \code{\link{rbind}} applied to them, along with an additional
  \code{which} column as described above.
}

\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{Lattice}}}
\examples{
sim.dat <-
    make.groups(uniform = runif(200),
                exponential = rexp(175),
                lognormal = rlnorm(150),
                normal = rnorm(125))
qqmath( ~ data | which, sim.dat, scales = list(y = "free"))
}
\keyword{dplot}

\eof
% --- Source file: melanoma.Rd ---
\name{melanoma}
\alias{melanoma}
\docType{data}
\title{ Melanoma skin cancer incidence }

\description{
  These data from the Connecticut Tumor Registry present
  age-adjusted numbers of melanoma skin-cancer incidences per
  100,000 people in Connectict for the years from 1936 to 1972.
}

\usage{melanoma}

\format{
  A data frame with 37 observations on the following 2 variables.
  \describe{
    \item{year}{Years 1936 to 1972.}
    \item{incidence}{Rate of melanoma cancer per 100,000 population.}
  }
}

\note{
  This dataset is not related to the \code{\link[boot]{melanoma}}
  dataset in the \bold{boot} package with the same name.

  The S-PLUS 6.2 help for the melanoma data says that the incidence rate is
  per \emph{million}, but this is not consistent with data found at the
  National Cancer Institute (\url{http://www.nci.nih.gov}).
}

\source{
    Houghton, A., E. W. Munster, and M. V. Viola.  (1978).  Increased
    Incidence of Malignant Melanoma After Peaks of Sunspot Activity.
    \emph{The Lancet}, \bold{8}, 759--760.
}

\author{
  Documentation contributed by Kevin Wright.
}

\references{
  Cleveland, William S. (1993). \emph{Visualizing Data}.  Hobart Press,
  Summit, New Jersey.
}

\examples{
# Time-series plot.  Figure 3.64 from Cleveland.
xyplot(incidence ~ year,
  data = melanoma,
	aspect = "xy",
	panel = function(x, y)
		panel.xyplot(x, y, type="o", pch = 16),
	ylim = c(0, 6),
	xlab = "Year",
	ylab = "Incidence")
}

\keyword{datasets}
\eof
% --- Source file: oneway.Rd ---
\name{oneway}
\alias{oneway}
\title{ Fit One-way Model}
\description{
  Fits a One-way model to univariate data grouped by a factor, the
  result often being displayed using \code{rfs} 
}
\usage{
oneway(formula, data, location=mean, spread=function(x) sqrt(var(x)))
}
\arguments{
  \item{formula}{ formula of the form \code{y ~ x} where \code{y} is the
    numeric response and \code{x} is the grouping factor
  }
  \item{data}{ data frame in which the model is to be evaluated }
  \item{location}{ function or numeric giving the location statistic to
    be used for centering the observations, e.g. \code{median}, 0 (to
    avoid centering).
  }
  \item{spread}{ function or numeric giving the spread statistic to
    be used for scaling the observations, e.g. \code{sd}, 1 (to
    avoid scaling).
  }
}
\value{
  A list with components
  \item{location}{ vector of locations for each group.}
  \item{spread}{ vector of spreads for each group.}
  \item{fitted.values}{ vector of locations for each observation.}
  \item{residuals}{ residuals (\code{y - fitted.values}).}
  \item{scaled.residuals}{residuals scaled by \code{spread} for their
    group} 
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{rfs}}, \code{\link{Lattice}} }
\keyword{dplot}
\eof
% --- Source file: packet.panel.default.Rd ---
\name{packet.panel.default}
\alias{packet.panel.default}

\title{Associating Packets with Panels}

\description{

  When a \code{"trellis"} object is plotted, panels are always drawn in
  an order such that columns vary the fastest, then rows and then pages.
  An optional function can be specified that determines, given the
  column, row and page and other relevant information, the packet (if
  any) which should be used in that panel.  The function documented here
  implements the default behaviour, which is to match panel order with
  packet order, determined by varying the first conditioning variable
  the fastest, then the second, and so on.  This matching is performed
  after any reordering and/or permutation of the conditioning variables.

}
\usage{

packet.panel.default(layout, condlevels, page, row, column,
                     skip, all.pages.skip = TRUE) 

}

\arguments{
  \item{layout}{ the \code{layout} argument in high level functions,
    suitably standardized.  }
  \item{condlevels}{ a list of levels of conditioning variables, after
    relevant permutations and/or reordering of levels }
  \item{page, row, column}{ the location of the panel in the coordinate
    system of pages, rows and columns.  }
  \item{skip}{ the \code{skip} argument in high level functions }
  \item{all.pages.skip}{ whether \code{skip} should be replicated over
    all pages.  If \code{FALSE}, \code{skip} will be replicated to be
    only as long as the number of positions on a page, and that
    template will be used for all pages. }
}

\value{

  A suitable combination of levels of the conditioning variables in the
  form of a numeric vector as long as the number of conditioning
  variables, with each element an integer indexing the levels of the
  corresponding variable.  Specifically, if the return value is
  \code{p}, then the \code{i}-th conditioning variable will have level
  \code{condlevels[[i]][p[i]]}.

}

\seealso{ \code{\link{Lattice}}, \code{\link{xyplot}} }

\examples{

packet.panel.page <- function(n)
{
    ## returns a function that when used as the 'packet.panel'
    ## argument in print.trellis plots page number 'n' only
    function(layout, page, ...) {
        stopifnot(layout[3] == 1)
        packet.panel.default(layout = layout, page = n, ...)
    }
}

data(mtcars)
HP <- equal.count(mtcars$hp, 6)
p <- 
    xyplot(mpg ~ disp | HP * factor(cyl),
           mtcars, layout = c(0, 6, 1))

print(p, packet.panel = packet.panel.page(1))
print(p, packet.panel = packet.panel.page(2))

}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}

\eof
% --- Source file: panel.axis.Rd ---
\name{panel.axis}
\alias{panel.axis}
\alias{current.panel.limits}
\title{Panel Function for Drawing Axis Ticks and Labels}
\description{
  \code{panel.axis} is the function used by lattice to draw axes. It is
  typically not used by users, except those wishing to create advanced
  annotation. Keep in mind issues of clipping when trying to use it as
  part of the panel function. \code{current.panel.limits} can be used to
  retrieve a panel's x and y limits.
}
\usage{
panel.axis(side = c("bottom", "left", "top", "right"),
           at,
           labels = TRUE,
           draw.labels = TRUE,
           check.overlap = FALSE,
           outside = FALSE,
           ticks = TRUE,
           half = !outside,
           which.half,
           tck = as.numeric(ticks),
           rot = if (is.logical(labels)) 0 else c(90, 0),
           text.col, text.alpha, text.cex, text.font,
           text.fontfamily, text.fontface,
           line.col, line.lty, line.lwd, line.alpha)

current.panel.limits(unit = "native")
}
\arguments{
  \item{side}{
    character string indicating which side axes are to be drawn
    on. Partial specification is allowed.
  }
  \item{at}{ location of labels }
  \item{labels}{
    the labels to go along with \code{at}. The labels can be a character
    vector or a vector of expressions. Alternatively, this can be a
    logical. If TRUE, the labels are derived from \code{at}, otherwise,
    labels are empty.
  }
  \item{draw.labels}{
    logical indicating whether labels are to be drawn
  }
  \item{check.overlap}{
    logical, whether to check for overlapping of labels.  This also has
    the effect of removing \code{at} values that are \sQuote{too close}
    to the limits.
  }
  \item{outside}{
    logical, whether to the labels draw outside the panel or inside.
    Note that \code{outside=TRUE} will only have a visible effect if
    clipping is disabled for the viewport (panel).
  }
  \item{ticks}{ logical, whether to draw the tickmarks }
  \item{half}{
    logical, whether only half of scales will be drawn for each side
  }
  \item{which.half}{
    character string, one of \code{"lower"} and
    \code{"upper"}. Indicates which half is to be used for tick
    locations if \code{half=TRUE}.  Defaults to whatever is suitable for
    \code{\link{splom}}
  }
  \item{tck}{
    numeric scalar, multiplier for tick length. Can be negative.
  }
  \item{rot}{
    rotation angles for labels in degrees. Can be a vector of length 2
    for x- and y-axes respectively
  }
  \item{text.col, text.alpha, text.cex, text.font, text.fontfamily,
    text.fontface, line.col, line.lty, line.lwd, line.alpha}{ graphical
    parameters }
  \item{unit}{ which grid \code{\link[grid:unit]{unit}} the values
    should be in }
}

\details{

  \code{panel.axis} can draw axis tick marks inside or outside a
  panel (more precisely, a grid viewport). It honours the (native) axis
  scales. Used in \code{\link{panel.pairs}} for \code{\link{splom}}, as
  well as for all the usual axis drawing by the print method for
  \code{"trellis"} objects. It can also be used to enhance plots
  \sQuote{after the fact} by adding axes.

}

\value{
  \code{current.panel.limits} returns a list with components \code{xlim}
  and \code{ylim}, which are both numeric vectors of length 2, giving
  the scales of the current panel (viewport).  The values correspond to
  the unit system specified by \code{\link[grid:unit]{unit}}, by default
  \code{"native"}.
}

\seealso{
  \code{\link{Lattice}}, \code{\link{xyplot}},
  \code{\link{trellis.focus}}, \code{\link[grid:unit]{unit}}
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}




\eof
% --- Source file: panel.barchart.Rd ---
\name{panel.barchart}
\alias{panel.barchart}
\title{ Default Panel Function for barchart}
\description{
  Default panel function for \code{barchart}.
}
\usage{
panel.barchart(x, y, box.ratio = 1, box.width,
               horizontal = TRUE,
               origin = NULL, reference = TRUE,
               stack = FALSE,
               groups = NULL, 
               col = if (is.null(groups)) plot.polygon$col
                     else superpose.polygon$col,
               border = if (is.null(groups)) plot.polygon$border
                        else superpose.polygon$border,
               lty = if (is.null(groups)) plot.polygon$lty
                     else superpose.polygon$lty, 
               lwd = if (is.null(groups)) plot.polygon$lwd
                     else superpose.polygon$lwd,
               \dots)
}
\arguments{
  \item{x}{ Extent of Bars. By default, bars start at left of panel,
    unless \code{origin} is specified, in which case they start there
  }
  \item{y}{ Horizontal location of bars, possibly factor}
  \item{box.ratio}{ratio of bar width to inter-bar space}
  \item{box.width}{ thickness of bars in absolute units; overrides
    \code{box.ratio}.  Useful for specifying thickness when the
    categorical variable is not a factor, as use of \code{box.ratio}
    alone cannot achieve a thickness greater than 1. }
  \item{horizontal}{
    logical. If FALSE, the plot is \sQuote{transposed} in the sense that
    the behaviours of x and y are switched. x is now the
    \sQuote{factor}.  Interpretation of other arguments change
    accordingly. See documentation of \code{\link{bwplot}} for a fuller
    explanation.
  }
  \item{origin}{ the origin for the bars.  For grouped displays with
    \code{stack = TRUE}, this argument is ignored and the origin set to
    0.  Otherwise, defaults to \code{NULL}, in which case bars start at
    the left (or bottom) end of a panel.  This choice is somewhat
    unfortuntate, as it can be misleading, but is the default for
    historical reasons.  For tabular (or similar) data, \code{origin =
      0} is usually more appropriate; if not, one should reconsider the
    use of a bar chart in the first place (dot plots are often a good
    alternative).
  }
  \item{reference}{ logical, whether a reference line is to be drawn at
    the origin
  }
  \item{stack}{ logical, relevant when groups is non-null. If
    \code{FALSE} (the default), bars for different values of the
    grouping variable are drawn side by side, otherwise they are
    stacked.
  }
  \item{groups}{ optional grouping variable}
  \item{col, border, lty, lwd}{
    Graphical parameters for the bars. By default, the trellis parameter
    \code{plot.polygon} is used if there is no grouping variable, otherwise
    \code{superpose.polygon} is used.  \code{col} gives the fill color,
    \code{border} the border color, and \code{lty} and \code{lwd} the
    line type and width of the borders.
  }
  \item{\dots}{ extra arguments will be accepted but ignored }
}

\details{
  A barchart is drawn in the panel. Note that most arguments controlling
  the display can be supplied to the high-level \code{barchart} call
  directly.
}

\seealso{
  \code{\link{barchart}}
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}

\eof
% --- Source file: panel.bwplot.Rd ---
\name{panel.bwplot}
\alias{panel.bwplot}
\title{ Default Panel Function for bwplot }
\description{
  This is the default panel function for \code{bwplot}.
}
\usage{
panel.bwplot(x, y, box.ratio = 1,
             box.width = box.ratio / (1 + box.ratio),
             horizontal = TRUE,
             pch, col, alpha, cex, 
             font, fontfamily, fontface, 
             fill, varwidth = FALSE,
             notch = FALSE, notch.frac = 0.5,
             \dots,
             levels.fos,
             stats = boxplot.stats,
             coef = 1.5,
             do.out = TRUE)
}
\arguments{
  \item{x, y}{ numeric vector or factor. Boxplots drawn for each unique value of
    \code{y} (\code{x}) if \code{horizontal} is \code{TRUE} (\code{FALSE})}
  \item{box.ratio}{ ratio of box thickness to inter box space}
  \item{box.width}{ thickness of box in absolute units; overrides
    \code{box.ratio}.  Useful for specifying thickness when the
    categorical variable is not a factor, as use of \code{box.ratio}
    alone cannot achieve a thickness greater than 1. }
  \item{horizontal}{
    logical. If FALSE, the plot is \sQuote{transposed} in the sense that
    the behaviours of x and y are switched. x is now the
    \sQuote{factor}.  Interpretation of other arguments change
    accordingly. See documentation of \code{\link{bwplot}} for a fuller
    explanation.
  }
  \item{pch, col, alpha, cex, font, fontfamily, fontface}{ graphical
    parameters controlling the dot.  \code{pch="|"} is treated
    specially, by replacing the dot with a line (similar to
    \code{\link{boxplot}})
  }
  \item{fill}{ color to fill the boxplot}
  \item{varwidth}{ logical. If TRUE, widths of boxplots are proportional
    to the number of points used in creating it.}
  \item{notch}{ if \code{notch} is \code{TRUE}, a notch is drawn in each
    side of the boxes.  If the notches of two plots do not overlap this
    is \sQuote{strong evidence} that the two medians differ (Chambers et
    al., 1983, p. 62).  See \code{\link{boxplot.stats}} for the
    calculations used. }
  \item{notch.frac}{ numeric in (0,1). When \code{notch=TRUE}, the
    fraction of the box width that the notches should use. }
  \item{stats}{ a function, defaulting to \code{\link{boxplot.stats}},
    that accepts a numeric vector and returns a list similar to the
    return value of \code{boxplot.stats}.  The function must accept
    arguments \code{coef} and \code{do.out} even if they do not use
    them (a \code{\dots} argument is good enough).  This function is
    used to determine the box and whisker plot.  }
  \item{coef, do.out}{ passed to \code{stats}}
  \item{levels.fos}{ numeric values corresponding to positions of the
    factor or shingle variable.  For internal use. }
  \item{\dots}{
    further arguments, ignored.
  }
}
\details{
  Creates Box and Whisker plot of \code{x} for every level of
  \code{y} (or the other way round if \code{horizontal=FALSE}).  By
  default, the actual boxplot statistics are calculated using
  \code{boxplot.stats}.  Note that most arguments controlling the
  display can be supplied to the high-level \code{bwplot} call directly.

%   Unlike the traditional
%   analog \code{\link{boxplot}}, notches are not implemented.

  Although the graphical parameters for the dot representing the median
  can be controlled by optional arguments, many others can not.  These
  parameters are obtained from the relevant settings parameters
  (\code{"box.rectangle"} for the box, \code{"box.umbrella"} for the
  whiskers and \code{"plot.symbol"} for the outliers).
}

\examples{

bwplot(voice.part ~ height, data = singer,
       xlab = "Height (inches)",
       panel = function(...) {
           panel.grid(v = -1, h = 0)
           panel.bwplot(...)
       },
       par.settings = list(plot.symbol = list(pch = 4)))

bwplot(voice.part ~ height, data = singer,
       xlab = "Height (inches)",
       notch = TRUE, pch = "|")


}

\seealso{
  \code{\link{bwplot}}, \code{\link{boxplot.stats}}
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}
\eof
% --- Source file: panel.cloud.Rd ---
\name{panel.cloud}
\alias{panel.cloud}
\alias{panel.wireframe}
\alias{panel.3dscatter}
\alias{panel.3dwire}
\title{ Default Panel Function for cloud }
\description{
  These are default panel functions controlling \code{cloud} and
  \code{wireframe} displays.
}

\usage{
panel.cloud(x, y, subscripts, z,
            groups = NULL,
            perspective = TRUE,
            distance = if (perspective) 0.2 else 0, 
            xlim, ylim, zlim,
            panel.3d.cloud = "panel.3dscatter",
            panel.3d.wireframe = "panel.3dwire",
            screen = list(z = 40, x = -60),
            R.mat = diag(4), aspect = c(1, 1),
            par.box = NULL,
            xlab, ylab, zlab,
            xlab.default, ylab.default, zlab.default,
            scales.3d,
            proportion = 0.6,
            wireframe = FALSE,
            scpos,
            \dots,
            at)
panel.wireframe(\dots)
panel.3dscatter(x, y, z, rot.mat, distance,
                groups, type = "p",
                xlim.scaled, ylim.scaled, zlim.scaled,
                zero.scaled,
                col, col.point, col.line,
                lty, lwd, cex, pch,
                cross, \dots, subscripts)
panel.3dwire(x, y, z, rot.mat = diag(4), distance,
             shade = FALSE,
             shade.colors.palette = trellis.par.get("shade.colors")$palette,
             light.source = c(0, 0, 1000),
             xlim.scaled,
             ylim.scaled,
             zlim.scaled,
             col = if (shade) "transparent" else "black",
             lty = 1, lwd = 1,
             alpha,
             col.groups = superpose.polygon$col,
             polynum = 100,
             \dots,
             drape = FALSE,
             at,
             col.regions = regions$col,
             alpha.regions = regions$alpha)
}
\arguments{
  \item{x, y, z}{
    numeric (or possibly factors) vectors representing the data to be
    displayed. The interpretation depends on the context.  For
    \code{panel.cloud} these are essentially the same as the data passed
    to the high level plot (except if \code{formula} was a matrix, the
    appropriate \code{x} and \code{y} vectors are generated).  By the
    time they are passed to \code{panel.3dscatter} and
    \code{panel.3dwire}, they have been appropriately subsetted (using
    \code{subscripts}) and scaled (to lie inside a bounding box, usually
    the [-0.5, 0.5] cube).

    Further, for \code{panel.3dwire}, \code{x} and \code{y} are shorter
    than \code{z} and represent the sorted locations defining a
    rectangular grid. Also in this case, \code{z} may be a matrix if the
    display is grouped, with each column representing one surface.

    In \code{panel.cloud} (called from \code{wireframe}) and
    \code{panel.3dwire}, \code{x}, \code{y} and \code{z} could also be
    matrices (of the same dimension) when they represent a 3-D surface
    parametrized on a 2-D grid.
  }
  \item{subscripts}{
    index specifying which points to draw. The same \code{x}, \code{y}
    and \code{z} values (representing the whole data) are passed to
    \code{panel.cloud} for each panel.  \code{subscripts} specifies the
    subset of rows to be used for the particular panel.
  }
  \item{groups}{
    specification of a grouping variable, passed down from the high
    level functions.
  }

  \item{perspective}{
    logical, whether to plot a perspective view. Setting this to
    \code{FALSE} is equivalent to setting \code{distance} to 0
  }
  \item{distance}{
    numeric, between 0 and 1, controls amount of perspective. The
    distance of the viewing point from the origin (in the transformed
    coordinate system) is \code{1 / distance}. This is described in a
    little more detail in the documentation for \code{\link{cloud}}
  }

  \item{screen}{
    A list determining the sequence of rotations to be applied to the
    data before being plotted. The initial position starts with the
    viewing point along the positive z-axis, and the x and y axes in the
    usual position. Each component of the list should be named one of
    \code{"x"}, \code{"y"} or \code{"z"} (repititions are allowed), with
    their values indicating the amount of rotation about that axis in
    degrees.
  }
  \item{R.mat}{
    initial rotation matrix in homogeneous coordinates, to be applied to
    the data before \code{screen} rotates the view further.
  }
  \item{par.box}{
    graphical parameters for box, namely, col, lty and lwd. By default
    obtained from the parameter \code{box.3d}
  }

  \item{xlim, ylim, zlim}{
    limits for the respective axes. As with other lattice functions,
    these could each be a numeric 2-vector or a character vector
    indicating levels of a factor.
  }
  \item{panel.3d.cloud, panel.3d.wireframe}{
    functions that draw the data-driven part of the plot (as opposed to
    the bounding box and scales) in \code{cloud} and
    \code{wireframe}. This function is called after the \sQuote{back} of
    the bounding box is drawn, but before the \sQuote{front} is drawn.

    Any user-defined custom display would probably want to change these
    functions. The intention is to pass as much information to this
    function as might be useful (not all of which are used by the
    defaults). In particular, these functions can expect arguments
    called \code{xlim}, \code{ylim}, \code{zlim} which give the bounding
    box ranges in the original data scale and \code{xlim.scaled},
    \code{ylim.scaled}, \code{zlim.scaled} which give the bounding box
    ranges in the transformed scale. More arguments can be considered on
    request.
  }
  \item{aspect}{ aspect as in \code{cloud} }
  \item{xlab, ylab, zlab}{
    Labels, have to be lists. Typically the user will not manipulate
    these, but instead control this via arguments to \code{cloud}
    directly.
  }
  \item{xlab.default}{ for internal use  }
  \item{ylab.default}{ for internal use  }
  \item{zlab.default}{ for internal use  }
  \item{scales.3d}{ list defining the scales }
  \item{proportion}{
    numeric scalar, gives the length of arrows as a proportion of the
    sides
  }
  \item{scpos}{
    A list with three components x, y and z (each a scalar integer),
    describing which of the 12 sides of the cube the scales should be
    drawn. The defaults should be OK. Valid values are x: 1, 3, 9, 11;
    y: 8, 5, 7, 6 and z: 4, 2, 10, 12. (See comments in the source code
    of \code{panel.cloud} to see the details of this enumeration.)
  }
  \item{wireframe}{logical, indicating whether this is a wireframe plot}
  \item{drape}{
    logical, whether the facets will be colored by height, in a manner
    similar to \code{levelplot}.  This is ignored if \code{shade=TRUE}.
  }
  \item{at, col.regions, alpha.regions}{
    deals with specification of colors when \code{drape = TRUE} in
    \code{\link{wireframe}}.  \code{at} can be a numeric vector,
    \code{col.regions} a vector of colors, and \code{alpha.regions} a
    numeric scalar controlling transparency.  The resulting behaviour is
    similar to \code{\link{levelplot}}, \code{at} giving the breakpoints
    along the z-axis where colors change, and the other two determining
    the colors of the facets that fall in between.
  }
  \item{rot.mat}{
    4x4 transformation matrix in homogeneous coordinates. This gives the
    rotation matrix combining the \code{screen} and \code{R.mat}
    arguments to \code{\link{panel.cloud}}
  }
  \item{type}{

    character vector, specifying type of cloud plot. Can include one or
    more of \code{"p"}, \code{"l"}, \code{"h"} or \code{"b"}. \code{"p"}
    and \code{"l"} mean \sQuote{points} and \sQuote{lines} respectively,
    and \code{"b"} means \sQuote{both}.  \code{"h"} stands for
    \sQuote{histogram}, and causes a line to be drawn from each point to
    the X-Y plane (i.e., the plane representing \code{z = 0}), or the
    lower (or upper) bounding box face, whichever is closer.

  }
  \item{xlim.scaled, ylim.scaled, zlim.scaled}{
     axis limits (after being scaled to the bounding box) 
  }
  \item{zero.scaled}{
    z-axis location (after being scaled to the bounding box) of the X-Y
    plane in the original data scale, to which lines will be dropped (if
    within range) from each point when \code{type = "h"}
  }
  \item{cross}{
    logical, defaults to \code{TRUE} if \code{pch = "+"}.
    \code{panel.3dscatter} can represent each point by a 3d
    \sQuote{cross} of sorts (it's much easier to understand looking at
    an example than from a description). This is different from the
    usual \code{pch} argument, and reflects the depth of the points and
    the orientation of the axes. This argument indicates whether this
    feature will be used.

    This is useful for two reasons. It can be set to \code{FALSE} to use
    \code{"+"} as the plotting character in the regular sense. It can
    also be used to force this feature in grouped displays.
  }
  \item{shade}{
    logical, indicating whether the surface is to be colored using an
    illumination model with a single light source
  }
  \item{shade.colors.palette}{
    a function (or the name of one) that is supposed to calculate the
    color of a facet when shading is being used. Three pieces of
    information are available to the function: first, the cosine of the
    angle between the incident light ray and the normal to the surface
    (representing foreshortening); second, the cosine of half the angle
    between the reflected ray and the viewing direction (useful for
    non-Lambertian surfaces); and third, the scaled (average) height of
    that particular facet with respect to the total plot z-axis limits.

    All three numbers should be between 0 and 1. The
    \code{shade.colors.palette} function should return a valid
    color. The default function is obtained from the trellis settings.
  }
  \item{light.source}{
    a 3-vector representing (in cartesian coordinates) the light
    source. This is relative to the viewing point being (0, 0,
    1/distance) (along the positive z-axis), keeping in mind that all
    observations are bounded within the [-0.5, 0.5] cube
  }
  \item{polynum}{
    quadrilateral faces are drawn in batches of \code{polynum} at a
    time. Drawing too few at a time increases the total number of calls
    to the underlying \code{grid.polygon} function, which affects
    speed. Trying to draw too many at once may be unnecessarily memory
    intensive. This argument controls the trade-off.
  }
  \item{col.groups}{colors for different groups}
  \item{col, col.point, col.line, lty, lwd, cex, pch, alpha}{
    graphical parameters
  }
  \item{\dots}{ other parameters, passed down when appropriate}
}
\details{
  These functions together are responsible for the content drawn inside
  each panel in \code{cloud} and \code{wireframe}.
  \code{panel.wireframe} is a wrapper to \code{panel.cloud}, which does
  the actual work.

  \code{panel.cloud} is responsible for drawing the content that does
  not depend on the data, namely, the bounding box, the arrows/scales,
  etc. At some point, depending on whether \code{wireframe} is TRUE, it
  calls either \code{panel.3d.wireframe} or \code{panel.3d.cloud}, which
  draws the data-driven part of the plot.

  The arguments accepted by these two functions are different, since
  they have essentially different purposes. For cloud, the data is
  unstructured, and \code{x}, \code{y} and \code{z} are all passed to
  the \code{panel.3d.cloud} function. For wireframe, on the other hand,
  \code{x} and \code{y} are increasing vectors with unique values,
  defining a rectangular grid. \code{z} must be a matrix with
  \code{length(x) * length(y)} rows, and as many columns as the number
  of groups.

  \code{panel.3dscatter} is the default \code{panel.3d.cloud} function.
  It has a \code{type} argument similar to \code{\link{panel.xyplot}},
  and supports grouped displays. It tries to honour depth ordering,
  i.e., points and lines closer to the camera are drawn later,
  overplotting more distant ones. (Of course there is no absolute
  ordering for line segments, so an ad hoc ordering is used. There is no
  hidden point removal.)

  \code{panel.3dwire} is the default \code{panel.3d.wireframe}
  function. It calculates polygons corresponding to the facets one by
  one, but waits till it has collected information about \code{polynum}
  facets, and draws them all at once. This avoids the overhead of
  drawing \code{grid.polygon} repeatedly, speeding up the rendering
  considerably. If \code{shade = TRUE}, these attempt to color the
  surface as being illuminated from a light source at
  \code{light.source}. \code{palette.shade} is a simple function that
  provides the deafult shading colors

  Multiple surfaces are drawn if \code{groups} is non-null in the call
  to \code{wireframe}, however, the algorithm is not sophisticated
  enough to render intersecting surfaces correctly.

}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{cloud}}, \code{\link{utilities.3d}}}
\keyword{dplot}
\eof
% --- Source file: panel.densityplot.Rd ---
\name{panel.densityplot}
\alias{panel.densityplot}
\title{ Default Panel Function for densityplot }
\description{
  This is the default panel function for \code{densityplot}.
}
\usage{
panel.densityplot(x, darg, plot.points = "jitter", ref = FALSE,
                  groups = NULL, weights = NULL,
                  jitter.amount, type, \dots)
}
\arguments{
  \item{x}{ data points for which density is to be estimated }
  \item{darg}{
    list of arguments to be passed to the \code{density}
    function. Typically, this should be a list with zero or more of the
    following components : \code{bw}, \code{adjust}, \code{kernel},
    \code{window}, \code{width}, \code{give.Rkern}, \code{n},
    \code{from}, \code{to}, \code{cut}, \code{na.rm} (see
    \code{\link{density}} for details)
  } 
  \item{plot.points}{
    logical specifying whether or not the data points should be plotted
    along with the estimated density.  Alternatively, a character string
    specifying how the points should be plotted.  Meaningful values are
    \code{"rug"}, in which case \code{\link{panel.rug}} is used to plot
    a \sQuote{rug}, and \code{"jitter"}, in which case the points are
    jittered vertically to better distinguish overlapping points.
  }
  \item{ref}{ logical, whether to draw x-axis }
  \item{groups}{ an optional grouping variable.  If present,
    \code{\link{panel.superpose}} will be used instead to display each
    subgroup }
  \item{weights}{ numeric vector of weights for the density
    calculations.  If this is specified, the \code{\dots} part must
    also include a \code{subscripts} argument that matches the weights
    to \code{x}.  }
  \item{jitter.amount}{
    when \code{plot.points="jitter"}, the value to use as the
    \code{amount} argument to \code{\link{jitter}}.
  }
  \item{type}{\code{type} argument used to plot points, if requested.
    This is not expected to be useful, it is available mostly to protect
    a \code{type} argument, if specified, from affecting the density
    curve.
  }
  \item{\dots}{ extra graphical parameters.  Note that additional
    arguments to \code{\link{panel.rug}} cannot be passed on through
    \code{panel.densityplot}. }
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{
  \code{\link{densityplot}},
  \code{\link{jitter}}
}
\keyword{dplot}
















\eof
% --- Source file: panel.dotplot.Rd ---
\name{panel.dotplot}
\alias{panel.dotplot}
\title{ Default Panel Function for dotplot}
\description{
  Default panel function for \code{dotplot}.
}
\usage{
panel.dotplot(x, y, horizontal = TRUE,
              pch, col, lty, lwd, 
              col.line, levels.fos,
              groups = NULL,
              \dots)
}
\arguments{
  \item{x,y}{ variables to be plotted in the panel. Typically y is the
    \sQuote{factor} }
  \item{horizontal}{ logical. If FALSE, the plot is \sQuote{transposed}
    in the sense that the behaviours of x and y are switched. x is now
    the \sQuote{factor}.  Interpretation of other arguments change
    accordingly. See documentation of \code{\link{bwplot}} for a fuller
    explanation.
  }
  \item{pch, col, lty, lwd, col.line}{ graphical parameters}
  \item{levels.fos}{ locations where reference lines will be drawn }
  \item{groups}{ grouping variable (affects graphical parameters)}
  \item{\dots}{
    extra parameters, passed to \code{panel.xyplot} which is responsible
    for drawing the foreground points (\code{panel.dotplot} only draws
    the background reference lines).
  }
}
\details{
  Creates (possibly grouped) Dotplot of \code{x} against \code{y} or
  vice versa
}
\seealso{\code{\link{dotplot}}}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}
















\eof
% --- Source file: panel.functions.Rd ---
\name{panel.functions}
\alias{panel.functions}
\alias{panel.abline}
\alias{panel.refline}
\alias{panel.curve}
\alias{panel.rug}
\alias{panel.fill}
\alias{panel.grid}
\alias{panel.lmline}
\alias{panel.loess}
\alias{panel.average}
\alias{panel.linejoin}
\alias{panel.mathdensity}
\title{Useful Panel Functions}
\description{
  These are predefined panel functions available in lattice for use in
  constructing new panel functions (usually on-the-fly).
}
\usage{

panel.abline(a = NULL, b = 0,
             h = NULL, v = NULL,
             reg = NULL, coef = NULL,
             col, col.line, lty, lwd, alpha, type,
             \dots,
             reference = FALSE)
panel.refline(\dots) 

panel.curve(expr, from, to, n = 101,
            curve.type = "l",
            col, lty, lwd, type,
            \dots)
panel.rug(x = NULL, y = NULL,
          regular = TRUE, 
          start = if (regular) 0 else 0.97,
          end = if (regular) 0.03 else 1,
          x.units = rep("npc", 2),
          y.units = rep("npc", 2),
          col, lty, lwd, alpha,
          \dots)
panel.average(x, y, fun = mean, horizontal = TRUE,
              lwd, lty, col, col.line, type,
              \dots)
panel.linejoin(x, y, fun = mean, horizontal = TRUE,
               lwd, lty, col, col.line, type,
               \dots)

% panel.abline(a, b, \dots)
% panel.abline(coef, \dots)
% panel.abline(reg, \dots)
% panel.abline(h= ,v= , \dots)
panel.fill(col, border, \dots)
panel.grid(h=3, v=3, col, col.line, lty, lwd, \dots)
panel.lmline(x, y, \dots)
panel.loess(x, y, span = 2/3, degree = 1,
            family = c("symmetric", "gaussian"),
            evaluation = 50,
            lwd, lty, col, col.line, type,
            horizontal = FALSE,
            \dots)
panel.mathdensity(dmath = dnorm, args = list(mean=0, sd=1),
                  n = 50, col, col.line, lwd, lty, type,
                  \dots)
}
\arguments{
  \item{x, y}{ variables defining the contents of the panel}
  \item{a, b}{ Coefficients of the line to be added by
    \code{panel.abline}.  \code{a} can be a vector of length 2,
    representing the coefficients of the line to be added, in which case
    \code{b} should be missing.  \code{a} can also be an appropriate
    \sQuote{regression} object, i.e., an object which has a
    \code{\link{coef}} method that returns a length 2 numeric vector.
    The corresponding line will be plotted.  The \code{reg} argument
    will override \code{a} if specified.
  }
  \item{coef}{ Coefficients of the line to be added as a length 2 vector}
  \item{reg}{ A regression object. The corresponding fitted line will
    be drawn }

  \item{h, v}{ For \code{panel.abline}, these are numeric vectors giving
    locations respectively of horizontal and vertical lines to be added
    to the plot, in native coordinates.  For \code{panel.grid}, these
    usually specify the number of horizontal and vertical reference
    lines to be added to the plot.  Alternatively, they can be negative
    numbers.  \code{h=-1} and \code{v=-1} are intended to make the grids
    aligned with the axis labels.  This doesn't always work; all that
    actually happens is that the locations are chosen using
    \code{pretty}, which is also how the label positions are chosen in
    the most common cases (but not for factor or date-time variables,
    for instance).  \code{h} and \code{v} can be negative numbers other
    than \code{-1}, in which case \code{-h} and \code{-v} (as
    appropriate) is supplied as the \code{n} argument to
    \code{\link{pretty}}. }
  \item{reference}{ logical indicating whether the default graphical
    parameters for \code{panel.abline} should be taken from the
    \dQuote{reference.line} parameter settings.  The default is to take
    them from the \dQuote{add.line} settings.  The \code{panel.refline}
    function is a wrapper around \code{panel.abline} that calls it with
    \code{reference=TRUE}.
  }

  \item{expr}{ expression as a function of x or a function to plot as a
    curve }
  \item{n}{ the number of points to use for drawing the curve }
  \item{regular}{ logical indicating whether the \sQuote{rug} is to be
    drawn on the regular side (left / bottom) or not (right / top)
  }
  \item{start, end}{ endpoints of rug segments, in normalized parent
    coordinates (between 0 and 1). Defaults depend on value of regular,
    and cover 3\% of the panel width and height
  }
  \item{x.units, y.units}{
    character vector, replicated to be of length two.  Specifies the
    (grid) units associated with \code{start} and \code{end} above.
    \code{x.units} and \code{y.units} are for the rug on the x-axis and
    y-axis respectively (and thus are associated with \code{start} and
    \code{end} values on the y and x scales respectively).
  }
  \item{from, to}{ optional lower and upper x-limits of curve. If
    missing, limits of current panel are used
  }
  \item{curve.type}{ type of curve (\code{"p"} for points, etc), passed
    to \code{\link{llines}}
  }
  \item{col, col.line, lty, lwd, alpha, border}{ graphical parameters }
  \item{type}{ passed on to \code{\link{panel.points}} by
    \code{panel.average}, but is usually ignored by the other panel
    functions documented here.  In such cases, the argument is present
    only to make sure an explicitly specified \code{type} argument
    (perhaps meant for another function) doesn't affect the display.
  }
  \item{span, degree, family, evaluation}{ arguments to
    \code{loess.smooth}, for which \code{panel.loess} is essentially
    a wrapper.
  }
  \item{fun}{ the function that will be applied to the subset of x(y)
    determined by the unique values of y(x)}
  \item{horizontal}{ logical. If FALSE, the plot is \sQuote{transposed}
    in the sense that the behaviours of x and y are switched. x is now
    the \sQuote{factor}.  Interpretation of other arguments change
    accordingly. See documentation of \code{\link{bwplot}} for a fuller
    explanation.
  }
  \item{dmath}{ A vectorized function that produces density values
    given a numeric vector named \code{x}, e.g., \code{dnorm}}
  \item{args}{ list giving additional arguments to be passed to dmath}
  \item{\dots}{ graphical parameters can be supplied. see function
    definition for details. Color can usually be specified by
    \code{col}, \code{col.line} and \code{col.symbol}, the last two
    overriding the first for lines and points respectively.
  }
}
\details{
  \code{panel.abline} adds a line of the form \code{y=a+bx} or vertical
  and/or horizontal lines.  Graphical parameters are obtained from the
  \dQuote{add.line} settings by default.  \code{panel.refline} is
  similar, but uses the \dQuote{reference.line} settings for the
  defaults.

  \code{panel.grid} draws a reference grid.

  \code{panel.curve} adds a curve, similar to what \code{curve} does
  with \code{add = TRUE}. Graphical parameters for the line are obtained
  from the \code{add.line} setting.

  \code{panel.average} treats one of x and y as a factor (according to
  the value of \code{horizontal}), calculates \code{fun} applied to the
  subsets of the other variable determined by each unique value of the
  factor, and joins them by a line. Can be used in conjunction with
  \code{panel.xyplot} and more commonly with panel.superpose to produce
  interaction plots.  See \code{\link{xyplot}} documentation for an
  example.  \code{panel.linejoin} is an alias for \code{panel.average}
  retained for back-compatibility and may go away in future.

  \code{panel.mathdensity} plots a (usually theoretical) probability
  density function.  This can be useful in conjunction with
  \code{histogram} and \code{densityplot} to visually estimate goodness
  of fit (note, however, that \code{qqmath} is more suitable for this).

  \code{panel.rug} adds a \emph{rug} representation of the (marginal)
  data to the panel, much like \code{\link{rug}}.

  \code{panel.lmline(x, y)} is equivalent to
  \code{panel.abline(lm(y~x))}.

}

\seealso{\code{\link[stats:scatter.smooth]{loess.smooth}},
  \code{\link{panel.axis}}, \code{\link{panel.identify}}
  \code{\link{identify}}, \code{\link{trellis.par.set}}
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}




\eof
% --- Source file: panel.histogram.Rd ---
\name{panel.histogram}
\alias{panel.histogram}
\title{ Default Panel Function for histogram }
\description{
  This is the default panel function for \code{histogram}.
}
\usage{
panel.histogram(x,
                breaks,
                equal.widths = TRUE,
                type = "density",
                nint = round(log2(length(x)) + 1), 
                alpha, col, border, lty, lwd,
                \dots)
}
\arguments{
  \item{x}{ The data points for which the histogram is to be drawn} 
  \item{breaks}{ The breakpoints for the histogram}
  \item{equal.widths}{ logical used when \code{breaks==NULL} }
  \item{type}{ Type of histogram, possible values being \code{"percent"},
    \code{"density"} and \code{"count"}}
  \item{nint}{ Number of bins for the histogram }
  \item{alpha, col, border, lty, lwd}{
    graphical parameters for bars; defaults are obtained from the
    \code{plot.polygon} settings.
  }
  \item{\dots}{ other arguments, passed to \code{\link{hist}} when
    deemed appropriate }
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{histogram}}}
\keyword{dplot}

\eof
% --- Source file: panel.levelplot.Rd ---
\name{panel.levelplot}
\alias{panel.levelplot}
\alias{panel.contourplot}
\title{ Default Panel Function for levelplot }
\description{
  This is the default panel function for \code{levelplot}.
}
\usage{
panel.levelplot(x, y, z, 
                subscripts,
                at = pretty(z),
                shrink,
                labels,
                label.style = c("mixed", "flat", "align"),
                contour = FALSE,
                region = TRUE,
                col = add.line$col,
                lty = add.line$lty,
                lwd = add.line$lwd,
                \dots,
                col.regions = regions$col,
                alpha.regions = regions$alpha)
panel.contourplot(\dots)
}
\arguments{
  \item{x, y, z}{ Variables defining the plot. }
  \item{subscripts}{
    Integer vector indicating what subset of \code{x}, \code{y} and
    \code{z} to draw.
  }
  \item{at}{
    Numeric vector giving breakpoints along the range of
    \code{z}.  See \code{\link{levelplot}} for details.
  }
  \item{shrink}{
    Either a numeric vector of length 2 (meant to work as both x and y
    components), or a list with components x and y which are numeric
    vectors of length 2.  This allows the rectangles to be scaled
    proportional to the z-value. The specification can be made
    separately for widths (x) and heights (y).  The elements of the
    length 2 numeric vector gives the minimum and maximum proportion of
    shrinkage (corresponding to min and max of z).
  }
  \item{labels}{
    Either a logical scalar indicating whether the labels are to be
    drawn, or a character or expression vector giving the labels
    associated with the \code{at} values.  Alternatively, \code{labels}
    can be a list with the following components:
    
    \describe{
    
      \item{\code{labels}:}{ a character or expression vector giving the
	labels.  This can be omitted, in which case the defaults will be
	used. }

      \item{\code{col, cex, alpha}:}{ graphical parameters for label
	texts }

      \item{\code{fontfamily, fontface, font}:}{ font used for the
	labels }
    }
    
  }
  \item{label.style}{
    Controls how label positions and rotation are determined.  A value
    of \code{"flat"} causes the label to be positioned where the contour
    is flattest, and the label is not rotated.  A value of
    \code{"align"} causes the label to be drawn as far from the
    boundaries as possible, and the label is rotated to align with the
    contour at that point.  The default is to mix these approaches,
    preferring the flattest location unless it is too close to the
    boundaries.
  }
  \item{contour}{
    A logical flag, specifying whether contour lines should be drawn.
  }
  \item{region}{
    A logical flag, specifying whether inter-contour regions should be
    filled with the appropriate color.
  }
  \item{col, lty, lwd}{ graphical parameters for contour lines}
%   \item{cex, col.text, font, fontfamily, fontface}{ graphical parameters for contour labels}
  \item{\dots}{ Extra parameters. }
  \item{col.regions}{
    A vector of colors, or a function to produce a vecor of colors, to
    be used if \code{region=TRUE}.  Each interval defined by \code{at}
    is assigned a color, so the number of colors actually used is one
    less than the length of \code{at}.  See \code{\link{level.colors}}
    for details on how the color assignment is done.
  }
  \item{alpha.regions}{
    numeric scalar controlling transparency of facets
  }
}

\details{
  The same panel function is used for both \code{levelplot} and
  \code{contourplot} (which differ only in default values of some
  arguments). \code{panel.contourplot} is a simple wrapper to
  \code{panel.levelplot}.

  When \code{contour=TRUE}, the \code{contourLines} function is used to
  calculate the contour lines.
} 

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{
  \code{\link{levelplot}},
  \code{\link{level.colors}},
  \code{\link{contourLines}}
}
\keyword{dplot}
















\eof
% --- Source file: panel.number.Rd ---
\name{panel.number}
\alias{current.row}
\alias{current.column}
\alias{packet.number}
\alias{panel.number}
\alias{which.packet}
\alias{trellis.currentLayout}

\title{Accessing Auxiliary Information During Plotting}

\description{

  Control over lattice plots are provided through a collection of user
  specifiable functions that perform various tasks during the plotting.
  Not all information is available to all functions.  The functions
  documented here attempt to provide a consistent interface to access
  relevant information from within these user specified functions,
  namely those specified as the \code{panel}, \code{strip} and
  \code{axis} functions.

}
\usage{

current.row()
current.column()
panel.number()
packet.number()
which.packet()

trellis.currentLayout(which = c("packet", "panel"))

}

\arguments{
  \item{which}{
    whether return value (a matrix) should contain panel numbers or
    packet numbers, which are usually, but not necessarily, the same
    (see below for details).
  }
}

\value{

  \code{trellis.currentLayout} returns a matrix with as many rows and
  columns as in the layout of panels in the current plot.  Entries in
  the matrix are integer indices indicating which packet (or panel; see
  below) occupies that position, with 0 indicating the absence of a
  panel.  \code{current.row} and \code{current.column} return integer
  indices specifying which row and column in the layout are currently
  active.  \code{panel.number} returns an integer counting which panel
  is being drawn (starting from 1 for the first panel, a.k.a. the panel
  order).  \code{packet.number} gives the packet number according to the
  packet order, which is determined by varying the first conditioning
  variable the fastest, then the second, and so on.  \code{which.packet}
  returns the combination of levels of the conditioning variables in the
  form of a numeric vector as long as the number of conditioning
  variables, with each element an integer indexing the levels of the
  corresponding variable.

}

\note{

  The availability of these functions make redundant some features
  available in earlier versions of lattice, namely optional arguments
  called \code{panel.number} and \code{packet.number} that were made
  available to \code{panel} and \code{strip}.  If you have written such
  functions, it should be enough to replace instances of
  \code{panel.number} and \code{packet.number} by the corresponding
  function calls.  You should also remove \code{panel.number} and
  \code{packet.number} from the argument list of your function to avoid
  a warning.

  If these accessor functions are not enough for your needs, feel free
  to contact the maintainer and ask for more.

}

\seealso{
  \code{\link{Lattice}}, \code{\link{xyplot}}
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}

\eof
% --- Source file: panel.pairs.Rd ---
\name{panel.pairs}
\alias{panel.pairs}
\alias{diag.panel.splom}
\title{ Default Superpanel Function for splom}
\description{
  This is the default superpanel function for \code{splom}.
}
\usage{

panel.pairs(z,
            panel = lattice.getOption("panel.splom"),
            lower.panel = panel,
            upper.panel = panel,
            diag.panel = "diag.panel.splom",
            as.matrix = FALSE,
            groups = NULL,
            panel.subscripts,
            subscripts,
            pscales = 5,
%             packet.number, panel.number,
            prepanel.limits = function(x) if (is.factor(x)) levels(x) else
            extend.limits(range(as.numeric(x), finite = TRUE)),

            varname.col, varname.cex, varname.font,
            varname.fontfamily, varname.fontface,
            axis.text.col, axis.text.cex, axis.text.font,
            axis.text.fontfamily, axis.text.fontface,
            axis.line.col, axis.line.lty, axis.line.lwd,
            axis.line.alpha, axis.line.tck,
            \dots)
diag.panel.splom(x = NULL,
                 varname = NULL, limits, at = NULL, lab = NULL,
                 draw = TRUE,
                 varname.col, varname.cex,
                 varname.lineheight, varname.font,
                 varname.fontfamily, varname.fontface,
                 axis.text.col, axis.text.alpha,
                 axis.text.cex, axis.text.font, 
                 axis.text.fontfamily, axis.text.fontface,
                 axis.line.col, axis.line.alpha,
                 axis.line.lty, axis.line.lwd,
                 axis.line.tck,
                 \dots)
}
\arguments{
  \item{z}{ The data frame used for the plot.}
  \item{panel, lower.panel, upper.panel}{
    The panel function used to display each pair of variables. If
    specified, \code{lower.panel} and \code{upper.panel} are used for
    panels below and above the diagonal respectively.
  }
  \item{diag.panel}{
    The panel function used for the diagonals. See arguments to
    \code{diag.panel.splom} to know what arguments this function is
    passed when called.
  }
  \item{as.matrix}{
    logical. If \code{TRUE}, the layout of the panels will have origin
    on the top left instead of bottom left (similar to
    \code{pairs}). This is in essence the same functionality as provided
    by \code{as.table} for the panel layout
  }
  \item{groups}{ Grouping variable, if any }
  \item{panel.subscripts}{
    logical specifying whether the panel function accepts an argument
    named \code{subscripts}.
  }
  \item{subscripts}{ The indices of the rows of \code{z} that are to be
    displayed in this (super)panel.
  }
  \item{pscales}{ Controls axis labels, passed down from \code{splom}.
    If \code{pscales} is a single number, it indicates the approximate
    number of equally-spaced ticks that should appear on each axis.  If
    \code{pscales} is a list, it should have one component for each
    column in \code{z}, each of which itself a list with the following
    valid components:

    \code{at}: a numeric vector specifying tick locations

    \code{labels}: character vector labels to go with at

    \code{limits}: numeric 2-vector specifying axis limits (should be
    made more flexible at some point to handle factors)

    These are specifications on a per-variable basis, and used on all
    four sides in the diagonal cells used for labelling.  Factor
    variables are labelled with the factor names.  Use \code{pscales=0}
    to supress the axes entirely.
  }
  \item{prepanel.limits}{ The \sQuote{regular} high level lattice plots
    such as \code{xyplot} use the \code{prepanel} function for deciding
    on axis limits from data.  This function serves a similar function,
    and works on a per-variable basis, by calculating the limits, which
    can be overridden by the corresponding \code{limits} component in
    the \code{pscales} list.
  }
  \item{x}{
    data vector corresponding to that row / column (which will be the
    same for diagonal \sQuote{panels}).
  }
  \item{varname}{ (scalar) character string or expression that is to be
    written centred within the panel
  }
  \item{limits}{
    numeric of length 2, or, vector of characters, specifying the scale
    for that panel (used to calculate tick locations when missing)
  }
  \item{at}{ locations of tick marks}
  \item{lab}{ optional labels for tick marks}
  \item{draw}{
    logical, specifying whether to draw the tick marks and labels. If
    \code{FALSE}, only variable names are written
  }
%   \item{panel.number, packet.number}{ integer indices for panel and
%     packet number (see \code{\link{xyplot}}).  Passed on to
%     \code{panel}, \code{lower.panel}, \code{upper.panel} and
%     \code{diag.panel}. }
  \item{varname.col, varname.cex, varname.lineheight, varname.font,
    varname.fontfamily, varname.fontface}{ graphical parameters for the
    variable name in each diagonal panel }
  \item{axis.text.col, axis.text.cex, axis.text.font,
    axis.text.fontfamily, axis.text.fontface, axis.line.col,
    axis.line.lty, axis.line.lwd, axis.text.alpha, axis.line.alpha}{
    graphical parameters for axis tick marks and labels }
  \item{axis.line.tck}{ length of tick marks in diagonal panels }
  \item{\dots}{ extra arguments passed on to \code{panel},
    \code{lower.panel}, \code{upper.panel} and \code{diag.panel} from
    \code{panel.pairs}.  Currently ignored by \code{diag.panel.splom}. }

}

\details{
  \code{panel.pairs} is the function that is actually passed in as the
  \code{panel} function in a trellis object produced by splom (taking
  the \code{panel} function as its argument).

  Note that the axis labeling does not support date-time classes at
  present.

}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{splom}}}
\keyword{dplot}

\eof
% --- Source file: panel.parallel.Rd ---
\name{panel.parallel}
\alias{panel.parallel}
\title{ Default Panel Function for parallel }
\description{
  This is the default panel function for \code{parallel}.
}
\usage{
panel.parallel(x, y, z, subscripts,
               groups = NULL,
               col, lwd, lty, alpha,
               common.scale = FALSE,
               lower,
               upper,
               \dots,
               horizontal.axis = TRUE)
}
\arguments{
  \item{x, y}{ dummy variables, ignored. }
  \item{z}{
    The data frame used for the plot.  Each column will be coerced to
    numeric before being plotted, and an error will be issued if this
    fails.
  }
  \item{subscripts}{
    The indices of the rows of \code{z} that are to be displyed in this
    panel.
  }
  \item{groups}{
    An optional grouping variable.  If specified, different groups are
    distinguished by use of different graphical parameters (i.e., rows
    of \code{z} in the same group share parameters).
  }
  \item{col, lwd, lty, alpha}{
    graphical parameters (defaults to the settings for
    \code{superpose.line}).  If \code{groups} is non-null, these
    parameters used one for each group.  Otherwise, they are recycled
    and used to distinguish between rows of the data frame \code{z}.
  }
  \item{common.scale}{
    logical, whether a common scale should be used columns of \code{z}.
    Defaults to \code{FALSE}, in which case the horizontal range for
    each column is different (as determined by \code{lower} and
    \code{upper}).
  }
  \item{lower, upper}{
    numeric vectors replicated to be as long as the number of columns in
    \code{z}.  Determines the lower and upper bounds to be used for
    scaling the corresponding columns of \code{z} after coercing them to
    numeric.  Defaults to the minimum and maximum of each column.
    Alternatively, these could be functions (to be applied on each
    column) that return a scalar.
  }
  \item{\dots}{ other arguments (ignored) }
  \item{horizontal.axis}{logical indicating whether the parallel axes should
    be laid out horizontally (\code{TRUE}) or vertically (\code{FALSE}).
  }
}

\details{ Produces parallel coordinate plots, which are easier to
  understand from an example than through a verbal description.  See
  example for \code{\link{parallel}}
}

\references{

  Inselberg, Alfred (2009) \dQuote{Parallel Coordinates: Visual
  Multidimensional Geometry and Its Applications}, Springer. ISBN:
  978-0-387-21507-5.

  Inselberg, A. (1985) \dQuote{The Plane with Parallel Coordinates},
  \emph{The Visual Computer}.
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{parallel}}}
\keyword{dplot}
\eof
% --- Source file: panel.qqmath.Rd ---
\name{panel.qqmath}
\alias{panel.qqmath}
\title{ Default Panel and Prepanel Function for qqmath }
\description{
  This is the default panel function for \code{qqmath}.
}
\usage{
panel.qqmath(x, f.value = NULL,
             distribution = qnorm,
             qtype = 7,
             groups = NULL, \dots)
}
\arguments{
  \item{x}{
    vector (typically numeric, coerced if not) of data values to be used
    in the panel.
  }
  \item{f.value, distribution}{
    Defines how quantiles are calculated.  See \code{\link{qqmath}} for
    details.
  }
  \item{qtype}{
    The \code{type} argument to be used in \code{\link{quantile}}
  }
  \item{groups}{
    An optional grouping variable.  Within each panel, one Q-Q plot is
    produced for every level of this grouping variable, differentiated
    by different graphical parameters.
  }
  \item{\dots}{
    further arguments, often graphical parameters.
  }
}

\details{

  Creates a Q-Q plot of the data and the theoretical distribution given
  by \code{distribution}.  Note that most of the arguments controlling
  the display can be supplied directly to the high-level \code{qqmath}
  call.

}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}

\seealso{
  \code{\link{qqmath}}
}
\keyword{dplot}
\eof
% --- Source file: panel.qqmathline.Rd ---
\name{panel.qqmathline}
\alias{panel.qqmathline}
\title{Useful panel function with qqmath}
\description{
  Useful panel function with qqmath. Draws a line passing through the
  points (usually) determined by the .25 and .75 quantiles of the sample
  and the theoretical distribution.
}
\usage{
panel.qqmathline(x, y = x,
                 distribution = qnorm,
                 probs = c(0.25, 0.75),
                 qtype = 7,
                 groups = NULL, 
                 \dots)
}
\arguments{
  \item{x}{ The original sample, possibly reduced to a fewer number of
    quantiles, as determined by the \code{f.value} argument to
    \code{qqmath}
  }
  \item{y}{
    an alias for \code{x} for backwards compatibility
  }
  \item{distribution}{
    quantile function for reference theoretical distribution.
  }
  \item{probs}{
    numeric vector of length two, representing probabilities.
    Corresponding quantile pairs define the line drawn.
  }
  \item{qtype}{
    the \code{type} of quantile computation used in
    \code{\link{quantile}}
  }
  \item{groups}{
    optional grouping variable.  If non-null, a line will be drawn for
    each group.
  }
  \item{\dots}{other arguments.}
}
\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{
  \code{\link{prepanel.qqmathline}},
  \code{\link{qqmath}},
  \code{\link{quantile}}
}
\keyword{dplot}
\eof
% --- Source file: panel.smoothScatter.Rd ---
\name{panel.smoothScatter}
\alias{panel.smoothScatter}
\title{Lattice panel function analogous to smoothScatter}
\description{
  This function allows the user to place \code{smoothScatter} plots in
  lattice graphics.
}
\usage{
panel.smoothScatter(x, y = NULL,
                    nbin = 64, cuts = 255,
                    bandwidth,
                    colramp,
                    nrpoints = 100,
                    transformation = function(x) x^0.25,
                    pch = ".",
                    cex = 1, col="black",
                    range.x,
                    ...,
                    subscripts)
}
\arguments{
  \item{x}{Numeric vector containing x-values or n by 2 matrix containing x
    and y values.}
  \item{y}{Numeric vector containing y-values (optional). The length of \code{x}
    must be the same as that of \code{y}.}
  \item{nbin}{Numeric vector of length 1 (for both directions) or
    2 (for x and y separately) containing the number of equally spaced
    grid points for the density estimation.}
  \item{cuts}{ number of cuts defining the color gradient }
  \item{bandwidth}{Numeric vector: the smoothing bandwidth.  If missing,
    these functions come up with a more or less useful guess.  This
    parameter then gets passed on to the function
    \code{\link[KernSmooth::bkde2D]{bkde2D}}.}
  \item{colramp}{Function accepting an integer \code{n} as an argument and
    returning \code{n} colors.}
  \item{nrpoints}{Numeric vector of length 1 giving number of points to
    be superimposed on the density image. The first \code{nrpoints} points
    from those areas of lowest regional densities will be plotted. Adding
    points to the plot allows for the identification of outliers.
    If all points are to be plotted, choose \code{nrpoints = Inf}.}
  \item{transformation}{Function that maps the density scale to the color scale.}
  \item{pch, cex}{ graphical parameters for the \code{nrpoints}
    \dQuote{outlying} points shown in the display }
  \item{range.x}{see  \code{\link[KernSmooth::bkde2D]{bkde2D}} for details.}
  \item{col}{\code{\link{points}} color parameter}
  \item{\dots}{Further arguments that are passed on to
    \code{\link{panel.levelplot}}.}
  \item{subscripts}{ ignored, but necessary for handling of \dots in
    certain situations.  Likely to be removed in future. }
}

\details{
  This replicates the display part of the \code{smoothScatter}
  function by replacing standard graphics calls by grid-compatible ones.
}

\value{
  The function is called for its side effects, namely the production
  of the appropriate plots on a graphics device.
}

\author{ Deepayan Sarkar \email{deepayan.sarkar@r-project.org} }
\examples{

ddf <- as.data.frame(matrix(rnorm(40000), ncol = 4) + 3 * rnorm(10000))
ddf[, c(2,4)] <- (-ddf[, c(2,4)])
xyplot(V1 ~ V2 + V3, ddf, outer = TRUE,
       panel = panel.smoothScatter, aspect = "iso")
splom(ddf, panel = panel.smoothScatter, nbin = 64)

}
\keyword{ hplot }

\eof
% --- Source file: panel.stripplot.Rd ---
\name{panel.stripplot}
\alias{panel.stripplot}
\title{ Default Panel Function for stripplot }
\description{
  This is the default panel function for \code{stripplot}. Also see
  \code{panel.superpose}
}
\usage{
panel.stripplot(x, y, jitter.data = FALSE,
                factor = 0.5, amount = NULL,
                horizontal = TRUE, groups = NULL,
                \dots)
}
\arguments{
  \item{x,y}{ coordinates of points to be plotted}
  \item{jitter.data}{ whether points should be jittered to avoid
    overplotting.  The actual jittering is performed inside
    \code{\link{panel.xyplot}}, using its \code{jitter.x} or
      \code{jitter.y} argument (depending on the value of
      \code{horizontal}).  }
  \item{factor, amount}{amount of jittering, see \code{\link{jitter}}}
  \item{horizontal}{ logical. If FALSE, the plot is \sQuote{transposed}
    in the sense that the behaviours of x and y are switched. x is now
    the \sQuote{factor}.  Interpretation of other arguments change
    accordingly. See documentation of \code{\link{bwplot}} for a fuller
    explanation.
  }
  \item{groups}{ optional grouping variable }

  \item{\dots}{ additional arguments, passed on to
    \code{\link{panel.xyplot}} }
}

\details{ Creates stripplot (one dimensional scatterplot) of \code{x}
  for each level of \code{y} (or vice versa, depending on the value of
  \code{horizontal})
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{stripplot}}, \code{\link{jitter}}}
\keyword{dplot}
















\eof
% --- Source file: panel.superpose.Rd ---
\name{panel.superpose}
\alias{panel.superpose}
\alias{panel.superpose.2}
\title{ Panel Function for Display Marked by groups }
\description{
  These are panel functions for Trellis displays useful when a grouping
  variable is specified for use within panels. The \code{x} (and
  \code{y} where appropriate) variables are plotted with different
  graphical parameters for each distinct value of the grouping variable.
}
\usage{
panel.superpose(x, y = NULL, subscripts, groups,
                panel.groups = "panel.xyplot",
                \dots,
                col, col.line, col.symbol,
                pch, cex, fill, font,
                fontface, fontfamily,
                lty, lwd, alpha,
                type = "p",
                distribute.type = FALSE)
panel.superpose.2(\dots, distribute.type = TRUE)
}
\arguments{
  \item{x,y}{ coordinates of the points to be displayed}
  \item{panel.groups}{
    the panel function to be used for each group of points. Defaults to
    \code{panel.xyplot} (behaviour in S).

    To be able to distinguish between different levels of the
    originating group inside \code{panel.groups}, it will be supplied a
    special argument called \code{group.number} which will hold the
    numeric code corresponding to the current level of \code{groups}.
    No special care needs to be taken when writing a \code{panel.groups}
    function if this feature is not used.
  }
  \item{subscripts}{ subscripts giving indices in original data frame }
  \item{groups}{ a grouping variable. Different graphical parameters
    will be used to plot the subsets of observations given by each
    distinct value of \code{groups}. The default graphical parameters
    are obtained from \code{superpose.symbol} and \code{superpose.line}
    using \code{\link{trellis.par.get}} wherever appropriate
  }
  \item{type}{
    usually a character vector specifying what should be drawn for each
    group, passed on to the \code{panel.groups} function, which must
    know what to do with it.  By default, this is
    \code{\link{panel.xyplot}}, whose help page describes the admissible
    values.

    The functions \code{panel.superpose} and \code{panel.superpose.2}
    differ only in the default value of \code{distribute.type}, which
    controls the way the \code{type} argument is interpreted.  If
    \code{distribute.type = FALSE}, then the interpretation is the same
    as for \code{panel.xyplot} for each of the unique groups.  In other
    words, if \code{type} is a vector, all the individual components are
    honoured concurrently.  If \code{distribute.type = TRUE},
    \code{type} is replicated to be as long as the number of unique
    values in \code{groups}, and one component used for the points
    corresponding to the each different group.  Even in this case, it is
    possible to request multiple types per group, specifying \code{type}
    as a list, each component being the desired \code{type} vector for
    the corresponding group.

    If \code{distribute.type = FALSE}, any occurrence of \code{"g"} in
    \code{type} causes a grid to be drawn, and all such occurrences are
    removed before \code{type} is passed on to \code{panel.groups}.
  }
  \item{col, col.line, col.symbol, pch, cex, fill, font, fontface,
    fontfamily, lty, lwd, alpha}{ graphical parameters, replicated to be
    as long as the number of groups.  These are eventually passed down
    to \code{panel.groups}, but as scalars rather than vectors.  When
    \code{panel.groups} is called for the i-th level of \code{groups},
    the corresponding element of each graphical parameter is passed to
    it.
  }
  \item{\dots}{ Extra arguments.  Passed down to \code{panel.superpose}
    from \code{panel.superpose.2}, and to \code{panel.groups} from
    \code{panel.superpose}.
  }
  \item{distribute.type}{logical controlling interpretation of the
    \code{type} argument.  
  }

}

\details{
  \code{panel.superpose} and \code{panel.superpose.2} differ essentially
  in how \code{type} is interpreted by default.  The default behaviour
  in \code{panel.superpose} is the opposite of that in S, which is the
  same as that of \code{panel.superpose.2}.
}

\seealso{
  Different functions when used as \code{panel.groups} gives different
  types of plots, for example \code{\link{panel.xyplot}},
  \code{\link{panel.dotplot}} and \code{\link{panel.linejoin}} (This can
  be used to produce interaction plots).

  See \code{\link{Lattice}} for an overview of the package.

}

\author{
  Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}
  (\code{panel.superpose.2} originally contributed by Neil Klepeis)
}
\keyword{dplot}
\eof
% --- Source file: panel.violin.Rd ---
\name{panel.violin}
\alias{panel.violin}
\title{ Panel Function to create Violin Plots }
\description{
  This is a panel function that can create a violin plot.  It is
  typically used in a high-level call to \code{bwplot}.
}
\usage{

panel.violin(x, y, box.ratio = 1, box.width,
             horizontal = TRUE,
             alpha, border, lty, lwd, col,
             varwidth = FALSE,
             bw, adjust, kernel, window, 
             width, n = 50, from, to, cut,
             na.rm, \dots)
}
\arguments{
  \item{x, y}{
    numeric vector or factor. Violin plots are drawn for each unique
    value of \code{y} (\code{x}) if \code{horizontal} is \code{TRUE}
    (\code{FALSE})
  }
  \item{box.ratio}{
    ratio of the thickness of each violin and inter violin space
  }
  \item{box.width}{ thickness of the violins in absolute units;
    overrides \code{box.ratio}.  Useful for specifying thickness when
    the categorical variable is not a factor, as use of \code{box.ratio}
    alone cannot achieve a thickness greater than 1. }
  \item{horizontal}{
    logical. If FALSE, the plot is \sQuote{transposed} in the sense that
    the behaviours of \code{x} and \code{y} are switched.  \code{x} is
    now the \sQuote{factor}. See documentation of \code{\link{bwplot}}
    for a fuller explanation.
  }
  \item{alpha, border, lty, lwd, col}{
    graphical parameters controlling the violin.  Defaults are taken
    from the \code{"plot.polygon"} settings.
  }
  \item{varwidth}{
    logical. If \code{FALSE}, the densities are scaled separately for
    each group, so that the maximum value of the density reaches the
    limit of the allocated space for each violin (as determined by
    \code{box.ratio}).  If \code{TRUE}, densities across violins will
    have comparable scale.
  }
  \item{bw, adjust, kernel, window, width, n, from, to, cut, na.rm}{
    arguments to \code{\link{density}}, passed on as appropriate }
  \item{\dots}{
    arguments passed on to \code{density}.
  }
}

\details{
  Creates Violin plot of \code{x} for every level of \code{y}. Note that
  most arguments controlling the display can be supplied to the
  high-level (typically \code{bwplot}) call directly.
}

\examples{

bwplot(voice.part ~ height, singer,
       panel = function(..., box.ratio) {
           panel.violin(..., col = "transparent",
                        varwidth = FALSE, box.ratio = box.ratio)
           panel.bwplot(..., fill = NULL, box.ratio = .1)
       } )

}

\seealso{
  \code{\link{bwplot}}, \code{\link{density}}
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}

\eof
% --- Source file: panel.xyplot.Rd ---
\name{panel.xyplot}
\alias{panel.xyplot}
\alias{panel.splom}
\alias{panel.qq}
\title{ Default Panel Function for xyplot }
\description{
  This is the default panel function for \code{xyplot}. Also see
  \code{panel.superpose}.  The default panel functions for
  \code{splom} and \code{qq} are essentially the same function.
}
\usage{
panel.xyplot(x, y, type = "p",
             groups = NULL,
             pch, col, col.line, col.symbol,
             font, fontfamily, fontface,
             lty, cex, fill, lwd,
             horizontal = FALSE, \dots,
             jitter.x = FALSE, jitter.y = FALSE,
             factor = 0.5, amount = NULL)
panel.splom(\dots)
panel.qq(\dots)
}
\arguments{
  \item{x,y}{ variables to be plotted in the scatterplot}
  \item{type}{ character vector consisting of one or more of the
    following: \code{"p"}, \code{"l"}, \code{"h"}, \code{"b"},
    \code{"o"}, \code{"s"}, \code{"S"}, \code{"r"}, \code{"a"},
    \code{"g"}, \code{"smooth"}.  If type has more than one element, an
    attempt is made to combine the effect of each of the components.

    The behaviour if any of the first six are included in \code{type} is
    similar to the effect of \code{type} in \code{\link{plot}} (type
    \code{"b"} is actually the same as \code{"o"}).  \code{"r"} adds a
    regression line (same as \code{\link{panel.lmline}}, except for
    default graphical parameters), and \code{"smooth"} adds a lowess fit
    (same as \code{\link{panel.loess}}).  \code{"g"} adds a reference
    grid using \code{\link{panel.grid}} in the background.  \code{"a"}
    has the effect of calling \code{\link{panel.linejoin}}, which can be
    useful for creating interaction plots.  The effect of several of
    these specifications depend on the value of \code{horizontal}.

    Type \code{"s"} (and \code{"S"}) sorts the values along one of the
    axes (depending on \code{horizontal}); this is unlike the behavior
    in \code{plot}.  For the latter behavior, use \code{type = "s"} with
    \code{panel = panel.points}.

    See \code{example(xyplot)} and \code{demo(lattice)} for examples.
  }
  \item{groups}{ an optional grouping variable.  If present,
    \code{\link{panel.superpose}} will be used instead to display each
    subgroup }
  \item{col, col.line, col.symbol}{
    default colours are obtained from \code{plot.symbol} and
    \code{plot.line} using \code{\link{trellis.par.get}}.
  }
  \item{font, fontface, fontfamily}{
    font used when \code{pch} is a character
  }
  \item{pch, lty, cex, lwd, fill}{
    other graphical parameters.  \code{fill} serves the purpose of
    \code{bg} in \code{\link{points}} for certain values of \code{pch}
  }
  \item{\dots}{ extra arguments, if any, for \code{panel.xyplot}. In
    most cases \code{panel.xyplot} ignores these. For types "r" and
    "smooth", these are passed on to \code{panel.lmline} and
    \code{panel.loess} respectively.
  }
  \item{horizontal}{ logical. Controls orientation for certain
    \code{type}'s, e.g.  one of \code{"h"}, \code{"s"} or \code{"S"}}.
  \item{jitter.x, jitter.y}{ logical, whether the data should be
    jittered before being plotted. }
  \item{factor, amount}{ controls amount of jittering. }
}



\details{

  Creates scatterplot of \code{x} and \code{y}, with various
  modifications possible via the type argument. \code{panel.qq} draws a
  45 degree line before calling \code{panel.xyplot}.

  Note that most of the arguments controlling the display can be
  supplied directly to the high-level (e.g. \code{\link{xyplot}}) call.

}

\examples{


types.plain <- c("p", "l", "o", "r", "g", "s", "S", "h", "a", "smooth")
types.horiz <- c("s", "S", "h", "a", "smooth")
horiz <- rep(c(FALSE, TRUE), c(length(types.plain), length(types.horiz)))

types <- c(types.plain, types.horiz)

x <- sample(seq(-10, 10, length.out = 15), 30, TRUE)
y <- x + 0.25 * (x + 1)^2 + rnorm(length(x), sd = 5)

xyplot(y ~ x | gl(1, length(types)),
       xlab = "type", 
       ylab = list(c("horizontal=TRUE", "horizontal=FALSE"), y = c(1/6, 4/6)),
       as.table = TRUE, layout = c(5, 3),
       between = list(y = c(0, 1)),
       strip = function(...) {
           panel.fill(trellis.par.get("strip.background")$col[1])
           type <- types[panel.number()]
           grid::grid.text(label = sprintf('"\%s"', type), 
                           x = 0.5, y = 0.5)
           grid::grid.rect()
       },
       scales = list(alternating = c(0, 2), tck = c(0, 0.7), draw = FALSE),
       par.settings = 
       list(layout.widths = list(strip.left = c(1, 0, 0, 0, 0))),
       panel = function(...) {
           type <- types[panel.number()]
           horizontal <- horiz[panel.number()]
           panel.xyplot(..., 
                        type = type,
                        horizontal = horizontal)
       })[rep(1, length(types))]

}


\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}

\seealso{
  \code{\link{panel.superpose}},
  \code{\link{xyplot}},
  \code{\link{splom}}
}
\keyword{dplot}
\eof
% --- Source file: prepanel.default.Rd ---
\name{prepanel.default}
\alias{prepanel.default.bwplot}
\alias{prepanel.default.histogram}
\alias{prepanel.default.qq}
\alias{prepanel.default.xyplot}
\alias{prepanel.default.cloud}
\alias{prepanel.default.levelplot}
\alias{prepanel.default.qqmath}
\alias{prepanel.default.densityplot}
\alias{prepanel.default.parallel}
\alias{prepanel.default.splom}

\title{ Default Prepanel Functions }

\description{
  These prepanel functions are used as fallback defaults in various
  high level plot functions in Lattice.  These are rarely useful to
  normal users but may be helpful in developing new displays.
}

\usage{

prepanel.default.bwplot(x, y, horizontal, nlevels, origin, stack, \dots)
prepanel.default.histogram(x, breaks, equal.widths, type, nint, \dots)
prepanel.default.qq(x, y, \dots)
prepanel.default.xyplot(x, y, type, subscripts, groups, \dots)
prepanel.default.cloud(perspective, distance,
                       xlim, ylim, zlim,
                       screen = list(z = 40, x = -60),
                       R.mat = diag(4),
                       aspect = c(1, 1), panel.aspect = 1,
                       \dots, zoom = 0.8)
prepanel.default.levelplot(x, y, subscripts, \dots)
prepanel.default.qqmath(x, f.value, distribution, qtype,
                        groups, subscripts, \dots)
prepanel.default.densityplot(x, darg, groups, weights, subscripts, \dots)
prepanel.default.parallel(x, y, z, \dots, horizontal.axis)
prepanel.default.splom(z, \dots)

}
\arguments{
  \item{x, y}{x and y values, numeric or factor}
  \item{horizontal}{ logical, applicable when one of the variables is to
    be treated as categorical (factor or shingle).
  }
  \item{horizontal.axis}{ logical indicating whether the
    parallel axes should be laid out horizontally (\code{TRUE}) or
    vertically (\code{FALSE}).
  }
  \item{nlevels}{ number of levels of such a categorical variable. }
  \item{origin, stack}{ for barcharts or the \code{type="h"} plot type}
  \item{breaks, equal.widths, type, nint}{ details of histogram
    calculations.  \code{type} has a different meaning in
    \code{prepanel.default.xyplot} (see \code{\link{panel.xyplot}})
  }
  \item{groups, subscripts}{ See \code{\link{xyplot}}.  Whenever
    appropriate, calculations are done separately for each group and
    then combined.  }
  \item{weights}{ numeric vector of weights for the density
    calculations.  If this is specified, it is subsetted by
    \code{subscripts} to match it to \code{x}.  }
  \item{perspective, distance, xlim, ylim, zlim, screen, R.mat, aspect,
    panel.aspect, zoom}{ see \code{\link{panel.cloud}}}
  \item{f.value, distribution}{ see \code{panel.qqmath} }
  \item{darg}{ list of arguments passed to \code{\link{density}}}
  \item{z}{ see \code{\link{panel.parallel}} and \code{\link{panel.pairs}} }

  \item{qtype}{ type of \code{\link{quantile}}}
  \item{\dots}{ other arguments, usually ignored }
}

\value{
  A list with components \code{xlim}, \code{ylim}, \code{dx} and
  \code{dy}, and possibly \code{xat} and \code{yat}, the first two being
  used to calculate panel axes limits, the last two for banking
  computations.  The form of these components are described in the help
  page for \code{\link{xyplot}}.
}

\seealso{

  \code{\link{xyplot}}, \code{\link{banking}}, \code{\link{Lattice}}.
  See documentation of corresponding panel functions for more details
  about the arguments.

}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}

\eof
% --- Source file: prepanel.functions.Rd ---
\name{prepanel.functions}
\alias{prepanel.lmline}
\alias{prepanel.loess}
\alias{prepanel.qqmathline}
\title{ Useful Prepanel Function for Lattice}
\description{
  These are predefined prepanel functions available in Lattice.
}

\usage{
prepanel.lmline(x, y, \dots)
prepanel.loess(x, y, span, degree, family, evaluation, \dots)
prepanel.qqmathline(x, y = x, distribution = qnorm,
                    probs = c(0.25, 0.75), qtype = 7,
                    groups, subscripts,
                    \dots) 
}
\arguments{
  \item{x, y}{x and y values, numeric or factor}
  \item{distribution}{ quantile function for theoretical
    distribution. This is automatically passed in when this is used as a
    prepanel function in \code{qqmath}.
  }
  \item{qtype}{ type of \code{\link{quantile}}}
  \item{probs}{
    numeric vector of length two, representing probabilities.  If used
    with \code{aspect="xy"}, the aspect ratio will be chosen to make the
    line passing through the corresponding quantile pairs as close to 45
    degrees as possible.
  }
  \item{span, degree, family, evaluation}{ arguments controlling the
    underlying \code{\link{loess}} smooth }
  \item{groups, subscripts}{ See \code{\link{xyplot}}.  Whenever
    appropriate, calculations are done separately for each group and
    then combined.  }
  \item{\dots}{ other arguments }
}
\value{
  usually a list with components \code{xlim}, \code{ylim}, \code{dx} and
  \code{dy}, the first two being used to calculate panel axes limits,
  the last two for banking computations.  The form of these components
  are described under \code{\link{xyplot}}.  There are also several
  prepanel functions that serve as the default for high level functions,
  see \code{\link{prepanel.default.xyplot}}
}

\seealso{

  \code{\link{trellis.par.get}}, \code{\link{xyplot}},
  \code{\link{banking}}, \code{\link{Lattice}}. See
  \code{\link{loess.smooth}} for further options to
  \code{prepanel.loess}

}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}

\eof
% --- Source file: print.trellis.Rd ---
\name{print.trellis}
\alias{print.trellis}
\alias{plot.trellis}
\alias{summary.trellis}
\alias{dim.trellis}
\alias{dimnames.trellis}
\alias{panel.error}
\title{Plot and Summarize Trellis Objects}
\usage{
\method{plot}{trellis}(x, position, split,
      more = FALSE, newpage = TRUE,
      packet.panel = packet.panel.default, 
      draw.in = NULL,
      panel.height = lattice.getOption("layout.heights")$panel,
      panel.width = lattice.getOption("layout.widths")$panel,
      save.object = lattice.getOption("save.object"),
      panel.error = lattice.getOption("panel.error"),
      prefix,
      \dots)
\method{print}{trellis}(x, \dots)

\method{summary}{trellis}(object, \dots)

\method{dim}{trellis}(x)
\method{dimnames}{trellis}(x)

panel.error(e)

}
\description{
  The \code{print} and \code{plot} methods produce a graph from a
  \code{"trellis"} object.  The \code{print} method is necessary for
  automatic plotting.  \code{plot} method is essentially
  an alias, provided for convenience.  The \code{summary} method
  gives a textual summary of the object.  \code{dim} and \code{dimnames}
  describe the cross-tabulation induced by conditioning.
  \code{panel.error} is the default handler used when an error occurs
  while executing the panel function.
}


\arguments{
  \item{x, object}{ an object of class \code{"trellis"}}
  \item{position}{ a vector of 4 numbers, typically c(xmin, ymin, xmax,
    ymax) that give the lower-left and upper-right corners of a
    rectangle in which the Trellis plot of x is to be positioned. The
    coordinate system for this rectangle is [0-1] in both the x and y
    directions.
  }
  \item{split}{ a vector of 4 integers, c(x,y,nx,ny) , that says to
    position the current plot at the x,y position in a regular array of
    nx by ny plots. (Note: this has origin at top left)
  }
  \item{more}{ A logical specifying whether more plots will follow on
    this page.
  }
  \item{newpage}{ A logical specifying whether the plot should be on a
    new page. This option is specific to lattice, and is useful for
    including lattice plots in an arbitrary grid viewport (see the
    details section).
  }
  \item{packet.panel}{ a function that determines which packet (data
    subset) is plotted in which panel.  Panels are always drawn in an
    order such that columns vary the fastest, then rows and then pages.
    This function determines, given the column, row and page and other
    relevant information, the packet (if any) which should be used in
    that panel.  By default, the association is determnined by matching
    panel order with packet order, which is determined by varying the
    first conditioning variable the fastest, then the second, and so
    on.  This association rule is encoded in the default, namely the
    function \code{\link{packet.panel.default}}, whose help page details
    the arguments supplied to whichever function is specified as the
    \code{packet.panel} argument.
  }
  \item{draw.in}{
    An optional (grid) viewport (used as the \code{name} argument in
    \code{downViewport}) in which the plot is to be drawn.  If
    specified, the \code{newpage} argument is ignored.  This feature is
    not well-tested.
  }
  \item{panel.width, panel.height}{
    lists with 2 components, that should be valid \code{x} and
    \code{units} arguments to \code{unit()} (the \code{data} argument
    cannot be specified currently, but can be considered for addition if
    needed).  The resulting \code{unit} object will be the width/height
    of each panel in the Lattice plot. These arguments can be used to
    explicitly control the dimensions of the panel, rather than letting
    them expand to maximize available space.  Vector widths are allowed,
    and can specify unequal lengths across rows or columns.

    Note that this option should not be used in conjunction with
    non-default values of the \code{aspect} argument in the original
    high level call (no error will be produced, but the resulting
    behaviour is undefined).
  }
  \item{save.object}{
    logical, specifying whether the object being printed is to be
    saved.  The last object thus saved can be subsequently retrieved.
    This is an experimental feature that should allow access to a
    panel's data after the plot is done, making it possible to enhance
    the plot after the fact.  This also allows the user to invoke the
    \code{update} method on the current plot, even if it was not
    assigned to a variable explicitly.  For more details, see
    \code{\link{trellis.focus}}.
  }
  \item{panel.error}{
    a function, or a character string naming a function, that is to be
    executed when an error occurs during the execution of the panel
    function.  The error is caught (using \code{\link{tryCatch}}) and
    supplied as the only argument to \code{panel.error}.  The default
    behaviour (implemented as the \code{panel.error} function) is to
    print the corresponding error message in the panel and continue.  To
    stop execution on error, use \code{panel.error = stop}.

    Normal error recovery and debugging tools are unhelpful when
    \code{tryCatch} is used.  \code{tryCatch} can be completely bypassed
    by setting \code{panel.error} to NULL.
  }
  \item{prefix}{
    character string used as a prefix in viewport and grob names, used
    to distinguish similar viewports if a page contains multiple plots. 
    The default is based on the serial number of the current plot on the
    current page (which is one more than the number of plots that have
    been drawn on the page before the current plot).  If supplied
    explicitly, this has to be a valid R symbol name (briefly, it must
    start with a letter or a period followed by a letter) and must not
    contain the grid path separator (currently \code{"::"}).
  }
  \item{e}{ an error condition caught by \code{\link{tryCatch}}}
  \item{\dots}{
    extra arguments, ignored by the \code{print} method.  All arguments
    to the \code{plot} method are passed on to the \code{print} method.
  }
}

\details{
  This is the default print method for objects of class
  \code{"trellis"}, produced by calls to functions like \code{xyplot},
  \code{bwplot} etc. It is usually called automatically when a trellis
  object is produced. It can also be called explicitly to control plot
  positioning by means of the arguments \code{split} and
  \code{position}.

  When \code{newpage = FALSE}, the current grid viewport is treated as
  the plotting area, making it possible to embed a Lattice plot inside
  an arbitrary grid viewport.  The \code{draw.in} argument provides an
  alternative mechanism that may be simpler to use.

  The print method uses the information in \code{x} (the object to be
  printed) to produce a display using the Grid graphics engine. At the
  heart of the plot is a grid layout, of which the entries of most
  interest to the user are the ones containing the display panels.

  Unlike in older versions of Lattice (and Grid), the grid display tree
  is retained after the plot is produced, making it possible to access
  individual viewport locations and make additions to the plot.  For
  more details and a lattice level interface to these viewports, see
  \code{\link{trellis.focus}}.

}

\note{
  Unlike S-PLUS, trying to position a multipage display (using
  \code{position} and/or \code{split}) will mess things up.
}

\seealso{
  \code{\link{Lattice}}, \code{\link[grid:unit]{unit}},
  \code{\link{update.trellis}}, \code{\link{trellis.focus}},
  \code{\link{packet.panel.default}}
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}

\examples{

p11 <- histogram( ~ height | voice.part, data = singer, xlab="Height")
p12 <- densityplot( ~ height | voice.part, data = singer, xlab = "Height")
p2 <- histogram( ~ height, data = singer, xlab = "Height")


## simple positioning by split
print(p11, split=c(1,1,1,2), more=TRUE)
print(p2, split=c(1,2,1,2))

## Combining split and position:
print(p11, position = c(0,0,.75,.75), split=c(1,1,1,2), more=TRUE)
print(p12, position = c(0,0,.75,.75), split=c(1,2,1,2), more=TRUE)
print(p2, position = c(.5,.75,1,1), more=FALSE)

## Using seekViewport

## repeat same plot, with different polynomial fits in each panel
xyplot(Armed.Forces ~ Year, longley, index.cond = list(rep(1, 6)),
       layout = c(3, 2),
       panel = function(x, y, ...)
       {
           panel.xyplot(x, y, ...)
           fm <- lm(y ~ poly(x, panel.number()))
           llines(x, predict(fm))
       })

\dontrun{
grid::seekViewport(trellis.vpname("panel", 1, 1))
cat("Click somewhere inside the first panel:\n")
ltext(grid::grid.locator(), lab = "linear")
}

grid::seekViewport(trellis.vpname("panel", 1, 1))
grid::grid.text("linear")

grid::seekViewport(trellis.vpname("panel", 2, 1))
grid::grid.text("quadratic")

grid::seekViewport(trellis.vpname("panel", 3, 1))
grid::grid.text("cubic")

grid::seekViewport(trellis.vpname("panel", 1, 2))
grid::grid.text("degree 4")

grid::seekViewport(trellis.vpname("panel", 2, 2))
grid::grid.text("degree 5")

grid::seekViewport(trellis.vpname("panel", 3, 2))
grid::grid.text("degree 6")
}
\keyword{hplot}



\eof
% --- Source file: qq.Rd ---
\name{qq}
\alias{qq}
\alias{qq.formula}
\title{ Quantile-Quantile Plots of Two Samples }
\description{
  Quantile-Quantile plots for comparing two Distributions
}
\usage{
qq(x, data, \dots)

\method{qq}{formula}(x, data, aspect = "fill", 
    panel = lattice.getOption("panel.qq"),
    prepanel, scales, strip, 
    groups, xlab, xlim, ylab, ylim, f.value = NULL, 
    drop.unused.levels = lattice.getOption("drop.unused.levels"),
    \dots,
    lattice.options = NULL,
    qtype = 7,
    default.scales = list(),
    subscripts,
    subset)
}
\arguments{
  \item{x}{
    The object on which method dispatch is carried out.

    For the formula method, a formula of the form \code{y ~ x | g1 * g2
      * \ldots}, where \code{x} must be a numeric, and \code{y} can be a
    factor, shingle, character or numeric vector, with the restriction
    that there must be exactly two levels of \code{y}, which divide the
    values of \code{x} into two groups. Quantiles for these groups will
    be plotted along the two axes.
  }
  \item{data}{
    For the \code{formula} methods, an optional data frame in which
    variables in the formula (as well as \code{groups} and
    \code{subset}, if any) are to be evaluated.
  }
  \item{f.value}{ optional numeric vector of probabilities, quantiles
    corresponding to which should be plotted.  Can also be a function of
    a single integer (representing sample size) that returns such a
    numeric vector.  The typical value for this argument is the function
    \code{ppoints}, which is also the S-PLUS default.  If specified, the
    probabilities generated by this function is used for the plotted
    quantiles, using the \code{quantile} function.

    \code{f.value} defaults to \code{NULL}, which is equivalent to
    using \code{function(n) ppoints(n, a = 1)}. This has the effect of
    including the minimum and maximum data values in the computed
    quantiles. This is similar to what happens for \code{qqplot} but
    different from the default \code{qq} behaviour in S-PLUS.

    For large data, this argument can be useful in plotting a smaller
    set of quantiles, which is usually enough to capture the pattern.
  }
  \item{panel}{ The function that uses the packet (subset of display
    variables) corresponding to a panel to create a display.  Default
    panel functions are documented separately, and often have arguments
    that can be used to customize its display in various ways.  Such
    arguments can usually be directly supplied to the high level
    function.  }
  \item{qtype}{ \code{type} argument for the \code{\link{quantile}} }
  \item{aspect, prepanel, scales,
    strip, groups, xlab, xlim, ylab, ylim, drop.unused.levels,
    lattice.options, default.scales, subscripts, subset}{ See
    \code{\link{xyplot}} }
  \item{\dots}{
    Further arguments.  See corresponding entry in \code{\link{xyplot}}
    for non-trivial details.
  }
}
\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}
\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\details{
  \code{qq} produces a Q-Q plot of two samples.  The default behaviour
  of \code{qq} is different from the corresponding S-PLUS function. See
  the entry for \code{f.value} for specifics.

  This and all other high level Trellis functions have several
  arguments in common. These are extensively documented only in the
  help page for \code{xyplot}, which should be consulted to learn more
  detailed usage.
}

\seealso{\code{\link{xyplot}}, \code{\link{panel.qq}},
  \code{\link{qqmath}}, \code{\link{Lattice}}
}

\examples{
qq(voice.part ~ height, aspect = 1, data = singer,
   subset = (voice.part == "Bass 2" | voice.part == "Tenor 1"))
}
\keyword{dplot}




\eof
% --- Source file: qqmath.Rd ---
\name{qqmath}
\alias{qqmath}
\alias{qqmath.formula}
\alias{qqmath.numeric}
\title{ Q-Q Plot with Theoretical Distribution }
\description{
  Quantile-Quantile plot of a sample and a theoretical distribution
}
\usage{
qqmath(x, data, \dots)


\method{qqmath}{formula}(x,
       data,
       allow.multiple = is.null(groups) || outer,
       outer = !is.null(groups),
       distribution = qnorm,
       f.value = NULL,
       auto.key = FALSE,
       aspect = "fill",
       panel = lattice.getOption("panel.qqmath"),
       prepanel = NULL,
       scales, strip, groups,
       xlab, xlim, ylab, ylim,
       drop.unused.levels = lattice.getOption("drop.unused.levels"),
       \dots,
       lattice.options = NULL,
       default.scales = list(),
       subscripts,
       subset)
\method{qqmath}{numeric}(x, data = NULL, ylab, \dots)
}
\arguments{
  \item{x}{
    The object on which method dispatch is carried out.

    For the \code{"formula"} method, a formula of the form \code{~ x |
      g1 * g2 * \ldots}, where \code{x} must be a numeric.  For the
    \code{"numeric"} method, a numeric vector.
  }
  \item{data}{
    For the \code{formula} method, an optional data frame in which
    variables in the formula (as well as \code{groups} and
    \code{subset}, if any) are to be evaluated.  Usualll ignored with a
    warning in other methods.
  }
  \item{distribution}{ a quantile function that takes a vector of
    probabilities as argument and produces the corresponding
    quantiles. Possible values are \code{qnorm}, \code{qunif} etc.
    Distributions with other required arguments need to be passed in as
    user defined functions.
  }
  \item{f.value}{ optional numeric vector of probabilities, quantiles
    corresponding to which should be plotted.  Can also be a function of
    a single integer (representing sample size) that returns such a
    numeric vector.  The typical value for this argument is the function
    \code{ppoints}, which is also the S-PLUS default.  If specified, the
    probabilities generated by this function is used for the plotted
    quantiles, using the \code{quantile} function for the sample, and
    the function specified as the \code{distribution} argument for the
    theoretical distribution.  

    \code{f.value} defaults to \code{NULL}, which has the effect of
    using \code{ppoints} for the quantiles of the theoretical
    distribution, but the exact data values for the sample.  This is
    similar to what happens for \code{qqnorm}, but different from the
    S-PLUS default of \code{f.value=ppoints}.

    For large \code{x}, this argument can be useful in plotting a
    smaller set of quantiles, which is usually enough to capture the
    pattern.
  }
  \item{panel}{
    The panel function to be used.  Unlike in older versions, the
    default panel function does most of the actual computations and has
    support for grouping.  See \code{\link{panel.qqmath}} for details.
  }
  \item{allow.multiple, outer, auto.key, aspect, prepanel, scales,
    strip, groups, xlab, xlim, ylab, ylim, drop.unused.levels,
    lattice.options, default.scales, subscripts, subset}{ See
    \code{\link{xyplot}} }
  \item{\dots}{
    Further arguments.  See corresponding entry in \code{\link{xyplot}}
    for non-trivial details.
  }
}
\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}
\details{
  \code{qqmath} produces a Q-Q plot of the given sample and a
  theoretical distribution.  The default behaviour of \code{qqmath} is
  different from the corresponding S-PLUS function, but is similar to
  \code{qqnorm}. See the entry for \code{f.value} for specifics.

  The implementation details are also different from S-PLUS.  In
  particular, all the important calculations are done by the panel (and
  prepanel function) and not \code{qqmath} itself.  In fact, both the
  arguments \code{distribution} and \code{f.value} are passed unchanged
  to the panel and prepanel function.  This allows, among other things,
  display of grouped Q-Q plots, which are often useful.  See the help
  page for \code{\link{panel.qqmath}} for further details.

  This and all other high level Trellis functions have several
  arguments in common. These are extensively documented only in the
  help page for \code{xyplot}, which should be consulted to learn more
  detailed usage.
}
\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{xyplot}}, \code{\link{panel.qqmath}},
  \code{\link{panel.qqmathline}}, \code{\link{prepanel.qqmathline}},
  \code{\link{Lattice}}, \code{\link{quantile}}
}
\examples{
qqmath(~ rnorm(100), distribution = function(p) qt(p, df = 10))
qqmath(~ height | voice.part, aspect = "xy", data = singer,
       prepanel = prepanel.qqmathline,
       panel = function(x, ...) {
          panel.qqmathline(x, ...)
          panel.qqmath(x, ...)
       })
vp.comb <-
    factor(sapply(strsplit(as.character(singer$voice.part), split = " "),
                  "[", 1),
           levels = c("Bass", "Tenor", "Alto", "Soprano"))
vp.group <-
    factor(sapply(strsplit(as.character(singer$voice.part), split = " "),
                  "[", 2))
qqmath(~ height | vp.comb, data = singer,
       groups = vp.group, auto.key = list(space = "right"),
       aspect = "xy",
       prepanel = prepanel.qqmathline,
       panel = function(x, ...) {
          panel.qqmathline(x, ...)
          panel.qqmath(x, ...)
       })
}
\keyword{dplot}

\eof
% --- Source file: rfs.Rd ---
\name{rfs}
\alias{rfs}
\title{ Residual and Fit Spread Plots}
\description{
  Plots fitted values and residuals (via qqmath) on a common scale for
  any object that has methods for fitted values and residuals. 
}
\usage{
rfs(model, layout=c(2, 1), xlab="f-value", ylab=NULL,
    distribution = qunif,
    panel, prepanel, strip, \dots)
}
\arguments{
  \item{model}{a fitted model object with methods \code{fitted.values}
    and \code{residuals}. Can be the value returned by \code{oneway} }
  \item{layout}{default layout is c(2,1)  }
  \item{xlab}{defaults to \code{"f.value"} }
  \item{distribution}{the distribution function to be used for \code{qqmath}}
  \item{ylab, panel, prepanel, strip}{ See \code{\link{xyplot}} }
  \item{\dots}{ other arguments, passed on to \code{\link{qqmath}}.  }
}
\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{oneway}}, \code{\link{qqmath}},
  \code{\link{xyplot}}, \code{\link{Lattice}}
}
\examples{
rfs(oneway(height ~ voice.part, data = singer, spread = 1), aspect = 1)
}
\keyword{dplot}
\eof
% --- Source file: shingles.Rd ---
\name{shingles}
\alias{equal.count}
\alias{plot.shingle}
\alias{print.shingle}
\alias{as.character.shingleLevel}
\alias{print.shingleLevel}
\alias{summary.shingle}
\alias{as.data.frame.shingle}
\alias{as.factorOrShingle}
\alias{as.shingle}
\alias{[.shingle}
\alias{is.shingle}
\alias{shingle}
\title{shingles}
\usage{
shingle(x, intervals=sort(unique(x)))
equal.count(x, \dots)
as.shingle(x)
is.shingle(x)

\method{plot}{shingle}(x, panel, xlab, ylab, \dots)

\method{print}{shingle}(x, showValues = TRUE, \dots)

\method{as.character}{shingleLevel}(x, \dots)

\method{print}{shingleLevel}(x, \dots)

\method{summary}{shingle}(object, showValues = FALSE, \dots)

% \method{as.data.frame}{shingle}(x, row.names = NULL, optional = FALSE)

\method{[}{shingle}(x, subset, drop = FALSE)
as.factorOrShingle(x, subset, drop)
}
\description{
  Functions to handle shingles
}
\arguments{
  \item{x}{
    numeric variable or R object, shingle in \code{plot.shingle} and
    \code{x[]}. An object (list of intervals) of class "shingleLevel" in
    \code{print.shingleLevel}
  }
  \item{object}{ shingle object to be summarized}
  \item{showValues}{ logical, whether to print the numeric part. If
    FALSE, only the intervals are printed}
%   \item{row.names}{ a character vector giving the row names for the data frame}
%   \item{optional}{
%     logical.  If \code{TRUE}, setting row names is optional
%   }
  \item{intervals}{ numeric vector or matrix with 2 columns}
  \item{subset}{logical vector}
  \item{drop}{whether redundant shingle levels are to be dropped}
  \item{panel, xlab, ylab}{ standard Trellis arguments (see
    \code{\link{xyplot}} ) }
  \item{\dots}{ other arguments, passed down as appropriate.  For
    example, extra arguments to \code{equal.count} are passed on to
    \code{co.intervals}.  graphical parameters can be passed as
    arguments to the \code{plot} method.
  }
}

\details{
  A shingle is a data structure used in Trellis, and is a generalization
  of factors to \sQuote{continuous} variables.  It consists of a numeric
  vector along with some possibly overlapping intervals. These intervals
  are the \sQuote{levels} of the shingle.  The \code{levels} and
  \code{nlevels} functions, usually applicable to factors, also work on
  shingles.  The implementation of shingles is slightly different from
  S.

  There are print methods for shingles, as well as for printing the
  result of \code{levels()} applied to a shingle.  For use in labelling,
  the \code{as.character} method can be used to convert levels of a
  shingle to character strings.

  \code{equal.count} converts \code{x} to a shingle using the equal
  count algorithm.  This is essentially a wrapper around
  \code{co.intervals}.  All arguments are passed to \code{co.intervals}.

  \code{shingle} creates a shingle using the given \code{intervals}. If
  \code{intervals} is a vector, these are used to form 0 length
  intervals.

  \code{as.shingle} returns \code{shingle(x)} if \code{x} is not a
  shingle.

  \code{is.shingle} tests whether \code{x} is a shingle.

  \code{plot.shingle} displays the ranges of shingles via
  rectangles. \code{print.shingle} and \code{summary.shingle} describe
  the shingle object.
}
\value{
  \code{x$intervals} for \code{levels.shingle(x)}, 
  logical for \code{is.shingle}, an object of class \code{"trellis"} for
  \code{plot} (printed by default by \code{print.trellis}), and 
  an object of class \code{"shingle"} for the others.
}
\examples{
z <- equal.count(rnorm(50))
plot(z)
print(z)
print(levels(z))
\testonly{data.frame(x = equal.count(rnorm(100)), y = rnorm(100))}
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{
  \code{\link{xyplot}},
  \code{\link{co.intervals}}, \code{\link{Lattice}} 
}
\keyword{print}
\keyword{hplot}
\keyword{methods}
\keyword{classes}



\eof
% --- Source file: simpleKey.Rd ---
\name{simpleKey}
\alias{simpleKey}
\title{ Function to generate a simple key }
\description{
  Simple interface to generate a list appropriate for \code{draw.key}
}
\usage{
simpleKey(text, points = TRUE,
          rectangles = FALSE,
          lines = FALSE,
          col, cex, alpha, font,
          fontface, fontfamily, 
          lineheight, \dots)
}
\arguments{
  \item{text}{
    character or expression vector, to be used as labels for levels of
    the grouping variable
  }
  \item{points}{ logical }
  \item{rectangles}{ logical }
  \item{lines}{ logical }
  \item{col, cex, alpha, font, fontface, fontfamily, lineheight}{
    Used as top-level components of the list produced, to be used for
    the text labels. Defaults to the values in
    \code{trellis.par.get("add.text")}
  }
  \item{\dots}{
    further arguments added to the list, eventually passed to
    \code{draw.key}
  }
}
\details{
  A lattice plot can include a legend (key) if an appropriate list is
  specified as the \code{key} argument to a high level Lattice function
  such as \code{xyplot}. This key can be very flexible, but that
  flexibility comes at the cost of this list being very complicated even
  in simple situations. The \code{simpleKey} function is a shortcut,
  which assumes that the key is being drawn in conjunction with the
  \code{groups} argument, and that the default Trellis settings are
  being used. At most one each of points, rectangles and lines can be
  drawn.

  See also the \code{auto.key} argument for high level plots.
}
\value{
  A list that would work as the \code{key} argument to \code{xyplot}
  etc.
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{
  \code{\link{draw.key}}, \code{\link{xyplot}}, \code{\link{Lattice}}
}
\keyword{dplot}
















\eof
% --- Source file: simpleTheme.Rd ---
\name{simpleTheme}
\alias{simpleTheme}
\title{ Function to generate a simple theme }
\description{
  Simple interface to generate a list appropriate as a theme, typically
  used as the \code{par.settings} argument in a high level call
}
\usage{
simpleTheme(col, alpha, 
            cex, pch, lty, lwd, font, fill, border,
            col.points, col.line, 
            alpha.points, alpha.line)
}
\arguments{
  \item{col, col.points, col.line}{
    A color specification.  \code{col} is used for components
    \code{plot.symbol}, \code{plot.line}, \code{plot.polygon},
    \code{superpose.symbol}, \code{superpose.line}, and
    \code{superpose.polygon}.  \code{col.points} overrides \code{col},
    and is used only for \code{plot.symbol} and
    \code{superpose.symbol}.  Similarly, \code{col.lines} overrides
    \code{col} for \code{plot.line} and \code{superpose.line}.  The
    arguments can be vectors, but only the first component is used for
    scalar targets (i.e., the ones without \code{"superpose"} in their
    name).
  }
  \item{alpha, alpha.points, alpha.line}{
    A numeric alpha transparency specification.  The same rules as
    \code{col}, etc., apply.
  }
  \item{cex, pch, font}{ Parameters for points.  Applicable for
    components \code{plot.symbol} (for which only the first component is
    used) and \code{superpose.symbol} (for which the arguments can be
    vectors).
  }
  \item{lty, lwd}{ Parameters for lines.  Applicable for
    components \code{plot.line} (for which only the first component is
    used) and \code{superpose.line} (for which the arguments can be
    vectors).
  }
  \item{fill}{ fill color, applicable for components \code{plot.symbol},
    \code{plot.polygon}, \code{superpose.symbol}, and
    \code{superpose.polygon}.  }
  \item{border}{ border color, applicable for components
    \code{plot.polygon} and \code{superpose.polygon}.  }

}
\details{

  The appearance of a lattice display depends partly on the
  \dQuote{theme} active when the display is plotted (see
  \code{\link{trellis.device}} for details).  This theme is used to
  obtain defaults for various graphical parameters, and in particular,
  the \code{auto.key} argument works on the premise that the same source
  is used for both the actual graphical encoding and the legend.  The
  easiest way to specify custom settings for a particular display is to
  use the \code{par.settings} argument, which is usually tedious to
  construct as it is a nested list.  The \code{simpleTheme} function can
  be used in such situations as a wrapper that generates a suitable list
  given parameters in simple \code{name=value} form, with the nesting
  made implicit.  This is less flexible, but straightforward and
  sufficient in most situations.

}
\value{
  A list that would work as the \code{theme} argument to
  \code{\link{trellis.device}} and \code{\link{trellis.par.set}}, or
  as the \code{par.settings} argument to any high level lattice function
  such as \code{\link{xyplot}}.
}
\examples{

str(simpleTheme(pch = 16))

dotplot(variety ~ yield | site, data = barley, groups = year,
        auto.key = list(space = "right"),
        par.settings = simpleTheme(pch = 16),
        xlab = "Barley Yield (bushels/acre) ",
        aspect=0.5, layout = c(1,6))

}
\author{
  Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}, based on a
  suggestion from John Maindonald.  
}
\seealso{
  \code{\link{trellis.device}}, \code{\link{xyplot}},
  \code{\link{Lattice}}
}
\keyword{dplot}
\eof
% --- Source file: singer.Rd ---
\name{singer}
\alias{singer}
\docType{data}
\title{ Heights of New York Choral Society singers }

\description{
  Heights in inches of the singers in the New York Choral Society in
  1979.  The data are grouped according to voice part.  The vocal range
  for each voice part increases in pitch according to the following
  order: Bass 2, Bass 1, Tenor 2, Tenor 1, Alto 2, Alto 1, Soprano 2,
  Soprano 1.
}

\usage{singer}

\format{
  A data frame with 235 observations on the following 2 variables.
  \describe{
    \item{height}{Height in inches of the singers.}
    \item{voice.part}{(Unordered) factor with levels "\code{Bass 2}",
      "\code{Bass 1}", "\code{Tenor 2}", "\code{Tenor 1}", "\code{Alto 2}",
      "\code{Alto 1}", "\code{Soprano 2}", "\code{Soprano 1}".}
  }
}

\source{
  Chambers, J.M., W. S. Cleveland, B. Kleiner, and P. A. Tukey. (1983).
  \emph{Graphical Methods for Data Analysis}.  Chapman and Hall, New York.
}

\author{
  Documentation contributed by Kevin Wright.
}

\references{
  Cleveland, William S. (1993). \emph{Visualizing Data}.  Hobart Press,
  Summit, New Jersey.
}

\examples{
# Separate histogram for each voice part (Figure 1.2 from Cleveland)
histogram(~ height | voice.part,
          data = singer,
          aspect=1,
          layout = c(2, 4), 
          nint=15,
          xlab = "Height (inches)")

# Quantile-Quantile plot (Figure 2.11 from Cleveland)
qqmath(~ height | voice.part,
       data=singer,
       aspect=1, 
       layout=c(2,4),
       prepanel = prepanel.qqmathline,
       panel = function(x, ...) {
         panel.grid()
         panel.qqmathline(x, ...)
         panel.qqmath(x, ...)
       },
       xlab = "Unit Normal Quantile",
       ylab="Height (inches)")
}

\keyword{datasets}
\eof
% --- Source file: splom.Rd ---
\name{splom}
\title{Scatter Plot Matrices}
\alias{splom}
\alias{parallel}
\alias{splom.matrix}
\alias{splom.data.frame}
\alias{parallel.matrix}
\alias{parallel.data.frame}
\alias{splom.formula}
\alias{parallel.formula}
\usage{
splom(x, data, \dots)
parallel(x, data, \dots)


\method{splom}{formula}(x,
      data,
      auto.key = FALSE,
      aspect = 1,
      between = list(x = 0.5, y = 0.5),
      panel = lattice.getOption("panel.splom"),
      prepanel,
      scales,
      strip,
      groups,
      xlab,
      xlim,
      ylab = NULL,
      ylim,
      superpanel = lattice.getOption("panel.pairs"),
      pscales = 5,
      varnames,
      drop.unused.levels,
      \dots,
      lattice.options = NULL,
      default.scales,
      subset = TRUE)
\method{parallel}{formula}(x,
         data,
         auto.key = FALSE,
         aspect = "fill",
         between = list(x = 0.5, y = 0.5),
         panel = lattice.getOption("panel.parallel"),
         prepanel,
         scales,
         strip,
         groups,
         xlab = NULL,
         xlim,
         ylab = NULL,
         ylim,
         varnames,
         horizontal.axis = TRUE,
         drop.unused.levels,
         \dots,
         lattice.options = NULL,
         default.scales,
         subset = TRUE)

\method{splom}{data.frame}(x, data = NULL, \dots, groups = NULL, subset = TRUE)
\method{splom}{matrix}(x, data = NULL, \dots, groups = NULL, subset = TRUE)

\method{parallel}{matrix}(x, data = NULL, \dots, groups = NULL, subset = TRUE)
\method{parallel}{data.frame}(x, data = NULL, \dots, groups = NULL, subset = TRUE)
}
\description{
  Draw Conditional Scatter Plot Matrices and Parallel Coordinate Plots
}
\arguments{
  \item{x}{
    The object on which method dispatch is carried out.

    For the \code{"formula"} method, a formula describing the structure
    of the plot, which should be of the form \code{~ x | g1 * g2 *
      \dots}, where \code{x} is a data frame or matrix.  Each of
    \code{g1,g2,\dots} must be either factors or shingles. The
    conditioning variables \code{g1, g2, \dots} may be omitted.

    For the \code{data.frame} methods, a data frame.
  }
  \item{data}{
    For the \code{formula} methods, an optional data frame in which
    variables in the formula (as well as \code{groups} and
    \code{subset}, if any) are to be evaluated.
  }
  \item{aspect}{ 
    aspect ratio of each panel (and subpanel), square by default for
    \code{splom}.
  }
  \item{between}{ 
    to avoid confusion between panels and subpanels, the default is to
    show the panels of a splom plot with space between them.
  }
  \item{panel}{
    Usual interpretation for \code{parallel}, namely the function that
    creates the display within each panel. 

    For \code{splom}, the terminology is slightly complicated. The role
    played by the panel function in most other high-level functions is
    played here by the \code{superpanel} function, which is responsible
    for the display for each conditional data subset. \code{panel} is
    simply an argument to the default \code{superpanel} function
    \code{panel.pairs}, and is passed on to it unchanged. It is used
    there to create each pairwise display. See \code{\link{panel.pairs}}
    for more useful options.

  }
  \item{superpanel}{ 
    function that sets up the splom display, by default as a scatterplot
    matrix.
  }
  \item{pscales}{ 
    a numeric value or a list, meant to be a less functional substitute
    for the \code{scales} argument in \code{xyplot} etc. This argument
    is passed to the \code{superpanel} function, and is handled by the
    default superpanel function \code{panel.pairs}. The help page for
    the latter documents this argument in more detail.
  }
  \item{varnames}{ 
    character vector giving the names of the p variables in x. By
    default, the column names of x.
  }
  \item{horizontal.axis}{logical indicating whether the parallel axes should
    be laid out horizontally (\code{TRUE}) or vertically (\code{FALSE}).
  }
  \item{auto.key, prepanel, scales,
    strip, groups, xlab, xlim, ylab, ylim, drop.unused.levels,
    lattice.options, default.scales, subset}{ See \code{\link{xyplot}} }
  \item{\dots}{ Further arguments.  See corresponding entry in
    \code{\link{xyplot}} for non-trivial details.  }
}
\details{
  \code{splom} produces Scatter Plot Matrices.  The role usually played
  by \code{panel} is taken over by \code{superpanel}, which takes a data
  frame subset and is responsible for plotting it.  It is called with
  the coordinate system set up to have both x- and y-limits from
  \code{0.5} to \code{ncol(z) + 0.5}.  The only built-in option
  currently available is \code{\link{panel.pairs}}, which calls a
  further panel function for each pair \code{(i, j)} of variables in
  \code{z} inside a rectangle of unit width and height centered at
  \code{c(i, j)} (see \code{\link{panel.pairs}} for details).

  Many of the finer customizations usually done via arguments to high
  level function like \code{xyplot} are instead done by
  \code{panel.pairs} for \code{splom}. These include control of axis
  limits, tick locations and prepanel calcultions. If you are trying to
  fine-tune your \code{splom} plot, definitely look at the
  \code{\link{panel.pairs}} help page. The \code{scales} argument is
  usually not very useful in \code{splom}, and trying to change it may
  have undesired effects.

  \code{\link{parallel}} draws Parallel Coordinate Plots. (Difficult to
  describe, see example.)
  
  These and all other high level Trellis functions have several
  arguments in common. These are extensively documented only in the
  help page for \code{xyplot}, which should be consulted to learn more
  detailed usage.
}
\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}

\seealso{
  \code{\link{xyplot}}, \code{\link{Lattice}}, \code{\link{panel.pairs},
    \code{\link{panel.parallel}}
  }
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\examples{
super.sym <- trellis.par.get("superpose.symbol")
splom(~iris[1:4], groups = Species, data = iris,
      panel = panel.superpose,
      key = list(title = "Three Varieties of Iris",
                 columns = 3, 
                 points = list(pch = super.sym$pch[1:3],
                 col = super.sym$col[1:3]),
                 text = list(c("Setosa", "Versicolor", "Virginica"))))
splom(~iris[1:3]|Species, data = iris, 
      layout=c(2,2), pscales = 0,
      varnames = c("Sepal\nLength", "Sepal\nWidth", "Petal\nLength"),
      page = function(...) {
          ltext(x = seq(.6, .8, length.out = 4), 
                y = seq(.9, .6, length.out = 4), 
                labels = c("Three", "Varieties", "of", "Iris"),
                cex = 2)
      })
parallel(~iris[1:4] | Species, iris) 
parallel(~iris[1:4], iris, groups = Species,
         horizontal.axis = FALSE, scales = list(x = list(rot = 90)))
}
\keyword{hplot}

\eof
% --- Source file: strip.default.Rd ---
\name{strip.default}
\alias{strip.default}
\alias{strip.custom}
\title{Default Trellis Strip Function}
\usage{
strip.default(which.given,
              which.panel,
%               packet.number,
%               panel.number,
              var.name,
              factor.levels,
              shingle.intervals,
              strip.names = c(FALSE, TRUE),
              strip.levels = c(TRUE, FALSE),
              sep = " : ",
              style = 1,
              horizontal = TRUE,
              bg = trellis.par.get("strip.background")$col[which.given],
              fg = trellis.par.get("strip.shingle")$col[which.given],
              par.strip.text = trellis.par.get("add.text"))
strip.custom(\dots)
}
\description{
  \code{strip.default} is the function that draws the strips by default
  in Trellis plots.  Users can write their own strip functions, but most
  commonly this involves calling \code{strip.default} with a slightly
  different arguments.  \code{strip.custom} provides a convenient way to
  obtain new strip functions that differ from \code{strip.default} only
  in the default values of certain arguments.
}

\arguments{
  \item{which.given}{ integer index specifying which of the conditioning
    variables this strip corresponds to. 
  }
  \item{which.panel}{ vector of integers as long as the number of
    conditioning variables. The contents are indices specifying the
    current levels of each of the conditioning variables (thus, this
    would be unique for each distinct packet).  This is identical to the
    return value of \code{\link{which.packet}}, which is a more accurate
    name.
  }
%   \item{panel.number, packet.number}{ integer indices specifying which
%     panel and packet is being drawn (see the entry for \code{panel} in
%     \code{\link{xyplot}} for details).  These arguments are ignored by
%     the \code{strip.default}, but may be used by user supplied
%     replacements.
%   }
  \item{var.name}{ vector of character strings or expressions as long as
    the number of conditioning variables.  The contents are interpreted
    as names for the conditioning variables.  Whether they are shown on
    the strip depends on the values of \code{strip.names} and
    \code{style} (see below).  By default, the names are shown for
    shingles, but not for factors.
  }
  \item{factor.levels}{ vector of character strings or expressions
    giving the levels of the conditioning variable currently being
    drawn.  For more than one conditioning variable, this will vary with
    \code{which.given}.  Whether these levels are shown on the strip
    depends on the values of \code{strip.levels} and \code{style} (see
    below).  \code{factor.levels} may be specified for both factors and
    shingles (despite the name), but by default they are shown only for
    factors.  If shown, the labels may optionally be abbreviated by
    specifying suitable components in \code{par.strip.text} (see
    \code{\link{xyplot}})
  }
  \item{shingle.intervals}{if the current strip corresponds to a shingle,
    this should be a 2-column matrix giving the levels of the shingle.
    (of the form that would be produced by \bold{printing}
    \code{levels(shingle)}). Otherwise, it should be \code{NULL}
  }
  \item{strip.names}{ a logical vector of length 2, indicating whether
    or not the name of the conditioning variable that corresponds to the
    strip being drawn is to be written on the strip. The two components
    give the values for factors and shingles respectively.

    This argument is ignored for a factor when \code{style} is not one
    of 1 and 3.
  }
  \item{strip.levels}{ a logical vector of length 2, indicating whether
    or not the level of the conditioning variable that corresponds to
    the strip being drawn is to be written on the strip.  The two
    components give the values for factors and shingles respectively.
  }
  \item{sep}{ character or expression, serving as a separator if the
    name and level are both to be shown.
  }
  \item{style}{ integer, with values 1, 2, 3, 4 and 5 currently
    supported, controlling how the current level of a factor is encoded.
    Ignored for shingles (actually, when \code{shingle.intervals} is
    non-null.  

    The best way to find out what effect the value of \code{style} has
    is to try them out. Here is a short description: for a style value
    of 1, the strip is colored in the background color with the strip
    text (as determined by other arguments) centered on it. A value of 3
    is the same, except that a part of the strip is colored in the
    foreground color, indicating the current level of the factor. For
    styles 2 and 4, the part corresponding to the current level remains
    colored in the foreground color, however, for style = 2, the
    remaining part is not colored at all, whereas for 4, it is colored
    with the background color. For both these, the names of all the
    levels of the factor are placed on the strip from left to right.
    Styles 5 and 6 produce the same effect (they are subtly different in
    S, this implementation corresponds to 5), they are similar to style
    1, except that the strip text is not centered, it is instead
    positioned according to the current level.

    Note that unlike S-PLUS, the default value of \code{style} is 1.
    \code{strip.names} and \code{strip.levels} have no effect if
    \code{style} is not 1 or 3.
  }
  \item{horizontal}{ logical, specifying whether the labels etc should
    be horizontal.  \code{horizontal=FALSE} is useful for strips on the
    left of panels using \code{strip.left=TRUE} }
  \item{par.strip.text}{ list with parameters controlling the text on
    each strip, with components \code{col}, \code{cex}, \code{font},
    etc.
  }
  \item{bg}{ strip background color. }
  \item{fg}{ strip foreground color. }
  \item{\dots}{
    arguments to be passed on to \code{strip.default}, overriding
    whatever value it would have normally assumed
  }
}

\value{
  \code{strip.default} is called for its side-effect, which is to draw a
  strip appropriate for multi-panel Trellis conditioning plots.
  \code{strip.custom} returns a function that is similar to
  \code{strip.default}, but with different defaults for the arguments
  specified in the call.
}
  

\details{ default strip function for trellis functions. Useful 
  mostly because of the \code{style} argument --- non-default styles
  are often more informative, especially when the names of the levels
  of the factor \code{x} are small. Traditional use is as
  \code{strip = function(\dots) strip.default(style=2,\dots)}, though
  this can be simplified by the use of \code{strip.custom}.
}
\seealso{
  \code{\link{xyplot}}, \code{\link{Lattice}} 
}

\examples{
## Traditional use
xyplot(Petal.Length ~ Petal.Width | Species, iris,
       strip = function(..., style) strip.default(..., style = 4))

## equivalent call using strip.custom
xyplot(Petal.Length ~ Petal.Width | Species, iris,
       strip = strip.custom(style = 4))

xyplot(Petal.Length ~ Petal.Width | Species, iris,
       strip = FALSE,
       strip.left = strip.custom(style = 4, horizontal = FALSE))
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\keyword{dplot}


\eof
% --- Source file: tmd.Rd ---
\name{tmd}
\alias{tmd}
\alias{tmd.formula}
\alias{tmd.trellis}
\alias{prepanel.tmd.default}
\alias{prepanel.tmd.qqmath}
\alias{panel.tmd.default}
\alias{panel.tmd.qqmath}
\title{Tukey Mean-Difference Plot}
\description{
  \code{tmd} Creates Tukey Mean-Difference Plots from a trellis object
  returned by \code{xyplot}, \code{qq} or \code{qqmath}.  The prepanel
  and panel functions are used as appropriate.  The \code{formula}
  method for \code{tmd} is provided for convenience, and simply calls
  \code{tmd} on the object created by calling \code{xyplot} on that
  formula.
}
\usage{
tmd(object, \dots)

\method{tmd}{trellis}(object,
    xlab = "mean",
    ylab = "difference",
    panel, 
    prepanel, 
    \dots)

prepanel.tmd.qqmath(x,
             f.value = NULL,
             distribution = qnorm,
             qtype = 7,
             groups = NULL,
             subscripts, \dots)
panel.tmd.qqmath(x,
             f.value = NULL,
             distribution = qnorm,
             qtype = 7,
             groups = NULL, 
             subscripts, \dots)
panel.tmd.default(x, y, groups = NULL, \dots)
prepanel.tmd.default(x, y, \dots)
}
\arguments{
  \item{object}{ An object of class \code{"trellis"} returned by
    \code{xyplot}, \code{qq} or \code{qqmath}.  }
  \item{xlab}{ x label}
  \item{ylab}{ y label}
  \item{panel}{ panel function to be used.  See details below.  }
  \item{prepanel}{ prepanel function.  See details below.  }
  \item{f.value, distribution, qtype}{see \code{\link{panel.qqmath}}.  }
  \item{groups, subscripts}{see \code{\link{xyplot}}.  }
  \item{x, y}{ data as passed to panel functions in original call.  }
  \item{\dots}{ other arguments}
}
\details{
  The Tukey Mean-difference plot is produced by modifying the (x,y)
  values of each panel as follows: the new coordinates are given by
  \code{x=(x+y)/2} and \code{y=y-x}, which are then plotted.  The
  default panel function(s) add a reference line at \code{y=0} as well.

  \code{tmd} acts on the a \code{"trellis"} object, not on the actual plot
  this object would have produced.  As such, it only uses the arguments
  supplied to the panel function in the original call, and completely
  ignores what the original panel function might have done with this
  data.  \code{tmd} uses these panel arguments to set up its own scales
  (using its \code{prepanel} argument) and display (using
  \code{panel}).  It is thus important to provide suitable prepanel and
  panel functions to \code{tmd} depending on the original call.

  Such functions currently exist for \code{xyplot}, \code{qq} (the ones
  with \code{default} in their name) and \code{qqmath}, as listed in the
  usage section above.  These assume the default displays for the
  corresponding high-level call.  If unspecified, the \code{prepanel} and
  \code{panel} arguments default to suitable choices.

  \code{tmd} uses the \code{update} method for \code{"trellis"} objects,
  which processes all extra arguments supplied to \code{tmd}.
}

\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{ \code{\link{qq}}, \code{\link{qqmath}}, \code{\link{xyplot}},
  \code{\link{Lattice}}
}

\examples{
tmd(qqmath(~height | voice.part, data = singer))
}
\keyword{dplot}
\eof
% --- Source file: trellis.device.Rd ---
\name{trellis.device}
\alias{trellis.device}
\alias{standard.theme}
\alias{canonical.theme}
\alias{col.whitebg}
\title{ Initializing Trellis Displays }
\description{
  Initialization of a display device with appropriate graphical
  parameters.
}

\usage{
trellis.device(device = getOption("device"),
               color = !(dev.name == "postscript"),
               theme = lattice.getOption("default.theme"),
               new = TRUE,
               retain = FALSE,
               \dots)

standard.theme(name, color)
canonical.theme(name, color)
col.whitebg()

}
\arguments{
  \item{device}{ function (or the name of one as a character string)
    that starts a device.  Admissible values depend on the platform and
    how \R was compiled (see \code{\link{Devices}}), but usually
    \code{"pdf"}, \code{"postscript"}, \code{"png"}, \code{"jpeg"} and
    at least one of \code{"X11"}, \code{"windows"} and \code{"quartz"}
    will be available.
  }
  \item{color}{ logical, whether the initial settings should be color or
    black and white.  Defaults to \code{FALSE} for postscript devices,
    \code{TRUE} otherwise.  Note that this only applies to the initial
    choice of colors, which can be overridden using \code{theme} or
    subsequent calls to \code{\link{trellis.par.set}} (and by arguments
    supplied directly in high level calls for some settings).
  }
  \item{theme}{ list of components that changes the settings of the
    device opened, or, a function that when called produces such a
    list.  The function name can be supplied as a quoted string.  These
    settings are only used to modify the default settings (determined by
    other arguments), and need not contain all possible parameters.

    A possible use of this argument is to change the default settings by 
    specifying \code{lattice.options(default.theme = "col.whitebg")}. 
    For back-compatibility, this is initially (when lattice is loaded)
    set to \code{options(lattice.theme)}.

    If \code{theme} is a function, it will not be supplied any
    arguments, however, it is guaranteed that a device will already be
    open when it is called, so one may use \code{.Device} inside the
    function to ascertain what device has been opened.
  }
  \item{new}{ logical flag indicating whether a new device should be
    started.  If \code{FALSE}, the options for the current device are
    changed to the defaults determined by the other arguments.
  }
  \item{retain}{
    logical. If \code{TRUE} and a setting for this device already
    exists, then that is used instead of the defaults for this
    device. By default, pre-existing settings are overwritten (and
    lost).
  }
  \item{name}{ name of the device for which the setting is required, as
    returned by \code{.Device}
  }
  \item{\dots}{ additional parameters to be passed to the \code{device}
    function, most commonly \code{file} for non-screen devices, as well
    as \code{height}, \code{width}, etc.  See the help file for
    individual devices for admissible arguments.
  }
}
\details{

  Trellis Graphics functions obtain the default values of various
  graphical parameters (colors, line types, fonts, etc.) from a
  customizable \dQuote{settings} list.  This functionality is analogous
  to \code{\link{par}} for standard \R graphics and, together with
  \code{\link{lattice.options}}, mostly supplants it (\code{\link{par}}
  settings are mostly ignored by Lattice).  Unlike \code{\link{par}},
  Trellis settings can be controlled separately for each different
  device type (but not concurrently for different instances of the same
  device).  \code{standard.theme} and \code{col.whitebg} produce
  predefined settings (a.k.a. themes), while \code{trellis.device}
  provides a high level interface to control which \dQuote{theme} will
  be in effect when a new device is opened.  \code{trellis.device} is
  called automatically when a \code{"trellis"} object is plotted, and
  the defaults can be used to provide sufficient control, so in a
  properly configured system it is rarely necessary for the user to call
  \code{trellis.device} explicitly.

  The \code{standard.theme} function is intended to provide device
  specific settings (e.g. light colors on a grey background for screen
  devices, dark colors or black and white for print devices) which were
  used as defaults prior to \R 2.3.0.  However, these defaults are not
  always appropriate, due to the variety of platforms and hardware
  settings on which \R is used, as well as the fact that a plot created
  on a particular device may be subsequently used in many different
  ways.  For this reason, a \dQuote{safe} default is used for all
  devices from \R 2.3.0 onwards.  The old behaviour can be reinstated by
  setting \code{standard.theme} as the default \code{theme} argument,
  e.g. by putting \code{options(lattice.theme = "standard.theme")} in a
  startup script (see the entry for \code{theme} above for details).
}

\value{
  \code{standard.theme} returns a list of components defining graphical
  parameter settings for Lattice displays. It is used internally in
  \code{trellis.device}, and can also be used as the \code{theme}
  argument to \code{trellis.par.set}, or even as \code{theme} in
  \code{trellis.device} to use the defaults for another device.
  \code{canonical.theme} is an alias for \code{standard.theme}.

  \code{col.whitebg} returns a similar (but smaller) list that is
  suitable as the \code{theme} argument to \code{trellis.device} and
  \code{\link{trellis.par.set}}.  It contains settings values which
  provide colors suitable for plotting on a white background.  Note that
  the name \code{col.whitebg} is somewhat of a misnomer, since it
  actually sets the background to transparent rather than white.
}

\note{
  Earlier versions of \code{trellis.device} had a \code{bg} argument to
  set the background color, but this is no longer supported.  If
  supplied, the \code{bg} argument will be passed on to the device
  function; however, this will have no effect on the Trellis settings.
  It is rarely meaningful to change the background alone; if you feel
  the need to change the background, consider using the \code{theme}
  argument instead.
}

\references{
  Sarkar, Deepayan (2008) "Lattice: Multivariate Data Visualization with
  R", Springer. \url{http://lmdvr.r-forge.r-project.org/}
}

\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{

  \code{\link{Lattice}} for an overview of the \code{lattice} package.
  
  \code{\link{Devices}} for valid choices of \code{device} on your
  platform.

  \code{\link{trellis.par.get}} and \code{\link{trellis.par.set}} can be
  used to query and modify the settings \emph{after} a device has been
  initialized.  The \code{par.settings} argument to high level
  functions, described in \code{\link{xyplot}}, can be used to attach
  transient settings to a \code{"trellis"} object.
}
\keyword{dplot}

\eof
% --- Source file: trellis.object.Rd ---
\name{trellis.object}
\alias{trellis.object}
\docType{class}
%%\non_function{}
\title{A Trellis Plot Object}

\description{

  This class of objects is returned by high level lattice functions, and
  is usually plotted by default by its
  \code{\link[lattice:print.trellis]{print}} method.

}

\details{
  A trellis object, as returned by high level lattice functions like
  \code{\link{xyplot}}, is a list with the \code{"class"} attribute set
  to \code{"trellis"}.  Many of the components of this list are simply
  the arguments to the high level function that produced the object.
  Among them are: \code{as.table}, \code{layout}, \code{page},
  \code{panel}, \code{prepanel}, \code{main}, \code{sub},
  \code{par.strip.text}, \code{strip}, \code{skip}, \code{xlab}
  \code{ylab}, \code{par.settings}, \code{lattice.options} and
  \code{plot.args}.  Some other typical components are:

  \describe{
    \item{\code{formula}}{
      the Trellis formula used in the call
    }
    \item{\code{index.cond}}{
      list with index for each of the conditioning variables
    }
    \item{\code{perm.cond}}{
      permutation of the order of the conditioning variables
    }
    \item{\code{aspect.fill}}{
      logical, whether \code{aspect} is \code{"fill"}
    }
    \item{\code{aspect.ratio}}{
      numeric, aspect ratio to be used if \code{aspect.fill} is
      \code{FALSE}
    }
    \item{\code{call}}{ call that generated the object. }
    \item{\code{condlevels}}{
      list with levels of the conditioning variables
    }
    \item{\code{legend}}{
      list describing the legend(s) to be drawn
    }
    \item{\code{panel.args}}{
      a list as long as the number of panels, each element being a list
      itself, containing the arguments in named form to be passed to the
      panel function in that panel.
    }
    \item{\code{panel.args.common}}{
      a list containing the arguments common to all the panel functions
      in \code{name=value} form
    }
    \item{\code{x.scales}}{
      list describing x-scale, can consist of several other lists,
      paralleling panel.args, if x-relation is not \code{"same"}
    }
    \item{\code{y.scales}}{
      list describing y-scale, similar to \code{x.scales}
    }
    \item{\code{x.between}}{ numeric vector of interpanel x-space }
    \item{\code{y.between}}{ numeric vector of interpanel y-space }
    \item{\code{x.limits}}{
      numeric vector of length 2 or list, giving x-axis limits
    }
    \item{\code{y.limits}}{ similar to \code{x.limits} }
    \item{\code{packet.sizes}}{
      array recording the number of observations in each packet
    }
  }
}

\seealso{
  \code{\link{Lattice}}, \code{\link{xyplot}},
  \code{\link{print.trellis}}
}

\author{Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}


\keyword{classes}

\eof
% --- Source file: trellis.par.get.Rd ---
\name{trellis.par.get}
\alias{trellis.par.get}
\alias{trellis.par.set}
\alias{show.settings}
\title{ Graphical Parameters for Trellis Displays }
\description{
  Functions used to query, display and modify graphical parameters for
  fine control of Trellis displays.  Modifications are made to the
  settings for the currently active device only.
}
\usage{
trellis.par.set(name, value, \dots, theme, warn = TRUE, strict = FALSE)
trellis.par.get(name = NULL)
% trellis.par.set(name, value, warn)
% trellis.par.set(theme)
% trellis.par.set(\dots)
show.settings(x = NULL)
}
\arguments{
  \item{name}{ character giving the name of a component. If unspecified,
    \code{names(trellis.par.get())} returns a list containing all the
    current settings (this can be used to get the valid values for
    \code{name})
  }
  \item{value}{
    a list giving the desired value of the component. Components that
    are already defined as part of the current settings but are not
    mentioned in \code{value} will remain unchanged.
  }
  \item{theme}{
    a list decribing how to change the settings, similar to what is
    returned by \code{trellis.par.get()}.  This is purely for
    convenience, allowing multiple calls to \code{trellis.par.set} to be
    condensed into one.  The name of each component must be a valid
    \code{name} as described above, with the corresponding value a valid
    \code{value} as described above.

    As in \code{\link{trellis.device}}, \code{theme} can also be a
    function that produces such a list when called.  The function name
    can be supplied as a quoted string.
  }
  \item{\dots}{
    Multiple settings can be specified in \code{name = value} form.
    Equivalent to calling with \code{theme = list(\dots)}
  }
  \item{warn}{
    logical, indicating whether a warning should be issued when
    \code{trellis.par.get} is called when no graphics device is open
  }
  \item{strict}{
    logical, indicating whether the \code{value} should be interpreted
    strictly.  Usually, assignment of value to the corresponding named
    component is fuzzy in the sense that sub-components that are absent
    from \code{value} but not currently \code{NULL} are retained.  By
    specifying \code{strict = TRUE}, the assignment will be exact.
  }
  \item{x}{
    optional list of components that change the settings (any valid
    value of \code{theme}).  These are used to modify the current
    settings (obtained by \code{trellis.par.get}) before they are
    displayed.
  }
}
\details{
  The various graphical parameters (color, line type, background etc)
  that control the look and feel of Trellis displays are highly
  customizable. Also, R can produce graphics on a number of devices, and
  it is expected that a different set of parameters would be more suited
  to different devices. These parameters are stored internally in a
  variable named \code{lattice.theme}, which is a list whose components
  define settings for particular devices. The components are idenified
  by the name of the device they represent (as obtained by
  \code{.Device}), and are created as and when new devices are opened
  for the first time using \code{trellis.device} (or Lattice plots are
  drawn on a device for the first time in that session).

  The initial settings for each device defaults to values appropriate
  for that device. In practice, this boils down to three distinct
  settings, one for screen devices like \code{x11} and \code{windows},
  one for black and white plots (mostly useful for \code{postscript})
  and one for color printers (color \code{postcript}, \code{pdf}).

  Once a device is open, its settings can be modified. When another
  instance of the same device is opened later using
  \code{trellis.device}, the settings for that device are reset to its
  defaults, unless otherwise specified in the call to
  \code{trellis.device}. But settings for different devices are treated
  separately, i.e., opening a postscript device will not alter the x11
  settings, which will remain in effect whenever an x11 device is
  active.

  The functions \code{trellis.par.*} are meant to be interfaces to the
  global settings. They always apply on the settings for the currently
  ACTIVE device.

  \code{trellis.par.get}, called without any arguments, returns the full
  list of settings for the active device. With the \code{name} argument
  present, it returns that component only. \code{trellis.par.get} sets
  the value of the \code{name} component of the current active device
  settings to \code{value}.

  \code{trellis.par.get} is usually used inside trellis functions to get
  graphical parameters before plotting. Modifications by users via
  \code{trellis.par.set} is traditionally done as follows:

  \code{add.line <- trellis.par.get("add.line")}

  \code{add.line$col <- "red"}

  \code{trellis.par.set("add.line", add.line)}

  More convenient (but not S compatible) ways to do this are

  \code{trellis.par.set(list(add.line = list(col = "red")))}

  and

  \code{trellis.par.set(add.line = list(col = "red"))}
  

  The actual list of the components in \code{trellis.settings} has not
  been finalized, so I'm not attempting to list them here. The current
  value can be obtained by \code{print(trellis.par.get())}. Most names
  should be self-explanatory.

  \code{show.settings} provides a graphical display summarizing some of
  the values in the current settings.
}


\note{
  In some ways, \code{trellis.par.get} and \code{trellis.par.set}
  together are a replacement for the \code{\link{par}} function used in
  traditional R graphics.  In particular, changing \code{par} settings
  has little (if any) effect on lattice output.  Since lattice plots are
  implemented using Grid graphics, its parameter system \emph{does} have
  an effect unless overridden by a suitable lattice parameter setting.
  Such parameters can be specified as part of a lattice theme by
  including them in the \code{grid.pars} component (see
  \code{\link[grid:gpar]{gpar}} for a list of valid parameter names).


  One of the uses of \code{par} is to set \code{par(ask = TRUE)} making
  R wait for user input before starting a new graphics page.  For Grid
  graphics, this is done using
  \code{\link[grid:grid.prompt]{grid.prompt}}.  Lattice has no separate
  interface for this, and the user must call \code{grid.prompt}
  directly.  If the grid package is not attached (lattice itself
  only loads the grid namespace), this may be done using
  \code{grid::grid.prompt(TRUE)}.
  
}

\value{
  \code{trellis.par.get} returns a list giving parameters for that
  component. If \code{name} is missing, it returns the full list.
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{
  \code{\link{trellis.device}}, \code{\link{Lattice}},
  \code{\link[grid:grid.prompt]{grid.prompt}},
  \code{\link[grid:gpar]{gpar}}
}

\examples{
show.settings()
}
\keyword{dplot}


\eof
% --- Source file: update.trellis.Rd ---
\name{update.trellis}
\alias{update.trellis}
\alias{[.trellis}
\alias{t.trellis}
\alias{trellis.last.object}
\title{Retrieve and Update Trellis Object}
\description{
  Update method for objects of class \code{"trellis"}, and a way to retrieve
  the last printed trellis object (that was saved).
}

\usage{
\method{update}{trellis}(object,
       panel,
       aspect,
       as.table,
       between,
       key,
       auto.key,
       legend,
       layout,
       main,
       page,
       par.strip.text,
       prepanel,
       scales,
       skip,
       strip,
       strip.left,
       sub,
       xlab,
       xlim,
       ylab,
       ylim,
       par.settings,
       plot.args,
       lattice.options,
       index.cond,
       perm.cond,
       \dots)

\method{t}{trellis}(x)

\method{[}{trellis}(x, i, j, \dots, drop = FALSE)

trellis.last.object(warn = TRUE, \dots)

}
\arguments{

  \item{object, x}{
    The object to be updated, of class \code{"trellis"}.
  }
  \item{i, j}{ indices to be used.  Names are not currently allowed. }
  \item{drop}{
    logical, whether dimensions with only one level are to be dropped.
    Currently ignored, behaves as if it were \code{FALSE}.
  }
  \item{warn}{
    logical, whether to warn when no plot is saved.
  }
  \item{panel, aspect, as.table, between, key, auto.key, legend, layout,
    main, page, par.strip.text, prepanel, scales, skip, strip,
    strip.left, sub, xlab, xlim, ylab, ylim, par.settings, plot.args,
    lattice.options, index.cond, perm.cond, \dots}{
    arguments that will be used to update \code{object}. See details
    below. 
  }
}


\details{

  All high level lattice functions such as \code{xyplot} produce an
  object of (S3) class \code{"trellis"}, which is usually displayed by its
  \code{print} method. However, the object itself can be manipulated and
  modified to a large extent using the \code{update} method, and then
  re-displayed as needed.

  Most arguments to high level functions can also be supplied to the
  \code{update} method as well, with some exceptions. Generally
  speaking, anything that would needs to change the data within each
  panel is a no-no (this includes the \code{formula, data, groups,
    subscripts} and \code{subset}). Everything else is technically game,
  though might not be implemented yet. If you find something missing
  that you wish to have, feel free to make a request.

  Not all arguments accepted by a Lattice function are processed by
  \code{update}, but the ones listed above should work.  The purpose of
  these arguments are described in the help page for
  \code{\link{xyplot}}.  Any other argument is added to the list of
  arguments to be passed to the \code{panel} function. Because of their
  somewhat special nature, updates to objects produced by \code{cloud}
  and \code{wireframe} do not work very well yet.

  The \code{"["} method is a convenient shortcut for updating
  \code{index.cond}.  The \code{t} method is a convenient shortcut for
  updating \code{perm.cond} in the special (but frequent) case where
  there are exactly two conditioning variables, when it has the effect
  of switching (\sQuote{transposing}) their order.

  The print method for \code{"trellis"} objects optionally saves the
  object after printing it.  If this feature is enabled,
  \code{trellis.last.object} can retrieve it.  Note that at most one
  object can be saved at a time.  If \code{\link{trellis.last.object}}
  is called with arguments, these are used to update the retrieved
  object before returning it.

}

% WAS: \dontrun{
% trellis.last.object(xlab = "Year")
% }

\examples{
spots <- by(sunspots, gl(235, 12, labels = 1749:1983), mean)
old.options <- lattice.options(save.object = TRUE)
xyplot(spots ~ 1749:1983, xlab = "", type = "l",
       scales = list(x = list(alternating = 2)),
       main = "Average Yearly Sunspots")
update(trellis.last.object(), aspect = "xy")
trellis.last.object(xlab = "Year")
lattice.options(old.options)
}

\value{
  An object of class \code{trellis}, by default plotted by
  \code{print.trellis}.  \code{trellis.last.object} returns
  \code{NULL} is no saved object is available.
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{
  \code{\link{trellis.object}}, \code{\link{Lattice}},
  \code{\link{xyplot}}
}
\keyword{dplot}
\eof
% --- Source file: utilities.3d.Rd ---
\name{utilities.3d}
\alias{utilities.3d}
\alias{palette.shade}
\alias{ltransform3dMatrix}
\alias{ltransform3dto3d}
\title{ Utility functions for 3-D plots }
\description{
  These are (related to) the default panel functions for \code{cloud}
  and \code{wireframe}.
}
\usage{
ltransform3dMatrix(screen, R.mat)
ltransform3dto3d(x, R.mat, dist)
% palette.shade(irr, ref, height, saturation)
}
\arguments{
  \item{x}{
    \code{x} can be a numeric matrix with 3 rows for
    \code{ltransform3dto3d}
  }
  \item{screen}{list, as described in \code{\link{panel.cloud}}}
  \item{R.mat}{4x4 transformation matrix in homogeneous
    coordinates}
  \item{dist}{controls transformation to account for
    perspective viewing}

%   \item{irr, ref}{
%     numeric, between 0 and 1. See details below. (The names are intended
%     to suggest a link with irradiance and reflectance respectively.)
%   }
%   \item{height}{
%     numeric, denoting height scaled to lie between 0 and 1
%   }
%   \item{saturation}{
%     used to control \code{s} in \code{hsv} inside \code{palette.shade}
%   }
}
\details{
  \code{ltransform3dMatrix} and \code{ltransform3dto3d} are utility
  functions to help in computation of projections. These functions are
  used inside the panel functions for \code{cloud} and
  \code{wireframe}. They may be useful in user-defined panel functions
  as well.

  The first function takes a list of the form of the \code{screen}
  argument in \code{cloud} and \code{wireframe} and a \code{R.mat}, a
  4x4 transformation matrix in homogeneous coordinates, to return a new
  4x4 transformation matrix that is the result of applying \code{R.mat}
  followed by the rotations in \code{screen}. The second function
  applies a 4x4 transformation matrix in homogeneous coordinates to a
  3xn matrix representing points in 3-D space, and optionally does some
  perspective computations. (There has been no testing with non-trivial
  transformation matrices, and my knowledge of the homogeneous
  coordinate system is very limited, so there may be bugs here.)

%   \code{palette.shade} is the function used by default for calculation
%   of colors when \sQuote{shading} a wireframe. Such a function can expect three
%   arguments in general, namely \code{irr}, \code{ref} and
%   \code{height}.  \code{irr} should represent foreshortening, being the
%   cosine of the angle between the incident light ray and the normal to
%   the surface.  \code{ref} represents the direction of the reflected
%   light, and in fact is the cosine of half the angle between the
%   reflected ray and the viewing direction. \code{height} is the scaled
%   (average) height (of any particular facet).

}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\seealso{\code{\link{cloud}}, \code{\link{panel.cloud}}}
\keyword{dplot}
\eof
% --- Source file: xyplot.Rd ---
\name{xyplot}
\title{Common Bivariate Trellis Plots}
\alias{xyplot}
\alias{xyplot.formula}
\alias{barchart}
\alias{barchart.formula}
\alias{barchart.numeric}
\alias{barchart.default}
\alias{bwplot}
\alias{bwplot.formula}
\alias{bwplot.numeric}
\alias{dotplot}
\alias{dotplot.formula}
\alias{dotplot.numeric}
\alias{dotplot.default}
\alias{stripplot}
\alias{stripplot.formula}
\alias{stripplot.numeric}
\usage{
xyplot(x, data, \dots)
dotplot(x, data, \dots)
barchart(x, data, \dots)
stripplot(x, data, \dots)
bwplot(x, data, \dots)

\method{xyplot}{formula}(x,
       data,
       allow.multiple = is.null(groups) || outer,
       outer = !is.null(groups),
       auto.key = FALSE,
       aspect = "fill",
       panel = lattice.getOption("panel.xyplot"),
       prepanel = NULL,
       scales = list(),
       strip = TRUE,
       groups = NULL,
       xlab,
       xlim,
       ylab,
       ylim,
       drop.unused.levels = lattice.getOption("drop.unused.levels"),
       \dots,
       lattice.options = NULL,
       default.scales,
       subscripts = !is.null(groups),
       subset = TRUE)


\method{dotplot}{formula}(x,
        data,
        panel = lattice.getOption("panel.dotplot"),
        \dots)

\method{barchart}{formula}(x,
         data,
         panel = lattice.getOption("panel.barchart"),
         box.ratio = 2,
         \dots)

\method{stripplot}{formula}(x,
          data,
          panel = lattice.getOption("panel.stripplot"),
          \dots)

\method{bwplot}{formula}(x,
       data,
       allow.multiple = is.null(groups) || outer,
       outer = FALSE,
       auto.key = FALSE,
       aspect = "fill",
       panel = lattice.getOption("panel.bwplot"),
       prepanel = NULL,
       scales = list(),
       strip = TRUE,
       groups = NULL,
       xlab,
       xlim,
       ylab,
       ylim,
       box.ratio = 1,
       horizontal = NULL,
       drop.unused.levels = lattice.getOption("drop.unused.levels"),
       \dots,
       lattice.options = NULL,
       default.scales,
       subscripts = !is.null(groups),
       subset = TRUE)


}

\description{
  These are the most commonly used high level Trellis functions to plot
  pairs of variables. By far the most common is \code{xyplot}, designed
  mainly for two continuous variates (though factors can be supplied as
  well, in which case they will simply be coerced to numeric), which
  produces Conditional Scatter plots. The others are useful when one of
  the variates is a factor or a shingle.  Most of these arguments are
  also applicable to other high level functions in the lattice package,
  but are only documented here.
}

\arguments{
  \item{x}{
    The object on which method dispatch is carried out.

    For the \code{"formula"} methods, a formula describing the form of
    conditioning plot. The formula is generally of the form \code{y ~ x
      | g1 * g2 * \dots}, indicating that plots of \code{y} (on the y
    axis) versus \code{x} (on the x axis) should be produced conditional
    on the variables \code{g1, g2, \dots}. However, the conditioning
    variables \code{g1,g2,\dots} may be omitted. The formula can also be
    supplied as \code{y ~ x | g1 + g2 + \dots}.

    For all of these functions, with the exception of \code{xyplot}, a
    formula of the form \code{ ~ x | g1 * g2 * \dots} is also
    allowed. In that case, \code{y} defaults to \code{names(x)} if
    \code{x} is named, and a factor with a single level otherwise.

    Other usage of the form \code{dotplot(x)} is handled by method
    dispatch as appropriate.  The \code{numeric} method is equivalent to
    a call with no left hand side and no conditioning variables in the
    formula.  For \code{barchart} and \code{dotplot}, non-trivial
    methods exist for tables and arrays, documented under
    \code{\link{barchart.table}}.

    The conditioning variables \code{g1, g2, \dots} must be either
    factors or shingles.  Shingles are a way of processing numeric
    variables for use in conditioning. See documentation of
    \code{\link{shingle}} for details. Like factors, they have a
    \code{"levels"} attribute, which is used in producing the
    conditional plots.

    Numeric conditioning variables are converted to shingles by the
    function \code{shingle} (however, using \code{\link{equal.count}}
    might be more appropriate in many cases) and character vectors are
    coerced to factors.

    The formula can involve expressions, e.g. \code{sqrt()},
    \code{log()}.

    A special case is when the left and/or right sides of the formula
    (before the conditioning variables) contain a \sQuote{+} sign, e.g.,
    \code{y1+y2 ~ x | a*b}. This formula would be taken to mean that the
    user wants to plot both \code{y1~x | a*b} and \code{y2~x | a*b}, but
    with the \code{y1~x} and \code{y2~x} superposed in each panel (this
    is slightly more complicated in \code{barchart}). The two parts
    would be distinguished by different graphical parameters. This is
    essentially what the \code{groups} argument would produce, if
    \code{y1} and \code{y2} were concatenated to produce a longer
    vector, with the \code{groups} argument being an indicator of which
    rows come from which variable.  In fact, this is exactly what is
    done internally using the \code{\link{reshape}} function. This
    feature cannot be used in conjunction with the \code{groups}
    argument.  

    To interpret \code{y1 + y2} as a sum, one can either set
    \code{allow.multiple=FALSE} or use \code{I(y1+y2)}.

    A variation on this feature is when the \code{outer} argument is set
    to \code{TRUE} as well as \code{allow.multiple}. In that case, the
    plots are not superposed in each panel, but instead separated into
    different panels (as if a new conditioning variable had been added).
    
    The \code{x} and \code{y} variables should both be numeric in
    \code{xyplot}, and an attempt is made to coerce them if
    not. However, if either is a factor, the levels of that factor are
    used as axis labels. In the other four functions documented here,
    exactly one of \code{x} and \code{y} should be numeric, and the
    other a factor or shingle. Which of these will happen is determined
    by the \code{horizontal} argument --- if \code{horizontal=TRUE},
    then \code{y} will be coerced to be a factor or shingle, otherwise
    \code{x}. The default value of \code{horizontal} is \code{FALSE} if
    \code{x} is a factor or shingle, \code{TRUE} otherwise. (The
    functionality provided by \code{horizontal=FALSE} is not
    S-compatible.)

    Note that this argument used to be called \code{formula} in earlier
    versions (when the high level functions were not generic and the
    formula method was essentially the only method).  This is no longer
    allowed.  It is recommended that this argument not be named in any
    case, but rather be the first (unnamed) argument.
    
    %     All points with at least one of its values missing (NA) in any
    %     of the variates involved are omitted from the plot.
  }
  \item{data}{
    For the \code{formula} method, a data frame containing values (or
    more precisely, anything that is a valid \code{envir} argument in
    \code{\link{eval}}, e.g. a list or an environment) for any variables in
    the formula, as well as \code{groups} and \code{subset} if
    applicable.  If not found in \code{data}, or if \code{data} is
    unspecified, the variables are looked for in the environment of the
    formula.  For other methods (where \code{x} is not a formula),
    \code{data} is usually ignored, often with a warning.
  }
  \item{allow.multiple, outer}{
    logical flags to control what happens with formulas like \code{y1 +
      y2 ~ x}. See the entry for \code{x} for details.
    \code{allow.multiple} defaults to \code{TRUE} whenever it makes
    sense, and \code{outer} defaults to \code{FALSE} except when
    \code{groups} is explicitly specified or grouping doesn't make sense
    for the default panel function
  }
  \item{box.ratio}{ applicable to \code{bwplot}, \code{barchart} and
    \code{stripplot}, specifies the ratio of the width of the rectangles
    to the inter rectangle space.
  }
  \item{horizontal}{ logical, applicable to \code{bwplot, dotplot,
      barchart} and \code{stripplot}. Determines which of \code{x} and
    \code{y} is to be a factor or shingle (\code{y} if TRUE, \code{x}
    otherwise). Defaults to \code{FALSE} if \code{x} is a factor or
    shingle, \code{TRUE} otherwise. This argument is used to process the  
    arguments to these high level functions, but more importantly, it is
    passed as an argument to the panel function, which is supposed to
    use it as appropriate.

    A potentially useful component of \code{scales} in this case might
    be \code{abbreviate = TRUE}, in which case long labels which would
    usually overlap will be abbreviated. \code{scales} could also
    contain a \code{minlength} argument in this case, which would be
    passed to the \code{abbreviate} function.
  }
  %   \item{jitter.data}{
  %     logical specifying whether the values should be jittered by adding a
  %     random noise in stripplot.  This is actually an argument of
  %     \code{panel.stripplot}.
  %   }
  %   \item{factor}{
  %     numeric controlling amount of jitter as in \code{\link{jitter}}.
  %   }

  The following arguments are common to all the functions documented
  here, as well as most other high level Trellis functions. These are
  not documented elsewhere, except to override the usage given here.

  \item{panel}{
    Once the subset of rows defined by each unique combination of the
    levels of the grouping variables are obtained (see details), the
    corresponding \code{x} and \code{y} variables (or other variables,
    as appropriate, in the case of other high level functions) are
    passed on to be plotted in each panel. The actual plotting is done
    by the function specified by the \code{panel} argument.  Each high
    level function has its own default panel function, which could
    depend on whether the \code{groups} argument was supplied.

    The panel function can be a function object or a character string
    giving the name of a predefined function.

    Much of the power of Trellis Graphics comes from the ability to
    define customized panel functions.  A panel function appropriate
    for the functions described here would usually expect arguments
    named \code{x} and \code{y}, which would be provided by the
    conditioning process.  It can also have other arguments. It might be
    useful to know in this context that all arguments passed to a high
    level Trellis function (such as \code{xyplot}) that are not
    recognized by it are passed through to the panel function. It is
    thus generally good practice when defining panel functions to allow
    a \code{\dots} argument. Such extra arguments typically control
    graphical parameters, but other uses are also common. See
    documentation for individual panel functions for specifics.

    Note that unlike in S-PLUS, it is not guaranteed that panel
    functions will be supplied only numeric vectors for the \code{x} and
    \code{y} arguments; they can be factors as well (but not
    shingles).  Panel functions need to handle this case, which in most
    cases can be done by simply coercing them to numeric.

    Technically speaking, panel functions must be written using Grid
    graphics functions.  However, knowledge of Grid is usually not
    necessary to construct new custom panel functions, there are several
    predefined panel functions which can help; for example,
    \code{panel.grid}, \code{panel.loess}, etc.  There are also some
    grid-compatible replacements of commonly used base R graphics
    functions useful for this purpose.  For example, \code{lines} can be
    replaced by \code{llines} (or equivalently, \code{panel.lines}).
    Note that base R graphics functions like \code{lines} will not work
    in a lattice panel function.

    One case where a bit more is required of the panel function is when
    the \code{groups} argument is not null. In that case, the panel
    function should also accept arguments named \code{groups} and
    \code{subscripts} (see below for details).  A useful panel function
    predefined for use in such cases is \code{panel.superpose}, which
    can be combined with different \code{panel.groups} functions
    determining what is plotted for each group.  See the examples
    section for an interaction plot constructed in this way.  Several
    other panel functions can also handle the \code{groups} argument,
    including the default ones for \code{barchart}, \code{dotplot} and
    \code{stripplot}.

    Even when \code{groups} is not present, the panel function can have
    \code{subscripts} as a formal argument.  In either case, the
    \code{subscripts} argument passed to the panel function are the
    indices of the \code{x} and \code{y} data for that panel in the
    original \code{data}, BEFORE taking into account the effect of
    the \code{subset} argument.  Note that \code{groups} remains
    unaffected by any subsetting operations, so
    \code{groups[subscripts]} gives the values of \code{groups} that
    correspond to the data in that panel.

    This interpretation of \code{subscripts} does not hold when the
    extended formula interface is in use (i.e., when
    \code{allow.multiple} is in effect).  A comprehensive description
    would be too complicated (details can be found in the source code of
    the function \code{latticeParseFormula}), but in short, the extended
    interface works by creating an artificial grouping variable that is
    longer than the original data frame, and consequently,
    \code{subscripts} needs to refer to rows beyond those in the
    original data.  To further complicate matters, the artificial
    grouping variable is created after any effect of \code{subset}, in
    which case \code{subscripts} has practically no relationship with
    corresponding rows in the original data frame.


    One can also use functions called \code{\link{panel.number}} and
    \code{\link{packet.number}}, representing panel order and packet
    order respectively, inside the panel function (as well as the strip
    function or while interacting with a lattice display using
    \code{\link{trellis.focus}} etc).  Both provide a simple integer
    index indicating which panel is currently being drawn, but differ in
    how the count is calculated.  The panel number is a simple
    incremental counter that starts with 1 and is incremented each time
    a panel is drawn.  The packet number on the other hand indexes the
    combination of levels of the conditioning variables that is
    represented by that panel.  The two indices coincide unless the
    order of conditioning variables is permuted and/or the plotting
    order of levels within one or more conditioning variables is altered
    (using \code{perm.cond} and \code{index.cond} respectively), in
    which case \code{packet.number} gives the index corresponding to the
    \sQuote{natural} ordering of that combination of levels of the
    conditioning variables.

    \code{\link{panel.xyplot}} has an argument called \code{type} which
    is worth mentioning here because it is quite frequently used (and as
    mentioned above, can be passed to \code{xyplot} directly).  In the
    event that a \code{groups} variable is used,
    \code{\link{panel.xyplot}} calls \code{\link{panel.superpose}},
    arguments of which can also be passed directly to \code{xyplot}.
    Panel functions for \code{bwplot} and friends should have an
    argument called \code{horizontal} to account for the cases when
    \code{x} is the factor or shingle.
  }

  % \item{panel.groups}{
  %     useful mostly for \code{xyplot} and \code{densityplot}. Applies when
  %     \code{panel} is \code{panel.superpose} (which happens by default in
  %     these cases if \code{groups} is non-null)
  %   }

  \item{aspect}{ controls physical aspect ratio of the panels (same for
    all the panels). It can be specified as a ratio (vertical
    size/horizontal size) or as a character string. Legitimate 
    values are \code{"fill"} (the default) which tries to make the
    panels as big as possible to fill the available space; \code{"xy"},
    which \bold{tries} to compute the aspect based on the 45 degree
    banking rule (see \emph{Visualizing Data} by William S. Cleveland
    for details); and \code{"iso"} for isometric scales, where the
    relation between physical distance on the device and distance in the
    data scale are forced to be the same for both axes.

    If a \code{prepanel} function is specified and it returns components
    \code{dx} and \code{dy}, these are used for banking calculations.
    Otherwise, values from the default prepanel function are used.
    Currently, only the default prepanel function for \code{xyplot} can
    be expected to produce sensible banking calculations.  See
    \code{\link{banking}} for details on the implementation of banking .
  }



  \item{groups}{ a variable or expression to be evaluated in the data
    frame specified by \code{data}, expected to act as a grouping
    variable within each panel, typically used to distinguish different
    groups by varying graphical parameters like color and line type.
    Formally, if \code{groups} is specified, then \code{groups} along
    with \code{subscripts} is passed to the panel function, which is
    expected to handle these arguments.  Not all pre-defined panel
    functions know how to, but for high level functions where grouping
    is appropriate, the default panel functions are chosen so that they
    do.

    It is very common to use a key (legend) when a grouping
    variable is specified.  See entries for \code{key}, \code{auto.key}
    and \code{\link{simpleKey}} for how to draw a key.
  }
  \item{auto.key}{
    A logical (indicating whether a key is to be drawn automatically when
    a grouping variable is present in the plot), or a list of parameters
    that would be valid arguments to \code{\link{simpleKey}} (in effect,
    most valid components of \code{key} can be specified in this
    manner).  If \code{auto.key} is not \code{FALSE}, \code{groups} is
    non-null and there is no \code{key} or \code{legend} argument
    specified in the call, a key is created with \code{simpleKey} with
    \code{levels(groups)} as the first argument. (Note: this may not
    work in all high level functions, but it does work for the ones
    where grouping makes sense with the default panel function)

    \code{simpleKey} uses the trellis settings to determine the
    graphical parameters in the key, so this will be meaningful only if
    the settings are used in the plot as well.

    One disadvantage to using \code{key} (or even \code{simpleKey})
    directly is that the graphical parameters used in the key are
    absolutely determined at the time when the \code{"trellis"} object is
    created. Consequently, if a plot once created is re-\code{print}ed
    with different settings, the parameter settings for the original
    device will be used. However, with \code{auto.key}, the key is
    actually created at printing time, so the key settings will match
    the device settings.
  }
  \item{prepanel}{
    function that takes the same arguments as the \code{panel} function
    and returns a list, possibly containing components named
    \code{xlim}, \code{ylim}, \code{dx} and \code{dy} (and less
    frequently, \code{xat} and \code{yat}).

    The \code{xlim} and \code{ylim} components are similar to the high
    level \code{xlim} and \code{ylim} arguments (i.e., they are usually
    a numeric vector of length 2 defining a range of values, or a
    character vector representing levels of a factor).  If the
    \code{xlim} and \code{ylim} arguments are not explicitly specified
    (possibly as components in \code{scales}), then the actual limits of
    the panels are guaranteed to include the limits returned by the
    prepanel function. This happens globally if the \code{relation}
    component of \code{scales} is \code{"same"}, and on a panel by panel
    basis otherwise. See \code{xlim} to see what forms of the components
    \code{xlim} and \code{ylim} are allowed.

    The \code{dx} and \code{dy} components are used for banking
    computations in case \code{aspect} is specified as \code{"xy"}.  See
    documentation for the function \code{banking} for details regarding
    how this is done.

    The return value of the prepanel function need not have all the
    components named above; in case some are missing, they are replaced
    by the usual component-wise defaults.

    If \code{xlim} or \code{ylim} is a character vector (which is
    appropriate when the corresponding variable is a factor), this
    implicitly indicates that the scale should include the first
    \code{n} integers, where \code{n} is the length of \code{xlim} or
    \code{ylim}, as the case may be.  The elements of the character
    vector are used as the default labels for these \code{n} integers.
    Thus, to make this information consistent between panels, the
    \code{xlim} or \code{ylim} values should represent all the levels of
    the corresponding factor, even if some are not used within that
    particular panel.

    In such cases, an additional component \code{xat} or \code{yat} may
    be returned by the \code{prepanel} function, which should be a
    subset of \code{1:n}, indicating which of the \code{n} values
    (levels) are actually represented in the panel.  This is useful when
    calculating the limits with \code{relation="free"} or
    \code{relation="sliced"} in \code{scales}.

    The prepanel function is responsible for providing a meaningful
    return value when the \code{x}, \code{y} (etc.) variables are
    zero-length vectors.  When nothing is appropriate, values of NA
    should be returned for the \code{xlim} and \code{ylim} components.
  }

  \item{strip}{
    logical flag or function.  If \code{FALSE}, strips are not drawn.
    Otherwise, strips are drawn using the \code{strip} function, which
    defaults to \code{strip.default}.  See documentation of
    \code{strip.default} to see the arguments that are available to the
    strip function.  This description also applies to the
    \code{strip.left} argument (see \code{\dots} below), which can be
    used to draw strips on the left of each panel, which can be useful
    for wide short panels, e.g. in time series plots.
  }

  \item{xlab}{ character string or expression (or a \code{"grob"}) giving
    label for the x-axis.  Defaults to the expression for \code{x} in
    \code{formula}.  Can be specified as \code{NULL} to omit the label
    altogether.  Finer control is possible, as described in the entry
    for \code{main}, with the additional feature that if the
    \code{label} component is omitted from the list, it is replaced by
    the default \code{xlab}.
  }
  \item{ylab}{ character string or expression (or \code{"grob"}) giving
    label for the y-axis.  Defaults to the expression for \code{y} in
    \code{formula}.  Fine control is possible, see entries for
    \code{main} and \code{xlab}.
  }

  \item{scales}{ list determining how the x- and y-axes (tick marks and
    labels) are drawn.  The list contains parameters in
    \code{name=value} form, and may also contain two other lists called
    \code{x} and \code{y} of the same form (described below).
    Components of \code{x} and \code{y} affect the respective axes only,
    while those in \code{scales} affect both.  When parameters are
    specified in both lists, the values in \code{x} or \code{y} are
    used.  Note that certain high-level functions have defaults that are
    specific to a particular axis (e.g., \code{bwplot} has
    \code{alternating=FALSE} for the y-axis only); these can be
    overridden only by an entry in the corresponding component of
    \code{scales}.

    The possible components are :

    \describe{
      \item{\code{relation}}{
	character string that determines how axis limits are calculated
	for each panel.  Possible values are \code{"same"} (default),
	\code{"free"} and \code{"sliced"}.  For \code{relation="same"},
	the same limits, usually large enough to encompass all the data,
	are used for all the panels.  For \code{relation="free"}, limits
	for each panel is determined by just the points in that panel.
	Behavior for \code{relation="sliced"} is similar, except that
	the length (max - min) of the scales are constrained to remain
	the same across panels.

	The determination of what axis limits are suitable for each
	panel can be controlled by the \code{prepanel} function, which
	can be overridden by \code{xlim}, \code{ylim} or
	\code{scales$limits}.  If relation is not \code{"same"}, the
	value of \code{xlim} etc is normally ignored, except when it is
	a list, in which case it is treated as if its components were
	the limit values obtained from the prepanel calculations for
	each panel.
      }
      \item{\code{tick.number}}{
	Suggested number of ticks (ignored for a factor, shingle or
	character vector, in which case there is no natural rule for
	leaving out some of the labels. But see \code{xlim}).
      }
      \item{\code{draw}}{
	logical, defaults to \code{TRUE}, whether to draw the axis at
	all.
      }
      \item{\code{alternating}}{
	logical specifying whether axis labels should alternate from one
	side of the group of panels to the other.  For finer control,
	alternating can be a vector (replicated to be as long as the
	number of rows or columns per page) consisting of the following
	numbers
	\itemize{
	  \item 0: do not draw tick labels
	  \item 1: bottom/left
	  \item 2: top/right
	  \item 3: both.
	}
	\code{alternating} applies only when \code{relation="same"}.
	The default is \code{TRUE}, or equivalently, \code{c(1, 2)}
      }
      \item{\code{limits}}{
	same as xlim and ylim.
      }
      \item{\code{at}}{ location of tick marks along the axis (in native
	coordinates), or a list as long as the number of panels
	describing tick locations for each panel.
      }
      \item{\code{labels}}{
	Labels (strings or expressions) to go along with \code{at}. Can
	be a list like \code{at} as well.
      }
      \item{\code{cex}}{
	numeric multiplier to control character sizes for axis labels.
	Can be a vector of length 2, to control left/bottom and
	right/top separately.
      }
      \item{\code{font}, \code{fontface}, \code{fontfamily}}{
	specifies font for axis labels.
      }
      \item{\code{tck}}{
	numeric to control length of tick marks. Can be a vector of
	length 2, to control left/bottom and right/top separately.
      }
      \item{\code{col}}{
	color of ticks and labels.
      }
      \item{\code{rot}}{
	Angle by which the axis labels are to be rotated. Can be a
	vector of length 2, to control left/bottom and right/top
	separately.
      }
      \item{\code{abbreviate}}{
	logical, whether to abbreviate the labels using
	\code{abbreviate}.  Can be useful for long labels (e.g., in
	factors), especially on the x-axis.
      }
      \item{\code{minlength}}{
	argument passed to \code{abbreviate} if \code{abbreviate=TRUE}.
      }
      \item{\code{log}}{
	Controls whether the corresponding variable (\code{x} or
	\code{y}) will be log transformed before being passed to the
	panel function.  Defaults to \code{FALSE}, in
	which case the data are not transformed.  Other possible values
	are any number that works as a base for taking logarithm,
	\code{TRUE} (which is equivalent to 10), and \code{"e"} (for the
	natural logarithm).  As a side effect, the corresponding axis is
	labeled differently.  Note that this is a transformation of the
	data, not the axes.  Other than the axis labeling, using this
	feature is no different than transforming the data in the
	formula; e.g., \code{scales=list(x = list(log = 2))} is
	equivalent to \code{y ~ log2(x)}.  


% 	whether to use a log scale. Defaults to \code{FALSE}, other
% 	possible values are any number that works as a base for taking
% 	logarithm, \code{TRUE}, equivalent to 10, and \code{"e"} (for
% 	natural logarithm).  Note that in this case the values passed to
% 	the panel function are already transformed, so all computations
% 	done inside the panel function will be affected accordingly. For
% 	example, \code{panel.lmline} will fit a line to the transformed
% 	values.
      }
      \item{\code{format}}{
	the \code{format} to use for POSIXct variables. See
	\code{\link{strptime}} for description of valid values.
      }
      \item{\code{axs}}{
	character, \code{"r"} or \code{"i"}.  In the latter case, the
	axis limits are calculated as the exact data range, instead of
	being padded on either side. (May not always work as expected.)
      }
    }

    Note that much of the function of \code{scales} is accomplished by
    \code{pscales} in \code{splom}.
  }
  \item{subscripts}{
    logical specifying whether or not a vector named \code{subscripts}
    should be passed to the panel function.  Defaults to \code{FALSE},
    unless \code{groups} is specified, or if the panel function accepts
    an argument named \code{subscripts}. (One should be careful when
    defining the panel function on-the-fly.)
  }
  \item{subset}{
    logical or integer indexing vector (can be specified in terms of
    variables in \code{data}).  Only these rows of \code{data} will be
    used for the plot.  If \code{subscripts} is \code{TRUE}, the
    subscripts will provide indices to the rows of data before the
    subsetting is done.  Whether levels of factors in the data frame
    that are unused after the subsetting will be dropped depends on the
    \code{drop.unused.levels} argument.
  }
  \item{xlim}{ Normally a numeric vector of length 2 (possibly a
    DateTime object) giving minimum and maximum for the x-axis, or, a
    character vector, expected to denote the levels of \code{x}.  The
    latter form is interpreted as a range containing c(1, length(xlim)),
    with the character vector determining labels at tick positions
    \code{1:length(xlim)}

    \code{xlim} could also be a list, with as many components as the
    number of panels (recycled if necessary), with each component as
    described above.  This is meaningful only when
    \code{scales$x$relation} is \code{"free"} or \code{"sliced"}, in
    which case these are treated as if they were the corresponding limit
    components returned by prepanel calculations.

  }
  \item{ylim}{ similar to \code{xlim}, applied to the y-axis. }
  \item{drop.unused.levels}{ 
    logical indicating whether the unused levels of factors will be
    dropped, usually relevant with a subsetting operation is performed
    or an \code{\link{interaction}} is created.  Unused levels are
    usually dropped, but it is sometimes appropriate to suppress
    dropping to preserve a useful layout.  For finer control, this
    argument could also be list containing components \code{cond} and
    \code{data}, both logical, indicating desired behavior for
    conditioning variables and data variables respectively.  The default
    is given by \code{lattice.getOption("drop.unused.levels")}, which
    is initially set to \code{TRUE} for both components.  Note that this
    argument does not control dropping of levels of the \code{groups}
    argument.
  }
  \item{ default.scales }{
    list giving the default values of \code{scales} for a particular
    high level function.  This should not be of any interest to the
    normal user, but may be helpful when defining other functions that
    act as a wrapper to one of the high level lattice functions.
  }
  \item{lattice.options}{
    a list that could be supplied to \code{\link{lattice.options}}.
    These options are temporarily in effect for the duration of the
    call, after which the settings revert back to whatever they were
    before.  The settings are also retained along with the object and
    reused during plotting.  This enables the user to attach options
    settings to the trellis object itself rather than change the
    settings globally.  See also the  \code{par.settings} argument
    described below for a similar treatment of graphical settings.
  }
  \item{\dots}{ further arguments, usually not directly processed by the
    high level functions documented here, but rather passed on to other
    functions. Such arguments can be broadly categorized into two types:
    those that affect all high level Trellis functions in a similar
    manner, and those that are meant for the specific panel function
    used, which may differ across high level functions.

    The first group of arguments are processed by a common, unexported
    function called \code{trellis.skeleton}.  These arguments affect all
    high level functions, but are only documented here, except to
    override the behaviour described here.  All other arguments
    specified in a high level call, specifically those neither described
    here nor in the help page of the relevant high level function, are
    passed unchanged to the panel function used.  By convention, the
    default panel function used for any high level function is named as
    \code{"panel."} followed by the name of the high level function; 
    for example, the default panel function for \code{bwplot} is
    \code{panel.bwplot}.  In practical terms, this means that in
    addition to the help page of the high level function being used, the
    user should also consult the help page of the corresponding panel
    function for arguments that may be specified in the high level call.

    The effect of the first group of common arguments are as follows:

    \describe{
      \item{\code{as.table}:}{ logical that controls the order in which panels
	should be plotted: if \code{FALSE} (the default), panels are drawn
	left to right, bottom to top (as in a graph); if \code{TRUE}, left
	to right, top to bottom.
      }

      \item{\code{between}:}{ a list with components \code{x} and \code{y} (both
	usually 0 by default), numeric vectors specifying the space between
	the panels (units are character heights). \code{x} and \code{y} are
	repeated to account for all panels in a page and any extra
	components are ignored. The result is used for all pages in a
	multi page display. (In other words, it is not possible to use
	different \code{between} values for different pages).
      }

      \item{\code{key}:}{
	A list of arguments that define a legend to be drawn on the plot.
	This list is used as an argument to the \code{\link{draw.key}}
	function, which produces a grid object eventually plotted by the
	print method for \code{"trellis"} objects.


	There is also a less flexible but usually sufficient shortcut
	function \code{\link{simpleKey}} that can generate such a list, as
	well as the argument \code{auto.key} that can be convenient in the
	most common situation where legends are used, namely when there is a
	grouping variable. To use more than one legend, or to have arbitrary
	legends not constrained by the structure imposed by \code{key}, use
	the \code{legend} argument.


	The position of the key can be controlled in either of two
	possible ways. If a component called \code{space} is present,
	the key is positioned outside the plot region, in one of the
	four sides, determined by the value of \code{space}, which can
	be one of \code{"top"}, \code{"bottom"}, \code{"left"} and
	\code{"right"}.  Alternatively, the key can be positioned inside
	the plot region by specifying components \code{x}, \code{y} and
	\code{corner}. \code{x} and \code{y} determine the location of
	the corner of the key given by \code{corner}, which is usually
	one of \code{c(0,0)}, \code{c(1,0)}, \code{c(1,1)} and
	\code{c(0,1)}, which denote the corners of the unit square.
	Fractional values are also allowed, in which case \code{x} and
	\code{y} determine the position of an arbitrary point inside (or
	outside for values outside the unit interval) the key.

	\code{x} and \code{y} should be numbers between 0 and 1, giving
	coordinates with respect to the \dQuote{display area}.
	Depending on the value of
	\code{lattice.getOption("legend.bbox")}, this can be either the
	full figure region (\code{"full"}), or just the region that
	bounds the panels and strips (\code{"panel"}).

	The key essentially consists of a number of columns, possibly
	divided into blocks, each containing some rows.  The contents of the
	key are determined by (possibly repeated) components named
	\code{"rectangles"}, \code{"lines"}, \code{"points"} or
	\code{"text"}.  Each of these must be lists with relevant graphical
	parameters (see later) controlling their appearance.  The \code{key}
	list itself can contain graphical parameters, these would be used if
	relevant graphical components are omitted from the other components.

	The length (number of rows) of each such column (except \code{"text"}s)
	is taken to be the largest of the lengths of the graphical
	components, including the ones specified outside (see the entry for
	\code{rep} below for details on this). The \code{"text"} component has to
	have a character or expression vector as its first component, and
	the length of this vector determines the number of rows.

	The graphical components that can be included in \code{key} (and
	also in the components named \code{"text"}, \code{"lines"},
	\code{"points"} and \code{"rectangles"} as appropriate) are:

	\itemize{
	  \item \code{cex=1}
	  \item \code{col="black"}
	  \item \code{alpha=1}
	  \item \code{lty=1}
	  \item \code{lwd=1}
	  \item \code{font=1}
	  \item \code{fontface}
	  \item \code{fontfamily}
	  \item \code{pch=8}
	  \item \code{adj=0}
	  \item \code{type="l"}
	  \item \code{size=5}
	  \item \code{angle=0}
	  \item \code{density=-1}
	}

	In addition, the component \code{border} can be included inside
	the \code{"rect"} component to control the border color of the
	rectangles; when specified at the top level, \code{border}
	controls the border of the entire key (see below).

	\code{angle} and \code{density} are unimplemented.  \code{size}
	determines the width of columns of rectangles and lines in
	character widths. \code{type} is relevant for lines; \code{"l"}
	denotes a line, \code{"p"} denotes a point, and \code{"b"} and
	\code{"o"} both denote both together.

	Other possible components of \code{key} are:

	\describe{
	  \item{\code{reverse.rows}}{
	    logical, defaulting to \code{FALSE}.  If \code{TRUE}, all
	    components are reversed \emph{after} being replicated
	    (the details of which may depend on the value of
	    \code{rep}).  This is useful in certain situations,
	    e.g. with a grouped \code{barchart} with \code{stack =
	      FALSE} with the categorical variable on the vertical axis,
	    where the bars in the plot will usually be ordered from
	    bottom to top, but the corresponding legend will have the
	    levels from top to bottom (unless, of course,
	    \code{reverse.rows = TRUE}).  Note that in this case, unless
	    all columns have the same number or rows, they will no
	    longer be aligned.
	  }
	  \item{\code{between}}{
	    numeric vector giving the amount of space (character widths)
	    surrounding each column (split equally on both sides)
	  }
	  \item{\code{title}}{
	    string or expression giving a title for the key
	  }
	  \item{\code{rep}}{
	    logical, defaults to \code{TRUE}.  By default, it's assumed that
	    all columns in the key (except the \code{"text"}s) will have the same
	    number of rows, and all components are replicated to be as long
	    as the longest. This can be suppressed by specifying
	    \code{rep=FALSE}, in which case the length of each column will
	    be determined by components of that column alone.
	  }
	  \item{\code{cex.title}}{
	    cex for the title
	  }
	  \item{\code{lines.title}}{
	    how many lines the title should occupy (in multiples of
	    itself).  Defaults to 2.
	  }
	  \item{\code{padding.text}}{
	    how much space (padding) should be used above and below each
	    row containing text, in multiples of the default, which is
	    currently \code{0.2 * "lines"}.  This padding is in addition to
	    the normal height of any row that contains text, which is the
	    minimum amount necessary to contain all the text entries.
	  }
	  \item{\code{background}}{
	    background color, defaults to default background
	  }
	  \item{\code{alpha.background}}{
	    An alpha transparency value between 0 and 1
	  }
	  \item{\code{border}}{
	    either a color for the border, or a logical.  In the latter
	    case, the border color is black if \code{border} is
	    \code{TRUE}, and no border is drawn if it is \code{FALSE} (the
	    default)
	  }
	  \item{\code{transparent=FALSE}}{
	    logical, whether key area should have a transparent background
	  }
	  \item{\code{columns}}{
	    the number of columns column-blocks the key is to be divided
	    into, which are drawn side by side.
	  }
	  \item{\code{between.columns}}{
	    Space between column blocks, in addition to \code{between}.
	  }
	  \item{\code{divide}}{
	    Number of point symbols to divide each line when \code{type} is
	    \code{"b"} or \code{"o"} in \code{lines}.
	  }
	}
      }
      \item{\code{legend}:}{
	the legend argument can be useful if one wants to place more than
	one key. It also allows one to use arbitrary \code{"grob"}s (grid
	objects) as legends.
	
	If used, \code{legend} must be a list, with an arbitrary number of
	components. Each component must be named one of \code{"left"},
	\code{"right"}, \code{"top"}, \code{"bottom"} or \code{"inside"}.
	The name \code{"inside"} can be repeated, but not the others.  This
	name will be used to determine the location for that component, and
	is similar to the \code{space} component of \code{key}.  If
	\code{key} (or \code{colorkey} for \code{\link{levelplot}} and
	\code{\link{wireframe}}) is specified, their \code{space} component
	must not conflict with the name of any component of \code{legend}.

	Each component of \code{legend} must have a component called
	\code{fun}. This can be a \code{"grob"}, or a function or the name of a
	function that produces a \code{"grob"} when called. If this function
	expects any arguments, they must be supplied as a list in another
	component called \code{args}. For components named \code{"inside"},
	there can be additional components called \code{x}, \code{y} and
	\code{corner}, which work in the same way as it does for \code{key}.
      }

      \item{\code{page}:}{ a function of one argument (page number) to be called
	after drawing each page. The function must be
	\sQuote{grid-compliant}, and is called with the whole display area
	as the default viewport.
      }
      \item{\code{main}:}{ typically a character string or expression
	describing the main title to be placed on top of each page.
	Defaults to \code{NULL}.  \code{main} (as well as \code{xlab},
	\code{ylab} and \code{sub}) is usually a character string or an
	expression that gets used as the label, but can also be a list
	that controls further details.  Expressions are treated as
	specification of LaTeX-like markup as described in
	\code{\link{plotmath}}.  The label can be a vector, in which
	case the components will be spaced out horizontally (or
	vertically for \code{ylab}).  This feature can be used to
	provide column or row labels rather than a single axis label.

	When \code{main} (etc.) is a list, the actual label should be
	specified as the \code{label} component (which may be unnamed if
	it is the first component).  The label can be missing, in which
	case the default will be used (\code{xlab} and \code{ylab}
	usually have defaults, but \code{main} and \code{sub} do not).
	Further named arguments are passed on to
	\code{\link[grid:grid.text]{textGrob}}; this can include
	arguments controlling positioning like \code{just} and
	\code{rot} as well as graphical parameters such as \code{col}
	and \code{font} (see \code{\link[grid:gpar]{gpar}} for a full
	list).

	\code{main}, \code{xlab}, \code{ylab} and \code{sub} can also be
	an arbitrary \code{"grob"} (grid graphical object).
      }
      \item{\code{sub}:}{
	character string or expression (or a list or \code{"grob"}) for
	a subtitle to be placed at the bottom of each page.  See entry
	for \code{main} for finer control options.
      }
      \item{\code{par.strip.text}:}{ list of  parameters to control the appearance
	of strip text.  Notable components are \code{col}, \code{cex},
	\code{font} and \code{lines}.  The first three control graphical
	parameters while the last is a means of altering the height of the
	strips.  This can be useful, for example, if the strip labels
	(derived from factor levels, say) are double height (i.e., contains
	\code{"\\n"}-s) or if the default height seems too small or too
	large.  The \code{lineheight} component can control the space
	between multiple lines.  Also, the labels can be abbreviated when
	shown by specifying \code{abbreviate = TRUE}, in which case the
	components \code{minlength} and \code{dot} (passed along to the
	\code{\link{abbreviate}} function) can be specified to control the
	details of how this is done.
      }
      \item{\code{layout}:}{
	In general, a Trellis conditioning plot consists of several panels
	arranged in a rectangular array, possibly spanning multiple
	pages. \code{layout} determines this arrangement.

	\code{layout} is a numeric vector giving the number of columns, rows
	and pages in a multi panel display.  By default, the number of
	columns is the number of levels of the first conditioning variable
	and the number of rows is the number of levels of the second
	conditioning variable.  If there is only one conditioning variable,
	the default layout vector is \code{c(0,n)}, where \code{n} is the
	number of levels of the given vector.  Any time the first value in
	the layout vector is 0, the second value is used as the desired
	number of panels per page and the actual layout is computed from
	this, taking into account the aspect ratio of the panels and the
	device dimensions (via \code{par("din")}).  The number of pages is
	by default set to as many as is required to plot all the panels.  In
	general, giving a high value of \code{layout[3]} is not wasteful
	because blank pages are never created.
      }
      \item{\code{skip}:}{
	logical vector (default \code{FALSE}), replicated to be as long as
	the number of panels (spanning all pages).  For elements that are
	\code{TRUE}, the corresponding panel position is skipped; i.e.,
	nothing is plotted in that position.  The panel that was supposed to
	be drawn there is now drawn in the next available panel position,
	and the positions of all the subsequent panels are bumped up
	accordingly.  This is often useful for arranging plots in an
	informative manner.
      }

      \item{\code{strip.left}:}{
	% FIXME: (update: fix what?)
	\code{strip.left} can be used to draw strips on the left of each
	panel, which can be useful for wide short panels, as in time
	series (or similar) plots.  It is a function similar to
	\code{strip}.
      }

      \item{\code{xlab.default}, \code{ylab.default}:}{ fallback default
	for \code{xlab} and \code{ylab} when they are not specified.  If
	\code{NULL}, the defaults are parsed from the Trellis formula.
	This is rarely useful for the end-user, but can be helpful when
	developing new Trellis functions.}

      \item{\code{xscale.components, yscale.components}:}{ 
	functions that determine axis annotation for the x and y axes
	respectively.  See documentation for
	\code{\link{xscale.components.default}}, the default values of
	these arguments, to learn more. }
      
      \item{\code{axis}:}{ function that draws axis annotation.  See
	documentation for \code{\link{axis.default}}, the default value
	of this argument, to learn more. }

      \item{\code{perm.cond}:}{
	numeric vector, a permutation of \code{1:n}, where \code{n} is the
	number of conditioning variables.  By default, the order in which
	panels are drawn depends on the order of the conditioning variables
	specified in the \code{formula}.  \code{perm.cond} can modify this
	order.  If the trellis display is thought of as an
	\code{n}-dimensional array, then during printing, its dimensions are
	permuted using \code{perm.cond} as the \code{perm} argument to
	\code{\link{aperm}}.
      }
      \item{\code{index.cond}:}{
	While \code{perm.cond} permutes the dimensions of the
	multidimensional array of panels, \code{index.cond} can be used to
	subset (or reorder) margins of that array.  \code{index.cond} can be
	a list or a function, with behavior in each case described
	below. 

	The panel display order within each conditioning variable depends on
	the order of their levels.  \code{index.cond} can be used to choose
	a \sQuote{subset} (in the R sense) of these levels, which is then
	used as the display order for that variable.  If \code{index.cond}
	is a list, it has to be as long as the number of conditioning
	variables, and the \code{i}-th component has to be a valid
	indexing vector for the integer vector \code{1:nlevels(g_i)}
	(which can, among other things, repeat some of the levels or
	drop some altogether).  The result of this indexing determines
	the order of panels within that conditioning variable. To keep
	the order of a particular variable unchanged, the corresponding
	component must be set to \code{TRUE}.

	Note that the components of \code{index.cond} are in the order of
	the conditioning variables in the original call, and is not affected
	by \code{perm.cond}.

	Another possibility is to specify \code{index.cond} as a function.
	In this case, this function is called once for each panel,
	potentially with all arguments that are passed to the panel function
	for that panel. (More specifically, if this function has a
	\code{\dots} argument, then all panel arguments are passed,
	otherwise, only named arguments that match are passed.) For a single
	conditioning variable, the levels of that variable are then sorted
	so that these values are in ascending order. For multiple
	conditioning variables, the order for each variable is determined by
	first taking the average over all other conditioning variables.

	Although they can be supplied in high level function calls directly,
	it is more typical to use \code{perm.cond} and \code{index.cond} to
	update an existing \code{"trellis"} object, thus allowing it to be
	displayed in a different arrangement without re-calculating the data
	subsets that go into each panel. In the \code{update} method, both
	can be set to \code{NULL}, which reverts these back to their
	defaults.
      }
      \item{\code{par.settings}:}{
	a list that could be supplied to \code{\link{trellis.par.set}}.
	This enables the user to attach some display settings to the trellis
	object itself rather than change the settings globally.  When the
	object is plotted, these settings are temporarily in effect for
	the duration of the plot, after which the settings revert back
	to whatever they were before.
      }
      \item{\code{plot.args}:}{
	a list of possible arguments to \code{\link{plot.trellis}},
	which will be used by the \code{plot} or \code{print} methods
	when drawing the object, unless overridden explicitly.  This
	enables the user to attach such arguments to the trellis object
	itself.  Partial matching is not performed.
      }
    }
  }
}
  

\value{

  An object of class \code{"trellis"}. The
  \code{\link[lattice:update.trellis]{update}} method can be used to
  update components of the object and the
  \code{\link[lattice:print.trellis]{print}} method (usually called by
  default) will plot it on an appropriate plotting device.

}
\details{

  All the functions documented here are generic, with the \code{formula}
  method usually doing the actual work.  The structure of the plot that
  is produced is mostly controlled by the formula.  For each unique
  combination of the levels of the conditioning variables \code{g1, g2,
    \dots}, a separate panel is produced using the points \code{(x,y)}
  for the subset of the data (also called packet) defined by that
  combination.  The display can be though of as a 3-dimensional array of
  panels, consisting of one 2-dimensional matrix per page.  The
  dimensions of this array are determined by the \code{layout} argument.
  If there are no conditioning variables, the plot produced consists of
  a single panel.

  The coordinate system used by lattice by default is like a graph,
  with the origin at the bottom left, with axes increasing to left and
  up. In particular, panels are by default drawn starting from the
  bottom left corner, going right and then up; unless \code{as.table =
    TRUE}, in which case panels are drawn from the top left corner,
  going right and then down.  One might wish to set a global preference
  for a table-like arrangement by changing the default to
  \code{as.table=TRUE}; this can be done by setting
  \code{lattice.options(default.args = list(as.table = TRUE))}.  In
  fact, default values can be set in this manner for the following
  arguments: \code{as.table}, \code{aspect}, \code{between},
  \code{page}, \code{main}, \code{sub}, \code{par.strip.text},
  \code{layout}, \code{skip} and \code{strip}.  Note that these global
  defaults are sometimes overridden by individual functions.

  The order of the panels depends on the order in which the conditioning
  variables are specified, with \code{g1} varying fastest. Within a
  conditioning variable, the order depends on the order of the levels
  (which for factors is usually in alphabetical order).  Both of these
  orders can be modified using the \code{index.cond} and
  \code{perm.cond} arguments, possibly using the
  \code{\link[lattice:update.trellis]{update}} (and other related)
  method(s).
}

\note{

  Most of the arguments documented here are also applicable for the
  other high level functions in the lattice package. These are not
  described in any detail elsewhere unless relevant, and this should be
  considered the canonical documentation for such arguments.

  Any arguments passed to these functions and not recognized by them
  will be passed to the panel function. Most predefined panel functions
  have arguments that customize its output. These arguments are
  described only in the help pages for these panel functions, but can
  usually be supplied as arguments to the high level plot.

}

\references{
  Sarkar, Deepayan (2008) "Lattice: Multivariate Data Visualization with
  R", Springer. \url{http://lmdvr.r-forge.r-project.org/}
}

\seealso{
  \code{\link{Lattice}} for an overview of the package, as well as 
  \code{\link{barchart.table}},
  \code{\link{Lattice}},
  \code{\link{print.trellis}},
  \code{\link{shingle}},
  \code{\link{banking}},
  \code{\link{reshape}},
  \code{\link{panel.xyplot}},
  \code{\link{panel.bwplot}},
  \code{\link{panel.barchart}},
  \code{\link{panel.dotplot}},
  \code{\link{panel.stripplot}},
  \code{\link{panel.superpose}},
  \code{\link{panel.loess}},
  \code{\link{panel.linejoin}},
  \code{\link{strip.default}},
  \code{\link{simpleKey}}
  \code{\link{trellis.par.set}}
}
\author{ Deepayan Sarkar \email{Deepayan.Sarkar@R-project.org}}
\examples{

\dontrun{
## wait for user input before each new page (like 'par(ask = TRUE)')
old.prompt <- grid::grid.prompt(TRUE)
}

require(stats)

## Tonga Trench Earthquakes

Depth <- equal.count(quakes$depth, number=8, overlap=.1)
xyplot(lat ~ long | Depth, data = quakes)
update(trellis.last.object(),
       strip = strip.custom(strip.names = TRUE, strip.levels = TRUE),
       par.strip.text = list(cex = 0.75),
       aspect = "iso")

## Examples with data from `Visualizing Data' (Cleveland)
## (obtained from Bill Cleveland's Homepage :
## http://cm.bell-labs.com/cm/ms/departments/sia/wsc/, also
## available at statlib)

EE <- equal.count(ethanol$E, number=9, overlap=1/4)
## Constructing panel functions on the fly; prepanel
xyplot(NOx ~ C | EE, data = ethanol,
       prepanel = function(x, y) prepanel.loess(x, y, span = 1),
       xlab = "Compression Ratio", ylab = "NOx (micrograms/J)",
       panel = function(x, y) {
           panel.grid(h=-1, v= 2)
           panel.xyplot(x, y)
           panel.loess(x,y, span=1)
       },
       aspect = "xy")



## with and without banking

plot <- xyplot(sunspot.year ~ 1700:1988, xlab = "", type = "l",
               scales = list(x = list(alternating = 2)),
               main = "Yearly Sunspots")
print(plot, position = c(0, .3, 1, .9), more = TRUE)
print(update(plot, aspect = "xy", main = "", xlab = "Year"),
      position = c(0, 0, 1, .3))




## Multiple variables in formula for grouped displays

xyplot(Sepal.Length + Sepal.Width ~ Petal.Length + Petal.Width | Species, 
       data = iris, scales = "free", layout = c(2, 2),
       auto.key = list(x = .6, y = .7, corner = c(0, 0)))


## user defined panel functions

states <- data.frame(state.x77,
                     state.name = dimnames(state.x77)[[1]], 
                     state.region = state.region) 
xyplot(Murder ~ Population | state.region, data = states, 
       groups = state.name, 
       panel = function(x, y, subscripts, groups)  
       ltext(x = x, y = y, labels = groups[subscripts], cex=1,
             fontfamily = "HersheySans"))

barchart(yield ~ variety | site, data = barley,
         groups = year, layout = c(1,6),
         ylab = "Barley Yield (bushels/acre)",
         scales = list(x = list(abbreviate = TRUE,
                       minlength = 5)))
barchart(yield ~ variety | site, data = barley,
         groups = year, layout = c(1,6), stack = TRUE, 
         auto.key = list(points = FALSE, rectangles = TRUE, space = "right"),
         ylab = "Barley Yield (bushels/acre)",
         scales = list(x = list(rot = 45)))

bwplot(voice.part ~ height, data=singer, xlab="Height (inches)")
dotplot(variety ~ yield | year * site, data=barley)

dotplot(variety ~ yield | site, data = barley, groups = year,
        key = simpleKey(levels(barley$year), space = "right"),
        xlab = "Barley Yield (bushels/acre) ",
        aspect=0.5, layout = c(1,6), ylab=NULL)

stripplot(voice.part ~ jitter(height), data = singer, aspect = 1,
          jitter.data = TRUE, xlab = "Height (inches)")
## Interaction Plot

xyplot(decrease ~ treatment, OrchardSprays, groups = rowpos,
       type = "a",
       auto.key =
       list(space = "right", points = FALSE, lines = TRUE))

## longer version with no x-ticks

\dontrun{
bwplot(decrease ~ treatment, OrchardSprays, groups = rowpos,
       panel = "panel.superpose",
       panel.groups = "panel.linejoin",
       xlab = "treatment",
       key = list(lines = Rows(trellis.par.get("superpose.line"),
                  c(1:7, 1)), 
                  text = list(lab = as.character(unique(OrchardSprays$rowpos))),
                  columns = 4, title = "Row position"))
}

\dontrun{
grid::grid.prompt(old.prompt)
}


}
\keyword{hplot}
\eof
